@@ -2,29 +2,69 @@
 /*
  Copyright 2012, Kovid Goyal <kovid@kovidgoyal.net>
  Released under the GPLv3 License
-*/
-
+ */
 
 (function() {
-  var PagedDisplay, log, runscripts;
+  var PagedDisplay, create_page_div, first_child, has_start_text, log, runscripts;
 
   log = window.calibre_utils.log;
 
   runscripts = function(parent) {
-    var script, _i, _len, _ref, _results;
-    _ref = parent.getElementsByTagName('script');
-    _results = [];
-    for (_i = 0, _len = _ref.length; _i < _len; _i++) {
-      script = _ref[_i];
-      _results.push(eval(script.text || script.textContent || script.innerHTML || ''));
+    var i, len, ref, results, script;
+    ref = parent.getElementsByTagName('script');
+    results = [];
+    for (i = 0, len = ref.length; i < len; i++) {
+      script = ref[i];
+      results.push(eval(script.text || script.textContent || script.innerHTML || ''));
     }
-    return _results;
+    return results;
+  };
+
+  first_child = function(parent) {
+    var c, count;
+    c = parent.firstChild;
+    count = 0;
+    while ((c != null ? c.nodeType : void 0) !== 1 && count < 20) {
+      c = c != null ? c.nextSibling : void 0;
+      count += 1;
+    }
+    if ((c != null ? c.nodeType : void 0) === 1) {
+      return c;
+    }
+    return null;
+  };
+
+  has_start_text = function(elem) {
+    var c, i, len, ref, ref1;
+    ref = elem.childNodes;
+    for (i = 0, len = ref.length; i < len; i++) {
+      c = ref[i];
+      if ((ref1 = c.nodeType) !== Node.TEXT_NODE && ref1 !== Node.COMMENT_NODE && ref1 !== Node.PROCESSING_INSTRUCTION_NODE) {
+        break;
+      }
+      if (c.nodeType === Node.TEXT_NODE && c.nodeValue !== null && /\S/.test(c.nodeValue)) {
+        return true;
+      }
+    }
+    return false;
+  };
+
+  create_page_div = function(elem) {
+    var div;
+    div = document.createElement('blank-page-div');
+    div.innerText = ' \n    ';
+    document.body.appendChild(div);
+    div.style.setProperty('-webkit-column-break-before', 'always');
+    div.style.setProperty('display', 'block');
+    div.style.setProperty('white-space', 'pre');
+    div.style.setProperty('background-color', 'transparent');
+    div.style.setProperty('background-image', 'none');
+    div.style.setProperty('border-width', '0');
+    div.style.setProperty('float', 'none');
+    return div.style.setProperty('position', 'static');
   };
 
   PagedDisplay = (function() {
-
-    PagedDisplay.name = 'PagedDisplay';
-
     function PagedDisplay() {
       if (!this instanceof arguments.callee) {
         throw new Error('PagedDisplay constructor called as function');
@@ -49,7 +89,7 @@
     }
 
     PagedDisplay.prototype.read_document_margins = function() {
-      var prop, pxval, rule, sheet, tmp, val, _i, _j, _k, _len, _len1, _len2, _ref, _ref1, _ref2;
+      var i, j, k, len, len1, len2, prop, pxval, ref, ref1, ref2, rule, sheet, tmp, val;
       if (this.document_margins === null) {
         this.document_margins = {
           left: null,
@@ -61,22 +101,24 @@
         tmp.style.visibility = 'hidden';
         tmp.style.position = 'absolute';
         document.body.appendChild(tmp);
-        _ref = document.styleSheets;
-        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
-          sheet = _ref[_i];
-          _ref1 = sheet.rules;
-          for (_j = 0, _len1 = _ref1.length; _j < _len1; _j++) {
-            rule = _ref1[_j];
-            if (rule.type === CSSRule.PAGE_RULE) {
-              _ref2 = ['left', 'top', 'bottom', 'right'];
-              for (_k = 0, _len2 = _ref2.length; _k < _len2; _k++) {
-                prop = _ref2[_k];
-                val = rule.style.getPropertyValue('margin-' + prop);
-                if (val) {
-                  tmp.style.height = val;
-                  pxval = parseInt(window.getComputedStyle(tmp).height);
-                  if (!isNaN(pxval)) {
-                    this.document_margins[prop] = pxval;
+        ref = document.styleSheets;
+        for (i = 0, len = ref.length; i < len; i++) {
+          sheet = ref[i];
+          if (sheet.rules) {
+            ref1 = sheet.rules;
+            for (j = 0, len1 = ref1.length; j < len1; j++) {
+              rule = ref1[j];
+              if (rule.type === CSSRule.PAGE_RULE) {
+                ref2 = ['left', 'top', 'bottom', 'right'];
+                for (k = 0, len2 = ref2.length; k < len2; k++) {
+                  prop = ref2[k];
+                  val = rule.style.getPropertyValue('margin-' + prop);
+                  if (val) {
+                    tmp.style.height = val;
+                    pxval = parseInt(window.getComputedStyle(tmp).height);
+                    if (!isNaN(pxval)) {
+                      this.document_margins[prop] = pxval;
+                    }
                   }
                 }
               }
@@ -114,9 +156,15 @@
       }
       this.cols_per_screen = cols_per_screen;
       if (this.use_document_margins && this.document_margins !== null) {
-        this.margin_top = this.document_margins.top || margin_top;
-        this.margin_bottom = this.document_margins.bottom || margin_bottom;
-        this.margin_side = this.document_margins.left || this.document_margins.right || margin_side;
+        this.margin_top = this.document_margins.top !== null ? this.document_margins.top : margin_top;
+        this.margin_bottom = this.document_margins.bottom !== null ? this.document_margins.bottom : margin_bottom;
+        if (this.document_margins.left !== null) {
+          this.margin_side = this.document_margins.left;
+        } else if (this.document_margins.right !== null) {
+          this.margin_side = this.document_margins.right;
+        } else {
+          this.margin_side = margin_side;
+        }
         this.effective_margin_top = this.margin_top;
         return this.effective_margin_bottom = this.margin_bottom;
       } else {
@@ -129,21 +177,22 @@
     };
 
     PagedDisplay.prototype.handle_rtl_body = function(body_style) {
-      var node, _i, _len, _ref;
+      var i, len, node, ref;
       if (body_style.direction === "rtl") {
-        _ref = document.body.childNodes;
-        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
-          node = _ref[_i];
+        ref = document.body.childNodes;
+        for (i = 0, len = ref.length; i < len; i++) {
+          node = ref[i];
           if (node.nodeType === node.ELEMENT_NODE && window.getComputedStyle(node).direction === "rtl") {
             node.style.setProperty("direction", "rtl");
           }
         }
-        return document.body.style.direction = "ltr";
+        document.body.style.direction = "ltr";
+        return document.documentElement.style.direction = 'ltr';
       }
     };
 
     PagedDisplay.prototype.layout = function(is_single_page) {
-      var adjust, body_style, body_width, bs, c, col_width, count, cprop, edge, eh, fgcolor, first_layout, has_svg, n, only_img, priority, prop, rule, sheet, single_screen, sm, val, ww, _i, _j, _k, _l, _len, _len1, _len2, _len3, _ref, _ref1, _ref2, _ref3;
+      var adjust, body_style, body_width, bs, c, c2, col_width, cprop, edge, eh, elems, fgcolor, first_layout, has_svg, has_viewport, i, j, k, len, len1, len2, len3, m, n, ncols, num, only_img, priority, prop, ref, ref1, ref2, ref3, ref4, rule, sheet, single_screen, sm, val, ww;
       if (is_single_page == null) {
         is_single_page = false;
       }
@@ -152,8 +201,27 @@
       first_layout = false;
       if (!this.in_paged_mode) {
         single_screen = document.body.scrollHeight < window.innerHeight + 75;
+        has_svg = document.getElementsByTagName('svg').length > 0;
+        only_img = document.getElementsByTagName('img').length === 1 && document.getElementsByTagName('div').length < 3 && document.getElementsByTagName('p').length < 2;
+        if (only_img) {
+          has_viewport = document.head && document.head.querySelector('meta[name="viewport"]');
+          if (has_viewport) {
+            single_screen = true;
+          }
+        }
         this.handle_rtl_body(body_style);
         first_layout = true;
+        if (!single_screen && this.cols_per_screen > 1) {
+          num = this.cols_per_screen - 1;
+          elems = document.querySelectorAll('body > *');
+          if (elems.length === 1) {
+            elems[0].style.height = 'auto';
+          }
+          while (num > 0) {
+            num -= 1;
+            create_page_div();
+          }
+        }
       }
       ww = window.innerWidth;
       n = this.cols_per_screen;
@@ -169,18 +237,19 @@
       this.side_margin = sm;
       this.screen_width = this.page_width * this.cols_per_screen;
       fgcolor = body_style.getPropertyValue('color');
-      bs.setProperty('-webkit-column-gap', (2 * sm) + 'px');
+      bs.setProperty('-webkit-column-gap', 2 * sm + 'px');
       bs.setProperty('-webkit-column-width', col_width + 'px');
-      bs.setProperty('-webkit-column-rule-color', fgcolor);
+      bs.setProperty('-webkit-column-rule', '0px inset blue');
       bs.setProperty('-webkit-margin-collapse', 'separate');
-      c = document.body.firstChild;
-      count = 0;
-      while ((c != null ? c.nodeType : void 0) !== 1 && count < 20) {
-        c = c != null ? c.nextSibling : void 0;
-        count += 1;
-      }
-      if ((c != null ? c.nodeType : void 0) === 1) {
-        c.style.setProperty('-webkit-margin-before', '0');
+      c = first_child(document.body);
+      if (c !== null) {
+        c.style.setProperty('-webkit-column-break-before', 'avoid');
+        if (((ref = c.tagName) != null ? ref.toLowerCase() : void 0) === 'div') {
+          c2 = first_child(c);
+          if (c2 !== null && !has_start_text(c)) {
+            c2.style.setProperty('-webkit-column-break-before', 'avoid');
+          }
+        }
       }
       this.effective_margin_top = this.margin_top;
       this.effective_margin_bottom = this.margin_bottom;
@@ -194,48 +263,57 @@
       bs.setProperty('overflow', 'visible');
       bs.setProperty('height', this.current_page_height + 'px');
       bs.setProperty('width', (window.innerWidth - 2 * sm) + 'px');
-      bs.setProperty('margin-top', this.effective_margin_top + 'px');
-      bs.setProperty('margin-bottom', this.effective_margin_bottom + 'px');
-      bs.setProperty('margin-left', sm + 'px');
-      bs.setProperty('margin-right', sm + 'px');
-      _ref = ['left', 'right', 'top', 'bottom'];
-      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
-        edge = _ref[_i];
-        bs.setProperty('padding-' + edge, '0px');
+      bs.setProperty('padding-top', this.effective_margin_top + 'px');
+      bs.setProperty('padding-bottom', this.effective_margin_bottom + 'px');
+      bs.setProperty('padding-left', sm + 'px');
+      bs.setProperty('padding-right', sm + 'px');
+      ref1 = ['left', 'right', 'top', 'bottom'];
+      for (i = 0, len = ref1.length; i < len; i++) {
+        edge = ref1[i];
+        bs.setProperty('margin-' + edge, '0px');
         bs.setProperty('border-' + edge + '-width', '0px');
       }
       bs.setProperty('min-width', '0');
       bs.setProperty('max-width', 'none');
       bs.setProperty('min-height', '0');
       bs.setProperty('max-height', 'none');
-      _ref1 = document.styleSheets;
-      for (_j = 0, _len1 = _ref1.length; _j < _len1; _j++) {
-        sheet = _ref1[_j];
-        _ref2 = sheet.rules;
-        for (_k = 0, _len2 = _ref2.length; _k < _len2; _k++) {
-          rule = _ref2[_k];
-          if (rule.type === CSSRule.STYLE_RULE) {
-            _ref3 = ['page-break-before', 'page-break-after', 'page-break-inside'];
-            for (_l = 0, _len3 = _ref3.length; _l < _len3; _l++) {
-              prop = _ref3[_l];
-              val = rule.style.getPropertyValue(prop);
-              if (val) {
-                cprop = '-webkit-column-' + prop.substr(5);
-                priority = rule.style.getPropertyPriority(prop);
-                rule.style.setProperty(cprop, val, priority);
+      ref2 = document.styleSheets;
+      for (j = 0, len1 = ref2.length; j < len1; j++) {
+        sheet = ref2[j];
+        if (sheet.rules) {
+          ref3 = sheet.rules;
+          for (k = 0, len2 = ref3.length; k < len2; k++) {
+            rule = ref3[k];
+            if (rule.type === CSSRule.STYLE_RULE) {
+              ref4 = ['page-break-before', 'page-break-after', 'page-break-inside'];
+              for (m = 0, len3 = ref4.length; m < len3; m++) {
+                prop = ref4[m];
+                val = rule.style.getPropertyValue(prop);
+                if (val) {
+                  cprop = '-webkit-column-' + prop.substr(5);
+                  priority = rule.style.getPropertyPriority(prop);
+                  rule.style.setProperty(cprop, val, priority);
+                }
               }
             }
           }
         }
       }
       if (first_layout) {
-        has_svg = document.getElementsByTagName('svg').length > 0;
-        only_img = document.getElementsByTagName('img').length === 1 && document.getElementsByTagName('div').length < 3 && document.getElementsByTagName('p').length < 2;
         body_width = document.body.offsetWidth + 2 * sm;
         this.is_full_screen_layout = (only_img || has_svg) && single_screen && document.body.scrollWidth > body_width && document.body.scrollWidth < 2 * body_width;
         if (is_single_page) {
           this.is_full_screen_layout = true;
         }
+        document.documentElement.addEventListener('keydown', function(evt) {
+          if (evt.keyCode === 9) {
+            return evt.preventDefault();
+          }
+        });
+      }
+      ncols = document.body.scrollWidth / this.page_width;
+      if (ncols !== Math.floor(ncols) && !this.is_full_screen_layout) {
+        bs.setProperty('width', Math.floor(ncols) * this.page_width - 2 * sm);
       }
       this.in_paged_mode = true;
       this.current_margin_side = sm;
@@ -265,8 +343,8 @@
     };
 
     PagedDisplay.prototype.position_header_footer = function() {
-      var left, top, _ref;
-      _ref = calibre_utils.viewport_to_document(0, 0, document.body.ownerDocument), left = _ref[0], top = _ref[1];
+      var left, ref, top;
+      ref = calibre_utils.viewport_to_document(0, 0, document.body.ownerDocument), left = ref[0], top = ref[1];
       if (this.header !== null) {
         this.header.style.setProperty('left', left + 'px');
       }
@@ -276,7 +354,7 @@
     };
 
     PagedDisplay.prototype.update_header_footer = function(pagenum) {
-      var author, cls, section, title;
+      var author, cls, section, title, tl_section;
       if (this.hf_style !== null) {
         if (pagenum % 2 === 1) {
           cls = "even_page";
@@ -287,25 +365,26 @@
         title = py_bridge.title();
         author = py_bridge.author();
         section = py_bridge.section();
+        tl_section = py_bridge.tl_section();
       }
       if (this.header !== null) {
-        this.header.innerHTML = this.header_template.replace(/_PAGENUM_/g, pagenum + "").replace(/_TITLE_/g, title + "").replace(/_AUTHOR_/g, author + "").replace(/_SECTION_/g, section + "");
+        this.header.innerHTML = this.header_template.replace(/_PAGENUM_/g, pagenum + "").replace(/_TITLE_/g, title + "").replace(/_AUTHOR_/g, author + "").replace(/_TOP_LEVEL_SECTION_/g, tl_section + "").replace(/_SECTION_/g, section + "");
         runscripts(this.header);
       }
       if (this.footer !== null) {
-        this.footer.innerHTML = this.footer_template.replace(/_PAGENUM_/g, pagenum + "").replace(/_TITLE_/g, title + "").replace(/_AUTHOR_/g, author + "").replace(/_SECTION_/g, section + "");
+        this.footer.innerHTML = this.footer_template.replace(/_PAGENUM_/g, pagenum + "").replace(/_TITLE_/g, title + "").replace(/_AUTHOR_/g, author + "").replace(/_TOP_LEVEL_SECTION_/g, tl_section + "").replace(/_SECTION_/g, section + "");
         return runscripts(this.footer);
       }
     };
 
     PagedDisplay.prototype.fit_images = function() {
-      var br, col, col_width, data, doc, images, img, left, max_width, maxh, previously_limited, rleft, rright, vimages, width, _i, _j, _k, _len, _len1, _len2, _ref, _ref1, _results;
+      var br, col, col_width, data, doc, i, images, img, j, k, left, len, len1, len2, max_width, maxh, previously_limited, ref, ref1, results, rleft, rright, vimages, width;
       images = [];
       vimages = [];
       maxh = this.current_page_height;
-      _ref = document.getElementsByTagName('img');
-      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
-        img = _ref[_i];
+      ref = document.getElementsByTagName('img');
+      for (i = 0, len = ref.length; i < len; i++) {
+        img = ref[i];
         previously_limited = calibre_utils.retrieve(img, 'width-limited', false);
         data = calibre_utils.retrieve(img, 'img-data', null);
         br = img.getBoundingClientRect();
@@ -337,23 +416,23 @@
         }
         img.style.setProperty('-webkit-column-break-inside', 'avoid');
       }
-      for (_j = 0, _len1 = images.length; _j < _len1; _j++) {
-        _ref1 = images[_j], img = _ref1[0], max_width = _ref1[1];
+      for (j = 0, len1 = images.length; j < len1; j++) {
+        ref1 = images[j], img = ref1[0], max_width = ref1[1];
         img.style.setProperty('max-width', max_width + 'px');
         calibre_utils.store(img, 'width-limited', true);
       }
-      _results = [];
-      for (_k = 0, _len2 = vimages.length; _k < _len2; _k++) {
-        img = vimages[_k];
+      results = [];
+      for (k = 0, len2 = vimages.length; k < len2; k++) {
+        img = vimages[k];
         data = calibre_utils.retrieve(img, 'img-data', null);
         img.style.setProperty('-webkit-column-break-before', 'always');
         img.style.setProperty('max-height', maxh + 'px');
         if (data.height > maxh) {
           img.style.setProperty('display', 'block');
         }
-        _results.push(calibre_utils.store(img, 'height-limited', true));
+        results.push(calibre_utils.store(img, 'height-limited', true));
       }
-      return _results;
+      return results;
     };
 
     PagedDisplay.prototype.scroll_to_pos = function(frac) {
@@ -393,18 +472,22 @@
       }
     };
 
+    PagedDisplay.prototype.scroll_to_column = function(number) {
+      return this.scroll_to_xpos(number * this.page_width + 10);
+    };
+
     PagedDisplay.prototype.column_at = function(xpos) {
       return Math.floor(xpos / this.page_width);
     };
 
     PagedDisplay.prototype.column_location = function(elem) {
-      var br, c, height, left, top, width, _ref, _ref1;
+      var br, c, height, left, ref, ref1, top, width;
       br = elem.getBoundingClientRect();
       if (br.top < -100) {
         elem.scrollIntoView();
-        _ref = calibre_utils.viewport_to_document(elem.scrollLeft, elem.scrollTop, elem.ownerDocument), left = _ref[0], top = _ref[1];
+        ref = calibre_utils.viewport_to_document(elem.scrollLeft, elem.scrollTop, elem.ownerDocument), left = ref[0], top = ref[1];
       } else {
-        _ref1 = calibre_utils.viewport_to_document(br.left, br.top, elem.ownerDocument), left = _ref1[0], top = _ref1[1];
+        ref1 = calibre_utils.viewport_to_document(br.left, br.top, elem.ownerDocument), left = ref1[0], top = ref1[1];
       }
       c = this.column_at(left);
       width = Math.min(br.right, (c + 1) * this.page_width) - br.left;
@@ -429,8 +512,7 @@
     };
 
     PagedDisplay.prototype.animated_scroll = function(pos, duration, notify) {
-      var delta, interval, step_size, steps,
-        _this = this;
+      var delta, interval, step_size, steps;
       if (duration == null) {
         duration = 1000;
       }
@@ -446,24 +528,26 @@
         step_size: step_size,
         interval: interval,
         notify: notify,
-        fn: function() {
-          var a, completed, npos;
-          a = _this.current_scroll_animation;
-          npos = window.pageXOffset + a.step_size;
-          completed = false;
-          if (Math.abs(npos - a.target) < Math.abs(a.step_size)) {
-            completed = true;
-            npos = a.target;
-          }
-          window.scrollTo(npos, 0);
-          if (completed) {
-            if (notify) {
-              return window.py_bridge.animated_scroll_done();
+        fn: (function(_this) {
+          return function() {
+            var a, completed, npos;
+            a = _this.current_scroll_animation;
+            npos = window.pageXOffset + a.step_size;
+            completed = false;
+            if (Math.abs(npos - a.target) < Math.abs(a.step_size)) {
+              completed = true;
+              npos = a.target;
             }
-          } else {
-            return setTimeout(a.fn, a.interval);
-          }
-        }
+            window.scrollTo(npos, 0);
+            if (completed) {
+              if (notify) {
+                return window.py_bridge.animated_scroll_done();
+              }
+            } else {
+              return setTimeout(a.fn, a.interval);
+            }
+          };
+        })(this)
       };
       return this.current_scroll_animation.fn();
     };
@@ -487,12 +571,19 @@
     };
 
     PagedDisplay.prototype.next_screen_location = function() {
-      var ans, cc, limit;
+      var ans, cc, limit, pages_left, width_left;
       if (this.is_full_screen_layout) {
         return -1;
       }
       cc = this.current_column_location();
       ans = cc + this.screen_width;
+      if (this.cols_per_screen > 1) {
+        width_left = document.body.scrollWidth - (window.pageXOffset + window.innerWidth);
+        pages_left = width_left / this.page_width;
+        if (Math.ceil(pages_left) < this.cols_per_screen) {
+          return -1;
+        }
+      }
       limit = document.body.scrollWidth - window.innerWidth;
       if (ans > limit) {
         ans = window.pageXOffset < limit ? limit : -1;
@@ -541,7 +632,7 @@
     };
 
     PagedDisplay.prototype.jump_to_anchor = function(name) {
-      var br, elem, elems, left, parent, _ref, _ref1, _ref2;
+      var br, elem, elems, left, parent, ref, ref1, ref2;
       elem = document.getElementById(name);
       if (!elem) {
         elems = document.getElementsByName(name);
@@ -552,12 +643,12 @@
       if (!elem) {
         return;
       }
-      if ((_ref = window.mathjax) != null ? _ref.math_present : void 0) {
+      if ((ref = window.mathjax) != null ? ref.math_present : void 0) {
         parent = elem;
-        while (parent && (parent != null ? (_ref1 = parent.tagName) != null ? _ref1.toLowerCase() : void 0 : void 0) !== 'svg') {
+        while (parent && (parent != null ? (ref1 = parent.tagName) != null ? ref1.toLowerCase() : void 0 : void 0) !== 'svg') {
           parent = parent.parentNode;
         }
-        if ((parent != null ? (_ref2 = parent.tagName) != null ? _ref2.toLowerCase() : void 0 : void 0) === 'svg') {
+        if ((parent != null ? (ref2 = parent.tagName) != null ? ref2.toLowerCase() : void 0 : void 0) === 'svg') {
           elem = parent.parentNode;
         }
       }
@@ -584,29 +675,36 @@
       }
     };
 
-    PagedDisplay.prototype.jump_to_cfi = function(cfi) {
-      var _this = this;
-      return window.cfi.scroll_to(cfi, function(x, y) {
-        if (_this.in_paged_mode) {
-          return _this.scroll_to_xpos(x);
-        } else {
-          return window.scrollTo(0, y);
-        }
-      });
+    PagedDisplay.prototype.jump_to_cfi = function(cfi, job_id) {
+      if (job_id == null) {
+        job_id = -1;
+      }
+      return window.cfi.scroll_to(cfi, (function(_this) {
+        return function(x, y) {
+          if (_this.in_paged_mode) {
+            _this.scroll_to_xpos(x);
+          } else {
+            window.scrollTo(0, y);
+          }
+          if (window.py_bridge) {
+            return window.py_bridge.jump_to_cfi_finished(job_id);
+          }
+        };
+      })(this));
     };
 
     PagedDisplay.prototype.current_cfi = function() {
-      var ans, c, cfi, curx, cury, deltax, deltay, left, right, x, _i, _len, _ref, _ref1, _ref2, _ref3;
+      var ans, c, cfi, curx, cury, deltax, deltay, err, i, left, len, ref, ref1, ref2, ref3, right, x;
       ans = null;
-      if (!(window.cfi != null) || (((_ref = window.mathjax) != null ? _ref.math_present : void 0) && !((_ref1 = window.mathjax) != null ? _ref1.math_loaded : void 0))) {
+      if ((window.cfi == null) || (((ref = window.mathjax) != null ? ref.math_present : void 0) && !((ref1 = window.mathjax) != null ? ref1.math_loaded : void 0))) {
         return ans;
       }
       if (this.in_paged_mode) {
         c = this.current_column_location();
-        _ref2 = [c, c - this.page_width, c + this.page_width];
-        for (_i = 0, _len = _ref2.length; _i < _len; _i++) {
-          x = _ref2[_i];
-          _ref3 = [x, x + this.page_width], left = _ref3[0], right = _ref3[1];
+        ref2 = [c, c - this.page_width, c + this.page_width];
+        for (i = 0, len = ref2.length; i < len; i++) {
+          x = ref2[i];
+          ref3 = [x, x + this.page_width], left = ref3[0], right = ref3[1];
           if (left < 0 || right > document.body.scrollWidth) {
             continue;
           }
@@ -632,7 +730,8 @@
           if (!ans) {
             ans = null;
           }
-        } catch (err) {
+        } catch (_error) {
+          err = _error;
           log(err);
         }
       }
@@ -664,4 +763,3 @@
   }
 
 }).call(this);
-
