@@ -26,7 +26,7 @@ class Plugin(object):  # {{{
     '''
     A calibre plugin. Useful members include:
 
-       * ``self.plugin_path``: Stores path to the zip file that contains
+       * ``self.plugin_path``: Stores path to the ZIP file that contains
                                this plugin or None if it is a builtin
                                plugin
        * ``self.site_customization``: Stores a customization string entered
@@ -62,8 +62,8 @@ class Plugin(object):  # {{{
     author         = _('Unknown')
 
     #: When more than one plugin exists for a filetype,
-    #: the plugins are run in order of decreasing priority
-    #: i.e. plugins with higher priority will be run first.
+    #: the plugins are run in order of decreasing priority.
+    #: Plugins with higher priority will be run first.
     #: The highest possible priority is ``sys.maxint``.
     #: Default priority is 1.
     priority = 1
@@ -91,7 +91,7 @@ class Plugin(object):  # {{{
         plugin will be initialized for every new worker process.
 
         Perform any plugin specific initialization here, such as extracting
-        resources from the plugin zip file. The path to the zip file is
+        resources from the plugin ZIP file. The path to the ZIP file is
         available as ``self.plugin_path``.
 
         Note that ``self.site_customization`` is **not** available at this point.
@@ -213,10 +213,10 @@ class Plugin(object):  # {{{
             pixmap.loadFromData(self.load_resources(['images/icon.png']).itervalues().next())
             icon = QIcon(pixmap)
 
-        :param names: List of paths to resources in the zip file using / as separator
+        :param names: List of paths to resources in the ZIP file using / as separator
 
         :return: A dictionary of the form ``{name: file_contents}``. Any names
-                 that were not found in the zip file will not be present in the
+                 that were not found in the ZIP file will not be present in the
                  dictionary.
 
         '''
@@ -346,20 +346,20 @@ class FileTypePlugin(Plugin):  # {{{
         '''
         Run the plugin. Must be implemented in subclasses.
         It should perform whatever modifications are required
-        on the ebook and return the absolute path to the
-        modified ebook. If no modifications are needed, it should
-        return the path to the original ebook. If an error is encountered
+        on the e-book and return the absolute path to the
+        modified e-book. If no modifications are needed, it should
+        return the path to the original e-book. If an error is encountered
         it should raise an Exception. The default implementation
-        simply return the path to the original ebook. Note that the path to
+        simply return the path to the original e-book. Note that the path to
         the original file (before any file type plugins are run, is available as
         self.original_path_to_file).
 
-        The modified ebook file should be created with the
+        The modified e-book file should be created with the
         :meth:`temporary_file` method.
 
-        :param path_to_ebook: Absolute path to the ebook.
+        :param path_to_ebook: Absolute path to the e-book.
 
-        :return: Absolute path to the modified ebook.
+        :return: Absolute path to the modified e-book.
         '''
         # Default implementation does nothing
         return path_to_ebook
@@ -402,7 +402,7 @@ class MetadataReaderPlugin(Plugin):  # {{{
     '''
     A plugin that implements reading metadata from a set of file types.
     '''
-    #: Set of file types for which this plugin should be run
+    #: Set of file types for which this plugin should be run.
     #: For example: ``set(['lit', 'mobi', 'prc'])``
     file_types     = set([])
 
@@ -423,7 +423,7 @@ class MetadataReaderPlugin(Plugin):  # {{{
         with the input data.
 
         :param type: The type of file. Guaranteed to be one of the entries
-        in :attr:`file_types`.
+            in :attr:`file_types`.
         :return: A :class:`calibre.ebooks.metadata.book.Metadata` object
         '''
         return None
@@ -434,7 +434,7 @@ class MetadataWriterPlugin(Plugin):  # {{{
     '''
     A plugin that implements reading metadata from a set of file types.
     '''
-    #: Set of file types for which this plugin should be run
+    #: Set of file types for which this plugin should be run.
     #: For example: ``set(['lit', 'mobi', 'prc'])``
     file_types     = set([])
 
@@ -455,7 +455,7 @@ class MetadataWriterPlugin(Plugin):  # {{{
         with the input data.
 
         :param type: The type of file. Guaranteed to be one of the entries
-        in :attr:`file_types`.
+            in :attr:`file_types`.
         :param mi: A :class:`calibre.ebooks.metadata.book.Metadata` object
         '''
         pass
@@ -470,7 +470,7 @@ class CatalogPlugin(Plugin):  # {{{
 
     resources_path = None
 
-    #: Output file type for which this plugin should be run
+    #: Output file type for which this plugin should be run.
     #: For example: 'epub' or 'xml'
     file_types = set([])
 
@@ -546,7 +546,7 @@ class CatalogPlugin(Plugin):  # {{{
     def initialize(self):
         '''
         If plugin is not a built-in, copy the plugin's .ui and .py files from
-        the zip file to $TMPDIR.
+        the ZIP file to $TMPDIR.
         Tab will be dynamically generated and added to the Catalog Options dialog in
         calibre.gui2.dialogs.catalog.py:Catalog
         '''
@@ -595,7 +595,7 @@ class InterfaceActionBase(Plugin):  # {{{
 
     supported_platforms = ['windows', 'osx', 'linux']
     author         = 'Kovid Goyal'
-    type = _('User Interface Action')
+    type = _('User interface action')
     can_be_disabled = False
 
     actual_plugin = None
@@ -687,18 +687,18 @@ class StoreBase(Plugin):  # {{{
     # Information about the store. Should be in the primary language
     # of the store. This should not be translatable when set by
     # a subclass.
-    description = _('An ebook store.')
+    description = _('An e-book store.')
     minimum_calibre_version = (0, 8, 0)
     version        = (1, 0, 1)
 
     actual_plugin = None
 
-    # Does the store only distribute ebooks without DRM.
+    # Does the store only distribute e-books without DRM.
     drm_free_only = False
     # This is the 2 letter country code for the corporate
     # headquarters of the store.
     headquarters = ''
-    # All formats the store distributes ebooks in.
+    # All formats the store distributes e-books in.
     formats = []
     # Is this store on an affiliate program?
     affiliate = False
@@ -734,7 +734,7 @@ class ViewerPlugin(Plugin):  # {{{
     type = _('Viewer')
 
     '''
-    These plugins are used to add functionality to the calibre viewer.
+    These plugins are used to add functionality to the calibre E-book viewer.
     '''
 
     def load_fonts(self):
@@ -791,7 +791,7 @@ class ViewerPlugin(Plugin):  # {{{
 
 class EditBookToolPlugin(Plugin):  # {{{
 
-    type = _('Edit Book Tool')
+    type = _('Edit book tool')
     minimum_calibre_version = (1, 46, 0)
 
 # }}}
@@ -803,7 +803,7 @@ class LibraryClosedPlugin(Plugin):  # {{{
     when the library is changed, or when a library is used in some other way.
     At the moment these plugins won't be called by the CLI functions.
     '''
-    type = _('Library Closed')
+    type = _('Library closed')
 
     # minimum version 2.54 because that is when support was added
     minimum_calibre_version = (2, 54, 0)
