@@ -3,12 +3,15 @@ __license__   = 'GPL v3'
 __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
 
 import os, shutil, traceback, functools, sys
+from collections import defaultdict
+from itertools import chain
 
 from calibre.customize import (CatalogPlugin, FileTypePlugin, PluginNotFound,
                               MetadataReaderPlugin, MetadataWriterPlugin,
                               InterfaceActionBase as InterfaceAction,
                               PreferencesPlugin, platform, InvalidPlugin,
-                              StoreBase as Store, ViewerPlugin, EditBookToolPlugin)
+                              StoreBase as Store, ViewerPlugin, EditBookToolPlugin,
+                              LibraryClosedPlugin)
 from calibre.customize.conversion import InputFormatPlugin, OutputFormatPlugin
 from calibre.customize.zipplugin import loader
 from calibre.customize.profiles import InputProfile, OutputProfile
@@ -18,13 +21,15 @@ from calibre.ebooks.metadata import MetaInformation
 from calibre.utils.config import (make_config_dir, Config, ConfigProxy,
                                  plugin_dir, OptionParser)
 from calibre.ebooks.metadata.sources.base import Source
-from calibre.constants import DEBUG
+from calibre.constants import DEBUG, numeric_version
+
+builtin_names = frozenset(p.name for p in builtin_plugins)
 
-builtin_names = frozenset([p.name for p in builtin_plugins])
 
 class NameConflict(ValueError):
     pass
 
+
 def _config():
     c = Config('customize')
     c.add_opt('plugins', default={}, help=_('Installed plugins'))
@@ -35,6 +40,7 @@ def _config():
 
     return ConfigProxy(c)
 
+
 config = _config()
 
 
@@ -44,9 +50,9 @@ def find_plugin(name):
             return plugin
 
 
-def load_plugin(path_to_zip_file): # {{{
+def load_plugin(path_to_zip_file):  # {{{
     '''
-    Load plugin from zip file or raise InvalidPlugin error
+    Load plugin from ZIP file or raise InvalidPlugin error
 
     :return: A :class:`Plugin` instance.
     '''
@@ -56,6 +62,7 @@ def load_plugin(path_to_zip_file): # {{{
 
 # Enable/disable plugins {{{
 
+
 def disable_plugin(plugin_or_name):
     x = getattr(plugin_or_name, 'name', plugin_or_name)
     plugin = find_plugin(x)
@@ -69,6 +76,7 @@ def disable_plugin(plugin_or_name):
         ep.remove(x)
     config['enabled_plugins'] = ep
 
+
 def enable_plugin(plugin_or_name):
     x = getattr(plugin_or_name, 'name', plugin_or_name)
     dp = config['disabled_plugins']
@@ -79,6 +87,7 @@ def enable_plugin(plugin_or_name):
     ep.add(x)
     config['enabled_plugins'] = ep
 
+
 def restore_plugin_state_to_default(plugin_or_name):
     x = getattr(plugin_or_name, 'name', plugin_or_name)
     dp = config['disabled_plugins']
@@ -90,92 +99,95 @@ def restore_plugin_state_to_default(plugin_or_name):
         ep.remove(x)
     config['enabled_plugins'] = ep
 
+
 default_disabled_plugins = set([
     'Overdrive', 'Douban Books', 'OZON.ru', 'Edelweiss', 'Google Images', 'Big Book Search',
 ])
 
+
 def is_disabled(plugin):
-    if plugin.name in config['enabled_plugins']: return False
+    if plugin.name in config['enabled_plugins']:
+        return False
     return plugin.name in config['disabled_plugins'] or \
             plugin.name in default_disabled_plugins
 # }}}
 
 # File type plugins {{{
 
+
 _on_import           = {}
 _on_postimport       = {}
 _on_preprocess       = {}
 _on_postprocess      = {}
+_on_postadd          = []
+
 
 def reread_filetype_plugins():
-    global _on_import
-    global _on_postimport
-    global _on_preprocess
-    global _on_postprocess
-    _on_import           = {}
-    _on_postimport       = {}
-    _on_preprocess       = {}
-    _on_postprocess      = {}
+    global _on_import, _on_postimport, _on_preprocess, _on_postprocess, _on_postadd
+    _on_import           = defaultdict(list)
+    _on_postimport       = defaultdict(list)
+    _on_preprocess       = defaultdict(list)
+    _on_postprocess      = defaultdict(list)
+    _on_postadd          = []
 
     for plugin in _initialized_plugins:
         if isinstance(plugin, FileTypePlugin):
             for ft in plugin.file_types:
                 if plugin.on_import:
-                    if not _on_import.has_key(ft):
-                        _on_import[ft] = []
                     _on_import[ft].append(plugin)
                 if plugin.on_postimport:
-                    if not _on_postimport.has_key(ft):
-                        _on_postimport[ft] = []
                     _on_postimport[ft].append(plugin)
+                    _on_postadd.append(plugin)
                 if plugin.on_preprocess:
-                    if not _on_preprocess.has_key(ft):
-                        _on_preprocess[ft] = []
                     _on_preprocess[ft].append(plugin)
                 if plugin.on_postprocess:
-                    if not _on_postprocess.has_key(ft):
-                        _on_postprocess[ft] = []
                     _on_postprocess[ft].append(plugin)
 
 
+def plugins_for_ft(ft, occasion):
+    op = {
+        'import':_on_import, 'preprocess':_on_preprocess, 'postprocess':_on_postprocess, 'postimport':_on_postimport,
+    }[occasion]
+    for p in chain(op.get(ft, ()), op.get('*', ())):
+        if not is_disabled(p):
+            yield p
+
+
 def _run_filetype_plugins(path_to_file, ft=None, occasion='preprocess'):
-    occasion_plugins = {'import':_on_import, 'preprocess':_on_preprocess,
-                'postprocess':_on_postprocess}[occasion]
     customization = config['plugin_customization']
     if ft is None:
         ft = os.path.splitext(path_to_file)[-1].lower().replace('.', '')
     nfp = path_to_file
-    for plugin in occasion_plugins.get(ft, []):
-        if is_disabled(plugin):
-            continue
+    for plugin in plugins_for_ft(ft, occasion):
         plugin.site_customization = customization.get(plugin.name, '')
+        oo, oe = sys.stdout, sys.stderr  # Some file type plugins out there override the output streams with buggy implementations
         with plugin:
             try:
-                nfp = plugin.run(path_to_file)
-                if not nfp:
-                    nfp = path_to_file
+                plugin.original_path_to_file = path_to_file
+            except Exception:
+                pass
+            try:
+                nfp = plugin.run(nfp) or nfp
             except:
-                print 'Running file type plugin %s failed with traceback:'%plugin.name
-                traceback.print_exc()
-    x = lambda j : os.path.normpath(os.path.normcase(j))
+                print >>oe, 'Running file type plugin %s failed with traceback:'%plugin.name
+                traceback.print_exc(file=oe)
+        sys.stdout, sys.stderr = oo, oe
+    x = lambda j: os.path.normpath(os.path.normcase(j))
     if occasion == 'postprocess' and x(nfp) != x(path_to_file):
         shutil.copyfile(nfp, path_to_file)
         nfp = path_to_file
     return nfp
 
-run_plugins_on_import      = functools.partial(_run_filetype_plugins,
-                                               occasion='import')
-run_plugins_on_preprocess  = functools.partial(_run_filetype_plugins,
-                                               occasion='preprocess')
-run_plugins_on_postprocess = functools.partial(_run_filetype_plugins,
-                                               occasion='postprocess')
+
+run_plugins_on_import      = functools.partial(_run_filetype_plugins, occasion='import')
+run_plugins_on_preprocess  = functools.partial(_run_filetype_plugins, occasion='preprocess')
+run_plugins_on_postprocess = functools.partial(_run_filetype_plugins, occasion='postprocess')
+
 
 def run_plugins_on_postimport(db, book_id, fmt):
     customization = config['plugin_customization']
     fmt = fmt.lower()
-    for plugin in _on_postimport.get(fmt, []):
-        if is_disabled(plugin):
-            continue
+    for plugin in plugins_for_ft(fmt, 'postimport'):
         plugin.site_customization = customization.get(plugin.name, '')
         with plugin:
             try:
@@ -185,25 +197,46 @@ def run_plugins_on_postimport(db, book_id, fmt):
                        plugin.name)
                 traceback.print_exc()
 
+
+def run_plugins_on_postadd(db, book_id, fmt_map):
+    customization = config['plugin_customization']
+    for plugin in _on_postadd:
+        if is_disabled(plugin):
+            continue
+        plugin.site_customization = customization.get(plugin.name, '')
+        with plugin:
+            try:
+                plugin.postadd(book_id, fmt_map, db)
+            except Exception:
+                print ('Running file type plugin %s failed with traceback:'%
+                       plugin.name)
+                traceback.print_exc()
+
 # }}}
 
 # Plugin customization {{{
+
+
 def customize_plugin(plugin, custom):
     d = config['plugin_customization']
     d[plugin.name] = custom.strip()
     config['plugin_customization'] = d
 
+
 def plugin_customization(plugin):
     return config['plugin_customization'].get(plugin.name, '')
 
 # }}}
 
 # Input/Output profiles {{{
+
+
 def input_profiles():
     for plugin in _initialized_plugins:
         if isinstance(plugin, InputProfile):
             yield plugin
 
+
 def output_profiles():
     for plugin in _initialized_plugins:
         if isinstance(plugin, OutputProfile):
@@ -212,6 +245,7 @@ def output_profiles():
 
 # Interface Actions # {{{
 
+
 def interface_actions():
     customization = config['plugin_customization']
     for plugin in _initialized_plugins:
@@ -223,6 +257,7 @@ def interface_actions():
 
 # Preferences Plugins # {{{
 
+
 def preferences_plugins():
     customization = config['plugin_customization']
     for plugin in _initialized_plugins:
@@ -232,8 +267,29 @@ def preferences_plugins():
                 yield plugin
 # }}}
 
+# Library Closed Plugins # {{{
+
+
+def available_library_closed_plugins():
+    customization = config['plugin_customization']
+    for plugin in _initialized_plugins:
+        if isinstance(plugin, LibraryClosedPlugin):
+            if not is_disabled(plugin):
+                plugin.site_customization = customization.get(plugin.name, '')
+                yield plugin
+
+
+def has_library_closed_plugins():
+    for plugin in _initialized_plugins:
+        if isinstance(plugin, LibraryClosedPlugin):
+            if not is_disabled(plugin):
+                return True
+    return False
+# }}}
+
 # Store Plugins # {{{
 
+
 def store_plugins():
     customization = config['plugin_customization']
     for plugin in _initialized_plugins:
@@ -241,17 +297,20 @@ def store_plugins():
             plugin.site_customization = customization.get(plugin.name, '')
             yield plugin
 
+
 def available_store_plugins():
     for plugin in store_plugins():
         if not is_disabled(plugin):
             yield plugin
 
+
 def stores():
     stores = set([])
     for plugin in store_plugins():
         stores.add(plugin.name)
     return stores
 
+
 def available_stores():
     stores = set([])
     for plugin in available_store_plugins():
@@ -261,24 +320,26 @@ def available_stores():
 # }}}
 
 # Metadata read/write {{{
+
+
 _metadata_readers = {}
 _metadata_writers = {}
+
+
 def reread_metadata_plugins():
     global _metadata_readers
     global _metadata_writers
-    _metadata_readers = {}
+    _metadata_readers = defaultdict(list)
+    _metadata_writers = defaultdict(list)
     for plugin in _initialized_plugins:
         if isinstance(plugin, MetadataReaderPlugin):
             for ft in plugin.file_types:
-                if not _metadata_readers.has_key(ft):
-                    _metadata_readers[ft] = []
                 _metadata_readers[ft].append(plugin)
         elif isinstance(plugin, MetadataWriterPlugin):
             for ft in plugin.file_types:
-                if not _metadata_writers.has_key(ft):
-                    _metadata_writers[ft] = []
                 _metadata_writers[ft].append(plugin)
 
+
 def metadata_readers():
     ans = set([])
     for plugins in _metadata_readers.values():
@@ -286,6 +347,7 @@ def metadata_readers():
             ans.add(plugin)
     return ans
 
+
 def metadata_writers():
     ans = set([])
     for plugins in _metadata_writers.values():
@@ -293,6 +355,7 @@ def metadata_writers():
             ans.add(plugin)
     return ans
 
+
 class QuickMetadata(object):
 
     def __init__(self):
@@ -304,8 +367,10 @@ class QuickMetadata(object):
     def __exit__(self, *args):
         self.quick = False
 
+
 quick_metadata = QuickMetadata()
 
+
 class ApplyNullMetadata(object):
 
     def __init__(self):
@@ -317,8 +382,10 @@ class ApplyNullMetadata(object):
     def __exit__(self, *args):
         self.apply_null = False
 
+
 apply_null_metadata = ApplyNullMetadata()
 
+
 class ForceIdentifiers(object):
 
     def __init__(self):
@@ -330,13 +397,15 @@ class ForceIdentifiers(object):
     def __exit__(self, *args):
         self.force_identifiers = False
 
+
 force_identifiers = ForceIdentifiers()
 
+
 def get_file_type_metadata(stream, ftype):
     mi = MetaInformation(None, None)
 
     ftype = ftype.lower().strip()
-    if _metadata_readers.has_key(ftype):
+    if ftype in _metadata_readers:
         for plugin in _metadata_readers[ftype]:
             if not is_disabled(plugin):
                 with plugin:
@@ -351,15 +420,18 @@ def get_file_type_metadata(stream, ftype):
                         continue
     return mi
 
+
 def set_file_type_metadata(stream, mi, ftype, report_error=None):
     ftype = ftype.lower().strip()
-    if _metadata_writers.has_key(ftype):
+    if ftype in _metadata_writers:
+        customization = config['plugin_customization']
         for plugin in _metadata_writers[ftype]:
             if not is_disabled(plugin):
                 with plugin:
                     try:
                         plugin.apply_null = apply_null_metadata.apply_null
                         plugin.force_identifiers = force_identifiers.force_identifiers
+                        plugin.site_customization = customization.get(plugin.name, '')
                         plugin.set_metadata(stream, mi, ftype.lower().strip())
                         break
                     except:
@@ -370,10 +442,19 @@ def set_file_type_metadata(stream, mi, ftype, report_error=None):
                         else:
                             report_error(mi, ftype, traceback.format_exc())
 
+
+def can_set_metadata(ftype):
+    ftype = ftype.lower().strip()
+    for plugin in _metadata_writers.get(ftype, ()):
+        if not is_disabled(plugin):
+            return True
+    return False
+
 # }}}
 
 # Add/remove plugins {{{
 
+
 def add_plugin(path_to_zip_file):
     make_config_dir()
     plugin = load_plugin(path_to_zip_file)
@@ -391,6 +472,7 @@ def add_plugin(path_to_zip_file):
     initialize_plugins()
     return plugin
 
+
 def remove_plugin(plugin_or_name):
     name = getattr(plugin_or_name, 'name', plugin_or_name)
     plugins = config['plugins']
@@ -415,11 +497,13 @@ def remove_plugin(plugin_or_name):
 
 # Input/Output format plugins {{{
 
+
 def input_format_plugins():
     for plugin in _initialized_plugins:
         if isinstance(plugin, InputFormatPlugin):
             yield plugin
 
+
 def plugin_for_input_format(fmt):
     customization = config['plugin_customization']
     for plugin in input_format_plugins():
@@ -427,15 +511,17 @@ def plugin_for_input_format(fmt):
             plugin.site_customization = customization.get(plugin.name, None)
             return plugin
 
+
 def all_input_formats():
-    formats = set([])
+    formats = set()
     for plugin in input_format_plugins():
         for format in plugin.file_types:
             formats.add(format)
     return formats
 
+
 def available_input_formats():
-    formats = set([])
+    formats = set()
     for plugin in input_format_plugins():
         if not is_disabled(plugin):
             for format in plugin.file_types:
@@ -449,6 +535,7 @@ def output_format_plugins():
         if isinstance(plugin, OutputFormatPlugin):
             yield plugin
 
+
 def plugin_for_output_format(fmt):
     customization = config['plugin_customization']
     for plugin in output_format_plugins():
@@ -456,6 +543,7 @@ def plugin_for_output_format(fmt):
             plugin.site_customization = customization.get(plugin.name, None)
             return plugin
 
+
 def available_output_formats():
     formats = set([])
     for plugin in output_format_plugins():
@@ -467,11 +555,13 @@ def available_output_formats():
 
 # Catalog plugins {{{
 
+
 def catalog_plugins():
     for plugin in _initialized_plugins:
         if isinstance(plugin, CatalogPlugin):
             yield plugin
 
+
 def available_catalog_formats():
     formats = set([])
     for plugin in catalog_plugins():
@@ -480,6 +570,7 @@ def available_catalog_formats():
                 formats.add(format)
     return formats
 
+
 def plugin_for_catalog_format(fmt):
     for plugin in catalog_plugins():
         if fmt.lower() in plugin.file_types:
@@ -488,6 +579,8 @@ def plugin_for_catalog_format(fmt):
 # }}}
 
 # Device plugins {{{
+
+
 def device_plugins(include_disabled=False):
     for plugin in _initialized_plugins:
         if isinstance(plugin, DevicePlugin):
@@ -498,6 +591,7 @@ def device_plugins(include_disabled=False):
                         plugin.do_delayed_plugin_initialization()
                     yield plugin
 
+
 def disabled_device_plugins():
     for plugin in _initialized_plugins:
         if isinstance(plugin, DevicePlugin):
@@ -507,6 +601,8 @@ def disabled_device_plugins():
 # }}}
 
 # Metadata sources2 {{{
+
+
 def metadata_plugins(capabilities):
     capabilities = frozenset(capabilities)
     for plugin in all_metadata_plugins():
@@ -514,13 +610,31 @@ def metadata_plugins(capabilities):
                 not is_disabled(plugin):
             yield plugin
 
+
 def all_metadata_plugins():
     for plugin in _initialized_plugins:
         if isinstance(plugin, Source):
             yield plugin
+
+
+def patch_metadata_plugins(possibly_updated_plugins):
+    patches = {}
+    for i, plugin in enumerate(_initialized_plugins):
+        if isinstance(plugin, Source) and plugin.name in builtin_names:
+            pup = possibly_updated_plugins.get(plugin.name)
+            if pup is not None:
+                if pup.version > plugin.version and pup.minimum_calibre_version <= numeric_version:
+                    patches[i] = pup(None)
+                    # Metadata source plugins dont use initialize() but that
+                    # might change in the future, so be safe.
+                    patches[i].initialize()
+    for i, pup in patches.iteritems():
+        _initialized_plugins[i] = pup
 # }}}
 
 # Viewer plugins {{{
+
+
 def all_viewer_plugins():
     for plugin in _initialized_plugins:
         if isinstance(plugin, ViewerPlugin):
@@ -528,6 +642,8 @@ def all_viewer_plugins():
 # }}}
 
 # Editor plugins {{{
+
+
 def all_edit_book_tool_plugins():
     for plugin in _initialized_plugins:
         if isinstance(plugin, EditBookToolPlugin):
@@ -536,8 +652,10 @@ def all_edit_book_tool_plugins():
 
 # Initialize plugins {{{
 
+
 _initialized_plugins = []
 
+
 def initialize_plugin(plugin, path_to_zip_file):
     try:
         p = plugin(path_to_zip_file)
@@ -549,10 +667,12 @@ def initialize_plugin(plugin, path_to_zip_file):
         raise InvalidPlugin((_('Initialization of plugin %s failed with traceback:')
                             %tb) + '\n'+tb)
 
+
 def has_external_plugins():
-    'True if there are updateable (zip file based) plugins'
+    'True if there are updateable (ZIP file based) plugins'
     return bool(config['plugins'])
 
+
 def initialize_plugins(perf=False):
     global _initialized_plugins
     _initialized_plugins = []
@@ -598,8 +718,10 @@ def initialize_plugins(perf=False):
     reread_filetype_plugins()
     reread_metadata_plugins()
 
+
 initialize_plugins()
 
+
 def initialized_plugins():
     for plugin in _initialized_plugins:
         yield plugin
@@ -608,6 +730,7 @@ def initialized_plugins():
 
 # CLI {{{
 
+
 def build_plugin(path):
     from calibre import prints
     from calibre.ptempfile import PersistentTemporaryFile
@@ -619,12 +742,13 @@ def build_plugin(path):
         raise SystemExit(1)
     t = PersistentTemporaryFile(u'.zip')
     with ZipFile(t, u'w', ZIP_STORED) as zf:
-        zf.add_dir(path)
+        zf.add_dir(path, simple_filter=lambda x:x in {'.git', '.bzr', '.svn', '.hg'})
     t.close()
     plugin = add_plugin(t.name)
     os.remove(t.name)
     prints(u'Plugin updated:', plugin.name, plugin.version)
 
+
 def option_parser():
     parser = OptionParser(usage=_('''\
     %prog options
@@ -632,7 +756,7 @@ def option_parser():
     Customize calibre by loading external plugins.
     '''))
     parser.add_option('-a', '--add-plugin', default=None,
-                      help=_('Add a plugin by specifying the path to the zip file containing it.'))
+                      help=_('Add a plugin by specifying the path to the ZIP file containing it.'))
     parser.add_option('-b', '--build-plugin', default=None,
             help=_('For plugin developers: Path to the directory where you are'
                 ' developing the plugin. This command will automatically zip '
@@ -649,6 +773,7 @@ def option_parser():
                       help=_('Disable the named plugin'))
     return parser
 
+
 def main(args=sys.argv):
     parser = option_parser()
     if len(args) < 2:
@@ -677,7 +802,10 @@ def main(args=sys.argv):
     if opts.disable_plugin is not None:
         disable_plugin(opts.disable_plugin.strip())
     if opts.list_plugins:
-        fmt = '%-15s%-20s%-15s%-15s%s'
+        type_len = name_len = 0
+        for plugin in initialized_plugins():
+            type_len, name_len = max(type_len, len(plugin.type)), max(name_len, len(plugin.name))
+        fmt = '%-{}s%-{}s%-15s%-15s%s'.format(type_len+1, name_len+1)
         print fmt%tuple(('Type|Name|Version|Disabled|Site Customization'.split('|')))
         print
         for plugin in initialized_plugins():
@@ -696,7 +824,7 @@ def main(args=sys.argv):
 
     return 0
 
+
 if __name__ == '__main__':
     sys.exit(main())
 # }}}
-
