@@ -15,23 +15,26 @@ from functools import partial
 from calibre.db.tables import ONE_ONE, MANY_ONE, MANY_MANY, null
 from calibre.db.write import Writer
 from calibre.db.utils import force_to_bool, atof
-from calibre.ebooks.metadata import title_sort, author_to_author_sort
+from calibre.ebooks.metadata import title_sort, author_to_author_sort, rating_to_stars
 from calibre.utils.config_base import tweaks
 from calibre.utils.icu import sort_key
 from calibre.utils.date import UNDEFINED_DATE, clean_date_for_sort, parse_date
 from calibre.utils.localization import calibre_langcode_to_name
 
+
 def bool_sort_key(bools_are_tristate):
     return (lambda x:{True: 1, False: 2, None: 3}.get(x, 3)) if bools_are_tristate else lambda x:{True: 1, False: 2, None: 2}.get(x, 2)
 
 IDENTITY = lambda x: x
 
+
 class InvalidLinkTable(Exception):
 
     def __init__(self, name):
         Exception.__init__(self, name)
         self.field_name = name
 
+
 class Field(object):
 
     is_many = False
@@ -77,7 +80,10 @@ class Field(object):
         self.default_value = {} if name == 'identifiers' else () if self.is_multiple else None
         self.category_formatter = type(u'')
         if dt == 'rating':
-            self.category_formatter = lambda x:'\u2605'*int(x/2)
+            if self.metadata['display'].get('allow_half_stars', False):
+                self.category_formatter = lambda x: rating_to_stars(x, True)
+            else:
+                self.category_formatter = rating_to_stars
         elif name == 'languages':
             self.category_formatter = calibre_langcode_to_name
         self.writer = Writer(self)
@@ -163,6 +169,7 @@ class Field(object):
                 ans.append(c)
         return ans
 
+
 class OneToOneField(Field):
 
     def for_book(self, book_id, default_value=None):
@@ -190,6 +197,7 @@ class OneToOneField(Field):
         for book_id in candidates:
             yield cbm.get(book_id, default_value), {book_id}
 
+
 class CompositeField(OneToOneField):
 
     is_composite = True
@@ -336,6 +344,7 @@ class CompositeField(OneToOneField):
                 ans.add(book_id)
         return ans
 
+
 class OnDeviceField(OneToOneField):
 
     def __init__(self, name, table, bools_are_tristate):
@@ -400,6 +409,7 @@ class OnDeviceField(OneToOneField):
         for val, book_ids in val_map.iteritems():
             yield val, book_ids
 
+
 class LazySortMap(object):
 
     __slots__ = ('default_sort_key', 'sort_key_func', 'id_map', 'cache')
@@ -466,6 +476,7 @@ class ManyToOneField(Field):
         except KeyError:
             raise InvalidLinkTable(self.name)
 
+
 class ManyToManyField(Field):
 
     is_many = True
@@ -531,6 +542,7 @@ class ManyToManyField(Field):
         except KeyError:
             raise InvalidLinkTable(self.name)
 
+
 class IdentifiersField(ManyToManyField):
 
     def for_book(self, book_id, default_value=None):
@@ -566,6 +578,7 @@ class IdentifiersField(ManyToManyField):
                 ans.append(c)
         return ans
 
+
 class AuthorsField(ManyToManyField):
 
     def author_data(self, author_id):
@@ -585,6 +598,7 @@ class AuthorsField(ManyToManyField):
         return ' & '.join(self.table.asort_map[k] for k in
                           self.table.book_col_map[book_id])
 
+
 class FormatsField(ManyToManyField):
 
     def for_book(self, book_id, default_value=None):
@@ -615,6 +629,7 @@ class FormatsField(ManyToManyField):
                 ans.append(c)
         return ans
 
+
 class LazySeriesSortMap(object):
 
     __slots__ = ('default_sort_key', 'sort_key_func', 'id_map', 'cache')
@@ -635,12 +650,14 @@ class LazySeriesSortMap(object):
                 val = self.cache[(item_id, lang)] = self.default_sort_key
             return val
 
+
 class SeriesField(ManyToOneField):
 
     def sort_keys_for_books(self, get_metadata, lang_map):
         sso = tweaks['title_series_sorting']
         ssk = self._sort_key
         ts = title_sort
+
         def sk(val, lang):
             return ssk(ts(val, order=sso, lang=lang))
         sk_map = LazySeriesSortMap(self._default_sort_key, sk, self.table.id_map)
@@ -715,6 +732,7 @@ class TagsField(ManyToManyField):
                 ans.append(c)
         return ans
 
+
 def create_field(name, table, bools_are_tristate):
     cls = {
             ONE_ONE: OneToOneField,
