@@ -9,10 +9,12 @@ __docformat__ = 'restructuredtext en'
 
 import datetime
 from io import BytesIO
+from time import time
 
 from calibre.utils.date import utc_tz
 from calibre.db.tests.base import BaseTest
 
+
 class ReadingTest(BaseTest):
 
     def test_read(self):  # {{{
@@ -328,6 +330,13 @@ class ReadingTest(BaseTest):
         self.assertEqual(cache.search('rating:2'), {1, 3})
         self.assertEqual(cache.search('rating:!=2'), {2})
 
+        cache.field_metadata.all_metadata()['#rating']['display']['allow_half_stars'] = True
+        cache.set_field('#rating', {1:3, 2:4, 3:9})
+        self.assertEqual(cache.search('#rating:1'), set())
+        self.assertEqual(cache.search('#rating:1.5'), {1})
+        self.assertEqual(cache.search('#rating:>4'), {3})
+        self.assertEqual(cache.search('#rating:2'), {2})
+
         # Note that the old db searched uuid for un-prefixed searches, the new
         # db does not, for performance
 
@@ -486,18 +495,22 @@ class ReadingTest(BaseTest):
     def test_search_caching(self):  # {{{
         ' Test caching of searches '
         from calibre.db.search import LRUCache
+
         class TestCache(LRUCache):
             hit_counter = 0
             miss_counter = 0
+
             def get(self, key, default=None):
                 ans = LRUCache.get(self, key, default=default)
                 if ans is not None:
                     self.hit_counter += 1
                 else:
                     self.miss_counter += 1
+
             @property
             def cc(self):
                 self.hit_counter = self.miss_counter = 0
+
             @property
             def counts(self):
                 return self.hit_counter, self.miss_counter
@@ -552,6 +565,7 @@ class ReadingTest(BaseTest):
                                 'Standard field: %s not the same for book %s' % (field, book_id))
                 self.assertEqual(mi.format_field(field), pmi.format_field(field),
                                 'Standard field format: %s not the same for book %s' % (field, book_id))
+
                 def f(x):
                     try:
                         x.pop('rec_index', None)
@@ -655,3 +669,15 @@ class ReadingTest(BaseTest):
             self.assertEqual(books, cache.find_identical_books(mi))
             self.assertEqual(books, find_identical_books(mi, data))
     # }}}
+
+    def test_last_read_positions(self):  # {{{
+        cache = self.init_cache(self.library_path)
+        self.assertFalse(cache.get_last_read_positions(1, 'x', 'u'))
+        self.assertRaises(Exception, cache.set_last_read_position, 12, 'x', cfi='c')
+        epoch = time()
+        cache.set_last_read_position(1, 'EPUB', 'user', 'device', 'cFi', epoch, 0.3)
+        self.assertFalse(cache.get_last_read_positions(1, 'x', 'u'))
+        self.assertEqual(cache.get_last_read_positions(1, 'ePuB', 'user'), [{'epoch':epoch, 'device':'device', 'cfi':'cFi', 'pos_frac':0.3}])
+        cache.set_last_read_position(1, 'EPUB', 'user', 'device')
+        self.assertFalse(cache.get_last_read_positions(1, 'ePuB', 'user'))
+    # }}}
