@@ -16,12 +16,14 @@ from calibre.ebooks.metadata import title_sort
 from calibre.utils.config_base import tweaks, prefs
 from calibre.db.write import uniq
 
+
 def sanitize_sort_field_name(field_metadata, field):
     field = field_metadata.search_term_to_field_key(field.lower().strip())
     # translate some fields to their hidden equivalent
     field = {'title': 'sort', 'authors':'author_sort'}.get(field, field)
     return field
 
+
 class MarkedVirtualField(object):
 
     def __init__(self, marked_ids):
@@ -35,6 +37,7 @@ class MarkedVirtualField(object):
         g = self.marked_ids.get
         return lambda book_id:g(book_id, None)
 
+
 class TableRow(object):
 
     def __init__(self, book_id, view):
@@ -57,6 +60,7 @@ class TableRow(object):
         for i in xrange(self.column_count):
             yield self[i]
 
+
 def format_is_multiple(x, sep=',', repl=None):
     if not x:
         return None
@@ -64,11 +68,13 @@ def format_is_multiple(x, sep=',', repl=None):
         x = (y.replace(sep, repl) for y in x)
     return sep.join(x)
 
+
 def format_identifiers(x):
     if not x:
         return None
     return ','.join('%s:%s'%(k, v) for k, v in x.iteritems())
 
+
 class View(object):
 
     ''' A table view of the database, with rows and columns. Also supports
@@ -94,8 +100,7 @@ class View(object):
                 }.get(col, self._get)
             if isinstance(col, int):
                 label = self.cache.backend.custom_column_num_map[col]['label']
-                label = (self.cache.backend.field_metadata.custom_field_prefix
-                        + label)
+                label = (self.cache.backend.field_metadata.custom_field_prefix + label)
             if label.endswith('_index'):
                 try:
                     num = int(label.partition('_')[0])
@@ -103,8 +108,7 @@ class View(object):
                     pass  # series_index
                 else:
                     label = self.cache.backend.custom_column_num_map[num]['label']
-                    label = (self.cache.backend.field_metadata.custom_field_prefix
-                            + label + '_index')
+                    label = (self.cache.backend.field_metadata.custom_field_prefix + label + '_index')
 
             fm = self.field_metadata[label]
             fm
