@@ -1,4 +1,4 @@
-#!/usr/bin/env  python
+#!/usr/bin/env  python2
 
 __license__   = 'GPL v3'
 __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
@@ -11,69 +11,70 @@ from calibre.utils.config import OptionParser
 from calibre.constants import iswindows
 from calibre import prints
 
+
 def option_parser():
     parser = OptionParser(usage=_('''\
-%prog [options]
+{0}
 
 Various command line interfaces useful for debugging calibre. With no options,
-this command starts an embedded python interpreter. You can also run the main
+this command starts an embedded Python interpreter. You can also run the main
 calibre GUI, the calibre viewer and the calibre editor in debug mode.
 
 It also contains interfaces to various bits of calibre that do not have
-dedicated command line tools, such as font subsetting, the ebook diff tool and so
+dedicated command line tools, such as font subsetting, the e-book diff tool and so
 on.
 
 You can also use %prog to run standalone scripts. To do that use it like this:
 
-    %prog myscript.py -- --option1 --option2 file1 file2 ...
+    {1}
 
 Everything after the -- is passed to the script.
-'''))
-    parser.add_option('-c', '--command', help='Run python code.')
-    parser.add_option('-e', '--exec-file', help='Run the python code in file.')
-    parser.add_option('-f', '--subset-font', help='Subset the specified font')
+''').format(_('%prog [options]'), '%prog myscript.py -- --option1 --option2 file1 file2 ...'))
+    parser.add_option('-c', '--command', help=_('Run Python code.'))
+    parser.add_option('-e', '--exec-file', help=_('Run the Python code in file.'))
+    parser.add_option('-f', '--subset-font', action='store_true', default=False,
+                      help=_('Subset the specified font. Use -- after this option to pass option to the font subsetting program.'))
     parser.add_option('-d', '--debug-device-driver', default=False, action='store_true',
-                      help='Debug device detection')
+                      help=_('Debug device detection'))
     parser.add_option('-g', '--gui',  default=False, action='store_true',
-                      help='Run the GUI with debugging enabled. Debug output is '
-                      'printed to stdout and stderr.')
+                      help=_('Run the GUI with debugging enabled. Debug output is '
+                      'printed to stdout and stderr.'))
     parser.add_option('--gui-debug',  default=None,
-                      help='Run the GUI with a debug console, logging to the'
+                      help=_('Run the GUI with a debug console, logging to the'
                       ' specified path. For internal use only, use the -g'
-                      ' option to run the GUI in debug mode',)
-    parser.add_option('--show-gui-debug',  default=None,
-                      help='Display the specified log file. For internal use'
-                      ' only.',)
+                      ' option to run the GUI in debug mode'))
     parser.add_option('-w', '--viewer',  default=False, action='store_true',
-                      help='Run the ebook viewer',)
+                      help=_('Run the E-book viewer in debug mode'))
     parser.add_option('--paths', default=False, action='store_true',
-            help='Output the paths necessary to setup the calibre environment')
+            help=_('Output the paths necessary to setup the calibre environment'))
     parser.add_option('--add-simple-plugin', default=None,
-            help='Add a simple plugin (i.e. a plugin that consists of only a '
+            help=_('Add a simple plugin (i.e. a plugin that consists of only a '
             '.py file), by specifying the path to the py file containing the '
-            'plugin code.')
+            'plugin code.'))
     parser.add_option('--reinitialize-db', default=None,
-            help='Re-initialize the sqlite calibre database at the '
-            'specified path. Useful to recover from db corruption.')
-    parser.add_option('-p', '--py-console', help='Run python console',
-            default=False, action='store_true')
+            help=_('Re-initialize the sqlite calibre database at the '
+            'specified path. Useful to recover from db corruption.'))
     parser.add_option('-m', '--inspect-mobi', action='store_true',
             default=False,
-            help='Inspect the MOBI file(s) at the specified path(s)')
+            help=_('Inspect the MOBI file(s) at the specified path(s)'))
     parser.add_option('-t', '--edit-book', action='store_true',
-            help='Launch the calibre Edit Book tool in debug mode.')
+            help=_('Launch the calibre "Edit book" tool in debug mode.'))
     parser.add_option('-x', '--explode-book', default=None,
-            help='Explode the book (exports the book as a collection of HTML '
+            help=_('Explode the book (exports the book as a collection of HTML '
             'files and metadata, which you can edit using standard HTML '
             'editing tools, and then rebuilds the file from the edited HTML. '
             'Makes no additional changes to the HTML, unlike a full calibre '
-            'conversion).')
+            'conversion).'))
+    parser.add_option('--export-all-calibre-data', default=False, action='store_true',
+        help=_('Export all calibre data (books/settings/plugins)'))
+    parser.add_option('--import-calibre-data', default=False, action='store_true',
+        help=_('Import previously exported calibre data'))
     parser.add_option('-s', '--shutdown-running-calibre', default=False,
             action='store_true',
             help=_('Cause a running calibre instance, if any, to be'
                 ' shutdown. Note that if there are running jobs, they '
                 'will be silently aborted, so use with care.'))
-    parser.add_option('--test-build', help='Test binary modules in build',
+    parser.add_option('--test-build', help=_('Test binary modules in build'),
             action='store_true', default=False)
     parser.add_option('-r', '--run-plugin', help=_(
         'Run a plugin that provides a command line interface. For example:\n'
@@ -82,9 +83,14 @@ Everything after the -- is passed to the script.
     parser.add_option('--diff', action='store_true', default=False, help=_(
         'Run the calibre diff tool. For example:\n'
         'calibre-debug --diff file1 file2'))
+    parser.add_option('--default-programs', default=None, choices=['register', 'unregister'],
+                          help=_('(Un)register calibre from Windows Default Programs.') + ' --default-programs=(register|unregister)')
+    parser.add_option('--new-server', action='store_true',
+        help='Run the new calibre content server. Any options specified after a -- will be passed to the server.')
 
     return parser
 
+
 def reinit_db(dbpath):
     from contextlib import closing
     from calibre import as_unicode
@@ -123,6 +129,7 @@ def reinit_db(dbpath):
         atomic_rename(tmpdb, dbpath)
     prints('Database successfully re-initialized')
 
+
 def debug_device_driver():
     from calibre.devices import debug
     debug(ioreg_to_tmp=True, buf=sys.stdout)
@@ -145,6 +152,7 @@ def add_simple_plugin(path_to_plugin):
     os.chdir(odir)
     shutil.rmtree(tdir)
 
+
 def print_basic_debug_info(out=None):
     if out is None:
         out = sys.stdout
@@ -153,7 +161,7 @@ def print_basic_debug_info(out=None):
     from calibre.constants import (__appname__, get_version, isportable, isosx,
                                    isfrozen, is64bit)
     out(__appname__, get_version(), 'Portable' if isportable else '',
-        'isfrozen:', isfrozen, 'is64bit:', is64bit)
+        'embedded-python:', isfrozen, 'is64bit:', is64bit)
     out(platform.platform(), platform.system(), platform.architecture())
     if iswindows and not is64bit:
         try:
@@ -174,6 +182,11 @@ def print_basic_debug_info(out=None):
             out('Linux:', platform.linux_distribution())
     except:
         pass
+    from calibre.customize.ui import has_external_plugins, initialized_plugins
+    if has_external_plugins():
+        names = ('{0} {1}'.format(p.name, p.version) for p in initialized_plugins() if getattr(p, 'plugin_path', None) is not None)
+        out('Successfully initialized third party plugins:', ' && '.join(names))
+
 
 def run_debug_gui(logpath):
     import time
@@ -181,8 +194,9 @@ def run_debug_gui(logpath):
     from calibre.constants import __appname__
     prints(__appname__, _('Debug log'))
     print_basic_debug_info()
-    from calibre.gui2.main import main
-    main(['__CALIBRE_GUI_DEBUG__', logpath])
+    from calibre.gui_launch import calibre
+    calibre(['__CALIBRE_GUI_DEBUG__', logpath])
+
 
 def run_script(path, args):
     # Load all user defined plugins so the script can import from the
@@ -192,48 +206,36 @@ def run_script(path, args):
 
     sys.argv = [path] + args
     ef = os.path.abspath(path)
-    base = os.path.dirname(ef)
-    sys.path.insert(0, base)
+    if '/src/calibre/' not in ef.replace(os.pathsep, '/'):
+        base = os.path.dirname(ef)
+        sys.path.insert(0, base)
     g = globals()
     g['__name__'] = '__main__'
     g['__file__'] = ef
     execfile(ef, g)
 
+
 def inspect_mobi(path):
     from calibre.ebooks.mobi.debug.main import inspect_mobi
     prints('Inspecting:', path)
     inspect_mobi(path)
     print
 
+
 def main(args=sys.argv):
     from calibre.constants import debug
     debug()
 
     opts, args = option_parser().parse_args(args)
     if opts.gui:
-        from calibre.gui2.main import main
+        from calibre.gui_launch import calibre
         print_basic_debug_info()
-        main(['calibre'])
+        calibre(['calibre'])
     elif opts.gui_debug is not None:
         run_debug_gui(opts.gui_debug)
-    elif opts.show_gui_debug:
-        import time, re
-        time.sleep(1)
-        from calibre.gui2 import open_local_file
-        if iswindows:
-            with open(opts.show_gui_debug, 'r+b') as f:
-                raw = f.read()
-                raw = re.sub('(?<!\r)\n', '\r\n', raw)
-                f.seek(0)
-                f.truncate()
-                f.write(raw)
-        open_local_file(opts.show_gui_debug)
     elif opts.viewer:
-        from calibre.gui2.viewer.main import main
-        main(['ebook-viewer'] + args[1:])
-    elif opts.py_console:
-        from calibre.utils.pyconsole.main import main
-        main()
+        from calibre.gui_launch import ebook_viewer
+        ebook_viewer(['ebook-viewer', '--debug-javascript'] + args[1:])
     elif opts.command:
         sys.argv = args
         exec(opts.command)
@@ -251,8 +253,8 @@ def main(args=sys.argv):
         for path in args[1:]:
             inspect_mobi(path)
     elif opts.edit_book:
-        from calibre.gui2.tweak_book.main import main
-        main(['ebook-edit'] + args[1:])
+        from calibre.gui_launch import ebook_edit
+        ebook_edit(['ebook-edit'] + args[1:])
     elif opts.explode_book:
         from calibre.ebooks.tweak import tweak
         tweak(opts.explode_book)
@@ -264,7 +266,7 @@ def main(args=sys.argv):
         shutdown_other()
     elif opts.subset_font:
         from calibre.utils.fonts.sfnt.subset import main
-        main(['subset-font']+[opts.subset_font]+args[1:])
+        main(['subset-font'] + args[1:])
     elif opts.exec_file:
         run_script(opts.exec_file, args[1:])
     elif opts.run_plugin:
@@ -277,6 +279,24 @@ def main(args=sys.argv):
     elif opts.diff:
         from calibre.gui2.tweak_book.diff.main import main
         main(['calibre-diff'] + args[1:])
+    elif opts.default_programs:
+        if not iswindows:
+            raise SystemExit('Can only be run on Microsoft Windows')
+        if opts.default_programs == 'register':
+            from calibre.utils.winreg.default_programs import register as func
+        else:
+            from calibre.utils.winreg.default_programs import unregister as func
+        print 'Running', func.__name__, '...'
+        func()
+    elif opts.new_server:
+        from calibre.srv.standalone import main
+        main(args)
+    elif opts.export_all_calibre_data:
+        from calibre.utils.exim import run_exporter
+        run_exporter()
+    elif opts.import_calibre_data:
+        from calibre.utils.exim import run_importer
+        run_importer()
     elif len(args) >= 2 and args[1].rpartition('.')[-1] in {'py', 'recipe'}:
         run_script(args[1], args[2:])
     elif len(args) >= 2 and args[1].rpartition('.')[-1] in {'mobi', 'azw', 'azw3', 'docx', 'odt'}:
@@ -289,12 +309,15 @@ def main(args=sys.argv):
                 inspect_mobi(path)
             else:
                 print ('Cannot dump unknown filetype: %s' % path)
+    elif len(args) >= 2 and os.path.exists(os.path.join(args[1], '__main__.py')):
+        sys.path.insert(0, args[1])
+        run_script(os.path.join(args[1], '__main__.py'), args[2:])
     else:
         from calibre import ipython
         ipython()
 
     return 0
 
+
 if __name__ == '__main__':
     sys.exit(main())
-
