@@ -14,7 +14,7 @@ class ESLICK(USBMS):
 
     name           = 'ESlick Device Interface'
     gui_name       = 'Foxit ESlick'
-    description    = _('Communicate with the ESlick eBook reader.')
+    description    = _('Communicate with the ESlick e-book reader.')
     author         = 'Kovid Goyal'
     supported_platforms = ['windows', 'osx', 'linux']
 
@@ -46,7 +46,7 @@ class EBK52(ESLICK):
 
     name           = 'EBK-52 Device Interface'
     gui_name       = 'Sigmatek EBK'
-    description    = _('Communicate with the Sigmatek eBook reader.')
+    description    = _('Communicate with the Sigmatek e-book reader.')
 
     FORMATS     = ['epub', 'fb2', 'pdf', 'txt']
 
@@ -59,5 +59,3 @@ class EBK52(ESLICK):
     @classmethod
     def can_handle(cls, dev, debug=False):
         return (dev[3], dev[4]) == ('philips', 'Philips d')
-
-
