@@ -11,6 +11,7 @@ import os
 from calibre.devices.usbms.driver import USBMS
 from calibre import fsync
 
+
 class PALMPRE(USBMS):
 
     name           = 'Palm Pre Device Interface'
@@ -52,6 +53,7 @@ class AVANT(USBMS):
     EBOOK_DIR_MAIN = ''
     SUPPORTS_SUB_DIRS = True
 
+
 class SWEEX(USBMS):
     # Identical to the Promedia
     name           = 'Sweex Device Interface'
@@ -101,6 +103,7 @@ class PDNOVEL(USBMS):
                 coverfile.write(coverdata[2])
                 fsync(coverfile)
 
+
 class PDNOVEL_KOBO(PDNOVEL):
     name = 'Pandigital Kobo device interface'
     gui_name = 'PD Novel (Kobo)'
@@ -139,6 +142,7 @@ class VELOCITYMICRO(USBMS):
     EBOOK_DIR_MAIN = 'eBooks'
     SUPPORTS_SUB_DIRS = False
 
+
 class GEMEI(USBMS):
     name           = 'Gemei Device Interface'
     gui_name       = 'GM2000'
@@ -159,6 +163,7 @@ class GEMEI(USBMS):
     EBOOK_DIR_MAIN = 'eBooks'
     SUPPORTS_SUB_DIRS = True
 
+
 class LUMIREAD(USBMS):
     name           = 'Acer Lumiread Device Interface'
     gui_name       = 'Lumiread'
@@ -193,6 +198,7 @@ class LUMIREAD(USBMS):
                 f.write(metadata.thumbnail[-1])
                 fsync(f)
 
+
 class ALURATEK_COLOR(USBMS):
 
     name           = 'Aluratek Color Device Interface'
@@ -215,6 +221,7 @@ class ALURATEK_COLOR(USBMS):
     SCAN_FROM_ROOT = True
     SUPPORTS_SUB_DIRS_FOR_SCAN = True
 
+
 class TREKSTOR(USBMS):
 
     name           = 'Trekstor E-book player device interface'
@@ -231,9 +238,9 @@ class TREKSTOR(USBMS):
             0x0067,  # This is for the Pyrus Mini
             0x006f,  # This is for the Pyrus Maxi
             0x003e,  # This is for the EBOOK_PLAYER_5M https://bugs.launchpad.net/bugs/792091
-            0x05cL,  # This is for the 4ink http://www.mobileread.com/forums/showthread.php?t=191318
-            0x006c,  # This is for the 4ink http://www.mobileread.com/forums/showthread.php?t=218273
-            0x006d,  # Another Pyrus? http://www.mobileread.com/forums/showthread.php?t=231982
+            0x05cL,  # This is for the 4ink https://www.mobileread.com/forums/showthread.php?t=191318
+            0x006c,  # This is for the 4ink https://www.mobileread.com/forums/showthread.php?t=218273
+            0x006d,  # Another Pyrus? https://www.mobileread.com/forums/showthread.php?t=231982
             0x73,    # This is for the Pyrus 2 LED https://bugs.launchpad.net/bugs/1376018
             ]
     BCD         = [0x0002, 0x100, 0x0222, 0x2]
@@ -246,6 +253,7 @@ class TREKSTOR(USBMS):
     SUPPORTS_SUB_DIRS = True
     SUPPORTS_SUB_DIRS_DEFAULT = False
 
+
 class EEEREADER(USBMS):
 
     name           = 'Asus EEE Reader device interface'
@@ -266,6 +274,7 @@ class EEEREADER(USBMS):
     VENDOR_NAME = ['LINUX', 'ASUS']
     WINDOWS_MAIN_MEM = WINDOWS_CARD_A_MEM = ['FILE-STOR_GADGET', 'EEE_NOTE']
 
+
 class ADAM(USBMS):
 
     name = 'Notion Ink Adam device interface'
@@ -288,6 +297,7 @@ class ADAM(USBMS):
     WINDOWS_MAIN_MEM = WINDOWS_CARD_A_MEM = ['ADAM']
     SUPPORTS_SUB_DIRS = True
 
+
 class NEXTBOOK(USBMS):
 
     name           = 'Nextbook device interface'
@@ -341,6 +351,7 @@ class NEXTBOOK(USBMS):
                 fsync(f)
     '''
 
+
 class MOOVYBOOK(USBMS):
 
     name           = 'Moovybook device interface'
@@ -363,6 +374,7 @@ class MOOVYBOOK(USBMS):
     def get_main_ebook_dir(self, for_upload=False):
         return 'Books' if for_upload else self.EBOOK_DIR_MAIN
 
+
 class COBY(USBMS):
 
     name           = 'COBY MP977 device interface'
@@ -389,6 +401,7 @@ class COBY(USBMS):
             return 'eBooks'
         return self.EBOOK_DIR_CARD_A
 
+
 class EX124G(USBMS):
 
     name = 'Motorola Ex124G device interface'
@@ -416,6 +429,7 @@ class EX124G(USBMS):
             return 'eBooks'
         return self.EBOOK_DIR_CARD_A
 
+
 class WAYTEQ(USBMS):
 
     name           = 'WayteQ device interface'
@@ -506,6 +520,7 @@ class WOXTER(USBMS):
     VENDOR_NAME = ['ROCKCHIP', 'TEXET']
     WINDOWS_MAIN_MEM = WINDOWS_CARD_A_MEM = ['EREADER', 'TB-146SE']
 
+
 class POCKETBOOK626(USBMS):
 
     name  = 'PocketBook Touch Lux 2'
@@ -526,6 +541,7 @@ class POCKETBOOK626(USBMS):
     VENDOR_NAME = ['USB_2.0']
     WINDOWS_MAIN_MEM = WINDOWS_CARD_A_MEM = ['USB_FLASH_DRIVER']
 
+
 class SONYDPTS1(USBMS):
 
     name  = 'SONY DPT-S1'
@@ -547,6 +563,7 @@ class SONYDPTS1(USBMS):
     WINDOWS_MAIN_MEM = ['DPT-S1']
     WINDOWS_CARD_A_MEM = ['DPT-S1__SD']
 
+
 class CERVANTES(USBMS):
 
     name = 'Bq Cervantes Device Interface'
@@ -556,11 +573,9 @@ class CERVANTES(USBMS):
     supported_platforms = ['windows', 'osx', 'linux']
     FORMATS = ['epub', 'fb2', 'mobi', 'doc', 'rtf', 'pdf', 'txt']
     VENDOR_ID   = [0x2a47]
-    PRODUCT_ID  = [0xad78]
+    PRODUCT_ID  = [0xad78, 0xad77, 0xad75]
     BCD         = [0x0110]
 
     EBOOK_DIR_MAIN = 'Books'
     SCAN_FROM_ROOT = True
     SUPPORTS_SUB_DIRS = True
-
-
