@@ -12,21 +12,23 @@ import os
 
 import cStringIO
 
+from calibre import fsync
 from calibre.devices.usbms.driver import USBMS
 
+
 class NOOK(USBMS):
 
     name           = 'Nook Device Interface'
     gui_name       = _('The Nook')
     description    = _('Communicate with the Nook eBook reader.')
     author         = 'John Schember'
-    icon           = I('devices/nook.jpg')
+    icon           = I('devices/nook.png')
     supported_platforms = ['windows', 'linux', 'osx']
 
     # Ordered list of supported formats
     FORMATS     = ['epub', 'pdb', 'pdf']
 
-    VENDOR_ID   = [0x2080, 0x18d1] # 0x18d1 is for softrooted nook
+    VENDOR_ID   = [0x2080, 0x18d1]  # 0x18d1 is for softrooted nook
     PRODUCT_ID  = [0x001]
     BCD         = [0x322]
 
@@ -52,12 +54,11 @@ class NOOK(USBMS):
         except ImportError:
             import Image, ImageDraw
 
-
         coverdata = getattr(metadata, 'thumbnail', None)
         if coverdata and coverdata[2]:
             cover = Image.open(cStringIO.StringIO(coverdata[2]))
         else:
-            coverdata = open(I('library.png'), 'rb').read()
+            coverdata = lopen(I('library.png'), 'rb').read()
 
             cover = Image.new('RGB', (96, 144), 'black')
             im = Image.open(cStringIO.StringIO(coverdata))
@@ -74,20 +75,29 @@ class NOOK(USBMS):
         cover.save(data, 'JPEG')
         coverdata = data.getvalue()
 
-        with open('%s.jpg' % os.path.join(path, filename), 'wb') as coverfile:
+        with lopen('%s.jpg' % os.path.join(path, filename), 'wb') as coverfile:
             coverfile.write(coverdata)
+            fsync(coverfile)
 
     def sanitize_path_components(self, components):
         return [x.replace('#', '_') for x in components]
 
-class NOOK_COLOR(NOOK):
-    description    = _('Communicate with the Nook Color and TSR eBook readers.')
 
-    PRODUCT_ID  = [0x002, 0x003]
+class NOOK_COLOR(NOOK):
+    name           = 'Nook Color Device Interface'
+    description    = _('Communicate with the Nook Color, TSR, Glowlight and Tablet eBook readers.')
+
+    PRODUCT_ID  = [
+        0x002, 0x003, 0x004,
+        0x005,  # Nook HD+
+        0x007,  # Glowlight from 2013
+    ]
     BCD         = [0x216]
 
-    WINDOWS_MAIN_MEM = WINDOWS_CARD_A_MEM = 'EBOOK_DISK'
+    WINDOWS_MAIN_MEM = WINDOWS_CARD_A_MEM = ['EBOOK_DISK', 'NOOK_TABLET',
+            'NOOK_SIMPLETOUCH', 'NOOK_GLOWLIGHT']
     EBOOK_DIR_MAIN = 'My Files'
+    SCAN_FROM_ROOT = True
     NEWS_IN_FOLDER = False
 
     def upload_cover(self, path, filename, metadata, filepath):
@@ -104,5 +114,3 @@ class NOOK_COLOR(NOOK):
         path = os.path.join(path, subdir)
         return USBMS.create_upload_path(self, path, mdata, fname,
                 create_dirs=create_dirs)
-
-
