@@ -25,14 +25,17 @@ from calibre.utils.filenames import ascii_filename as sanitize
 
 if isosx:
     usbobserver, usbobserver_err = plugins['usbobserver']
+    osx_sanitize_name_pat = re.compile(r'[.-]')
 
 if iswindows:
     usb_info_cache = {}
 
+
 def eject_exe():
     base = sys.extensions_location if hasattr(sys, 'new_app_layout') else os.path.dirname(sys.executable)
     return os.path.join(base, 'calibre-eject.exe')
 
+
 class USBDevice:
 
     def __init__(self, dev):
@@ -55,8 +58,17 @@ class USBDevice:
         return self.idVendor == vid and self.idProduct == pid and self.bcdDevice == bcd
 
     def match_strings(self, vid, pid, bcd, man, prod):
-        return self.match_numbers(vid, pid, bcd) and \
-                self.manufacturer == man and self.product == prod
+        if not self.match_numbers(vid, pid, bcd):
+            return False
+        if man == self.manufacturer and prod == self.product:
+            return True
+        # As of OS X 10.11.4 Apple started mangling the names returned via the
+        # IOKit registry. See
+        # https://www.mobileread.com/forums/showthread.php?t=273213
+        m = osx_sanitize_name_pat.sub('_', (self.manufacturer or ''))
+        p = osx_sanitize_name_pat.sub('_', (self.product or ''))
+        return m == man and p == prod
+
 
 class Device(DeviceConfig, DevicePlugin):
 
@@ -365,20 +377,24 @@ class Device(DeviceConfig, DevicePlugin):
             for path, vid, pid, bcd, ven, prod, serial in drives:
                 if d.match_serial(serial):
                     matches.append(path)
+        if not matches and d.manufacturer and d.product:
+            for path, vid, pid, bcd, man, prod, serial in drives:
+                if d.match_strings(vid, pid, bcd, man, prod):
+                    matches.append(path)
         if not matches:
-            if d.manufacturer and d.product:
-                for path, vid, pid, bcd, man, prod, serial in drives:
-                    if d.match_strings(vid, pid, bcd, man, prod):
-                        matches.append(path)
-            else:
-                for path, vid, pid, bcd, man, prod, serial in drives:
-                    if d.match_numbers(vid, pid, bcd):
-                        matches.append(path)
+            # Since Apple started mangling the names stored in the IOKit
+            # registry, we cannot trust match_strings() so fallback to matching
+            # on just numbers. See http://www.mobileread.com/forums/showthread.php?t=273213
+            for path, vid, pid, bcd, man, prod, serial in drives:
+                if d.match_numbers(vid, pid, bcd):
+                    matches.append(path)
         if not matches:
+            from pprint import pformat
             raise DeviceError(
-             'Could not detect BSD names for %s. Try rebooting.' % self.name)
+                'Could not detect BSD names for %s. Try rebooting.\nOutput from osx_get_usb_drives():\n%s' % (self.name, pformat(drives)))
 
         pat = re.compile(r'(?P<m>\d+)([a-z]+(?P<p>\d+)){0,1}')
+
         def nums(x):
             'Return (disk num, partition number)'
             m = pat.search(x)
@@ -452,6 +468,7 @@ class Device(DeviceConfig, DevicePlugin):
                         break
 
         self._main_prefix = drives['main']+os.sep
+
         def get_card_prefix(c):
             ans = drives.get(c, None)
             if ans is not None:
@@ -528,6 +545,9 @@ class Device(DeviceConfig, DevicePlugin):
                             ok[node] = False
                     except:
                         ok[node] = False
+                    if DEBUG and not ok[node]:
+                        print '\nIgnoring the node: %s as could not read size from: %s' % (node, sz)
+
                     devnodes.append(node)
 
         devnodes += list(repeat(None, 3))
@@ -568,6 +588,7 @@ class Device(DeviceConfig, DevicePlugin):
             mp = self.node_mountpoint(node)
             if mp is not None:
                 return mp, 0
+
             def do_mount(node):
                 try:
                     from calibre.devices.udisks import mount
@@ -627,7 +648,7 @@ class Device(DeviceConfig, DevicePlugin):
             path = os.path.join(mp, 'calibre_readonly_test')
             ro = True
             try:
-                with open(path, 'wb'):
+                with lopen(path, 'wb'):
                     ro = False
             except:
                 pass
@@ -699,7 +720,9 @@ class Device(DeviceConfig, DevicePlugin):
                         d.manufacturer == objif.GetProperty('usb.vendor') and \
                         d.product == objif.GetProperty('usb.product') and \
                         d.serial == objif.GetProperty('usb.serial'):
-                    dpaths = manager.FindDeviceStringMatch('storage.originating_device', path)
+                    midpath = manager.FindDeviceStringMatch('info.parent', path)
+                    dpaths = manager.FindDeviceStringMatch(
+                        'storage.originating_device', path) + manager.FindDeviceStringMatch('storage.originating_device', midpath[0])
                     for dpath in dpaths:
                         # devif = dbus.Interface(bus.get_object('org.freedesktop.Hal', dpath), 'org.freedesktop.Hal.Device')
                         try:
