@@ -10,20 +10,20 @@ driver. It is intended to be subclassed with the relevant parts implemented
 for a particular device.
 '''
 
-import os, re, time, json, uuid, functools
+import os, time, json, shutil
 from itertools import cycle
 
 from calibre.constants import numeric_version
-from calibre import prints, isbytestring
+from calibre import prints, isbytestring, fsync
 from calibre.constants import filesystem_encoding, DEBUG
 from calibre.devices.usbms.cli import CLI
 from calibre.devices.usbms.device import Device
 from calibre.devices.usbms.books import BookList, Book
 from calibre.ebooks.metadata.book.json_codec import JsonCodec
-from calibre.utils.config import from_json, to_json
-from calibre.utils.date import now, isoformat
 
 BASE_TIME = None
+
+
 def debug_print(*args):
     global BASE_TIME
     if BASE_TIME is None:
@@ -31,16 +31,58 @@ def debug_print(*args):
     if DEBUG:
         prints('DEBUG: %6.1f'%(time.time()-BASE_TIME), *args)
 
+
+def safe_walk(top, topdown=True, onerror=None, followlinks=False):
+    ' A replacement for os.walk that does not die when it encounters undecodeable filenames in a linux filesystem'
+    islink, join, isdir = os.path.islink, os.path.join, os.path.isdir
+
+    # We may not have read permission for top, in which case we can't
+    # get a list of the files the directory contains.  os.path.walk
+    # always suppressed the exception then, rather than blow up for a
+    # minor reason when (say) a thousand readable directories are still
+    # left to visit.  That logic is copied here.
+    try:
+        names = os.listdir(top)
+    except os.error as err:
+        if onerror is not None:
+            onerror(err)
+        return
+
+    dirs, nondirs = [], []
+    for name in names:
+        if isinstance(name, bytes):
+            try:
+                name = name.decode(filesystem_encoding)
+            except UnicodeDecodeError:
+                debug_print('Skipping undecodeable file: %r' % name)
+                continue
+        if isdir(join(top, name)):
+            dirs.append(name)
+        else:
+            nondirs.append(name)
+
+    if topdown:
+        yield top, dirs, nondirs
+    for name in dirs:
+        new_path = join(top, name)
+        if followlinks or not islink(new_path):
+            for x in safe_walk(new_path, topdown, onerror, followlinks):
+                yield x
+    if not topdown:
+        yield top, dirs, nondirs
+
+
 # CLI must come before Device as it implements the CLI functions that
 # are inherited from the device interface in Device.
 class USBMS(CLI, Device):
+
     '''
     The base class for all USBMS devices. Implements the logic for
     sending/getting/updating metadata/caching metadata/etc.
     '''
 
     description    = _('Communicate with an eBook reader.')
-    author         = _('John Schember')
+    author         = 'John Schember'
     supported_platforms = ['windows', 'osx', 'linux']
 
     # Store type instances of BookList and Book. We must do this because
@@ -58,11 +100,13 @@ class USBMS(CLI, Device):
     SCAN_FROM_ROOT = False
 
     def _update_driveinfo_record(self, dinfo, prefix, location_code, name=None):
+        from calibre.utils.date import now, isoformat
+        import uuid
         if not isinstance(dinfo, dict):
             dinfo = {}
         if dinfo.get('device_store_uuid', None) is None:
             dinfo['device_store_uuid'] = unicode(uuid.uuid4())
-        if dinfo.get('device_name') is None:
+        if dinfo.get('device_name', None) is None:
             dinfo['device_name'] = self.get_gui_name()
         if name is not None:
             dinfo['device_name'] = name
@@ -74,20 +118,23 @@ class USBMS(CLI, Device):
         return dinfo
 
     def _update_driveinfo_file(self, prefix, location_code, name=None):
+        from calibre.utils.config import from_json, to_json
         if os.path.exists(os.path.join(prefix, self.DRIVEINFO)):
-            with open(os.path.join(prefix, self.DRIVEINFO), 'rb') as f:
+            with lopen(os.path.join(prefix, self.DRIVEINFO), 'rb') as f:
                 try:
                     driveinfo = json.loads(f.read(), object_hook=from_json)
                 except:
                     driveinfo = None
                 driveinfo = self._update_driveinfo_record(driveinfo, prefix,
                                                           location_code, name)
-            with open(os.path.join(prefix, self.DRIVEINFO), 'wb') as f:
+            with lopen(os.path.join(prefix, self.DRIVEINFO), 'wb') as f:
                 f.write(json.dumps(driveinfo, default=to_json))
+                fsync(f)
         else:
             driveinfo = self._update_driveinfo_record({}, prefix, location_code, name)
-            with open(os.path.join(prefix, self.DRIVEINFO), 'wb') as f:
+            with lopen(os.path.join(prefix, self.DRIVEINFO), 'wb') as f:
                 f.write(json.dumps(driveinfo, default=to_json))
+                fsync(f)
         return driveinfo
 
     def get_device_information(self, end_session=True):
@@ -127,10 +174,16 @@ class USBMS(CLI, Device):
         elif location_code == 'B':
             self._update_driveinfo_file(self._card_b_prefix, location_code, name)
 
+    def formats_to_scan_for(self):
+        return set(self.settings().format_map) | set(self.FORMATS)
+
+    def is_allowed_book_file(self, filename, path, prefix):
+        return True
+
     def books(self, oncard=None, end_session=True):
         from calibre.ebooks.metadata.meta import path_to_ext
 
-        debug_print ('USBMS: Fetching list of books from device. Device=',
+        debug_print('USBMS: Fetching list of books from device. Device=',
                      self.__class__.__name__,
                      'oncard=', oncard)
 
@@ -154,7 +207,7 @@ class USBMS(CLI, Device):
             self.EBOOK_DIR_CARD_B if oncard == 'cardb' else \
             self.get_main_ebook_dir()
 
-        debug_print ('USBMS: dirs are:', prefix, ebook_dirs)
+        debug_print('USBMS: dirs are:', prefix, ebook_dirs)
 
         # get the metadata cache
         bl = self.booklist_class(oncard, prefix, self.settings)
@@ -162,14 +215,14 @@ class USBMS(CLI, Device):
 
         # make a dict cache of paths so the lookup in the loop below is faster.
         bl_cache = {}
-        for idx,b in enumerate(bl):
+        for idx, b in enumerate(bl):
             bl_cache[b.lpath] = idx
 
-        all_formats = set(self.settings().format_map) | set(self.FORMATS)
+        all_formats = self.formats_to_scan_for()
 
         def update_booklist(filename, path, prefix):
             changed = False
-            if path_to_ext(filename) in all_formats:
+            if path_to_ext(filename) in all_formats and self.is_allowed_book_file(filename, path, prefix):
                 try:
                     lpath = os.path.join(path, filename).partition(self.normalize_path(prefix))[2]
                     if lpath.startswith(os.sep):
@@ -179,13 +232,13 @@ class USBMS(CLI, Device):
                     if idx is not None:
                         bl_cache[lpath] = None
                         if self.update_metadata_item(bl[idx]):
-                            #print 'update_metadata_item returned true'
+                            # print 'update_metadata_item returned true'
                             changed = True
                     else:
                         if bl.add_book(self.book_from_path(prefix, lpath),
                                               replace_metadata=False):
                             changed = True
-                except: # Probably a filename encoding error
+                except:  # Probably a filename encoding error
                     import traceback
                     traceback.print_exc()
             return changed
@@ -196,16 +249,17 @@ class USBMS(CLI, Device):
             if self.SCAN_FROM_ROOT:
                 ebook_dir = self.normalize_path(prefix)
             else:
-                ebook_dir = self.normalize_path( \
-                            os.path.join(prefix, *(ebook_dir.split('/'))) \
-                                    if ebook_dir else prefix)
+                ebook_dir = self.normalize_path(
+                            os.path.join(prefix, *(ebook_dir.split('/')))
+                            if ebook_dir else prefix)
             debug_print('USBMS: scan from root', self.SCAN_FROM_ROOT, ebook_dir)
-            if not os.path.exists(ebook_dir): continue
+            if not os.path.exists(ebook_dir):
+                continue
             # Get all books in the ebook_dir directory
-            if self.SUPPORTS_SUB_DIRS:
+            if self.SUPPORTS_SUB_DIRS or self.SUPPORTS_SUB_DIRS_FOR_SCAN:
                 # build a list of files to check, so we can accurately report progress
                 flist = []
-                for path, dirs, files in os.walk(ebook_dir):
+                for path, dirs, files in safe_walk(ebook_dir):
                     for filename in files:
                         if filename != self.METADATA_CACHE:
                             flist.append({'filename': self.path_to_unicode(filename),
@@ -231,9 +285,9 @@ class USBMS(CLI, Device):
                 need_sync = True
                 del bl[idx]
 
-        debug_print('USBMS: count found in cache: %d, count of files in metadata: %d, need_sync: %s' % \
+        debug_print('USBMS: count found in cache: %d, count of files in metadata: %d, need_sync: %s' %
             (len(bl_cache), len(bl), need_sync))
-        if need_sync: #self.count_found_in_bl != len(bl) or need_sync:
+        if need_sync:  # self.count_found_in_bl != len(bl) or need_sync:
             if oncard == 'cardb':
                 self.sync_booklists((None, None, bl))
             elif oncard == 'carda':
@@ -266,7 +320,7 @@ class USBMS(CLI, Device):
                 self.upload_cover(os.path.dirname(filepath),
                                   os.path.splitext(os.path.basename(filepath))[0],
                                   mdata, filepath)
-            except: # Failure to upload cover is not catastrophic
+            except:  # Failure to upload cover is not catastrophic
                 import traceback
                 traceback.print_exc()
 
@@ -284,7 +338,7 @@ class USBMS(CLI, Device):
         :param filename: The name of the book file without the extension.
         :param metadata: metadata belonging to the book. Use metadata.thumbnail
                          for cover
-        :param filepath: The full path to the ebook file
+        :param filepath: The full path to the e-book file
 
         '''
         pass
@@ -328,6 +382,26 @@ class USBMS(CLI, Device):
         self.report_progress(1.0, _('Adding books to device metadata listing...'))
         debug_print('USBMS: finished adding metadata')
 
+    def delete_single_book(self, path):
+        os.unlink(path)
+
+    def delete_extra_book_files(self, path):
+        filepath = os.path.splitext(path)[0]
+        for ext in self.DELETE_EXTS:
+            for x in (filepath, path):
+                x += ext
+                if os.path.exists(x):
+                    if os.path.isdir(x):
+                        shutil.rmtree(x, ignore_errors=True)
+                    else:
+                        os.unlink(x)
+
+        if self.SUPPORTS_SUB_DIRS:
+            try:
+                os.removedirs(os.path.dirname(path))
+            except:
+                pass
+
     def delete_books(self, paths, end_session=True):
         debug_print('USBMS: deleting %d books'%(len(paths)))
         for i, path in enumerate(paths):
@@ -335,20 +409,9 @@ class USBMS(CLI, Device):
             path = self.normalize_path(path)
             if os.path.exists(path):
                 # Delete the ebook
-                os.unlink(path)
+                self.delete_single_book(path)
+                self.delete_extra_book_files(path)
 
-                filepath = os.path.splitext(path)[0]
-                for ext in self.DELETE_EXTS:
-                    if os.path.exists(filepath + ext):
-                        os.unlink(filepath + ext)
-                    if os.path.exists(path + ext):
-                        os.unlink(path + ext)
-
-                if self.SUPPORTS_SUB_DIRS:
-                    try:
-                        os.removedirs(os.path.dirname(path))
-                    except:
-                        pass
         self.report_progress(1.0, _('Removing books from device...'))
         debug_print('USBMS: finished deleting %d books'%(len(paths)))
 
@@ -375,11 +438,13 @@ class USBMS(CLI, Device):
             os.makedirs(self.normalize_path(self._main_prefix))
 
         def write_prefix(prefix, listid):
-            if prefix is not None and isinstance(booklists[listid], self.booklist_class):
+            if (prefix is not None and len(booklists) > listid and
+                    isinstance(booklists[listid], self.booklist_class)):
                 if not os.path.exists(prefix):
                     os.makedirs(self.normalize_path(prefix))
-                with open(self.normalize_path(os.path.join(prefix, self.METADATA_CACHE)), 'wb') as f:
+                with lopen(self.normalize_path(os.path.join(prefix, self.METADATA_CACHE)), 'wb') as f:
                     json_codec.encode_to_file(f, booklists[listid])
+                    fsync(f)
         write_prefix(self._main_prefix, 0)
         write_prefix(self._card_a_prefix, 1)
         write_prefix(self._card_b_prefix, 2)
@@ -396,21 +461,8 @@ class USBMS(CLI, Device):
 
     @classmethod
     def build_template_regexp(cls):
-        def replfunc(match, seen=None):
-            v = match.group(1)
-            if v in ['title', 'series', 'series_index', 'isbn']:
-                if v not in seen:
-                    seen |= set([v])
-                    return '(?P<' + v + '>.+?)'
-            elif v in ['authors', 'author_sort']:
-                if v not in seen:
-                    seen |= set([v])
-                    return '(?P<author>.+?)'
-            return '(.+?)'
-        s = set()
-        f = functools.partial(replfunc, seen=s)
-        template = cls.save_template().rpartition('/')[2]
-        return re.compile(re.sub('{([^}]*)}', f, template) + '([_\d]*$)')
+        from calibre.devices.utils import build_template_regexp
+        return build_template_regexp(cls.save_template())
 
     @classmethod
     def path_to_unicode(cls, path):
@@ -436,7 +488,7 @@ class USBMS(CLI, Device):
         cache_file = cls.normalize_path(os.path.join(prefix, name))
         if os.access(cache_file, os.R_OK):
             try:
-                with open(cache_file, 'rb') as f:
+                with lopen(cache_file, 'rb') as f:
                     json_codec.decode_from_file(f, bl, cls.book_class, prefix)
             except:
                 import traceback
