@@ -15,9 +15,11 @@ from calibre.utils.logging import default_log
 from calibre.ptempfile import TemporaryFile
 from calibre import force_unicode
 
+
 def _clean(s):
     return s.replace(u'\u00a0', u' ')
 
+
 def _detag(tag):
     str = u""
     if tag is None:
@@ -44,6 +46,7 @@ def _metadata_from_table(soup, searchfor):
         meta = _detag(td)
         return re.sub(r'^[^:]+:', '', meta).strip()
 
+
 def _metadata_from_span(soup, searchfor):
     span = soup.find('span', {'class': re.compile(searchfor, flags=re.I)})
     if span is None:
@@ -51,27 +54,26 @@ def _metadata_from_span(soup, searchfor):
     # this metadata might need some cleaning up still :/
     return _detag(span.renderContents(None).strip())
 
+
 def _get_authors(soup):
-    aut = (_metadata_from_span(soup, r'author')
-        or _metadata_from_table(soup, r'^\s*by\s*:?\s+'))
+    aut = (_metadata_from_span(soup, r'author') or _metadata_from_table(soup, r'^\s*by\s*:?\s+'))
     ans = [_('Unknown')]
     if aut is not None:
         ans = string_to_authors(aut)
     return ans
 
+
 def _get_publisher(soup):
-    return (_metadata_from_span(soup, 'imprint')
-        or _metadata_from_table(soup, 'publisher'))
+    return (_metadata_from_span(soup, 'imprint') or _metadata_from_table(soup, 'publisher'))
+
 
 def _get_isbn(soup):
-    return (_metadata_from_span(soup, 'isbn')
-        or _metadata_from_table(soup, 'isbn'))
+    return (_metadata_from_span(soup, 'isbn') or _metadata_from_table(soup, 'isbn'))
+
 
 def _get_comments(soup):
-    date = (_metadata_from_span(soup, 'cwdate')
-        or _metadata_from_table(soup, 'pub date'))
-    pages = ( _metadata_from_span(soup, 'pages')
-        or _metadata_from_table(soup, 'pages'))
+    date = (_metadata_from_span(soup, 'cwdate') or _metadata_from_table(soup, 'pub date'))
+    pages = (_metadata_from_span(soup, 'pages') or _metadata_from_table(soup, 'pages'))
     try:
         # date span can have copyright symbols in it...
         date = date.replace(u'\u00a9', '').strip()
@@ -82,6 +84,7 @@ def _get_comments(soup):
         pass
     return None
 
+
 def _get_cover(soup, rdr):
     ans = None
     try:
@@ -164,6 +167,7 @@ def get_metadata_from_reader(rdr):
 
     return mi
 
+
 def get_metadata(stream):
     with TemporaryFile('_chm_metadata.chm') as fname:
         with open(fname, 'wb') as f:
