@@ -18,7 +18,7 @@ class DOCXInput(InputFormatPlugin):
     options = {
         OptionRecommendation(name='docx_no_cover', recommended_value=False,
             help=_('Normally, if a large image is present at the start of the document that looks like a cover, '
-                   'it will be removed from the document and used as the cover for created ebook. This option '
+                   'it will be removed from the document and used as the cover for created e-book. This option '
                    'turns off that behavior.')),
         OptionRecommendation(name='docx_no_pagebreaks_between_notes', recommended_value=False,
             help=_('Do not insert a page break after every endnote.')),
@@ -32,4 +32,3 @@ class DOCXInput(InputFormatPlugin):
         from calibre.ebooks.docx.to_html import Convert
         return Convert(stream, detect_cover=not options.docx_no_cover, log=log, notes_nopb=options.docx_no_pagebreaks_between_notes,
                        nosupsub=options.docx_inline_subsup)()
-
