@@ -52,11 +52,10 @@ class PDFOutput(OutputFormatPlugin):
     file_type = 'pdf'
 
     options = set([
-        OptionRecommendation(name='override_profile_size', recommended_value=False,
-            help=_('Normally, the PDF page size is set by the output profile'
-                   ' chosen under the page setup options. This option will cause the '
-                   ' page size settings under PDF Output to override the '
-                   ' size specified by the output profile.')),
+        OptionRecommendation(name='use_profile_size', recommended_value=False,
+            help=_('Instead of using the paper size specified in the PDF Output options,'
+                   ' use a paper size corresponding to the current output profile.'
+                   ' Useful if you want to generate a PDF for viewing on a specific device.')),
         OptionRecommendation(name='unit', recommended_value='inch',
             level=OptionRecommendation.LOW, short_switch='u', choices=UNITS,
             help=_('The unit of measure for page sizes. Default is inch. Choices '
@@ -97,8 +96,6 @@ class PDFOutput(OutputFormatPlugin):
                 'The default font size for monospaced text')),
         OptionRecommendation(name='pdf_mark_links', recommended_value=False,
             help=_('Surround all links with a red box, useful for debugging.')),
-        OptionRecommendation(name='old_pdf_engine', recommended_value=False,
-            help=_('Use the old, less capable engine to generate the PDF')),
         OptionRecommendation(name='uncompressed_pdf',
             recommended_value=False, help=_(
                 'Generate an uncompressed PDF, useful for debugging, '
@@ -119,7 +116,31 @@ class PDFOutput(OutputFormatPlugin):
         OptionRecommendation(name='toc_title', recommended_value=None,
             help=_('Title for generated table of contents.')
         ),
-        ])
+
+        OptionRecommendation(name='pdf_page_margin_left', recommended_value=72.0,
+            level=OptionRecommendation.LOW,
+            help=_('The size of the left page margin, in pts. Default is 72pt.'
+                   ' Overrides the common left page margin setting.')
+        ),
+
+        OptionRecommendation(name='pdf_page_margin_top', recommended_value=72.0,
+            level=OptionRecommendation.LOW,
+            help=_('The size of the top page margin, in pts. Default is 72pt.'
+                   ' Overrides the common top page margin setting, unless set to zero.')
+        ),
+
+        OptionRecommendation(name='pdf_page_margin_right', recommended_value=72.0,
+            level=OptionRecommendation.LOW,
+            help=_('The size of the right page margin, in pts. Default is 72pt.'
+                   ' Overrides the common right page margin setting, unless set to zero.')
+        ),
+
+        OptionRecommendation(name='pdf_page_margin_bottom', recommended_value=72.0,
+            level=OptionRecommendation.LOW,
+            help=_('The size of the bottom page margin, in pts. Default is 72pt.'
+                   ' Overrides the common bottom page margin setting, unless set to zero.')
+        ),
+    ])
 
     def convert(self, oeb_book, output_path, input_plugin, opts, log):
         from calibre.gui2 import must_use_qt, load_builtin_fonts
@@ -158,7 +179,7 @@ class PDFOutput(OutputFormatPlugin):
             os.environ.pop('CALIBRE_WEBKIT_NO_HINTING', None)
 
     def convert_images(self, images):
-        from calibre.ebooks.pdf.writer import ImagePDFWriter
+        from calibre.ebooks.pdf.render.from_html import ImagePDFWriter
         self.write(ImagePDFWriter, images, None)
 
     def get_cover_data(self):
@@ -216,11 +237,7 @@ class PDFOutput(OutputFormatPlugin):
 
     def convert_text(self, oeb_book):
         from calibre.ebooks.metadata.opf2 import OPF
-        if self.opts.old_pdf_engine:
-            from calibre.ebooks.pdf.writer import PDFWriter
-            PDFWriter
-        else:
-            from calibre.ebooks.pdf.render.from_html import PDFWriter
+        from calibre.ebooks.pdf.render.from_html import PDFWriter
 
         self.log.debug('Serializing oeb input to disk for processing...')
         self.get_cover_data()
