@@ -1,4 +1,5 @@
-#!/usr/bin/env  python
+#!/usr/local/bin/python2.7
+# vim:fileencoding=utf-8
 __license__   = 'GPL v3'
 __copyright__ = '2008, Kovid Goyal kovid@kovidgoyal.net'
 __docformat__ = 'restructuredtext en'
@@ -7,6 +8,7 @@ __docformat__ = 'restructuredtext en'
 Provides abstraction for metadata reading.writing from a variety of ebook formats.
 """
 import os, sys, re
+
 from urlparse import urlparse
 
 from calibre import relpath, guess_type, remove_bracketed_text, prints
@@ -20,6 +22,7 @@ except:
             'is invalid, using default')
     _author_pat = re.compile(r'(?i),?\s+(and|with)\s+')
 
+
 def string_to_authors(raw):
     if not raw:
         return []
@@ -28,12 +31,14 @@ def string_to_authors(raw):
     authors = [a.strip().replace(u'\uffff', '&') for a in raw.split('&')]
     return [a for a in authors if a]
 
+
 def authors_to_string(authors):
     if authors is not None:
         return ' & '.join([a.replace('&', '&&') for a in authors if a])
     else:
         return ''
 
+
 def author_to_author_sort(author, method=None):
     if not author:
         return u''
@@ -91,10 +96,13 @@ def author_to_author_sort(author, method=None):
 
     return u' '.join(atokens)
 
+
 def authors_to_sort_string(authors):
     return ' & '.join(map(author_to_author_sort, authors))
 
 _title_pats = {}
+
+
 def get_title_sort_pat(lang=None):
     ans = _title_pats.get(lang, None)
     if ans is not None:
@@ -127,6 +135,7 @@ def get_title_sort_pat(lang=None):
 _ignore_starts = u'\'"'+u''.join(unichr(x) for x in
         range(0x2018, 0x201e)+[0x2032, 0x2033])
 
+
 def title_sort(title, order=None, lang=None):
     if order is None:
         order = tweaks['title_series_sorting']
@@ -175,6 +184,7 @@ def fmt_sidx(i, fmt='%.2f', use_roman=False):
         return roman(int(i)) if use_roman else '%d'%int(i)
     return fmt%i
 
+
 class Resource(object):
 
     '''
@@ -323,6 +333,7 @@ def MetaInformation(title, authors=(_('Unknown'),)):
         authors = mi.authors
     return Metadata(title, authors, other=mi)
 
+
 def check_isbn10(isbn):
     try:
         digits = map(int, isbn[:9])
@@ -334,6 +345,7 @@ def check_isbn10(isbn):
         pass
     return None
 
+
 def check_isbn13(isbn):
     try:
         digits = map(int, isbn[:12])
@@ -347,6 +359,7 @@ def check_isbn13(isbn):
         pass
     return None
 
+
 def check_isbn(isbn):
     if not isbn:
         return None
@@ -360,6 +373,22 @@ def check_isbn(isbn):
         return check_isbn13(isbn)
     return None
 
+
+def check_issn(issn):
+    if not issn:
+        return None
+    issn = re.sub(r'[^0-9X]', '', issn.upper())
+    try:
+        digits = map(int, issn[:7])
+        products = [(8 - i) * d for i, d in enumerate(digits)]
+        check = 11 - sum(products) % 11
+        if (check == 10 and issn[7] == 'X') or check == int(issn[7]):
+            return issn
+    except Exception:
+        pass
+    return None
+
+
 def format_isbn(isbn):
     cisbn = check_isbn(isbn)
     if not cisbn:
@@ -369,6 +398,7 @@ def format_isbn(isbn):
         return '-'.join((i[:2], i[2:6], i[6:9], i[9]))
     return '-'.join((i[:3], i[3:5], i[5:9], i[9:12], i[12]))
 
+
 def check_doi(doi):
     'Check if something that looks like a DOI is present anywhere in the string'
     if not doi:
@@ -378,3 +408,13 @@ def check_doi(doi):
         return doi_check.group()
     return None
 
+
+def rating_to_stars(value, allow_half_stars=False, star=u'★', half=u'½'):
+    r = max(0, min(int(value or 0), 10))
+    if allow_half_stars:
+        ans = star * (r // 2)
+        if r % 2:
+            ans += half
+    else:
+        ans = star * int(r/2.0)
+    return ans
