@@ -8,13 +8,14 @@ import cStringIO, os
 
 from calibre.ebooks.metadata.opf2 import OPF
 
+
 def get_metadata(stream):
     from calibre.ebooks.lit.reader import LitContainer
     from calibre.utils.logging import Log
     litfile = LitContainer(stream, Log())
     src = litfile.get_metadata().encode('utf-8')
     litfile = litfile._litfile
-    opf = OPF(cStringIO.StringIO(src), os.getcwd())
+    opf = OPF(cStringIO.StringIO(src), os.getcwdu())
     mi = opf.to_book_metadata()
     covers = []
     for item in opf.iterguide():
