@@ -15,7 +15,7 @@ from calibre import prints
 from calibre.ebooks.metadata import check_isbn, authors_to_string, string_to_authors
 from calibre.ebooks.metadata.book.base import Metadata
 from calibre.ebooks.metadata.book.json_codec import object_to_unicode, decode_is_multiple, encode_is_multiple
-from calibre.ebooks.metadata.utils import parse_opf, pretty_print_opf, ensure_unique, normalize_languages
+from calibre.ebooks.metadata.utils import parse_opf, pretty_print_opf, ensure_unique, normalize_languages, create_manifest_item
 from calibre.ebooks.oeb.base import OPF2_NSMAP, OPF, DC
 from calibre.utils.config import from_json, to_json
 from calibre.utils.date import parse_date as parse_date_, fix_only_date, is_date_undefined, isoformat
@@ -26,6 +26,7 @@ from calibre.utils.localization import canonicalize_lang
 _xpath_cache = {}
 _re_cache = {}
 
+
 def uniq(vals):
     ''' Remove all duplicates from vals, while preserving order.  '''
     vals = vals or ()
@@ -33,9 +34,11 @@ def uniq(vals):
     seen_add = seen.add
     return list(x for x in vals if x not in seen and not seen_add(x))
 
+
 def dump_dict(cats):
     return json.dumps(object_to_unicode(cats or {}), ensure_ascii=False, skipkeys=True)
 
+
 def XPath(x):
     try:
         return _xpath_cache[x]
@@ -43,6 +46,7 @@ def XPath(x):
         _xpath_cache[x] = ans = etree.XPath(x, namespaces=OPF2_NSMAP)
         return ans
 
+
 def regex(r, flags=0):
     try:
         return _re_cache[(r, flags)]
@@ -50,15 +54,18 @@ def regex(r, flags=0):
         _re_cache[(r, flags)] = ans = re.compile(r, flags)
         return ans
 
+
 def remove_refines(e, refines):
     for x in refines[e.get('id')]:
         x.getparent().remove(x)
     refines.pop(e.get('id'), None)
 
+
 def remove_element(e, refines):
     remove_refines(e, refines)
     e.getparent().remove(e)
 
+
 def properties_for_id(item_id, refines):
     ans = {}
     if item_id:
@@ -70,6 +77,7 @@ def properties_for_id(item_id, refines):
                     ans[key] = val
     return ans
 
+
 def properties_for_id_with_scheme(item_id, prefixes, refines):
     ans = {}
     if item_id:
@@ -90,6 +98,7 @@ def properties_for_id_with_scheme(item_id, prefixes, refines):
                     ans[key] = (scheme_ns, scheme, val)
     return ans
 
+
 def getroot(elem):
     while True:
         q = elem.getparent()
@@ -97,6 +106,7 @@ def getroot(elem):
             return elem
         elem = q
 
+
 def ensure_id(elem):
     root = getroot(elem)
     eid = elem.get('id')
@@ -105,21 +115,38 @@ def ensure_id(elem):
         elem.set('id', eid)
     return eid
 
+
 def normalize_whitespace(text):
     if not text:
         return text
     return re.sub(r'\s+', ' ', text).strip()
 
+
 def simple_text(f):
     @wraps(f)
     def wrapper(*args, **kw):
         return normalize_whitespace(f(*args, **kw))
     return wrapper
+
+
+def items_with_property(root, q, prefixes=None):
+    if prefixes is None:
+        prefixes = read_prefixes(root)
+    q = expand_prefix(q, known_prefixes).lower()
+    for item in XPath("./opf:manifest/opf:item[@properties]")(root):
+        for prop in (item.get('properties') or '').lower().split():
+            prop = expand_prefix(prop, prefixes)
+            if prop == q:
+                yield item
+                break
+
 # }}}
 
 # Prefixes {{{
 
 # http://www.idpf.org/epub/vocab/package/pfx/
+
+
 reserved_prefixes = {
     'dcterms':  'http://purl.org/dc/terms/',
     'epubsc':   'http://idpf.org/epub/vocab/sc/#',
@@ -132,19 +159,27 @@ reserved_prefixes = {
 }
 
 CALIBRE_PREFIX = 'https://calibre-ebook.com'
+known_prefixes = reserved_prefixes.copy()
+known_prefixes['calibre'] = CALIBRE_PREFIX
+
 
 def parse_prefixes(x):
     return {m.group(1):m.group(2) for m in re.finditer(r'(\S+): \s*(\S+)', x)}
 
+
 def read_prefixes(root):
     ans = reserved_prefixes.copy()
     ans.update(parse_prefixes(root.get('prefix') or ''))
     return ans
 
+
 def expand_prefix(raw, prefixes):
     return regex(r'(\S+)\s*:\s*(\S+)').sub(lambda m:(prefixes.get(m.group(1), m.group(1)) + ':' + m.group(2)), raw or '')
 
+
 def ensure_prefix(root, prefixes, prefix, value=None):
+    if prefixes is None:
+        prefixes = read_prefixes(root)
     prefixes[prefix] = value or reserved_prefixes[prefix]
     prefixes = {k:v for k, v in prefixes.iteritems() if reserved_prefixes.get(k) != v}
     if prefixes:
@@ -155,6 +190,8 @@ def ensure_prefix(root, prefixes, prefix, value=None):
 # }}}
 
 # Refines {{{
+
+
 def read_refines(root):
     ans = defaultdict(list)
     for meta in XPath('./opf:metadata/opf:meta[@refines]')(root):
@@ -163,9 +200,11 @@ def read_refines(root):
             ans[r[1:]].append(meta)
     return ans
 
+
 def refdef(prop, val, scheme=None):
     return (prop, val, scheme)
 
+
 def set_refines(elem, existing_refines, *new_refines):
     eid = ensure_id(elem)
     remove_refines(elem, existing_refines)
@@ -181,6 +220,8 @@ def set_refines(elem, existing_refines, *new_refines):
 # }}}
 
 # Identifiers {{{
+
+
 def parse_identifier(ident, val, refines):
     idid = ident.get('id')
     refines = refines[idid]
@@ -221,6 +262,7 @@ def parse_identifier(ident, val, refines):
     prefix, rest = val.partition(':')[::2]
     return finalize(prefix, rest)
 
+
 def read_identifiers(root, prefixes, refines):
     ans = defaultdict(list)
     for ident in XPath('./opf:metadata/dc:identifier')(root):
@@ -231,6 +273,7 @@ def read_identifiers(root, prefixes, refines):
                 ans[scheme].append(val)
     return ans
 
+
 def set_identifiers(root, prefixes, refines, new_identifiers, force_identifiers=False):
     uid = root.get('unique-identifier')
     package_identifier = None
@@ -256,6 +299,7 @@ def set_identifiers(root, prefixes, refines, new_identifiers, force_identifiers=
             p = package_identifier.getparent()
             p.insert(p.index(package_identifier), ident)
 
+
 def identifier_writer(name):
     def writer(root, prefixes, refines, ival=None):
         uid = root.get('unique-identifier')
@@ -277,6 +321,8 @@ def identifier_writer(name):
                 p = package_identifier.getparent()
                 p.insert(p.index(package_identifier), ident)
     return writer
+
+
 set_application_id = identifier_writer('calibre')
 set_uuid = identifier_writer('uuid')
 
@@ -284,6 +330,7 @@ set_uuid = identifier_writer('uuid')
 
 # Title {{{
 
+
 def find_main_title(root, refines, remove_blanks=False):
     first_title = main_title = None
     for title in XPath('./opf:metadata/dc:title')(root):
@@ -301,11 +348,13 @@ def find_main_title(root, refines, remove_blanks=False):
         main_title = first_title
     return main_title
 
+
 @simple_text
 def read_title(root, prefixes, refines):
     main_title = find_main_title(root, refines)
     return None if main_title is None else main_title.text.strip()
 
+
 @simple_text
 def read_title_sort(root, prefixes, refines):
     main_title = find_main_title(root, refines)
@@ -319,6 +368,7 @@ def read_title_sort(root, prefixes, refines):
         if ans:
             return ans
 
+
 def set_title(root, prefixes, refines, title, title_sort=None):
     main_title = find_main_title(root, refines, remove_blanks=True)
     if main_title is None:
@@ -334,6 +384,8 @@ def set_title(root, prefixes, refines, title, title_sort=None):
 # }}}
 
 # Languages {{{
+
+
 def read_languages(root, prefixes, refines):
     ans = []
     for lang in XPath('./opf:metadata/dc:language')(root):
@@ -342,6 +394,7 @@ def read_languages(root, prefixes, refines):
             ans.append(val)
     return uniq(ans)
 
+
 def set_languages(root, prefixes, refines, languages):
     opf_languages = []
     for lang in XPath('./opf:metadata/dc:language')(root):
@@ -362,8 +415,10 @@ def set_languages(root, prefixes, refines, languages):
 
 # Creator/Contributor {{{
 
+
 Author = namedtuple('Author', 'name sort')
 
+
 def is_relators_role(props, q):
     role = props.get('role')
     if role:
@@ -371,6 +426,7 @@ def is_relators_role(props, q):
         return role.lower() == q and (scheme_ns is None or (scheme_ns, scheme) == (reserved_prefixes['marc'], 'relators'))
     return False
 
+
 def read_authors(root, prefixes, refines):
     roled_authors, unroled_authors = [], []
 
@@ -400,27 +456,30 @@ def read_authors(root, prefixes, refines):
 
     return uniq(roled_authors or unroled_authors)
 
+
 def set_authors(root, prefixes, refines, authors):
     ensure_prefix(root, prefixes, 'marc')
     for item in XPath('./opf:metadata/dc:creator')(root):
         props = properties_for_id_with_scheme(item.get('id'), prefixes, refines)
         opf_role = item.get(OPF('role'))
-        if (is_relators_role(props, 'aut')) or (opf_role and opf_role.lower() != 'aut'):
+        if (opf_role and opf_role.lower() != 'aut') or (props.get('role') and not is_relators_role(props, 'aut')):
             continue
         remove_element(item, refines)
     metadata = XPath('./opf:metadata')(root)[0]
     for author in authors:
-        a = metadata.makeelement(DC('creator'))
-        aid = ensure_id(a)
-        a.text = author.name
-        metadata.append(a)
-        m = metadata.makeelement(OPF('meta'), attrib={'refines':'#'+aid, 'property':'role', 'scheme':'marc:relators'})
-        m.text = 'aut'
-        metadata.append(m)
-        if author.sort:
-            m = metadata.makeelement(OPF('meta'), attrib={'refines':'#'+aid, 'property':'file-as'})
-            m.text = author.sort
+        if author.name:
+            a = metadata.makeelement(DC('creator'))
+            aid = ensure_id(a)
+            a.text = author.name
+            metadata.append(a)
+            m = metadata.makeelement(OPF('meta'), attrib={'refines':'#'+aid, 'property':'role', 'scheme':'marc:relators'})
+            m.text = 'aut'
             metadata.append(m)
+            if author.sort:
+                m = metadata.makeelement(OPF('meta'), attrib={'refines':'#'+aid, 'property':'file-as'})
+                m.text = author.sort
+                metadata.append(m)
+
 
 def read_book_producers(root, prefixes, refines):
     ans = []
@@ -437,26 +496,29 @@ def read_book_producers(root, prefixes, refines):
                 ans.append(normalize_whitespace(val))
     return ans
 
+
 def set_book_producers(root, prefixes, refines, producers):
     for item in XPath('./opf:metadata/dc:contributor')(root):
         props = properties_for_id_with_scheme(item.get('id'), prefixes, refines)
         opf_role = item.get(OPF('role'))
-        if (is_relators_role(props, 'bkp')) or (opf_role and opf_role.lower() != 'bkp'):
+        if (opf_role and opf_role.lower() != 'bkp') or (props.get('role') and not is_relators_role(props, 'bkp')):
             continue
         remove_element(item, refines)
     metadata = XPath('./opf:metadata')(root)[0]
     for bkp in producers:
-        a = metadata.makeelement(DC('contributor'))
-        aid = ensure_id(a)
-        a.text = bkp
-        metadata.append(a)
-        m = metadata.makeelement(OPF('meta'), attrib={'refines':'#'+aid, 'property':'role', 'scheme':'marc:relators'})
-        m.text = 'bkp'
-        metadata.append(m)
+        if bkp:
+            a = metadata.makeelement(DC('contributor'))
+            aid = ensure_id(a)
+            a.text = bkp
+            metadata.append(a)
+            m = metadata.makeelement(OPF('meta'), attrib={'refines':'#'+aid, 'property':'role', 'scheme':'marc:relators'})
+            m.text = 'bkp'
+            metadata.append(m)
 # }}}
 
 # Dates {{{
 
+
 def parse_date(raw, is_w3cdtf=False):
     raw = raw.strip()
     if is_w3cdtf:
@@ -469,6 +531,7 @@ def parse_date(raw, is_w3cdtf=False):
             ans = fix_only_date(ans)
     return ans
 
+
 def read_pubdate(root, prefixes, refines):
     for date in XPath('./opf:metadata/dc:date')(root):
         val = (date.text or '').strip()
@@ -478,6 +541,7 @@ def read_pubdate(root, prefixes, refines):
             except Exception:
                 continue
 
+
 def set_pubdate(root, prefixes, refines, val):
     for date in XPath('./opf:metadata/dc:date')(root):
         remove_element(date, refines)
@@ -488,6 +552,7 @@ def set_pubdate(root, prefixes, refines, val):
         d.text = val
         m.append(d)
 
+
 def read_timestamp(root, prefixes, refines):
     pq = '%s:timestamp' % CALIBRE_PREFIX
     sq = '%s:w3cdtf' % reserved_prefixes['dcterms']
@@ -509,6 +574,7 @@ def read_timestamp(root, prefixes, refines):
             except Exception:
                 continue
 
+
 def set_timestamp(root, prefixes, refines, val):
     ensure_prefix(root, prefixes, 'calibre', CALIBRE_PREFIX)
     ensure_prefix(root, prefixes, 'dcterms')
@@ -542,6 +608,7 @@ def read_last_modified(root, prefixes, refines):
 
 # Comments {{{
 
+
 def read_comments(root, prefixes, refines):
     ans = ''
     for dc in XPath('./opf:metadata/dc:description')(root):
@@ -549,6 +616,7 @@ def read_comments(root, prefixes, refines):
             ans += '\n' + dc.text.strip()
     return ans.strip()
 
+
 def set_comments(root, prefixes, refines, val):
     for dc in XPath('./opf:metadata/dc:description')(root):
         remove_element(dc, refines)
@@ -563,12 +631,14 @@ def set_comments(root, prefixes, refines, val):
 
 # Publisher {{{
 
+
 @simple_text
 def read_publisher(root, prefixes, refines):
     for dc in XPath('./opf:metadata/dc:publisher')(root):
         if dc.text:
             return dc.text
 
+
 def set_publisher(root, prefixes, refines, val):
     for dc in XPath('./opf:metadata/dc:publisher')(root):
         remove_element(dc, refines)
@@ -583,6 +653,7 @@ def set_publisher(root, prefixes, refines, val):
 
 # Tags {{{
 
+
 def read_tags(root, prefixes, refines):
     ans = []
     for dc in XPath('./opf:metadata/dc:subject')(root):
@@ -590,6 +661,7 @@ def read_tags(root, prefixes, refines):
             ans.extend(map(normalize_whitespace, dc.text.split(',')))
     return uniq(filter(None, ans))
 
+
 def set_tags(root, prefixes, refines, val):
     for dc in XPath('./opf:metadata/dc:subject')(root):
         remove_element(dc, refines)
@@ -605,6 +677,7 @@ def set_tags(root, prefixes, refines, val):
 
 # Rating {{{
 
+
 def read_rating(root, prefixes, refines):
     pq = '%s:rating' % CALIBRE_PREFIX
     for meta in XPath('./opf:metadata/opf:meta[@property]')(root):
@@ -624,6 +697,7 @@ def read_rating(root, prefixes, refines):
             except Exception:
                 continue
 
+
 def set_rating(root, prefixes, refines, val):
     pq = '%s:rating' % CALIBRE_PREFIX
     for meta in XPath('./opf:metadata/opf:meta[@name="calibre:rating"]')(root):
@@ -642,6 +716,7 @@ def set_rating(root, prefixes, refines, val):
 
 # Series {{{
 
+
 def read_series(root, prefixes, refines):
     series_index = 1.0
     for meta in XPath('./opf:metadata/opf:meta[@property="belongs-to-collection" and @id]')(root):
@@ -666,6 +741,7 @@ def read_series(root, prefixes, refines):
             return s, series_index
     return None, series_index
 
+
 def set_series(root, prefixes, refines, series, series_index):
     for meta in XPath('./opf:metadata/opf:meta[@name="calibre:series" or @name="calibre:series_index"]')(root):
         remove_element(meta, refines)
@@ -681,6 +757,7 @@ def set_series(root, prefixes, refines, series, series_index):
 
 # User metadata {{{
 
+
 def dict_reader(name, load=json.loads, try2=True):
     pq = '%s:%s' % (CALIBRE_PREFIX, name)
 
@@ -708,9 +785,11 @@ def dict_reader(name, load=json.loads, try2=True):
                         continue
     return reader
 
+
 read_user_categories = dict_reader('user_categories')
 read_author_link_map = dict_reader('author_link_map')
 
+
 def dict_writer(name, serialize=dump_dict, remove2=True):
     pq = '%s:%s' % (CALIBRE_PREFIX, name)
 
@@ -730,9 +809,11 @@ def dict_writer(name, serialize=dump_dict, remove2=True):
             m.append(d)
     return writer
 
+
 set_user_categories = dict_writer('user_categories')
 set_author_link_map = dict_writer('author_link_map')
 
+
 def deserialize_user_metadata(val):
     val = json.loads(val, object_hook=from_json)
     ans = {}
@@ -740,8 +821,11 @@ def deserialize_user_metadata(val):
         decode_is_multiple(fm)
         ans[name] = fm
     return ans
+
+
 read_user_metadata3 = dict_reader('user_metadata', load=deserialize_user_metadata, try2=False)
 
+
 def read_user_metadata2(root):
     ans = {}
     for meta in XPath('./opf:metadata/opf:meta[starts-with(@name, "calibre:user_metadata:")]')(root):
@@ -761,14 +845,18 @@ def read_user_metadata2(root):
             continue
     return ans
 
+
 def read_user_metadata(root, prefixes, refines):
     return read_user_metadata3(root, prefixes, refines) or read_user_metadata2(root)
 
+
 def serialize_user_metadata(val):
     return json.dumps(object_to_unicode(val), ensure_ascii=False, default=to_json, indent=2, sort_keys=True)
 
+
 set_user_metadata3 = dict_writer('user_metadata', serialize=serialize_user_metadata, remove2=False)
 
+
 def set_user_metadata(root, prefixes, refines, val):
     for meta in XPath('./opf:metadata/opf:meta[starts-with(@name, "calibre:user_metadata:")]')(root):
         remove_element(meta, refines)
@@ -782,7 +870,57 @@ def set_user_metadata(root, prefixes, refines, val):
 
 # }}}
 
-def read_metadata(root):
+# Covers {{{
+
+
+def read_raster_cover(root, prefixes, refines):
+
+    def get_href(item):
+        mt = item.get('media-type')
+        if mt and 'xml' not in mt and 'html' not in mt:
+            href = item.get('href')
+            if href:
+                return href
+
+    for item in items_with_property(root, 'cover-image', prefixes):
+        href = get_href(item)
+        if href:
+            return href
+
+    for item_id in XPath('./opf:metadata/opf:meta[@name="cover"]/@content')(root):
+        for item in XPath('./opf:manifest/opf:item[@id and @href and @media-type]')(root):
+            if item.get('id') == item_id:
+                href = get_href(item)
+                if href:
+                    return href
+
+
+def ensure_is_only_raster_cover(root, prefixes, refines, raster_cover_item_href):
+    for item in XPath('./opf:metadata/opf:meta[@name="cover"]')(root):
+        remove_element(item, refines)
+    for item in items_with_property(root, 'cover-image', prefixes):
+        prop = normalize_whitespace(item.get('properties').replace('cover-image', ''))
+        if prop:
+            item.set('properties', prop)
+        else:
+            del item.attrib['properties']
+    for item in XPath('./opf:manifest/opf:item')(root):
+        if item.get('href') == raster_cover_item_href:
+            item.set('properties', normalize_whitespace((item.get('properties') or '') + ' cover-image'))
+
+# }}}
+
+# Reading/setting Metadata objects {{{
+
+
+def first_spine_item(root, prefixes, refines):
+    for i in XPath('./opf:spine/opf:itemref/@idref')(root):
+        for item in XPath('./opf:manifest/opf:item')(root):
+            if item.get('id') == i:
+                return item.get('href') or None
+
+
+def read_metadata(root, ver=None, return_extra_data=False):
     ans = Metadata(_('Unknown'), [_('Unknown')])
     prefixes, refines = read_prefixes(root), read_refines(root)
     identifiers = read_identifiers(root, prefixes, refines)
@@ -805,7 +943,8 @@ def read_metadata(root):
     ans.author_sort = authors_to_string(aus) or ans.author_sort
     bkp = read_book_producers(root, prefixes, refines)
     if bkp:
-        ans.book_producer = bkp[0]
+        if bkp[0]:
+            ans.book_producer = bkp[0]
     pd = read_pubdate(root, prefixes, refines)
     if not is_date_undefined(pd):
         ans.pubdate = pd
@@ -826,13 +965,17 @@ def read_metadata(root):
     ans.user_categories = read_user_categories(root, prefixes, refines) or ans.user_categories
     for name, fm in (read_user_metadata(root, prefixes, refines) or {}).iteritems():
         ans.set_user_metadata(name, fm)
+    if return_extra_data:
+        ans = ans, ver, read_raster_cover(root, prefixes, refines), first_spine_item(root, prefixes, refines)
     return ans
 
+
 def get_metadata(stream):
     root = parse_opf(stream)
     return read_metadata(root)
 
-def apply_metadata(root, mi, cover_prefix='', cover_data=None, apply_null=False, update_timestamp=False, force_identifiers=False):
+
+def apply_metadata(root, mi, cover_prefix='', cover_data=None, apply_null=False, update_timestamp=False, force_identifiers=False, add_missing_cover=True):
     prefixes, refines = read_prefixes(root), read_refines(root)
     current_mi = read_metadata(root)
     if apply_null:
@@ -902,8 +1045,19 @@ def apply_metadata(root, mi, cover_prefix='', cover_data=None, apply_null=False,
             current_user_metadata[key] = meta
 
     set_user_metadata(root, prefixes, refines, current_user_metadata)
+    raster_cover = read_raster_cover(root, prefixes, refines)
+    if not raster_cover and cover_data and add_missing_cover:
+        if cover_prefix and not cover_prefix.endswith('/'):
+            cover_prefix += '/'
+        name = cover_prefix + 'cover.jpg'
+        i = create_manifest_item(root, name, 'cover')
+        if i is not None:
+            ensure_is_only_raster_cover(root, prefixes, refines, name)
+            raster_cover = name
 
     pretty_print_opf(root)
+    return raster_cover
+
 
 def set_metadata(stream, mi, cover_prefix='', cover_data=None, apply_null=False, update_timestamp=False, force_identifiers=False, add_missing_cover=True):
     root = parse_opf(stream)
@@ -911,6 +1065,8 @@ def set_metadata(stream, mi, cover_prefix='', cover_data=None, apply_null=False,
         root, mi, cover_prefix=cover_prefix, cover_data=cover_data,
         apply_null=apply_null, update_timestamp=update_timestamp,
         force_identifiers=force_identifiers)
+# }}}
+
 
 if __name__ == '__main__':
     import sys
