@@ -15,7 +15,6 @@ from calibre import as_unicode, browser, random_user_agent
 from calibre.ebooks.metadata import check_isbn
 from calibre.ebooks.metadata.book.base import Metadata
 from calibre.ebooks.metadata.sources.base import Option, Source, fixauthors, fixcase
-from calibre.ebooks.metadata.sources.update import search_engines_module
 from calibre.utils.localization import canonicalize_lang
 from calibre.utils.random_ua import accept_header_for_ua, all_user_agents
 
@@ -533,6 +532,12 @@ class Worker(Thread):  # Get details {{{
                             ' @class="emptyClear" or @id="collapsePS" or'
                             ' @id="expandPS"]'):
             c.getparent().remove(c)
+        for b in desc.xpath('descendant::b[@style]'):
+            # Bing highlights search results
+            s = b.get('style', '')
+            if 'color' in s:
+                b.tag = 'span'
+                del b.attrib['style']
 
         for a in desc.xpath('descendant::a[@href]'):
             del a.attrib['href']
@@ -821,7 +826,7 @@ class Worker(Thread):  # Get details {{{
 class Amazon(Source):
 
     name = 'Amazon.com'
-    version = (1, 1, 0)
+    version = (1, 2, 0)
     minimum_calibre_version = (2, 82, 0)
     description = _('Downloads metadata and covers from Amazon')
 
@@ -1249,6 +1254,7 @@ class Amazon(Source):
     # }}}
 
     def search_search_engine(self, br, testing, log, abort, title, authors, identifiers, timeout):  # {{{
+        from calibre.ebooks.metadata.sources.update import search_engines_module
         terms, domain = self.create_query(log, title=title, authors=authors,
                                           identifiers=identifiers, for_amazon=False)
         site = self.referrer_for_domain(
@@ -1300,6 +1306,7 @@ class Amazon(Source):
         udata = self._get_book_url(identifiers)
         br = self.browser
         log('User-agent:', br.current_user_agent())
+        log('Server:', self.server)
         if testing:
             print('User-agent:', br.current_user_agent())
         if udata is not None and not self.use_search_engine:
