@@ -9,14 +9,17 @@ __docformat__ = 'restructuredtext en'
 
 from calibre.ebooks.metadata.sources.base import Source
 
+
 class OpenLibrary(Source):
 
     name = 'Open Library'
+    version = (1, 0, 0)
+    minimum_calibre_version = (2, 80, 0)
     description = _('Downloads covers from The Open Library')
 
     capabilities = frozenset(['cover'])
 
-    OPENLIBRARY = 'http://covers.openlibrary.org/b/isbn/%s-L.jpg?default=false'
+    OPENLIBRARY = 'https://covers.openlibrary.org/b/isbn/%s-L.jpg?default=false'
 
     def download_cover(self, log, result_queue, abort,
             title=None, authors=None, identifiers={}, timeout=30, get_best_cover=False):
@@ -32,4 +35,3 @@ class OpenLibrary(Source):
                 log.error('No cover for ISBN: %r found'%isbn)
             else:
                 log.exception('Failed to download cover for ISBN:', isbn)
-
