@@ -17,6 +17,7 @@ from calibre.ebooks.metadata import check_isbn
 from calibre.ebooks.metadata.sources.base import create_log, get_cached_cover_urls
 from calibre.ebooks.metadata.sources.prefs import msprefs
 
+
 def isbn_test(isbn):
     isbn_ = check_isbn(isbn)
 
@@ -29,6 +30,7 @@ def isbn_test(isbn):
 
     return test
 
+
 def title_test(title, exact=False):
 
     title = title.lower()
@@ -43,6 +45,7 @@ def title_test(title, exact=False):
 
     return test
 
+
 def authors_test(authors):
     authors = set([x.lower() for x in authors])
 
@@ -67,6 +70,7 @@ def authors_test(authors):
 
     return test
 
+
 def tags_test(tags):
     tags = set([x.lower() for x in tags])
 
@@ -79,6 +83,7 @@ def tags_test(tags):
 
     return test
 
+
 def series_test(series, series_index):
     series = series.lower()
 
@@ -96,6 +101,7 @@ def series_test(series, series_index):
 
     return test
 
+
 def comments_test(sentinel):
 
     def test(mi):
@@ -106,6 +112,7 @@ def comments_test(sentinel):
         return False
     return test
 
+
 def pubdate_test(year, month, day):
 
     def test(mi):
@@ -116,6 +123,7 @@ def pubdate_test(year, month, day):
 
     return test
 
+
 def init_test(tdir_name):
     tdir = tempfile.gettempdir()
     lf = os.path.join(tdir, tdir_name.replace(' ', '')+'_identify_test.txt')
@@ -123,6 +131,11 @@ def init_test(tdir_name):
     abort = Event()
     return tdir, lf, log, abort
 
+
+def dump_log(lf):
+    prints(open(lf, 'rb').read().decode('utf-8'))
+
+
 def test_identify(tests):  # {{{
     '''
     :param tests: List of 2-tuples. Each two tuple is of the form (args,
@@ -139,6 +152,7 @@ def test_identify(tests):  # {{{
     times = []
 
     for kwargs, test_funcs in tests:
+        log('')
         log('#'*80)
         log('### Running test with:', kwargs)
         log('#'*80)
@@ -157,6 +171,8 @@ def test_identify(tests):  # {{{
 
         for i, mi in enumerate(results):
             prints('*'*30, 'Relevance:', i, '*'*30)
+            if mi.rating:
+                mi.rating *= 2
             prints(mi)
             prints('\nCached cover URLs    :',
                     [x[0].name for x in get_cached_cover_urls(mi)])
@@ -175,6 +191,8 @@ def test_identify(tests):  # {{{
         if not possibles:
             prints('ERROR: No results that passed all tests were found')
             prints('Log saved to', lf)
+            log.close()
+            dump_log(lf)
             raise SystemExit(1)
 
         if results[0] is not possibles[0]:
@@ -189,8 +207,9 @@ def test_identify(tests):  # {{{
 
 # }}}
 
-def test_identify_plugin(name, tests, modify_plugin=lambda plugin:None,
-        fail_missing_meta=True):  # {{{
+
+def test_identify_plugin(name, tests, modify_plugin=lambda plugin:None,  # {{{
+        fail_missing_meta=True):
     '''
     :param name: Plugin name
     :param tests: List of 2-tuples. Each two tuple is of the form (args,
@@ -213,6 +232,10 @@ def test_identify_plugin(name, tests, modify_plugin=lambda plugin:None,
 
     times = []
     for kwargs, test_funcs in tests:
+        log('')
+        log('#'*80)
+        log('### Running test with:', kwargs)
+        log('#'*80)
         prints('Running test with:', kwargs)
         rq = Queue()
         args = (log, rq, abort)
@@ -245,6 +268,8 @@ def test_identify_plugin(name, tests, modify_plugin=lambda plugin:None,
 
         for i, mi in enumerate(results):
             prints('*'*30, 'Relevance:', i, '*'*30)
+            if mi.rating:
+                mi.rating *= 2
             prints(mi)
             prints('\nCached cover URL    :',
                     plugin.get_cached_cover_url(mi.identifiers))
@@ -263,6 +288,8 @@ def test_identify_plugin(name, tests, modify_plugin=lambda plugin:None,
         if not possibles:
             prints('ERROR: No results that passed all tests were found')
             prints('Log saved to', lf)
+            log.close()
+            dump_log(lf)
             raise SystemExit(1)
 
         good = [x for x in possibles if plugin.test_fields(x) is
@@ -309,4 +336,3 @@ def test_identify_plugin(name, tests, modify_plugin=lambda plugin:None,
     if os.stat(lf).st_size > 10:
         prints('There were some errors/warnings, see log', lf)
 # }}}
-
