@@ -38,6 +38,7 @@ XML_DOCS = OEB_DOCS | {SVG_MIME}
 # with 4 digits
 to_ref = partial(to_base, base=32, min_num_digits=4)
 
+
 class KF8Writer(object):
 
     def __init__(self, oeb, opts, resources):
@@ -154,11 +155,12 @@ class KF8Writer(object):
     def extract_css_into_flows(self):
         inlines = defaultdict(list)  # Ensure identical <style>s not repeated
         sheets = {}
+        passthrough = getattr(self.opts, 'mobi_passthrough', False)
 
         for item in self.oeb.manifest:
             if item.media_type in OEB_STYLES:
                 sheet = self.data(item)
-                if not self.opts.expand_css and hasattr(item.data, 'cssText'):
+                if not passthrough and not self.opts.expand_css and hasattr(item.data, 'cssText'):
                     condense_sheet(sheet)
                 sheets[item.href] = len(self.flows)
                 self.flows.append(sheet)
@@ -279,6 +281,7 @@ class KF8Writer(object):
             root = self.data(item)
             aidbase = i * int(1e6)
             j = 0
+
             def in_table(elem):
                 p = elem.getparent()
                 if p is None:
@@ -489,7 +492,7 @@ class KF8Writer(object):
             self.guide_table.sort(key=lambda x:x.type)  # Needed by the Kindle
             self.guide_records = GuideIndex(self.guide_table)()
 
+
 def create_kf8_book(oeb, opts, resources, for_joint=False):
     writer = KF8Writer(oeb, opts, resources)
     return KF8Book(writer, for_joint=for_joint)
-
