@@ -28,6 +28,7 @@ Entry = namedtuple('IndexEntry', 'index start length depth parent '
         'first_child last_child title action start_offset length_offset '
         'text_record_length')
 
+
 def fill_entry(entry, start_offset, text_record_length):
     length_offset = start_offset + entry.length
     if start_offset < 0:
@@ -38,6 +39,7 @@ def fill_entry(entry, start_offset, text_record_length):
     return Entry(*(entry[:-4] + (action, start_offset, length_offset,
         text_record_length)))
 
+
 def populate_strand(parent, entries):
     ans = [parent]
     children = [c for c in entries if c.parent == parent.index]
@@ -53,8 +55,7 @@ def populate_strand(parent, entries):
         current_index = parent.index
         siblings = []
         for entry in list(entries):
-            if (entry.depth == parent.depth and entry.parent == parent.parent
-                    and entry.index == current_index+1):
+            if (entry.depth == parent.depth and entry.parent == parent.parent and entry.index == current_index+1):
                 current_index += 1
                 entries.remove(entry)
                 children = [c for c in entries if c.parent == entry.index]
@@ -66,6 +67,7 @@ def populate_strand(parent, entries):
         ans += siblings
     return ans
 
+
 def separate_strands(entries):
     ans = []
     while entries:
@@ -79,6 +81,7 @@ def separate_strands(entries):
         ans.append(layers)
     return ans
 
+
 def collect_indexing_data(entries, text_record_lengths):
     ''' For every text record calculate which index entries start, end, span or
     are contained within that record. Arrange these entries in 'strands'. '''
@@ -106,9 +109,11 @@ def collect_indexing_data(entries, text_record_lengths):
 
     return data
 
+
 class NegativeStrandIndex(Exception):
     pass
 
+
 def encode_strands_as_sequences(strands, tbs_type=8):
     ''' Encode the list of strands for a single text record into a list of
     sequences, ready to be converted into TBS bytes.    '''
@@ -171,15 +176,17 @@ def encode_strands_as_sequences(strands, tbs_type=8):
 
     return ans
 
+
 def sequences_to_bytes(sequences):
     ans = []
     flag_size = 3
     for val, extra in sequences:
         ans.append(encode_tbs(val, extra, flag_size))
         flag_size = 4  # only the first sequence has flag size 3 as all
-                      # subsequent sequences could need the 0b1000 flag
+        # subsequent sequences could need the 0b1000 flag
     return b''.join(ans)
 
+
 def calculate_all_tbs(indexing_data, tbs_type=8):
     rmap = {}
     for i, strands in enumerate(indexing_data):
@@ -188,6 +195,7 @@ def calculate_all_tbs(indexing_data, tbs_type=8):
         rmap[i+1] = tbs_bytes
     return rmap
 
+
 def apply_trailing_byte_sequences(index_table, records, text_record_lengths):
     entries = tuple(Entry(r['index'], r['offset'], r['length'], r['depth'],
         r.get('parent', None), r.get('first_child', None), r.get('last_child',
