@@ -13,9 +13,11 @@ try:
     from calibre.utils.serve_coffee import serve
 except ImportError:
     import init_calibre
-    if False: init_calibre, serve
+    if False:
+        init_calibre, serve
     from calibre.utils.serve_coffee import serve
 
+
 def run_devel_server():
     os.chdir(os.path.dirname(os.path.abspath(__file__)))
     serve(resources={'cfi.coffee':'../cfi.coffee', '/':'index.html'})
