@@ -16,6 +16,7 @@ from collections import namedtuple
 from calibre import guess_type, replace_entities
 from calibre.ebooks.chardet import xml_to_unicode
 
+
 def character_count(html):
     ''' Return the number of "significant" text characters in a HTML string. '''
     count = 0
@@ -24,6 +25,7 @@ def character_count(html):
         count += len(strip_space.sub(' ', match.group()))-2
     return count
 
+
 def anchor_map(html):
     ''' Return map of all anchor names to their offsets in the html '''
     ans = {}
@@ -33,6 +35,7 @@ def anchor_map(html):
         ans[anchor] = ans.get(anchor, match.start())
     return ans
 
+
 def all_links(html):
     ''' Return set of all links in the file '''
     ans = set()
@@ -41,6 +44,7 @@ def all_links(html):
         ans.add(replace_entities(match.group(2)))
     return ans
 
+
 class SpineItem(unicode):
 
     def __new__(cls, path, mime_type=None, read_anchor_map=True,
@@ -82,6 +86,7 @@ class SpineItem(unicode):
         obj.is_single_page = None
         return obj
 
+
 class IndexEntry(object):
 
     def __init__(self, spine, toc_entry, num):
@@ -111,9 +116,7 @@ class IndexEntry(object):
         potential_enders = [i for i in all_entries if
                 i.depth <= self.depth and
                 (
-                    (i.spine_pos == self.spine_pos and i.anchor_pos >
-                                                            self.anchor_pos)
-                    or
+                    (i.spine_pos == self.spine_pos and i.anchor_pos > self.anchor_pos) or
                     i.spine_pos > self.spine_pos
                 )]
         if potential_enders:
@@ -125,6 +128,7 @@ class IndexEntry(object):
             self.end_spine_pos = self.spine_count - 1
             self.end_anchor = None
 
+
 def create_indexing_data(spine, toc):
     if not toc:
         return
