@@ -14,6 +14,7 @@ try:
 except ImportError:
     raise RuntimeError('You need cssutils >= 0.9.9 for calibre')
 from cssutils import profile as cssprofiles, CSSParser
+from tinycss.fonts3 import parse_font, serialize_font_family
 
 DEFAULTS = {'azimuth': 'center', 'background-attachment': 'scroll',  # {{{
             'background-color': 'transparent', 'background-image': 'none',
@@ -59,6 +60,7 @@ DEFAULTS = {'azimuth': 'center', 'background-attachment': 'scroll',  # {{{
 EDGES = ('top', 'right', 'bottom', 'left')
 BORDER_PROPS = ('color', 'style', 'width')
 
+
 def normalize_edge(name, cssvalue):
     style = {}
     if isinstance(cssvalue, PropertyValue):
@@ -88,6 +90,7 @@ def normalize_edge(name, cssvalue):
 
 def simple_normalizer(prefix, names, check_inherit=True):
     composition = tuple('%s-%s' %(prefix, n) for n in names)
+
     @wraps(normalize_simple_composition)
     def wrapper(name, cssvalue):
         return normalize_simple_composition(name, cssvalue, composition, check_inherit=check_inherit)
@@ -113,57 +116,26 @@ def normalize_simple_composition(name, cssvalue, composition, check_inherit=True
 
 font_composition = ('font-style', 'font-variant', 'font-weight', 'font-size', 'line-height', 'font-family')
 
+
 def normalize_font(cssvalue, font_family_as_list=False):
     # See https://developer.mozilla.org/en-US/docs/Web/CSS/font
     composition = font_composition
     val = cssvalue.cssText
     if val == 'inherit':
-        return {k:'inherit' for k in composition}
-    if val in {'caption', 'icon', 'menu', 'message-box', 'small-caption', 'status-bar'}:
-        return {k:DEFAULTS[k] for k in composition}
-    if getattr(cssvalue, 'length', 1) < 2:
-        return {}  # Mandatory to define both font size and font family
-    style = {k:DEFAULTS[k] for k in composition}
-    families = []
-    vals = [x.cssText for x in cssvalue]
-    found_font_size = False
-    while vals:
-        text = vals.pop()
-        if not families and text == 'inherit':
-            families.append(text)
-            continue
-        if cssprofiles.validate('line-height', text):
-            if not vals or not cssprofiles.validate('font-size', vals[-1]):
-                if cssprofiles.validate('font-size', text):
-                    style['font-size'] = text
-                    found_font_size = True
-                    break
-                return {}  # must have font-size here
-            style['line-height'] = text
-            style['font-size'] = vals.pop()
-            found_font_size = True
-            break
-        if cssprofiles.validate('font-size', text):
-            style['font-size'] = text
-            found_font_size = True
-            break
-        if families == ['inherit']:
-            return {}  # Cannot have multiple font-families if the last one if inherit
-        families.insert(0, text)
-    if not families or not found_font_size:
-        return {}  # font-family required
-    style['font-family'] = families if font_family_as_list else ', '.join(families)
-    props = ['font-style', 'font-variant', 'font-weight']
-    while vals:
-        for i, prop in enumerate(tuple(props)):
-            if cssprofiles.validate(prop, vals[0]):
-                props.pop(i)
-                style[prop] = vals.pop(0)
-                break
-        else:
-            return {}  # unrecognized value
+        ans = {k:'inherit' for k in composition}
+    elif val in {'caption', 'icon', 'menu', 'message-box', 'small-caption', 'status-bar'}:
+        ans = {k:DEFAULTS[k] for k in composition}
+    else:
+        ans = {k:DEFAULTS[k] for k in composition}
+        ans.update(parse_font(val))
+    if font_family_as_list:
+        if isinstance(ans['font-family'], basestring):
+            ans['font-family'] = [x.strip() for x in ans['font-family'].split(',')]
+    else:
+        if not isinstance(ans['font-family'], basestring):
+            ans['font-family'] = serialize_font_family(ans['font-family'])
+    return ans
 
-    return style
 
 def normalize_border(name, cssvalue):
     style = normalizers['border-' + EDGES[0]]('border-' + EDGES[0], cssvalue)
@@ -192,6 +164,8 @@ SHORTHAND_DEFAULTS = {
 }
 
 _safe_parser = None
+
+
 def safe_parser():
     global _safe_parser
     if _safe_parser is None:
@@ -199,6 +173,7 @@ def safe_parser():
         _safe_parser = CSSParser(loglevel=logging.CRITICAL, validate=False)
     return _safe_parser
 
+
 def normalize_filter_css(props):
     ans = set()
     p = safe_parser()
@@ -211,6 +186,7 @@ def normalize_filter_css(props):
             ans |= set(n(prop, cssvalue))
     return ans
 
+
 def condense_edge(vals):
     edges = {x.name.rpartition('-')[-1]:x.value for x in vals}
     if len(edges) != 4 or set(edges) != {'left', 'top', 'right', 'bottom'}:
@@ -232,6 +208,7 @@ def condense_edge(vals):
             return ce['top']
         return ' '.join(ce[x] for x in ('top', 'left'))
 
+
 def simple_condenser(prefix, func):
     @wraps(func)
     def condense_simple(style, props):
@@ -242,6 +219,7 @@ def simple_condenser(prefix, func):
             style.setProperty(prefix, cp)
     return condense_simple
 
+
 def condense_border(style, props):
     prop_map = {p.name:p for p in props}
     edge_vals = []
@@ -279,11 +257,13 @@ def condense_rule(style):
         if len(vals) > 1 and {x.priority for x in vals} == {''}:
             condensers[prefix[:-1]](style, vals)
 
+
 def condense_sheet(sheet):
     for rule in sheet.cssRules:
         if rule.type == rule.STYLE_RULE:
             condense_rule(rule.style)
 
+
 def test_normalization(return_tests=False):  # {{{
     import unittest
     from cssutils import parseStyle
@@ -300,15 +280,16 @@ def test_normalization(return_tests=False):  # {{{
                 return ans
 
             for raw, expected in {
-                'some_font': {}, 'none': {}, 'inherit':{k:'inherit' for k in font_composition},
+                'some_font': {'font-family':'some_font'}, 'inherit':{k:'inherit' for k in font_composition},
                 '1.2pt/1.4 A_Font': {'font-family':'A_Font', 'font-size':'1.2pt', 'line-height':'1.4'},
-                'bad font': {}, '10% serif': {'font-family':'serif', 'font-size':'10%'},
+                'bad font': {'font-family':'"bad font"'}, '10% serif': {'font-family':'serif', 'font-size':'10%'},
                 '12px "My Font", serif': {'font-family':'"My Font", serif', 'font-size': '12px'},
                 'normal 0.6em/135% arial,sans-serif': {'font-family': 'arial, sans-serif', 'font-size': '0.6em', 'line-height':'135%', 'font-style':'normal'},
                 'bold italic large serif': {'font-family':'serif', 'font-weight':'bold', 'font-style':'italic', 'font-size':'large'},
                 'bold italic small-caps larger/normal serif':
                 {'font-family':'serif', 'font-weight':'bold', 'font-style':'italic', 'font-size':'larger',
                  'line-height':'normal', 'font-variant':'small-caps'},
+                '2em A B': {'font-family': '"A B"', 'font-size': '2em'},
             }.iteritems():
                 val = tuple(parseStyle('font: %s' % raw, validate=False))[0].cssValue
                 style = normalizers['font']('font', val)
@@ -320,11 +301,13 @@ def test_normalization(return_tests=False):  # {{{
                 for x, v in expected.iteritems():
                     ans['border-%s-%s' % (edge, x)] = v
                 return ans
+
             def border_dict(expected):
                 ans = {}
                 for edge in EDGES:
                     ans.update(border_edge_dict(expected, edge))
                 return ans
+
             def border_val_dict(expected, val='color'):
                 ans = {'border-%s-%s' % (edge, val): DEFAULTS['border-%s-%s' % (edge, val)] for edge in EDGES}
                 for edge in EDGES:
