@@ -42,7 +42,7 @@ class IncorrectCover(BaseError):
 class NookCover(BaseError):
 
     HELP = _(
-            'Some ebook readers such as the Nook fail to recognize covers if'
+            'Some e-book readers such as the Nook fail to recognize covers if'
             ' the content attribute comes before the name attribute.'
             ' For maximum compatibility move the name attribute before the content attribute.')
     INDIVIDUAL_FIX = _('Move the name attribute before the content attribute')
@@ -152,7 +152,7 @@ class NonLinearItems(BaseError):
     has_multiple_locations = True
 
     HELP = xml(_('There are items marked as non-linear in the <spine>.'
-                 ' These will be displayed in random order by different ebook readers.'
+                 ' These will be displayed in random order by different e-book readers.'
                  ' Some will ignore the non-linear attribute, some will display'
                  ' them at the end or the beginning of the book and some will'
                  ' fail to display them at all. Instead of using non-linear items'
@@ -241,13 +241,21 @@ class NoUID(BaseError):
         return True
 
 
+class EmptyIdentifier(BaseError):
+
+    HELP = xml(_('The <dc:identifier> element must not be empty.'))
+
+    def __init__(self, name, lnum):
+        BaseError.__init__(self, _('Empty identifier element'), name, lnum)
+
+
 class BadSpineMime(BaseError):
 
     def __init__(self, name, iid, mt, lnum, opf_name):
         BaseError.__init__(self, _('Incorrect media-type for spine item'), opf_name, lnum)
         self.HELP = _(
             'The item {0} present in the spine has the media-type {1}. '
-            ' Most ebook software cannot handle non-HTML spine items. '
+            ' Most e-book software cannot handle non-HTML spine items. '
             ' If the item is actually HTML, you should change its media-type to {2}.'
             ' If it is not-HTML you should consider replacing it with an HTML item, as it'
             ' is unlikely to work in most readers.').format(name, mt, XHTML_MIME)
@@ -370,6 +378,9 @@ def check_opf(container):
     uid = container.opf.get('unique-identifier', None)
     if uid is None or not container.opf_xpath('/opf:package/opf:metadata/dc:identifier[@id=%r]' % uid):
         errors.append(NoUID(container.opf_name))
+    for elem in container.opf_xpath('/opf:package/opf:metadata/dc:identifier'):
+        if not elem.text or not elem.text.strip():
+            errors.append(EmptyIdentifier(container.opf_name, elem.sourceline))
 
     for item, name, linear in container.spine_iter:
         mt = container.mime_map[name]
