@@ -8,16 +8,17 @@ __copyright__ = '2013, Kovid Goyal <kovid at kovidgoyal.net>'
 __docformat__ = 'restructuredtext en'
 
 import sys
+from future_builtins import map
 
 from lxml import etree
 
 from calibre import prints
 from calibre.ebooks.oeb.base import XHTML
-from calibre.ebooks.oeb.polish.stats import normalize_font_properties
 from calibre.utils.filenames import ascii_filename
 
 props = {'font-family':None, 'font-weight':'normal', 'font-style':'normal', 'font-stretch':'normal'}
 
+
 def matching_rule(font, rules):
     ff = font['font-family']
     if not isinstance(ff, basestring):
@@ -35,6 +36,129 @@ def matching_rule(font, rules):
             if icu_lower(ff) == family:
                 return rule
 
+
+def format_fallback_match_report(matched_font, font_family, css_font, report):
+    msg = _('Could not find a font in the "%s" family exactly matching the CSS font specification,'
+            ' will embed a fallback font instead. CSS font specification:') % font_family
+    msg += '\n\n* font-weight: %s' % css_font.get('font-weight', 'normal')
+    msg += '\n* font-style: %s' % css_font.get('font-style', 'normal')
+    msg += '\n* font-stretch: %s' % css_font.get('font-stretch', 'normal')
+    msg += '\n\n' + _('Matched font specification:')
+    msg += '\n' + matched_font['path']
+    msg += '\n\n* font-weight: %s' % matched_font.get('font-weight', 'normal').strip()
+    msg += '\n* font-style: %s' % matched_font.get('font-style', 'normal').strip()
+    msg += '\n* font-stretch: %s' % matched_font.get('font-stretch', 'normal').strip()
+    report(msg)
+    report('')
+
+
+def stretch_as_number(val):
+    try:
+        return int(val)
+    except Exception:
+        pass
+    try:
+        return ('ultra-condensed', 'extra-condensed', 'condensed', 'semi-condensed',
+         'normal', 'semi-expanded', 'expanded', 'extra-expanded',
+         'ultra-expanded').index(val)
+    except Exception:
+        return 4  # normal
+
+
+def filter_by_stretch(fonts, val):
+    val = stretch_as_number(val)
+    stretch_map = [stretch_as_number(f['font-stretch']) for f in fonts]
+    equal = [f for i, f in enumerate(fonts) if stretch_map[i] == val]
+    if equal:
+        return equal
+    condensed = [i for i in range(len(fonts)) if stretch_map[i] <= 4]
+    expanded = [i for i in range(len(fonts)) if stretch_map[i] > 4]
+    if val <= 4:
+        candidates = condensed or expanded
+    else:
+        candidates = expanded or condensed
+    distance_map = {i:abs(stretch_map[i] - val) for i in candidates}
+    min_dist = min(distance_map.itervalues())
+    return [fonts[i] for i in candidates if distance_map[i] == min_dist]
+
+
+def filter_by_style(fonts, val):
+    order = {
+        'normal':('normal', 'oblique', 'italic'),
+        'italic':('italic', 'oblique', 'normal'),
+        'oblique':('oblique', 'italic', 'normal'),
+    }
+    if val not in order:
+        val = 'normal'
+    for q in order[val]:
+        ans = [f for f in fonts if f['font-style'] == q]
+        if ans:
+            return ans
+    return fonts
+
+
+def weight_as_number(wt):
+    try:
+        return int(wt)
+    except Exception:
+        return {'normal':400, 'bold':700}.get(wt, 400)
+
+
+def filter_by_weight(fonts, val):
+    val = weight_as_number(val)
+    weight_map = [weight_as_number(f['font-weight']) for f in fonts]
+    equal = [f for i, f in enumerate(fonts) if weight_map[i] == val]
+    if equal:
+        return equal
+    rmap = {w:i for i, w in enumerate(weight_map)}
+    below = [i for i in range(len(fonts)) if weight_map[i] < val]
+    above = [i for i in range(len(fonts)) if weight_map[i] > val]
+    if val < 400:
+        candidates = below or above
+    elif val > 500:
+        candidates = above or below
+    elif val == 400:
+        if 500 in rmap:
+            return [fonts[rmap[500]]]
+        candidates = below or above
+    else:
+        if 400 in rmap:
+            return [fonts[rmap[400]]]
+        candidates = below or above
+    distance_map = {i:abs(weight_map[i] - val) for i in candidates}
+    min_dist = min(distance_map.itervalues())
+    return [fonts[i] for i in candidates if distance_map[i] == min_dist]
+
+
+def find_matching_font(fonts, weight='normal', style='normal', stretch='normal'):
+    # See https://www.w3.org/TR/css-fonts-3/#font-style-matching
+    # We dont implement the unicode character range testing
+    # We also dont implement bolder, lighter
+    for f, q in ((filter_by_stretch, stretch), (filter_by_style, style), (filter_by_weight, weight)):
+        fonts = f(fonts, q)
+        if len(fonts) == 1:
+            return fonts[0]
+    return fonts[0]
+
+
+def do_embed(container, font, report):
+    from calibre.utils.fonts.scanner import font_scanner
+    report('Embedding font %s from %s' % (font['full_name'], font['path']))
+    data = font_scanner.get_font_data(font)
+    fname = font['full_name']
+    ext = 'otf' if font['is_otf'] else 'ttf'
+    fname = ascii_filename(fname).replace(' ', '-').replace('(', '').replace(')', '')
+    item = container.generate_item('fonts/%s.%s'%(fname, ext), id_prefix='font')
+    name = container.href_to_name(item.get('href'), container.opf_name)
+    with container.open(name, 'wb') as out:
+        out.write(data)
+    href = container.name_to_href(name)
+    rule = {k:font.get(k, v) for k, v in props.iteritems()}
+    rule['src'] = 'url(%s)' % href
+    rule['name'] = name
+    return rule
+
+
 def embed_font(container, font, all_font_rules, report, warned):
     rule = matching_rule(font, all_font_rules)
     ff = font['font-family']
@@ -50,28 +174,16 @@ def embed_font(container, font, all_font_rules, report, warned):
             report(_('Failed to find fonts for family: %s, not embedding') % ff)
             warned.add(ff)
             return
-        wt = int(font.get('font-weight', '400'))
+        wt = weight_as_number(font.get('font-weight'))
         for f in fonts:
             if f['weight'] == wt and f['font-style'] == font.get('font-style', 'normal') and f['font-stretch'] == font.get('font-stretch', 'normal'):
-                report('Embedding font %s from %s' % (f['full_name'], f['path']))
-                data = font_scanner.get_font_data(f)
-                fname = f['full_name']
-                ext = 'otf' if f['is_otf'] else 'ttf'
-                fname = ascii_filename(fname).replace(' ', '-').replace('(', '').replace(')', '')
-                item = container.generate_item('fonts/%s.%s'%(fname, ext), id_prefix='font')
-                name = container.href_to_name(item.get('href'), container.opf_name)
-                with container.open(name, 'wb') as out:
-                    out.write(data)
-                href = container.name_to_href(name)
-                rule = {k:f.get(k, v) for k, v in props.iteritems()}
-                rule['src'] = 'url(%s)' % href
-                rule['name'] = name
-                return rule
-        msg = _('Failed to find font matching: family: %(family)s; weight: %(weight)s; style: %(style)s; stretch: %(stretch)s') % dict(
-            family=ff, weight=font['font-weight'], style=font['font-style'], stretch=font['font-stretch'])
-        if msg not in warned:
-            warned.add(msg)
-            report(msg)
+                return do_embed(container, f, report)
+        f = find_matching_font(fonts, font.get('font-weight', '400'), font.get('font-style', 'normal'), font.get('font-stretch', 'normal'))
+        wkey = ('fallback-font', ff, wt, font.get('font-style'), font.get('font-stretch'))
+        if wkey not in warned:
+            warned.add(wkey)
+            format_fallback_match_report(f, ff, font, report)
+        return do_embed(container, f, report)
     else:
         name = rule['src']
         href = container.name_to_href(name)
@@ -80,10 +192,15 @@ def embed_font(container, font, all_font_rules, report, warned):
         rule['name'] = name
         return rule
 
+
+def font_key(font):
+    return tuple(map(font.get, 'font-family font-weight font-style font-stretch'.split()))
+
+
 def embed_all_fonts(container, stats, report):
     all_font_rules = tuple(stats.all_font_rules.itervalues())
     warned = set()
-    rules, nrules = [], []
+    rules, nrules = [], {}
     modified = set()
 
     for path in container.spine_items:
@@ -101,12 +218,13 @@ def embed_all_fonts(container, stats, report):
             if rule is None:
                 # This font was not already embedded in this HTML file, before
                 # processing started
-                rule = matching_rule(font, nrules)
+                key = font_key(font)
+                rule = nrules.get(key)
                 if rule is None:
                     rule = embed_font(container, font, all_font_rules, report, warned)
                     if rule is not None:
                         rules.append(rule)
-                        nrules.append(normalize_font_properties(rule.copy()))
+                        nrules[key] = rule
                         modified.add(name)
                         stats.font_stats[rule['name']] = font['text']
                 else:
@@ -156,4 +274,3 @@ if __name__ == '__main__':
         prints(msg)
     print()
     prints('Output written to:', outbook)
-
