@@ -12,15 +12,17 @@ from zipfile import ZipFile
 from calibre import CurrentDir
 from calibre.ebooks.oeb.polish.tests.base import BaseTest, get_simple_book, get_split_book
 from calibre.ebooks.oeb.polish.container import get_container as _gc, clone_container, OCF_NS
-from calibre.ebooks.oeb.polish.replace import rename_files
+from calibre.ebooks.oeb.polish.replace import rename_files, rationalize_folders
 from calibre.ebooks.oeb.polish.split import split, merge
 from calibre.utils.filenames import nlinks_file
 from calibre.ptempfile import TemporaryFile, TemporaryDirectory
 
+
 def get_container(*args, **kwargs):
     kwargs['tweak_mode'] = True
     return _gc(*args, **kwargs)
 
+
 class ContainerTests(BaseTest):
 
     def test_clone(self):
@@ -81,11 +83,11 @@ class ContainerTests(BaseTest):
         for x in files:
             self.assertNotIn(x, raw)
 
-    def run_external_tools(self, container, gvim=False, epubcheck=True):
+    def run_external_tools(self, container, vim=False, epubcheck=True):
         with TemporaryFile(suffix='.epub', dir=self.tdir) as f:
             container.commit(outpath=f)
-            if gvim:
-                subprocess.Popen(['gvim', '-f', f]).wait()
+            if vim:
+                subprocess.Popen(['vim', '-f', f]).wait()
             if epubcheck:
                 subprocess.Popen(['epubcheck', f]).wait()
 
@@ -93,6 +95,7 @@ class ContainerTests(BaseTest):
         ' Test renaming of files '
         book = get_simple_book()
         count = [0]
+
         def new_container():
             count[0] += 1
             tdir = os.mkdir(os.path.join(self.tdir, str(count[0])))
@@ -166,7 +169,7 @@ class ContainerTests(BaseTest):
         rename_files(c, {'index_split_000.html':'Index_split_000.html'})
         self.check_links(c)
 
-        # self.run_external_tools(c, gvim=True)
+        # self.run_external_tools(c, vim=True)
 
     def test_file_add(self):
         ' Test adding of files '
@@ -183,6 +186,9 @@ class ContainerTests(BaseTest):
         self.assertEqual('xxx', c.raw_data(name))
         self.assertIn(name, set(c.manifest_id_map.itervalues()))
         self.assertNotIn(name, {x[0] for x in c.spine_names})
+        self.assertEqual(c.make_name_unique(name), 'added-1.css')
+        c.add_file('added-1.css', b'xxx')
+        self.assertEqual(c.make_name_unique(name.upper()), 'added-2.css'.upper())
 
         self.check_links(c)
 
@@ -261,3 +267,12 @@ class ContainerTests(BaseTest):
                 self.assertTrue(os.path.exists('.git/xxx'))
                 self.assertTrue(os.path.exists('images/test-container.xyz'))
                 self.assertFalse(os.path.exists('images/cover.jpg'))
+
+    def test_folder_type_map_case(self):
+        book = get_simple_book()
+        c = get_container(book)
+        c.add_file('Image/testcase.png', b'xxx')
+        rationalize_folders(c, {'image':'image'})
+        self.assertTrue(c.has_name('Image/testcase.png'))
+        self.assertTrue(c.exists('Image/testcase.png'))
+        self.assertFalse(c.has_name('image/testcase.png'))
