@@ -11,10 +11,12 @@ __docformat__ = 'restructuredtext en'
 import os
 import re
 import StringIO
+from copy import deepcopy
 
 from calibre import my_unichr, prepare_string_for_xml
 from calibre.ebooks.metadata.toc import TOC
 
+
 class PML_HTMLizer(object):
 
     STATES = [
@@ -25,6 +27,7 @@ class PML_HTMLizer(object):
         'sp',
         'sb',
         'h1',
+        'h1c',
         'h2',
         'h3',
         'h4',
@@ -58,6 +61,7 @@ class PML_HTMLizer(object):
 
     STATES_TAGS = {
         'h1': ('<h1 style="page-break-before: always;">', '</h1>'),
+        'h1c': ('<h1>', '</h1>'),
         'h2': ('<h2>', '</h2>'),
         'h3': ('<h3>', '</h3>'),
         'h4': ('<h4>', '</h4>'),
@@ -77,7 +81,7 @@ class PML_HTMLizer(object):
         'b': ('<span style="font-weight: bold;">', '</span>'),
         'l': ('<span style="font-size: 150%;">', '</span>'),
         'k': ('<span style="font-size: 75%; font-variant: small-caps;">', '</span>'),
-        'FN': ('<br /><br style="page-break-after: always;" /><div id="fn-%s"><p>', '</p><<small><a href="#rfn-%s">return</a></small></div>'),
+        'FN': ('<br /><br style="page-break-after: always;" /><div id="fn-%s"><p>', '</p><small><a href="#rfn-%s">return</a></small></div>'),
         'SB': ('<br /><br style="page-break-after: always;" /><div id="sb-%s"><p>', '</p><small><a href="#rsb-%s">return</a></small></div>'),
     }
 
@@ -141,6 +145,10 @@ class PML_HTMLizer(object):
         'b',
     ]
 
+    NEW_LINE_EXCHANGE_STATES = {
+        'h1': 'h1c',
+    }
+
     def __init__(self):
         self.state = {}
         # toc consists of a tuple
@@ -151,8 +159,10 @@ class PML_HTMLizer(object):
     def prepare_pml(self, pml):
         # Give Chapters the form \\*='text'text\\*. This is used for generating
         # the TOC later.
-        pml = re.sub(r'(?<=\\x)(?P<text>.*?)(?=\\x)', lambda match: '="%s"%s' % (self.strip_pml(match.group('text')), match.group('text')), pml)
-        pml = re.sub(r'(?<=\\X[0-4])(?P<text>.*?)(?=\\X[0-4])', lambda match: '="%s"%s' % (self.strip_pml(match.group('text')), match.group('text')), pml)
+        pml = re.sub(r'(?msu)(?P<c>\\x)(?P<text>.*?)(?P=c)', lambda match: '%s="%s"%s%s' %
+                     (match.group('c'), self.strip_pml(match.group('text')), match.group('text'), match.group('c')), pml)
+        pml = re.sub(r'(?msu)(?P<c>\\X[0-4])(?P<text>.*?)(?P=c)', lambda match: '%s="%s"%s%s' %
+                     (match.group('c'), self.strip_pml(match.group('text')), match.group('text'), match.group('c')), pml)
 
         # Remove comments
         pml = re.sub(r'(?mus)\\v(?P<text>.*?)\\v', '', pml)
@@ -164,8 +174,10 @@ class PML_HTMLizer(object):
         pml = re.sub(r'(?mus)^[ ]*$', '', pml)
 
         # Footnotes and Sidebars.
-        pml = re.sub(r'(?mus)<footnote\s+id="(?P<target>.+?)">\s*(?P<text>.*?)\s*</footnote>', lambda match: '\\FN="%s"%s\\FN' % (match.group('target'), match.group('text')) if match.group('text') else '', pml)
-        pml = re.sub(r'(?mus)<sidebar\s+id="(?P<target>.+?)">\s*(?P<text>.*?)\s*</sidebar>', lambda match: '\\SB="%s"%s\\SB' % (match.group('target'), match.group('text')) if match.group('text') else '', pml)
+        pml = re.sub(r'(?mus)<footnote\s+id="(?P<target>.+?)">\s*(?P<text>.*?)\s*</footnote>', lambda match: '\\FN="%s"%s\\FN' %
+                     (match.group('target'), match.group('text')) if match.group('text') else '', pml)
+        pml = re.sub(r'(?mus)<sidebar\s+id="(?P<target>.+?)">\s*(?P<text>.*?)\s*</sidebar>', lambda match: '\\SB="%s"%s\\SB' %
+                     (match.group('target'), match.group('text')) if match.group('text') else '', pml)
 
         # Convert &'s into entities so &amp; in the text doesn't get turned into
         # &. It will display as &amp;
@@ -190,9 +202,10 @@ class PML_HTMLizer(object):
         pml = re.sub(r'\\a\d\d\d', '', pml)
         pml = re.sub(r'\\U\d\d\d\d', '', pml)
         pml = re.sub(r'\\.', '', pml)
-        pml.replace('\r\n', ' ')
-        pml.replace('\n', ' ')
-        pml.replace('\r', ' ')
+        pml = pml.replace('\r\n', ' ')
+        pml = pml.replace('\n', ' ')
+        pml = pml.replace('\r', ' ')
+        pml = pml.strip()
 
         return pml
 
@@ -218,11 +231,17 @@ class PML_HTMLizer(object):
     def start_line(self):
         start = u''
 
+        state = deepcopy(self.state)
         div = []
         span = []
         other = []
 
-        for key, val in self.state.items():
+        for key, val in state.items():
+            if key in self.NEW_LINE_EXCHANGE_STATES and val[0]:
+                state[self.NEW_LINE_EXCHANGE_STATES[key]] = val
+                state[key] = [False, '']
+
+        for key, val in state.items():
             if val[0]:
                 if key in self.DIV_STATES:
                     div.append((key, val[1]))
@@ -513,7 +532,7 @@ class PML_HTMLizer(object):
         empty_count = 0
 
         for s in self.STATES:
-            self.state[s] = [False, ''];
+            self.state[s] = [False, '']
 
         for line in pml.splitlines():
             parsed = []
@@ -630,7 +649,7 @@ class PML_HTMLizer(object):
                 empty_count = 0
                 text = self.end_line()
                 parsed.append(text)
-                
+
                 # Basic indent will be set if the \t starts the line or
                 # if we are in a continuing \t block.
                 if basic_indent:
@@ -652,7 +671,7 @@ class PML_HTMLizer(object):
                     parsed.append(self.STATES_TAGS['T'][1])
                     indent_state['T'] = False
                     adv_indent_val = ''
-                
+
                 output.append(u''.join(parsed))
             line.close()
 
@@ -663,7 +682,7 @@ class PML_HTMLizer(object):
     def get_toc(self):
         '''
         Toc can have up to 5 levels, 0 - 4 inclusive.
-        
+
         This function will add items to their appropriate
         depth in the TOC tree. If the specified depth is
         invalid (item would not have a valid parent) add
@@ -686,23 +705,23 @@ class PML_HTMLizer(object):
                 t_l2 = None
                 t_l3 = None
             elif level == u'1':
-                if t_l0 == None:
+                if t_l0 is None:
                     t_l0 = n_toc
                 t_l1 = t_l0.add_item(href, id, text)
                 t_l2 = None
                 t_l3 = None
             elif level == u'2':
-                if t_l1 == None:
-                    if t_l0 == None:
+                if t_l1 is None:
+                    if t_l0 is None:
                         t_l1 = n_toc
                     else:
                         t_l1 = t_l0
                 t_l2 = t_l1.add_item(href, id, text)
                 t_l3 = None
             elif level == u'3':
-                if t_l2 == None:
-                    if t_l1 == None:
-                        if t_l0 == None:
+                if t_l2 is None:
+                    if t_l1 is None:
+                        if t_l0 is None:
                             t_l2 = n_toc
                         else:
                             t_l2 = t_l0
@@ -713,10 +732,10 @@ class PML_HTMLizer(object):
             # Anything above 4 is invalid but we will count
             # it as level 4.
             else:
-                if t_l3 == None:
-                    if t_l2 == None:
-                        if t_l1 == None:
-                            if t_l0 == None:
+                if t_l3 is None:
+                    if t_l2 is None:
+                        if t_l1 is None:
+                            if t_l0 is None:
                                 t_l3 = n_toc
                             else:
                                 t_l3 = t_l0
@@ -733,13 +752,20 @@ def pml_to_html(pml):
     hizer = PML_HTMLizer()
     return hizer.parse_pml(pml)
 
+
 def footnote_sidebar_to_html(pre_id, id, pml):
     id = id.strip('\x01')
-    html = '<br /><br style="page-break-after: always;" /><div id="%s-%s"><p>%s</p><small><a href="#r%s-%s">return</a></small></div>' % (pre_id, id, pml_to_html(pml), pre_id, id)
+    if id.strip():
+        html = '<br /><br style="page-break-after: always;" /><div id="%s-%s">%s<small><a href="#r%s-%s">return</a></small></div>' % (
+            pre_id, id, pml_to_html(pml), pre_id, id)
+    else:
+        html = '<br /><br style="page-break-after: always;" /><div>%s</div>' % pml_to_html(pml)
     return html
 
+
 def footnote_to_html(id, pml):
     return footnote_sidebar_to_html('fn', id, pml)
 
+
 def sidebar_to_html(id, pml):
     return footnote_sidebar_to_html('sb', id, pml)
