@@ -70,7 +70,9 @@ SEPARATE_TAGS = [
     'tr',
 ]
 
+
 class PMLMLizer(object):
+
     def __init__(self, log):
         self.log = log
         self.image_hrefs = {}
@@ -211,7 +213,8 @@ class PMLMLizer(object):
         if self.opts.remove_paragraph_spacing:
             text = re.sub('\n{2,}', '\n', text)
             # Only indent lines that don't have special formatting
-            text = re.sub('(?imu)^(?P<text>.+)$', lambda mo: mo.group('text') if re.search(r'\\[XxCmrctTp]', mo.group('text')) else '        %s' % mo.group('text'), text)
+            text = re.sub('(?imu)^(?P<text>.+)$', lambda mo: mo.group('text')
+                          if re.search(r'\\[XxCmrctTp]', mo.group('text')) else '        %s' % mo.group('text'), text)
         else:
             text = re.sub('\n{3,}', '\n\n', text)
 
@@ -220,8 +223,11 @@ class PMLMLizer(object):
     def dump_text(self, elem, stylizer, page, tag_stack=[]):
         from calibre.ebooks.oeb.base import XHTML_NS, barename, namespace
 
-        if not isinstance(elem.tag, basestring) \
-           or namespace(elem.tag) != XHTML_NS:
+        if not isinstance(elem.tag, basestring) or namespace(elem.tag) != XHTML_NS:
+            p = elem.getparent()
+            if p is not None and isinstance(p.tag, basestring) and namespace(p.tag) == XHTML_NS \
+                    and elem.tail:
+                return [elem.tail]
             return []
 
         text = []
@@ -230,6 +236,8 @@ class PMLMLizer(object):
 
         if style['display'] in ('none', 'oeb-page-head', 'oeb-page-foot') \
            or style['visibility'] == 'hidden':
+            if hasattr(elem, 'tail') and elem.tail:
+                return [elem.tail]
             return []
 
         tag = barename(elem.tag)
@@ -246,7 +254,8 @@ class PMLMLizer(object):
                     if len(self.image_hrefs.keys()) == 0:
                         self.image_hrefs[page.abshref(elem.attrib['src'])] = 'cover.png'
                     else:
-                        self.image_hrefs[page.abshref(elem.attrib['src'])] = image_name('%s.png' % len(self.image_hrefs.keys()), self.image_hrefs.keys()).strip('\x00')
+                        self.image_hrefs[page.abshref(elem.attrib['src'])] = image_name(
+                            '%s.png' % len(self.image_hrefs.keys()), self.image_hrefs.keys()).strip('\x00')
                 text.append('\\m="%s"' % self.image_hrefs[page.abshref(elem.attrib['src'])])
         elif tag == 'hr':
             w = '\\w'
@@ -346,7 +355,7 @@ class PMLMLizer(object):
         tags.reverse()
         text += self.close_tags(tags)
 
-        #if tag in SEPARATE_TAGS:
+        # if tag in SEPARATE_TAGS:
         #    text.append('\n\n')
 
         if style['page-break-after'] == 'always':
