@@ -13,31 +13,34 @@ from lxml.html import (fragment_fromstring, document_fromstring,
 from calibre.ebooks.readability.htmls import build_doc, get_body, get_title, shorten_title
 from calibre.ebooks.readability.cleaners import html_cleaner, clean_attributes
 
+
 def tounicode(tree_or_node, **kwargs):
     kwargs['encoding'] = unicode
     return htostring(tree_or_node, **kwargs)
 
 
 REGEXES = {
-    'unlikelyCandidatesRe': re.compile('combx|comment|community|disqus|extra|foot|header|menu|remark|rss|shoutbox|sidebar|sponsor|ad-break|agegate|pagination|pager|popup|tweet|twitter',re.I),
+    'unlikelyCandidatesRe': re.compile('combx|comment|community|disqus|extra|foot|header|menu|remark|rss|shoutbox|sidebar|sponsor|ad-break|agegate|pagination|pager|popup|tweet|twitter',re.I),  # noqa
     'okMaybeItsACandidateRe': re.compile('and|article|body|column|main|shadow',re.I),
     'positiveRe': re.compile('article|body|content|entry|hentry|main|page|pagination|post|text|blog|story',re.I),
-    'negativeRe': re.compile('combx|comment|com-|contact|foot|footer|footnote|masthead|media|meta|outbrain|promo|related|scroll|shoutbox|sidebar|sponsor|shopping|tags|tool|widget',re.I),
+    'negativeRe': re.compile('combx|comment|com-|contact|foot|footer|footnote|masthead|media|meta|outbrain|promo|related|scroll|shoutbox|sidebar|sponsor|shopping|tags|tool|widget',re.I),  # noqa
     'divToPElementsRe': re.compile('<(a|blockquote|dl|div|img|ol|p|pre|table|ul)',re.I),
-    #'replaceBrsRe': re.compile('(<br[^>]*>[ \n\r\t]*){2,}',re.I),
-    #'replaceFontsRe': re.compile('<(\/?)font[^>]*>',re.I),
-    #'trimRe': re.compile('^\s+|\s+$/'),
-    #'normalizeRe': re.compile('\s{2,}/'),
-    #'killBreaksRe': re.compile('(<br\s*\/?>(\s|&nbsp;?)*){1,}/'),
-    #'videoRe': re.compile('http:\/\/(www\.)?(youtube|vimeo)\.com', re.I),
-    #skipFootnoteLink:    /^\s*(\[?[a-z0-9]{1,2}\]?|^|edit|citation needed)\s*$/i,
+    # 'replaceBrsRe': re.compile('(<br[^>]*>[ \n\r\t]*){2,}',re.I),
+    # 'replaceFontsRe': re.compile('<(\/?)font[^>]*>',re.I),
+    # 'trimRe': re.compile('^\s+|\s+$/'),
+    # 'normalizeRe': re.compile('\s{2,}/'),
+    # 'killBreaksRe': re.compile('(<br\s*\/?>(\s|&nbsp;?)*){1,}/'),
+    # 'videoRe': re.compile('http:\/\/(www\.)?(youtube|vimeo)\.com', re.I),
+    # skipFootnoteLink:    /^\s*(\[?[a-z0-9]{1,2}\]?|^|edit|citation needed)\s*$/i,
 }
 
+
 def describe(node, depth=1):
     if not hasattr(node, 'tag'):
         return "[%s]" % type(node)
     name = node.tag
-    if node.get('id', ''): name += '#'+node.get('id')
+    if node.get('id', ''):
+        name += '#'+node.get('id')
     if node.get('class', ''):
         name += '.' + node.get('class').replace(' ','.')
     if name[:4] in ['div#', 'div.']:
@@ -46,8 +49,10 @@ def describe(node, depth=1):
         return name+' - '+describe(node.getparent(), depth-1)
     return name
 
+
 def to_int(x):
-    if not x: return None
+    if not x:
+        return None
     x = x.strip()
     if x.endswith('px'):
         return int(x[:-2])
@@ -55,17 +60,21 @@ def to_int(x):
         return int(x[:-2]) * 12
     return int(x)
 
+
 def clean(text):
     text = re.sub('\s*\n\s*', '\n', text)
     text = re.sub('[ \t]{2,}', ' ', text)
     return text.strip()
 
+
 def text_length(i):
     return len(clean(i.text_content() or ""))
 
+
 class Unparseable(ValueError):
     pass
 
+
 class Document:
     TEXT_LENGTH_THRESHOLD = 25
     RETRY_LENGTH = 250
@@ -142,11 +151,11 @@ class Document:
                 of_acceptable_length = len(cleaned_article or '') >= (self.options['retry_length'] or self.RETRY_LENGTH)
                 if ruthless and not of_acceptable_length:
                     ruthless = False
-                    continue # try again
+                    continue  # try again
                 else:
                     return cleaned_article
         except StandardError, e:
-            self.log.exception('error getting summary: ' )
+            self.log.exception('error getting summary: ')
             raise Unparseable(str(e)), None, sys.exc_info()[2]
 
     def get_article(self, candidates, best_candidate):
@@ -158,7 +167,7 @@ class Document:
         parent = output.xpath('//div')[0]
         best_elem = best_candidate['elem']
         for sibling in best_elem.getparent().getchildren():
-            #if isinstance(sibling, NavigableString): continue#in lxml there no concept of simple text
+            # if isinstance(sibling, NavigableString): continue#in lxml there no concept of simple text
             append = False
             if sibling is best_elem:
                 append = True
@@ -179,7 +188,7 @@ class Document:
 
             if append:
                 parent.append(sibling)
-        #if output is not None:
+        # if output is not None:
         #   output.append(best_elem)
         return output.find('body')
 
@@ -195,12 +204,11 @@ class Document:
         best_candidate = sorted_candidates[0]
         return best_candidate
 
-
     def get_link_density(self, elem):
         link_length = 0
         for i in elem.findall(".//a"):
             link_length += text_length(i)
-        #if len(elem.findall(".//div") or elem.findall(".//p")):
+        # if len(elem.findall(".//div") or elem.findall(".//p")):
         #   link_length = link_length
         total_length = text_length(elem)
         return float(link_length) / max(total_length, 1)
@@ -208,7 +216,7 @@ class Document:
     def score_paragraphs(self, ):
         MIN_LEN = self.options.get('min_text_length', self.TEXT_LENGTH_THRESHOLD)
         candidates = {}
-        #self.debug(str([describe(node) for node in self.tags(self.html, "div")]))
+        # self.debug(str([describe(node) for node in self.tags(self.html, "div")]))
 
         ordered = []
         for elem in self.tags(self.html, "p", "pre", "td"):
@@ -235,10 +243,10 @@ class Document:
             content_score = 1
             content_score += len(inner_text.split(','))
             content_score += min((inner_text_len / 100), 3)
-            #if elem not in candidates:
+            # if elem not in candidates:
             #   candidates[elem] = self.score_node(elem)
 
-            #WTF? candidates[elem]['content_score'] += content_score
+            # WTF? candidates[elem]['content_score'] += content_score
             candidates[parent_node]['content_score'] += content_score
             if grand_parent_node is not None:
                 candidates[grand_parent_node]['content_score'] += content_score / 2.0
@@ -289,15 +297,15 @@ class Document:
         }
 
     def debug(self, *a):
-        #if self.options['debug']:
-            self.log.debug(*a)
+        # if self.options['debug']:
+        self.log.debug(*a)
 
     def remove_unlikely_candidates(self):
         for elem in self.html.iter():
             if elem in self.keep_elements:
                 continue
             s = "%s %s" % (elem.get('class', ''), elem.get('id', ''))
-            #self.debug(s)
+            # self.debug(s)
             if REGEXES['unlikelyCandidatesRe'].search(s) and (not REGEXES['okMaybeItsACandidateRe'].search(s)) and elem.tag != 'body':
                 self.debug("Removing unlikely candidate - %s" % describe(elem))
                 elem.drop_tree()
@@ -306,9 +314,9 @@ class Document:
         for elem in self.tags(self.html, 'div'):
             # transform <div>s that do not contain other block elements into <p>s
             if not REGEXES['divToPElementsRe'].search(unicode(''.join(map(tostring, list(elem))))):
-                #self.debug("Altering %s to p" % (describe(elem)))
+                # self.debug("Altering %s to p" % (describe(elem)))
                 elem.tag = "p"
-                #print "Fixed element "+describe(elem)
+                # print "Fixed element "+describe(elem)
 
         for elem in self.tags(self.html, 'div'):
             if elem.text and elem.text.strip():
@@ -316,7 +324,7 @@ class Document:
                 p.text = elem.text
                 elem.text = None
                 elem.insert(0, p)
-                #print "Appended "+tounicode(p)+" to "+describe(elem)
+                # print "Appended "+tounicode(p)+" to "+describe(elem)
 
             for pos, child in reversed(list(enumerate(elem))):
                 if child.tail and child.tail.strip():
@@ -324,9 +332,9 @@ class Document:
                     p.text = child.tail
                     child.tail = None
                     elem.insert(pos + 1, p)
-                    #print "Inserted "+tounicode(p)+" to "+describe(elem)
+                    # print "Inserted "+tounicode(p)+" to "+describe(elem)
                 if child.tag == 'br':
-                    #print 'Dropped <br> at '+describe(elem)
+                    # print 'Dropped <br> at '+describe(elem)
                     child.drop_tree()
 
     def tags(self, node, *tag_names):
@@ -355,7 +363,7 @@ class Document:
             weight = self.class_weight(el)
             if el in candidates:
                 content_score = candidates[el]['content_score']
-                #print '!',el, '-> %6.3f' % content_score
+                # print '!',el, '-> %6.3f' % content_score
             else:
                 content_score = 0
             tag = el.tag
@@ -370,7 +378,7 @@ class Document:
                     counts[kind] = len(el.findall('.//%s' %kind))
                 counts["li"] -= 100
 
-                content_length = text_length(el) # Count the text length excluding any surrounding whitespace
+                content_length = text_length(el)  # Count the text length excluding any surrounding whitespace
                 link_density = self.get_link_density(el)
                 parent_node = el.getparent()
                 if parent_node is not None:
@@ -378,16 +386,16 @@ class Document:
                         content_score = candidates[parent_node]['content_score']
                     else:
                         content_score = 0
-                #if parent_node is not None:
-                    #pweight = self.class_weight(parent_node) + content_score
-                    #pname = describe(parent_node)
-                #else:
-                    #pweight = 0
-                    #pname = "no parent"
+                # if parent_node is not None:
+                    # pweight = self.class_weight(parent_node) + content_score
+                    # pname = describe(parent_node)
+                # else:
+                    # pweight = 0
+                    # pname = "no parent"
                 to_remove = False
                 reason = ""
 
-                #if el.tag == 'div' and counts["img"] >= 1:
+                # if el.tag == 'div' and counts["img"] >= 1:
                 #   continue
                 if counts["p"] and counts["img"] > counts["p"]:
                     reason = "too many images (%s)" % counts["img"]
@@ -402,8 +410,8 @@ class Document:
                     reason = "too short content length %s without a single image" % content_length
                     to_remove = True
                 elif weight < 25 and link_density > 0.2:
-                        reason = "too many links %.3f for its weight %s" % (link_density, weight)
-                        to_remove = True
+                    reason = "too many links %.3f for its weight %s" % (link_density, weight)
+                    to_remove = True
                 elif weight >= 25 and link_density > 0.5:
                     reason = "too many links %.3f for its weight %s" % (link_density, weight)
                     to_remove = True
@@ -429,12 +437,12 @@ class Document:
 #                       for desnode in self.tags(el, "table", "ul", "div"):
 #                           allowed[desnode] = True
 
-                    #find x non empty preceding and succeeding siblings
+                    # find x non empty preceding and succeeding siblings
                     i, j = 0, 0
                     x  = 1
                     siblings = []
                     for sib in el.itersiblings():
-                        #self.debug(sib.text_content())
+                        # self.debug(sib.text_content())
                         sib_content_length = text_length(sib)
                         if sib_content_length:
                             i =+ 1
@@ -442,14 +450,14 @@ class Document:
                             if i == x:
                                 break
                     for sib in el.itersiblings(preceding=True):
-                        #self.debug(sib.text_content())
+                        # self.debug(sib.text_content())
                         sib_content_length = text_length(sib)
                         if sib_content_length:
                             j =+ 1
                             siblings.append(sib_content_length)
                             if j == x:
                                 break
-                    #self.debug(str(siblings))
+                    # self.debug(str(siblings))
                     if siblings and sum(siblings) > 1000 :
                         to_remove = False
                         self.debug("Allowing %s" % describe(el))
@@ -459,12 +467,13 @@ class Document:
                 if to_remove:
                     self.debug("Cleaned %6.3f %s with weight %s cause it has %s." %
                         (content_score, describe(el), weight, reason))
-                    #print tounicode(el)
-                    #self.debug("pname %s pweight %.3f" %(pname, pweight))
+                    # print tounicode(el)
+                    # self.debug("pname %s pweight %.3f" %(pname, pweight))
                     el.drop_tree()
 
         return clean_attributes(tounicode(node))
 
+
 def option_parser():
     from calibre.utils.config import OptionParser
     parser = OptionParser(usage='%prog: [options] file')
@@ -477,6 +486,7 @@ def option_parser():
 
     return parser
 
+
 def main():
     from calibre.utils.logging import default_log
     parser = option_parser()
