@@ -8,20 +8,18 @@
 #   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU    #
 #   General Public License for more details.                            #
 #                                                                       #
-#   You should have received a copy of the GNU General Public License   #
-#   along with this program; if not, write to the Free Software         #
-#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA            #
-#   02111-1307 USA                                                      #
-#                                                                       #
 #                                                                       #
 #########################################################################
 import sys, re
+
+
 class FieldStrings:
     """
     This module is given a string. It processes the field instruction string and
     returns a list of three values.
     """
-    def __init__(self, bug_handler, run_level = 1):
+
+    def __init__(self, bug_handler, run_level=1):
         """
         Requires:
             nothing
@@ -31,6 +29,7 @@ class FieldStrings:
         self.__run_level = run_level
         self.__bug_handler = bug_handler
         self.__initiate_values()
+
     def __initiate_values(self):
         """
         Requires:
@@ -81,7 +80,7 @@ class FieldStrings:
         'INCLUDETEXT'   :       (self.__include_text_func, 'include-text-from-file'),
         'INDEX'         :       (self.__index_func, 'index'),
         'NOTEREF'       :       (self.__note_ref_func, 'reference-to-note'),
-        'PAGEREF'	:	(self.__page_ref_func, 'reference-to-page'),
+        'PAGEREF'	: (self.__page_ref_func, 'reference-to-page'),
         'REF'           :       (self.__ref_func, 'reference'),
         'ref'           :       (self.__ref_func, 'reference'),
         'SEQ'           :       (self.__sequence_func, 'numbering-sequence'),
@@ -109,7 +108,7 @@ class FieldStrings:
         'ADVANCE'       :       (self.__default_inst_func, 'advance'),
         'ASK'           :       (self.__default_inst_func, 'prompt-user'),
         'AUTONUMLGL'    :       (self.__default_inst_func, 'automatic-number'),
-        'AUTONUM'       :	(self.__default_inst_func, 'automatic-number'),
+        'AUTONUM'       : (self.__default_inst_func, 'automatic-number'),
         'AUTOTEXTLIST'  :       (self.__default_inst_func, 'auto-list-text'),
         'AUTOTEXT'      :       (self.__default_inst_func, 'auto-text'),
         'BARCODE'       :       (self.__default_inst_func, 'barcode'),
@@ -156,10 +155,11 @@ class FieldStrings:
         self.__symbol_num_exp = re.compile(r'SYMBOL (.*?) ')
         self.__symbol_font_exp = re.compile(r'\\f "(.*?)"')
         self.__symbol_size_exp = re.compile(r'\\s (\d+)')
-        ##self.__toc_figure_exp = re.compile(r'\\c "Figure"')
+        # self.__toc_figure_exp = re.compile(r'\\c "Figure"')
         # \\@ "dddd, MMMM d, yyyy"
         self.__date_exp = re.compile(r'\\@\s{1,}"(.*?)"')
-        self.__num_type_exp = re.compile(r'\\\*\s{1,}(Arabic|alphabetic|ALPHABETIC|roman|ROMAN|Ordinal|CardText|OrdText|Hex|DollarText|Upper|Lower|FirstCap|Caps)')
+        self.__num_type_exp = re.compile(
+            r'\\\*\s{1,}(Arabic|alphabetic|ALPHABETIC|roman|ROMAN|Ordinal|CardText|OrdText|Hex|DollarText|Upper|Lower|FirstCap|Caps)')
         self.__format_text_exp = re.compile(r'\\\*\s{1,}(Upper|Lower|FirstCap|Caps)')
         self.__merge_format_exp = re.compile(r'\\\*\s{1,}MERGEFORMAT')
         self.__ta_short_field_exp = re.compile(r'\\s\s{1,}"(.*?)"')
@@ -179,6 +179,7 @@ class FieldStrings:
         self.__quote_exp = re.compile(r'"(.*?)"')
         self.__filter_switch = re.compile(r'\\c\s{1,}(.*?)\s')
         self.__link_switch = re.compile(r'\\l\s{1,}(.*?)\s')
+
     def process_string(self, my_string, type):
         """
         Requires:
@@ -222,6 +223,7 @@ class FieldStrings:
             the_list = self.__fall_back_func(field_name, line)
             return the_list
         return the_list
+
     def __default_inst_func(self, field_name, name, line):
         """
         Requires:
@@ -234,6 +236,7 @@ class FieldStrings:
             I only need the changed name for the field.
         """
         return [None, None, name]
+
     def __fall_back_func(self, field_name,  line):
         """
         Requires:
@@ -248,6 +251,7 @@ class FieldStrings:
         the_string = field_name
         the_string += '<update>none'
         return [None, None, the_string]
+
     def __equation_func(self, field_name, name, line):
         """
         Requried:
@@ -259,6 +263,7 @@ class FieldStrings:
         Logic:
         """
         return [None, None, name]
+
     def __no_switch_func(self, field_name, name, line):
         """
         Required:
@@ -271,6 +276,7 @@ class FieldStrings:
         Logic:
         """
         return [None, None, name]
+
     def __num_type_and_format_func(self, field_name, name, line):
         """
         Required:
@@ -297,6 +303,7 @@ class FieldStrings:
                 arg = match_group.group(1)
                 the_string += '<argument>%s' % arg
         return [None, None, the_string]
+
     def __num_format_func(self, field_name, name, line):
         """
         Required:
@@ -312,6 +319,7 @@ class FieldStrings:
         if num_format:
             the_string += '<number-format>%s' % num_format
         return [None, None, the_string]
+
     def __parse_num_format(self, the_string):
         """
         Required:
@@ -324,6 +332,7 @@ class FieldStrings:
         match_group = re.search(self.__date_exp, the_string)
         if match_group:
             return match_group(1)
+
     def __parse_num_type(self, the_string):
         """
         Required:
@@ -348,6 +357,7 @@ class FieldStrings:
                 sys.stderr.write('module is fields_string\n')
                 sys.stderr.write('method is __parse_num_type\n')
                 sys.stderr.write('no dictionary entry for %s\n' % name)
+
     def __date_func(self, field_name, name, line):
         """
         Required:
@@ -364,6 +374,7 @@ class FieldStrings:
         if match_group:
             the_string += '<date-format>%s' % match_group.group(1)
         return [None, None, the_string]
+
     def __simple_info_func(self, field_name, name, line):
         """
         Requried:
@@ -391,6 +402,7 @@ class FieldStrings:
                 sys.stderr.write('method is __parse_num_type\n')
                 sys.stderr.write('no dictionary entry for %s\n' % name)
         return [None, None, the_string]
+
     def __hyperlink_func(self, field_name, name, line):
         """
         Requried:
@@ -428,6 +440,7 @@ class FieldStrings:
         if index > -1:
             the_string += '<no-history>true'
         return [None, None, the_string]
+
     def __include_text_func(self, field_name, name, line):
         """
         Requried:
@@ -469,6 +482,7 @@ class FieldStrings:
         if index > -1:
             the_string += '<no-field-update>true'
         return [None, None, the_string]
+
     def __include_pict_func(self, field_name, name, line):
         """
         Requried:
@@ -500,6 +514,7 @@ class FieldStrings:
         if index > -1:
             the_string += '<external>true'
         return [None, None, the_string]
+
     def __ref_func(self, field_name, name, line):
         """
         Requires:
@@ -527,7 +542,7 @@ class FieldStrings:
                 sys.stderr.write('no dictionary entry for %s\n' % name)
         line = re.sub(self.__merge_format_exp, '', line)
         words = line.split()
-        words = words[1:] #  get rid of field name
+        words = words[1:]  # get rid of field name
         for word in words:
             if word[0:1] != '\\':
                 the_string += '<bookmark>%s' % word
@@ -553,6 +568,7 @@ class FieldStrings:
         if index > -1:
             the_string += '<insert-number-full>true'
         return [None, None, the_string]
+
     def __toc_table_func(self, field_name, name, line):
         """
         Requires:
@@ -571,6 +587,7 @@ class FieldStrings:
             the_string = the_string.replace('table-of-contents', 'table-of-figures')
         # don't really need the first value in this list, I don't believe
         return [name, None, the_string]
+
     def __sequence_func(self, field_name, name, line):
         """
         Requires:
@@ -578,7 +595,7 @@ class FieldStrings:
             name --the changed name according to the dictionary.
             line -- the string to parse.
         Returns:
-            A string with a a value for the type and label attributes
+            A string with a value for the type and label attributes
         Logic:
             The type of sequence--whether figure, graph, my-name, or
             whatever--is represented by the second word in the string. Extract
@@ -589,6 +606,7 @@ class FieldStrings:
         label = fields[1]
         my_string = '%s<label>%s' % (name, label)
         return [None, None, my_string]
+
     def __ta_func(self, field_name, name, line):
         """
         Requires:
@@ -596,7 +614,7 @@ class FieldStrings:
             name --the changed name according to the dictionary.
             line -- the string to parse.
         Returns:
-            A string with a a value for the type and label attributes
+            A string with a value for the type and label attributes
         Logic:
         """
         the_string = name
@@ -619,6 +637,7 @@ class FieldStrings:
         if index > -1:
             the_string += '<italics>true'
         return [None, None, the_string]
+
     def __index_func(self, field_name, name, line):
         """
         Requires:
@@ -626,7 +645,7 @@ class FieldStrings:
             name --the changed name according to the dictionary.
             line -- the string to parse.
         Returns:
-            A string with a a value for the type and label attributes
+            A string with a value for the type and label attributes
         Logic:
         """
         # self.__index_insert_blank_line_exp = re.compile(r'\\h\s{1,}""')
@@ -691,6 +710,7 @@ class FieldStrings:
         if index > -1:
             the_string += '<enable-yomi-text>true'
         return [None, None, the_string]
+
     def __page_ref_func(self, field_name, name, line):
         """
         Requires:
@@ -710,7 +730,7 @@ class FieldStrings:
             the_string += '<number-type>%s' % num_type
         line = re.sub(self.__merge_format_exp, '', line)
         words = line.split()
-        words = words[1:] #  get rid of field name
+        words = words[1:]  # get rid of field name
         for word in words:
             if word[0:1] != '\\':
                 the_string += '<bookmark>%s' % word
@@ -721,6 +741,7 @@ class FieldStrings:
         if index > -1:
             the_string += '<paragraph-relative-position>true'
         return [None, None, the_string]
+
     def __note_ref_func(self, field_name, name, line):
         """
         Requires:
@@ -734,7 +755,7 @@ class FieldStrings:
         the_string = name
         line = re.sub(self.__merge_format_exp, '', line)
         words = line.split()
-        words = words[1:] #  get rid of field name
+        words = words[1:]  # get rid of field name
         for word in words:
             if word[0:1] != '\\':
                 the_string += '<bookmark>%s' % word
@@ -748,6 +769,7 @@ class FieldStrings:
         if index > -1:
             the_string += '<include-note-number>true'
         return [None, None, the_string]
+
     def __symbol_func(self, field_name, name, line):
         """
         Requires:
