@@ -10,9 +10,11 @@
 #                                                                       #
 #                                                                       #
 #########################################################################
-import sys, os, tempfile, re
+import sys, os, re
 
 from calibre.ebooks.rtf2xml import field_strings, copy
+from calibre.ptempfile import better_mktemp
+
 
 class FieldsSmall:
     """
@@ -31,11 +33,12 @@ until the closing bracket entry is found. Send the string to the module
 field_strings to process it. Write the processed string to the output
 file.
     """
+
     def __init__(self,
             in_file,
             bug_handler,
-            copy = None,
-            run_level = 1,
+            copy=None,
+            run_level=1,
             ):
         """
         Required:
@@ -50,14 +53,14 @@ file.
         self.__file = in_file
         self.__bug_handler = bug_handler
         self.__copy = copy
-        self.__write_to = tempfile.mktemp()
+        self.__write_to = better_mktemp()
         self.__run_level = run_level
 
     def __initiate_values(self):
         """
         Initiate all values.
         """
-        self.__string_obj = field_strings.FieldStrings(bug_handler = self.__bug_handler)
+        self.__string_obj = field_strings.FieldStrings(bug_handler=self.__bug_handler)
         self.__state = 'before_body'
         self.__text_string = ''
         self.__marker = 'mi<mk<inline-fld\n'
@@ -174,7 +177,7 @@ file.
             paragraphs within toc or index entries.
         """
         my_string, see_string = self.__index_see_func(my_string)
-        my_string, bookmark_string = self.__index_bookmark_func( my_string)
+        my_string, bookmark_string = self.__index_bookmark_func(my_string)
         italics, bold = self.__index__format_func(my_string)
         found_sub = 0
         my_changed_string = 'mi<tg<empty-att_<field<type>index-entry'
@@ -448,7 +451,7 @@ file.
                         sys.stderr.write('No matching state in module fields_small.py\n')
                         sys.stderr.write(self.__state + '\n')
                     action(line)
-        copy_obj = copy.Copy(bug_handler = self.__bug_handler)
+        copy_obj = copy.Copy(bug_handler=self.__bug_handler)
         if self.__copy:
             copy_obj.copy_file(self.__write_to, "fields_small.data")
         copy_obj.rename(self.__write_to, self.__file)
