@@ -10,8 +10,11 @@
 #                                                                       #
 #                                                                       #
 #########################################################################
-import sys, os, tempfile
+import sys, os
 from calibre.ebooks.rtf2xml import copy, border_parse
+from calibre.ptempfile import better_mktemp
+
+
 class ParagraphDef:
     """
 =================
@@ -36,7 +39,9 @@ If 'mi<mk<para-start' (the start of a paragraph) or 'mi<mk<para-end__' (the end
     state changes to 'in_paragraphs'
 If 'cw<pf<par-def___' (paragraph_definition) is found:
     state changes to collect_tokens
-if 'mi<mk<body-close', 'mi<mk<par-in-fld', 'cw<tb<cell______','cw<tb<row-def___','cw<tb<row_______',    'mi<mk<sect-close',   'mi<mk<header-beg',  'mi<mk<header-end'
+if 'mi<mk<body-close', 'mi<mk<par-in-fld',
+'cw<tb<cell______','cw<tb<row-def___','cw<tb<row_______',
+'mi<mk<sect-close',   'mi<mk<header-beg',  'mi<mk<header-end'
 are found. (All these tokens mark the start of a bigger element. para_def must
 be closed:
     state changes to  'after_para_def'
@@ -44,12 +49,13 @@ be closed:
 'mi<mk<para-start'  changes state to in_paragraphs
 if another paragraph_def is found, the state changes to collect_tokens.
     """
+
     def __init__(self,
         in_file,
         bug_handler,
         default_font,
-        copy = None,
-        run_level = 1,):
+        copy=None,
+        run_level=1,):
         """
         Required:
             'file'--file to parse
@@ -66,7 +72,8 @@ if another paragraph_def is found, the state changes to collect_tokens.
         self.__default_font = default_font
         self.__copy = copy
         self.__run_level = run_level
-        self.__write_to = tempfile.mktemp()
+        self.__write_to = better_mktemp()
+
     def __initiate_values(self):
         """
         Initiate all values.
@@ -74,160 +81,160 @@ if another paragraph_def is found, the state changes to collect_tokens.
         # Dictionary needed to convert shortened style names to readable names
         self.__token_dict={
         # paragraph formatting => pf
-        'par-end___'    :	'para',
-        'par-def___'    :	'paragraph-definition',
-        'keep-w-nex'    :	'keep-with-next',
-        'widow-cntl'    :	'widow-control',
-        'adjust-rgt'    :	'adjust-right',
-        'language__'    :	'language',
-        'right-inde'    :	'right-indent',
-        'fir-ln-ind'    :	'first-line-indent',
-        'left-inden'    :	'left-indent',
-        'space-befo'    :	'space-before',
-        'space-afte'    :	'space-after',
-        'line-space'    :	'line-spacing',
-        'default-ta'    :	'default-tab',
-        'align_____'    :	'align',
-        'widow-cntr'    :	'widow-control',
+        'par-end___'    : 'para',
+        'par-def___'    : 'paragraph-definition',
+        'keep-w-nex'    : 'keep-with-next',
+        'widow-cntl'    : 'widow-control',
+        'adjust-rgt'    : 'adjust-right',
+        'language__'    : 'language',
+        'right-inde'    : 'right-indent',
+        'fir-ln-ind'    : 'first-line-indent',
+        'left-inden'    : 'left-indent',
+        'space-befo'    : 'space-before',
+        'space-afte'    : 'space-after',
+        'line-space'    : 'line-spacing',
+        'default-ta'    : 'default-tab',
+        'align_____'    : 'align',
+        'widow-cntr'    : 'widow-control',
         # stylesheet = > ss
-        'style-shet'    :	'stylesheet',
-        'based-on__'    :	'based-on-style',
-        'next-style'    :	'next-style',
-        'char-style'    :	'character-style',
+        'style-shet'    : 'stylesheet',
+        'based-on__'    : 'based-on-style',
+        'next-style'    : 'next-style',
+        'char-style'    : 'character-style',
         # this is changed to get a nice attribute
-        'para-style'    :	'name',
+        'para-style'    : 'name',
         # graphics => gr
-        'picture___'    :	'pict',
-        'obj-class_'    :	'obj_class',
-        'mac-pic___'    :	'mac-pict',
+        'picture___'    : 'pict',
+        'obj-class_'    : 'obj_class',
+        'mac-pic___'    : 'mac-pict',
         # section => sc
-        'section___'    :	'section-new',
-        'sect-defin'    :	'section-reset',
-        'sect-note_'    :	'endnotes-in-section',
+        'section___'    : 'section-new',
+        'sect-defin'    : 'section-reset',
+        'sect-note_'    : 'endnotes-in-section',
         # list=> ls
-        'list-text_'    :	'list-text',
+        'list-text_'    : 'list-text',
         # this line must be wrong because it duplicates an earlier one
-        'list-text_'    :	'list-text',
-        'list______'    :	'list',
-        'list-lev-d'    :	'list-level-definition',
-        'list-cardi'    :	'list-cardinal-numbering',
-        'list-decim'    :	'list-decimal-numbering',
-        'list-up-al'    :	'list-uppercase-alphabetic-numbering',
-        'list-up-ro'    :	'list-uppercae-roman-numbering',
-        'list-ord__'    :	'list-ordinal-numbering',
-        'list-ordte'    :	'list-ordinal-text-numbering',
-        'list-bulli'    :	'list-bullet',
-        'list-simpi'    :	'list-simple',
-        'list-conti'    :	'list-continue',
-        'list-hang_'    :	'list-hang',
+        'list-text_'    : 'list-text',
+        'list______'    : 'list',
+        'list-lev-d'    : 'list-level-definition',
+        'list-cardi'    : 'list-cardinal-numbering',
+        'list-decim'    : 'list-decimal-numbering',
+        'list-up-al'    : 'list-uppercase-alphabetic-numbering',
+        'list-up-ro'    : 'list-uppercae-roman-numbering',
+        'list-ord__'    : 'list-ordinal-numbering',
+        'list-ordte'    : 'list-ordinal-text-numbering',
+        'list-bulli'    : 'list-bullet',
+        'list-simpi'    : 'list-simple',
+        'list-conti'    : 'list-continue',
+        'list-hang_'    : 'list-hang',
         # 'list-tebef'    :	'list-text-before',
-        'list-level'    :	'level',
-        'list-id___'    :	'list-id',
-        'list-start'    :	'list-start',
-        'nest-level'    :	'nest-level',
+        'list-level'    : 'level',
+        'list-id___'    : 'list-id',
+        'list-start'    : 'list-start',
+        'nest-level'    : 'nest-level',
         # duplicate
-        'list-level'    :	'list-level',
+        'list-level'    : 'list-level',
         # notes => nt
-        'footnote__'    :	'footnote',
-        'type______'    :	'type',
+        'footnote__'    : 'footnote',
+        'type______'    : 'type',
         # anchor => an
-        'toc_______'    :	'anchor-toc',
-        'book-mk-st'    :	'bookmark-start',
-        'book-mk-en'    :	'bookmark-end',
-        'index-mark'    :	'anchor-index',
-        'place_____'    :	'place',
+        'toc_______'    : 'anchor-toc',
+        'book-mk-st'    : 'bookmark-start',
+        'book-mk-en'    : 'bookmark-end',
+        'index-mark'    : 'anchor-index',
+        'place_____'    : 'place',
         # field => fd
-        'field_____'    :	'field',
-        'field-inst'    :	'field-instruction',
-        'field-rslt'    :	'field-result',
-        'datafield_'    :	'data-field',
+        'field_____'    : 'field',
+        'field-inst'    : 'field-instruction',
+        'field-rslt'    : 'field-result',
+        'datafield_'    : 'data-field',
         # info-tables => it
-        'font-table'    :	'font-table',
-        'colr-table'    :	'color-table',
-        'lovr-table'    :	'list-override-table',
-        'listtable_'    :	'list-table',
-        'revi-table'    :	'revision-table',
+        'font-table'    : 'font-table',
+        'colr-table'    : 'color-table',
+        'lovr-table'    : 'list-override-table',
+        'listtable_'    : 'list-table',
+        'revi-table'    : 'revision-table',
         # character info => ci
-        'hidden____'    :	'hidden',
-        'italics___'    :	'italics',
-        'bold______'    :	'bold',
-        'strike-thr'   :	'strike-through',
-        'shadow____'   :	'shadow',
-        'outline___'   :	'outline',
-        'small-caps'   :	'small-caps',
+        'hidden____'    : 'hidden',
+        'italics___'    : 'italics',
+        'bold______'    : 'bold',
+        'strike-thr'   : 'strike-through',
+        'shadow____'   : 'shadow',
+        'outline___'   : 'outline',
+        'small-caps'   : 'small-caps',
         'caps______'   :       'caps',
-        'dbl-strike'   :	'double-strike-through',
-        'emboss____'    :	'emboss',
-        'engrave___'    :	'engrave',
-        'subscript_'    :	'subscript',
-        'superscrip'    :	'superscipt',
-        'font-style'    :	'font-style',
-        'font-color'    :	'font-color',
-        'font-size_'    :	'font-size',
-        'font-up___'    :	'superscript',
-        'font-down_'    :	'subscript',
-        'red_______'    :	'red',
-        'blue______'    :	'blue',
-        'green_____'    :	'green',
+        'dbl-strike'   : 'double-strike-through',
+        'emboss____'    : 'emboss',
+        'engrave___'    : 'engrave',
+        'subscript_'    : 'subscript',
+        'superscrip'    : 'superscipt',
+        'font-style'    : 'font-style',
+        'font-color'    : 'font-color',
+        'font-size_'    : 'font-size',
+        'font-up___'    : 'superscript',
+        'font-down_'    : 'subscript',
+        'red_______'    : 'red',
+        'blue______'    : 'blue',
+        'green_____'    : 'green',
         # table => tb
-        'row-def___'    :	'row-definition',
-        'cell______'    :	'cell',
-        'row_______'    :	'row',
-        'in-table__'    :	'in-table',
-        'columns___'    :	'columns',
-        'row-pos-le'    :	'row-position-left',
-        'cell-posit'    :	'cell-position',
+        'row-def___'    : 'row-definition',
+        'cell______'    : 'cell',
+        'row_______'    : 'row',
+        'in-table__'    : 'in-table',
+        'columns___'    : 'columns',
+        'row-pos-le'    : 'row-position-left',
+        'cell-posit'    : 'cell-position',
         # preamble => pr
         # underline
-        'underlined'    :	'underlined',
+        'underlined'    : 'underlined',
         # border => bd
-        'bor-t-r-hi'    :	'border-table-row-horizontal-inside',
-        'bor-t-r-vi'    :	'border-table-row-vertical-inside',
-        'bor-t-r-to'    :	'border-table-row-top',
-        'bor-t-r-le'    :	'border-table-row-left',
-        'bor-t-r-bo'    :	'border-table-row-bottom',
-        'bor-t-r-ri'    :	'border-table-row-right',
-        'bor-cel-bo'    :	'border-cell-bottom',
-        'bor-cel-to'    :	'border-cell-top',
-        'bor-cel-le'    :	'border-cell-left',
-        'bor-cel-ri'    :	'border-cell-right',
-        'bor-par-bo'    :	'border-paragraph-bottom',
-        'bor-par-to'    :	'border-paragraph-top',
-        'bor-par-le'    :	'border-paragraph-left',
-        'bor-par-ri'    :	'border-paragraph-right',
-        'bor-par-bo'    :	'border-paragraph-box',
-        'bor-for-ev'    :	'border-for-every-paragraph',
-        'bor-outsid'    :	'border-outisde',
-        'bor-none__'    :	'border',
+        'bor-t-r-hi'    : 'border-table-row-horizontal-inside',
+        'bor-t-r-vi'    : 'border-table-row-vertical-inside',
+        'bor-t-r-to'    : 'border-table-row-top',
+        'bor-t-r-le'    : 'border-table-row-left',
+        'bor-t-r-bo'    : 'border-table-row-bottom',
+        'bor-t-r-ri'    : 'border-table-row-right',
+        'bor-cel-bo'    : 'border-cell-bottom',
+        'bor-cel-to'    : 'border-cell-top',
+        'bor-cel-le'    : 'border-cell-left',
+        'bor-cel-ri'    : 'border-cell-right',
+        'bor-par-bo'    : 'border-paragraph-bottom',
+        'bor-par-to'    : 'border-paragraph-top',
+        'bor-par-le'    : 'border-paragraph-left',
+        'bor-par-ri'    : 'border-paragraph-right',
+        'bor-par-bo'    : 'border-paragraph-box',
+        'bor-for-ev'    : 'border-for-every-paragraph',
+        'bor-outsid'    : 'border-outisde',
+        'bor-none__'    : 'border',
         # border type => bt
-        'bdr-single'    :	'single',
-        'bdr-doubtb'    :	'double-thickness-border',
-        'bdr-shadow'    :	'shadowed-border',
-        'bdr-double'    :	'double-border',
-        'bdr-dotted'    :	'dotted-border',
-        'bdr-dashed'    :	'dashed',
-        'bdr-hair__'    :	'hairline',
-        'bdr-inset_'    :	'inset',
-        'bdr-das-sm'    :	'dash-small',
-        'bdr-dot-sm'    :	'dot-dash',
-        'bdr-dot-do'    :	'dot-dot-dash',
-        'bdr-outset'    :	'outset',
-        'bdr-trippl'    :	'tripple',
-        'bdr-thsm__'    :	'thick-thin-small',
-        'bdr-htsm__'    :	'thin-thick-small',
-        'bdr-hthsm_'    :	'thin-thick-thin-small',
-        'bdr-thm__'     :	'thick-thin-medium',
-        'bdr-htm__'     :	'thin-thick-medium',
-        'bdr-hthm_'     :	'thin-thick-thin-medium',
-        'bdr-thl__'     :	'thick-thin-large',
-        'bdr-hthl_'     :	'think-thick-think-large',
-        'bdr-wavy_'     :	'wavy',
-        'bdr-d-wav'     :	'double-wavy',
-        'bdr-strip'     :	'striped',
-        'bdr-embos'     :	'emboss',
-        'bdr-engra'     :	'engrave',
-        'bdr-frame'     :	'frame',
-        'bdr-li-wid'    :	'line-width',
+        'bdr-single'    : 'single',
+        'bdr-doubtb'    : 'double-thickness-border',
+        'bdr-shadow'    : 'shadowed-border',
+        'bdr-double'    : 'double-border',
+        'bdr-dotted'    : 'dotted-border',
+        'bdr-dashed'    : 'dashed',
+        'bdr-hair__'    : 'hairline',
+        'bdr-inset_'    : 'inset',
+        'bdr-das-sm'    : 'dash-small',
+        'bdr-dot-sm'    : 'dot-dash',
+        'bdr-dot-do'    : 'dot-dot-dash',
+        'bdr-outset'    : 'outset',
+        'bdr-trippl'    : 'tripple',
+        'bdr-thsm__'    : 'thick-thin-small',
+        'bdr-htsm__'    : 'thin-thick-small',
+        'bdr-hthsm_'    : 'thin-thick-thin-small',
+        'bdr-thm__'     : 'thick-thin-medium',
+        'bdr-htm__'     : 'thin-thick-medium',
+        'bdr-hthm_'     : 'thin-thick-thin-medium',
+        'bdr-thl__'     : 'thick-thin-large',
+        'bdr-hthl_'     : 'think-thick-think-large',
+        'bdr-wavy_'     : 'wavy',
+        'bdr-d-wav'     : 'double-wavy',
+        'bdr-strip'     : 'striped',
+        'bdr-embos'     : 'emboss',
+        'bdr-engra'     : 'engrave',
+        'bdr-frame'     : 'frame',
+        'bdr-li-wid'    : 'line-width',
         }
         self.__tabs_dict = {
         'cw<pf<tab-stop__'  :   self.__tab_stop_func,
@@ -252,10 +259,10 @@ if another paragraph_def is found, the state changes to collect_tokens.
         self.__body_style_strings = []
         self.__state = 'before_1st_para_def'
         self.__att_val_dict = {}
-        self.__start_marker =  'mi<mk<pard-start\n' # outside para tags
-        self.__start2_marker = 'mi<mk<pardstart_\n' # inside para tags
-        self.__end2_marker =   'mi<mk<pardend___\n' # inside para tags
-        self.__end_marker =    'mi<mk<pard-end__\n' # outside para tags
+        self.__start_marker =  'mi<mk<pard-start\n'  # outside para tags
+        self.__start2_marker = 'mi<mk<pardstart_\n'  # inside para tags
+        self.__end2_marker =   'mi<mk<pardend___\n'  # inside para tags
+        self.__end_marker =    'mi<mk<pard-end__\n'  # outside para tags
         self.__text_string = ''
         self.__state_dict = {
         'before_1st_para_def'   : self.__before_1st_para_def_func,
@@ -296,6 +303,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
         'mi<mk<fldbk-end_'      : self.__stop_block_func,
         'mi<mk<lst-txbeg_'      : self.__stop_block_func,
         }
+
     def __before_1st_para_def_func(self, line):
         """
         Required:
@@ -305,16 +313,18 @@ if another paragraph_def is found, the state changes to collect_tokens.
         Logic:
             Look for the beginning of a paragaraph definition
         """
-        ##cw<pf<par-def___<nu<true
+        # cw<pf<par-def___<nu<true
         if self.__token_info == 'cw<pf<par-def___':
             self.__found_para_def_func()
         else:
             self.__write_obj.write(line)
+
     def __found_para_def_func(self):
         self.__state = 'collect_tokens'
         # not exactly right--have to reset the dictionary--give it default
         # values
         self.__reset_dict()
+
     def __collect_tokens_func(self, line):
         """
         Required:
@@ -346,38 +356,43 @@ if another paragraph_def is found, the state changes to collect_tokens.
                 token = self.__token_dict.get(line[6:16])
                 if token:
                     self.__att_val_dict[token] = line[20:-1]
+
     def __tab_stop_func(self, line):
         """
         """
         self.__att_val_dict['tabs'] += '%s:' % self.__tab_type
         self.__att_val_dict['tabs'] += '%s;' % line[20:-1]
         self.__tab_type = 'left'
+
     def __tab_type_func(self, line):
         """
         """
         type = self.__tab_type_dict.get(self.__token_info)
-        if type != None:
+        if type is not None:
             self.__tab_type = type
         else:
             if self.__run_level > 3:
                 msg = 'no entry for %s\n' % self.__token_info
                 raise self.__bug_handler, msg
+
     def __tab_leader_func(self, line):
         """
         """
         leader = self.__tab_type_dict.get(self.__token_info)
-        if leader != None:
+        if leader is not None:
             self.__att_val_dict['tabs'] += '%s^' % leader
         else:
             if self.__run_level > 3:
                 msg = 'no entry for %s\n' % self.__token_info
                 raise self.__bug_handler, msg
+
     def __tab_bar_func(self, line):
         """
         """
         # self.__att_val_dict['tabs-bar'] += '%s:' % line[20:-1]
         self.__att_val_dict['tabs'] += 'bar:%s;' % (line[20:-1])
         self.__tab_type = 'left'
+
     def __parse_border(self, line):
         """
         Requires:
@@ -390,6 +405,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
         """
         border_dict = self.__border_obj.parse_border(line)
         self.__att_val_dict.update(border_dict)
+
     def __para_def_in_para_def_func(self, line):
         """
         Requires:
@@ -403,6 +419,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
         # Change this
         self.__state = 'collect_tokens'
         self.__reset_dict()
+
     def __end_para_def_func(self, line):
         """
         Requires:
@@ -418,6 +435,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
         self.__write_para_def_beg()
         self.__write_obj.write(line)
         self.__state = 'in_paragraphs'
+
     def __start_para_after_def_func(self, line):
         """
         Requires:
@@ -434,6 +452,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
         self.__write_para_def_beg()
         self.__write_obj.write(line)
         self.__state = 'in_paragraphs'
+
     def __after_para_def_func(self, line):
         """
         Requires:
@@ -451,6 +470,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
             action(line)
         else:
             self.__write_obj.write(line)
+
     def __in_paragraphs_func(self, line):
         """
         Requires:
@@ -465,6 +485,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
             action(line)
         else:
             self.__write_obj.write(line)
+
     def __found_para_end_func(self,line):
         """
         Requires:
@@ -478,6 +499,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
         """
         self.__state = 'after_para_end'
         self.__write_obj.write(line)
+
     def __after_para_end_func(self, line):
         """
         Requires:
@@ -501,6 +523,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
         action = self.__after_para_end_dict.get(self.__token_info)
         if action:
             action(line)
+
     def __continue_block_func(self, line):
         """
         Requires:
@@ -517,6 +540,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
         self.__write_obj.write(self.__text_string)
         self.__text_string = ''
     # found a new paragraph definition after an end of a paragraph
+
     def __new_para_def_func(self, line):
         """
         Requires:
@@ -532,6 +556,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
         self.__write_para_def_end_func()
         self.__found_para_def_func()
     # after a paragraph and found reason to stop this block
+
     def __stop_block_func(self, line):
         """
         Requires:
@@ -546,6 +571,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
         """
         self.__write_para_def_end_func()
         self.__state = 'after_para_def'
+
     def __write_para_def_end_func(self):
         """
         Requires:
@@ -567,6 +593,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
             self.__write_obj.write('mi<mk<font-end__\n')
         if 'caps' in keys:
             self.__write_obj.write('mi<mk<caps-end__\n')
+
     def __get_num_of_style(self):
         """
         Requires:
@@ -589,7 +616,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
             my_string += '%s:%s' % (key, self.__att_val_dict[key])
         if my_string in self.__style_num_strings:
             num = self.__style_num_strings.index(my_string)
-            num += 1 # since indexing starts at zero, rather than 1
+            num += 1  # since indexing starts at zero, rather than 1
         else:
             self.__style_num_strings.append(my_string)
             num = len(self.__style_num_strings)
@@ -598,6 +625,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
         self.__att_val_dict['style-num'] = 's' + str(num)
         if new_style:
             self.__write_body_styles()
+
     def __write_body_styles(self):
         style_string = ''
         style_string += 'mi<tg<empty-att_<paragraph-style-in-body'
@@ -617,6 +645,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
                 style_string += ('<%s>%s' % (key, self.__att_val_dict[key]))
         style_string += '\n'
         self.__body_style_strings.append(style_string)
+
     def __write_para_def_beg(self):
         """
         Requires:
@@ -675,10 +704,12 @@ if another paragraph_def is found, the state changes to collect_tokens.
         if 'caps' in keys:
             value = self.__att_val_dict['caps']
             self.__write_obj.write('mi<mk<caps______<%s\n' % value)
+
     def __empty_table_element_func(self, line):
         self.__write_obj.write('mi<mk<in-table__\n')
         self.__write_obj.write(line)
         self.__state = 'after_para_def'
+
     def __reset_dict(self):
         """
         Requires:
@@ -699,6 +730,7 @@ if another paragraph_def is found, the state changes to collect_tokens.
         self.__att_val_dict['tabs-decimal'] = ''
         self.__att_val_dict['tabs-bar'] = ''
         self.__att_val_dict['tabs'] = ''
+
     def make_paragraph_def(self):
         """
         Requires:
@@ -718,13 +750,13 @@ if another paragraph_def is found, the state changes to collect_tokens.
             line = line_to_read
             self.__token_info = line[:16]
             action = self.__state_dict.get(self.__state)
-            if action == None:
+            if action is None:
                 sys.stderr.write('no no matching state in module sections.py\n')
                 sys.stderr.write(self.__state + '\n')
             action(line)
         read_obj.close()
         self.__write_obj.close()
-        copy_obj = copy.Copy(bug_handler = self.__bug_handler)
+        copy_obj = copy.Copy(bug_handler=self.__bug_handler)
         if self.__copy:
             copy_obj.copy_file(self.__write_to, "paragraphs_def.data")
         copy_obj.rename(self.__write_to, self.__file)
