@@ -9,7 +9,7 @@ A Humane Web Text Generator
 
 # Last upstream version basis
 # __version__ = '2.1.4'
-#__date__ = '2009/12/04'
+# __date__ = '2009/12/04'
 
 __copyright__ = """
 Copyright (c) 2011, Leigh Parry <leighparry@blueyonder.co.uk>
@@ -66,6 +66,7 @@ from urlparse import urlparse
 
 from calibre.utils.smartypants import smartyPants
 
+
 def _normalize_newlines(string):
     out = re.sub(r'\r\n', '\n', string)
     out = re.sub(r'\n{3,}', '\n\n', out)
@@ -73,6 +74,7 @@ def _normalize_newlines(string):
     out = re.sub(r'"$', '" ', out)
     return out
 
+
 def getimagesize(url):
     """
     Attempts to determine an image's width and height, and returns a string
@@ -111,6 +113,7 @@ def getimagesize(url):
     except (IOError, ValueError):
         return None
 
+
 class Textile(object):
     hlgn = r'(?:\<(?!>)|(?<!<)\>|\<\>|\=|[()]+(?! ))'
     vlgn = r'[\-^~]'
@@ -133,143 +136,142 @@ class Textile(object):
     btag_lite = ('bq', 'bc', 'p')
 
     macro_defaults = [
-        (re.compile(r'{(c\||\|c)}'),     r'&#162;'),   #  cent
-        (re.compile(r'{(L-|-L)}'),       r'&#163;'),   #  pound
-        (re.compile(r'{(Y=|=Y)}'),       r'&#165;'),   #  yen
-        (re.compile(r'{\(c\)}'),         r'&#169;'),   #  copyright
-        (re.compile(r'{\(r\)}'),         r'&#174;'),   #  registered
-        (re.compile(r'{(\+_|_\+)}'),     r'&#177;'),   #  plus-minus
-        (re.compile(r'{1/4}'),           r'&#188;'),   #  quarter
-        (re.compile(r'{1/2}'),           r'&#189;'),   #  half
-        (re.compile(r'{3/4}'),           r'&#190;'),   #  three-quarter
-        (re.compile(r'{(A`|`A)}'),       r'&#192;'),   #  A-acute
-        (re.compile(r'{(A\'|\'A)}'),     r'&#193;'),   #  A-grave
-        (re.compile(r'{(A\^|\^A)}'),     r'&#194;'),   #  A-circumflex
-        (re.compile(r'{(A~|~A)}'),       r'&#195;'),   #  A-tilde
-        (re.compile(r'{(A\"|\"A)}'),     r'&#196;'),   #  A-diaeresis
-        (re.compile(r'{(Ao|oA)}'),       r'&#197;'),   #  A-ring
-        (re.compile(r'{(AE)}'),          r'&#198;'),   #  AE
-        (re.compile(r'{(C,|,C)}'),       r'&#199;'),   #  C-cedilla
-        (re.compile(r'{(E`|`E)}'),       r'&#200;'),   #  E-acute
-        (re.compile(r'{(E\'|\'E)}'),     r'&#201;'),   #  E-grave
-        (re.compile(r'{(E\^|\^E)}'),     r'&#202;'),   #  E-circumflex
-        (re.compile(r'{(E\"|\"E)}'),     r'&#203;'),   #  E-diaeresis
-        (re.compile(r'{(I`|`I)}'),       r'&#204;'),   #  I-acute
-        (re.compile(r'{(I\'|\'I)}'),     r'&#205;'),   #  I-grave
-        (re.compile(r'{(I\^|\^I)}'),     r'&#206;'),   #  I-circumflex
-        (re.compile(r'{(I\"|\"I)}'),     r'&#207;'),   #  I-diaeresis
-        (re.compile(r'{(D-|-D)}'),       r'&#208;'),   #  ETH
-        (re.compile(r'{(N~|~N)}'),       r'&#209;'),   #  N-tilde
-        (re.compile(r'{(O`|`O)}'),       r'&#210;'),   #  O-acute
-        (re.compile(r'{(O\'|\'O)}'),     r'&#211;'),   #  O-grave
-        (re.compile(r'{(O\^|\^O)}'),     r'&#212;'),   #  O-circumflex
-        (re.compile(r'{(O~|~O)}'),       r'&#213;'),   #  O-tilde
-        (re.compile(r'{(O\"|\"O)}'),     r'&#214;'),   #  O-diaeresis
-        (re.compile(r'{x}'),             r'&#215;'),   #  dimension
-        (re.compile(r'{(O\/|\/O)}'),     r'&#216;'),   #  O-slash
-        (re.compile(r'{(U`|`U)}'),       r'&#217;'),   #  U-acute
-        (re.compile(r'{(U\'|\'U)}'),     r'&#218;'),   #  U-grave
-        (re.compile(r'{(U\^|\^U)}'),     r'&#219;'),   #  U-circumflex
-        (re.compile(r'{(U\"|\"U)}'),     r'&#220;'),   #  U-diaeresis
-        (re.compile(r'{(Y\'|\'Y)}'),     r'&#221;'),   #  Y-grave
-        (re.compile(r'{sz}'),            r'&szlig;'),  #  sharp-s
-        (re.compile(r'{(a`|`a)}'),       r'&#224;'),   #  a-grave
-        (re.compile(r'{(a\'|\'a)}'),     r'&#225;'),   #  a-acute
-        (re.compile(r'{(a\^|\^a)}'),     r'&#226;'),   #  a-circumflex
-        (re.compile(r'{(a~|~a)}'),       r'&#227;'),   #  a-tilde
-        (re.compile(r'{(a\"|\"a)}'),     r'&#228;'),   #  a-diaeresis
-        (re.compile(r'{(ao|oa)}'),       r'&#229;'),   #  a-ring
-        (re.compile(r'{ae}'),            r'&#230;'),   #  ae
-        (re.compile(r'{(c,|,c)}'),       r'&#231;'),   #  c-cedilla
-        (re.compile(r'{(e`|`e)}'),       r'&#232;'),   #  e-grave
-        (re.compile(r'{(e\'|\'e)}'),     r'&#233;'),   #  e-acute
-        (re.compile(r'{(e\^|\^e)}'),     r'&#234;'),   #  e-circumflex
-        (re.compile(r'{(e\"|\"e)}'),     r'&#235;'),   #  e-diaeresis
-        (re.compile(r'{(i`|`i)}'),       r'&#236;'),   #  i-grave
-        (re.compile(r'{(i\'|\'i)}'),     r'&#237;'),   #  i-acute
-        (re.compile(r'{(i\^|\^i)}'),     r'&#238;'),   #  i-circumflex
-        (re.compile(r'{(i\"|\"i)}'),     r'&#239;'),   #  i-diaeresis
-        (re.compile(r'{(d-|-d)}'),       r'&#240;'),   #  eth
-        (re.compile(r'{(n~|~n)}'),       r'&#241;'),   #  n-tilde
-        (re.compile(r'{(o`|`o)}'),       r'&#242;'),   #  o-grave
-        (re.compile(r'{(o\'|\'o)}'),     r'&#243;'),   #  o-acute
-        (re.compile(r'{(o\^|\^o)}'),     r'&#244;'),   #  o-circumflex
-        (re.compile(r'{(o~|~o)}'),       r'&#245;'),   #  o-tilde
-        (re.compile(r'{(o\"|\"o)}'),     r'&#246;'),   #  o-diaeresis
-        (re.compile(r'{(o\/|\/o)}'),     r'&#248;'),   #  o-stroke
-        (re.compile(r'{(u`|`u)}'),       r'&#249;'),   #  u-grave
-        (re.compile(r'{(u\'|\'u)}'),     r'&#250;'),   #  u-acute
-        (re.compile(r'{(u\^|\^u)}'),     r'&#251;'),   #  u-circumflex
-        (re.compile(r'{(u\"|\"u)}'),     r'&#252;'),   #  u-diaeresis
-        (re.compile(r'{(y\'|\'y)}'),     r'&#253;'),   #  y-acute
-        (re.compile(r'{(y\"|\"y)}'),     r'&#255;'),   #  y-diaeresis
+        (re.compile(r'{(c\||\|c)}'),     r'&#162;'),  # cent
+        (re.compile(r'{(L-|-L)}'),       r'&#163;'),  # pound
+        (re.compile(r'{(Y=|=Y)}'),       r'&#165;'),  # yen
+        (re.compile(r'{\(c\)}'),         r'&#169;'),  # copyright
+        (re.compile(r'{\(r\)}'),         r'&#174;'),  # registered
+        (re.compile(r'{(\+_|_\+)}'),     r'&#177;'),  # plus-minus
+        (re.compile(r'{1/4}'),           r'&#188;'),  # quarter
+        (re.compile(r'{1/2}'),           r'&#189;'),  # half
+        (re.compile(r'{3/4}'),           r'&#190;'),  # three-quarter
+        (re.compile(r'{(A`|`A)}'),       r'&#192;'),  # A-acute
+        (re.compile(r'{(A\'|\'A)}'),     r'&#193;'),  # A-grave
+        (re.compile(r'{(A\^|\^A)}'),     r'&#194;'),  # A-circumflex
+        (re.compile(r'{(A~|~A)}'),       r'&#195;'),  # A-tilde
+        (re.compile(r'{(A\"|\"A)}'),     r'&#196;'),  # A-diaeresis
+        (re.compile(r'{(Ao|oA)}'),       r'&#197;'),  # A-ring
+        (re.compile(r'{(AE)}'),          r'&#198;'),  # AE
+        (re.compile(r'{(C,|,C)}'),       r'&#199;'),  # C-cedilla
+        (re.compile(r'{(E`|`E)}'),       r'&#200;'),  # E-acute
+        (re.compile(r'{(E\'|\'E)}'),     r'&#201;'),  # E-grave
+        (re.compile(r'{(E\^|\^E)}'),     r'&#202;'),  # E-circumflex
+        (re.compile(r'{(E\"|\"E)}'),     r'&#203;'),  # E-diaeresis
+        (re.compile(r'{(I`|`I)}'),       r'&#204;'),  # I-acute
+        (re.compile(r'{(I\'|\'I)}'),     r'&#205;'),  # I-grave
+        (re.compile(r'{(I\^|\^I)}'),     r'&#206;'),  # I-circumflex
+        (re.compile(r'{(I\"|\"I)}'),     r'&#207;'),  # I-diaeresis
+        (re.compile(r'{(D-|-D)}'),       r'&#208;'),  # ETH
+        (re.compile(r'{(N~|~N)}'),       r'&#209;'),  # N-tilde
+        (re.compile(r'{(O`|`O)}'),       r'&#210;'),  # O-acute
+        (re.compile(r'{(O\'|\'O)}'),     r'&#211;'),  # O-grave
+        (re.compile(r'{(O\^|\^O)}'),     r'&#212;'),  # O-circumflex
+        (re.compile(r'{(O~|~O)}'),       r'&#213;'),  # O-tilde
+        (re.compile(r'{(O\"|\"O)}'),     r'&#214;'),  # O-diaeresis
+        (re.compile(r'{x}'),             r'&#215;'),  # dimension
+        (re.compile(r'{(O\/|\/O)}'),     r'&#216;'),  # O-slash
+        (re.compile(r'{(U`|`U)}'),       r'&#217;'),  # U-acute
+        (re.compile(r'{(U\'|\'U)}'),     r'&#218;'),  # U-grave
+        (re.compile(r'{(U\^|\^U)}'),     r'&#219;'),  # U-circumflex
+        (re.compile(r'{(U\"|\"U)}'),     r'&#220;'),  # U-diaeresis
+        (re.compile(r'{(Y\'|\'Y)}'),     r'&#221;'),  # Y-grave
+        (re.compile(r'{sz}'),            r'&szlig;'),  # sharp-s
+        (re.compile(r'{(a`|`a)}'),       r'&#224;'),  # a-grave
+        (re.compile(r'{(a\'|\'a)}'),     r'&#225;'),  # a-acute
+        (re.compile(r'{(a\^|\^a)}'),     r'&#226;'),  # a-circumflex
+        (re.compile(r'{(a~|~a)}'),       r'&#227;'),  # a-tilde
+        (re.compile(r'{(a\"|\"a)}'),     r'&#228;'),  # a-diaeresis
+        (re.compile(r'{(ao|oa)}'),       r'&#229;'),  # a-ring
+        (re.compile(r'{ae}'),            r'&#230;'),  # ae
+        (re.compile(r'{(c,|,c)}'),       r'&#231;'),  # c-cedilla
+        (re.compile(r'{(e`|`e)}'),       r'&#232;'),  # e-grave
+        (re.compile(r'{(e\'|\'e)}'),     r'&#233;'),  # e-acute
+        (re.compile(r'{(e\^|\^e)}'),     r'&#234;'),  # e-circumflex
+        (re.compile(r'{(e\"|\"e)}'),     r'&#235;'),  # e-diaeresis
+        (re.compile(r'{(i`|`i)}'),       r'&#236;'),  # i-grave
+        (re.compile(r'{(i\'|\'i)}'),     r'&#237;'),  # i-acute
+        (re.compile(r'{(i\^|\^i)}'),     r'&#238;'),  # i-circumflex
+        (re.compile(r'{(i\"|\"i)}'),     r'&#239;'),  # i-diaeresis
+        (re.compile(r'{(d-|-d)}'),       r'&#240;'),  # eth
+        (re.compile(r'{(n~|~n)}'),       r'&#241;'),  # n-tilde
+        (re.compile(r'{(o`|`o)}'),       r'&#242;'),  # o-grave
+        (re.compile(r'{(o\'|\'o)}'),     r'&#243;'),  # o-acute
+        (re.compile(r'{(o\^|\^o)}'),     r'&#244;'),  # o-circumflex
+        (re.compile(r'{(o~|~o)}'),       r'&#245;'),  # o-tilde
+        (re.compile(r'{(o\"|\"o)}'),     r'&#246;'),  # o-diaeresis
+        (re.compile(r'{(o\/|\/o)}'),     r'&#248;'),  # o-stroke
+        (re.compile(r'{(u`|`u)}'),       r'&#249;'),  # u-grave
+        (re.compile(r'{(u\'|\'u)}'),     r'&#250;'),  # u-acute
+        (re.compile(r'{(u\^|\^u)}'),     r'&#251;'),  # u-circumflex
+        (re.compile(r'{(u\"|\"u)}'),     r'&#252;'),  # u-diaeresis
+        (re.compile(r'{(y\'|\'y)}'),     r'&#253;'),  # y-acute
+        (re.compile(r'{(y\"|\"y)}'),     r'&#255;'),  # y-diaeresis
 
-        (re.compile(r'{(C\ˇ|\ˇC)}'),     r'&#268;'),   #  C-caron
-        (re.compile(r'{(c\ˇ|\ˇc)}'),     r'&#269;'),   #  c-caron
-        (re.compile(r'{(D\ˇ|\ˇD)}'),     r'&#270;'),   #  D-caron
-        (re.compile(r'{(d\ˇ|\ˇd)}'),     r'&#271;'),   #  d-caron
-        (re.compile(r'{(E\ˇ|\ˇE)}'),     r'&#282;'),   #  E-caron
-        (re.compile(r'{(e\ˇ|\ˇe)}'),     r'&#283;'),   #  e-caron
-        (re.compile(r'{(L\'|\'L)}'),     r'&#313;'),   #  L-acute
-        (re.compile(r'{(l\'|\'l)}'),     r'&#314;'),   #  l-acute
-        (re.compile(r'{(L\ˇ|\ˇL)}'),     r'&#317;'),   #  L-caron
-        (re.compile(r'{(l\ˇ|\ˇl)}'),     r'&#318;'),   #  l-caron
-        (re.compile(r'{(N\ˇ|\ˇN)}'),     r'&#327;'),   #  N-caron
-        (re.compile(r'{(n\ˇ|\ˇn)}'),     r'&#328;'),   #  n-caron
+        (re.compile(r'{(C\ˇ|\ˇC)}'),     r'&#268;'),  # C-caron
+        (re.compile(r'{(c\ˇ|\ˇc)}'),     r'&#269;'),  # c-caron
+        (re.compile(r'{(D\ˇ|\ˇD)}'),     r'&#270;'),  # D-caron
+        (re.compile(r'{(d\ˇ|\ˇd)}'),     r'&#271;'),  # d-caron
+        (re.compile(r'{(E\ˇ|\ˇE)}'),     r'&#282;'),  # E-caron
+        (re.compile(r'{(e\ˇ|\ˇe)}'),     r'&#283;'),  # e-caron
+        (re.compile(r'{(L\'|\'L)}'),     r'&#313;'),  # L-acute
+        (re.compile(r'{(l\'|\'l)}'),     r'&#314;'),  # l-acute
+        (re.compile(r'{(L\ˇ|\ˇL)}'),     r'&#317;'),  # L-caron
+        (re.compile(r'{(l\ˇ|\ˇl)}'),     r'&#318;'),  # l-caron
+        (re.compile(r'{(N\ˇ|\ˇN)}'),     r'&#327;'),  # N-caron
+        (re.compile(r'{(n\ˇ|\ˇn)}'),     r'&#328;'),  # n-caron
 
-        (re.compile(r'{OE}'),            r'&#338;'),   #  OE
-        (re.compile(r'{oe}'),            r'&#339;'),   #  oe
+        (re.compile(r'{OE}'),            r'&#338;'),  # OE
+        (re.compile(r'{oe}'),            r'&#339;'),  # oe
 
-        (re.compile(r'{(R\'|\'R)}'),     r'&#340;'),   #  R-acute
-        (re.compile(r'{(r\'|\'r)}'),     r'&#341;'),   #  r-acute
-        (re.compile(r'{(R\ˇ|\ˇR)}'),     r'&#344;'),   #  R-caron
-        (re.compile(r'{(r\ˇ|\ˇr)}'),     r'&#345;'),   #  r-caron
+        (re.compile(r'{(R\'|\'R)}'),     r'&#340;'),  # R-acute
+        (re.compile(r'{(r\'|\'r)}'),     r'&#341;'),  # r-acute
+        (re.compile(r'{(R\ˇ|\ˇR)}'),     r'&#344;'),  # R-caron
+        (re.compile(r'{(r\ˇ|\ˇr)}'),     r'&#345;'),  # r-caron
 
-        (re.compile(r'{(S\^|\^S)}'),     r'&#348;'),   #  S-circumflex
-        (re.compile(r'{(s\^|\^s)}'),     r'&#349;'),   #  s-circumflex
+        (re.compile(r'{(S\^|\^S)}'),     r'&#348;'),  # S-circumflex
+        (re.compile(r'{(s\^|\^s)}'),     r'&#349;'),  # s-circumflex
 
-        (re.compile(r'{(S\ˇ|\ˇS)}'),     r'&#352;'),   #  S-caron
-        (re.compile(r'{(s\ˇ|\ˇs)}'),     r'&#353;'),   #  s-caron
-        (re.compile(r'{(T\ˇ|\ˇT)}'),     r'&#356;'),   #  T-caron
-        (re.compile(r'{(t\ˇ|\ˇt)}'),     r'&#357;'),   #  t-caron
-        (re.compile(r'{(U\°|\°U)}'),     r'&#366;'),   #  U-ring
-        (re.compile(r'{(u\°|\°u)}'),     r'&#367;'),   #  u-ring
-        (re.compile(r'{(Z\ˇ|\ˇZ)}'),     r'&#381;'),   #  Z-caron
-        (re.compile(r'{(z\ˇ|\ˇz)}'),     r'&#382;'),   #  z-caron
+        (re.compile(r'{(S\ˇ|\ˇS)}'),     r'&#352;'),  # S-caron
+        (re.compile(r'{(s\ˇ|\ˇs)}'),     r'&#353;'),  # s-caron
+        (re.compile(r'{(T\ˇ|\ˇT)}'),     r'&#356;'),  # T-caron
+        (re.compile(r'{(t\ˇ|\ˇt)}'),     r'&#357;'),  # t-caron
+        (re.compile(r'{(U\°|\°U)}'),     r'&#366;'),  # U-ring
+        (re.compile(r'{(u\°|\°u)}'),     r'&#367;'),  # u-ring
+        (re.compile(r'{(Z\ˇ|\ˇZ)}'),     r'&#381;'),  # Z-caron
+        (re.compile(r'{(z\ˇ|\ˇz)}'),     r'&#382;'),  # z-caron
 
-        (re.compile(r'{\*}'),            r'&#8226;'),  #  bullet
-        (re.compile(r'{Fr}'),            r'&#8355;'),  #  Franc
-        (re.compile(r'{(L=|=L)}'),       r'&#8356;'),  #  Lira
-        (re.compile(r'{Rs}'),            r'&#8360;'),  #  Rupee
-        (re.compile(r'{(C=|=C)}'),       r'&#8364;'),  #  euro
-        (re.compile(r'{tm}'),            r'&#8482;'),  #  trademark
-        (re.compile(r'{spades?}'),       r'&#9824;'),  #  spade
-        (re.compile(r'{clubs?}'),        r'&#9827;'),  #  club
-        (re.compile(r'{hearts?}'),       r'&#9829;'),  #  heart
-        (re.compile(r'{diam(onds?|s)}'), r'&#9830;'),  #  diamond
-        (re.compile(r'{"}'),             r'&#34;'),    #  double-quote
-        (re.compile(r"{'}"),             r'&#39;'),    #  single-quote
-        (re.compile(r"{(’|'/|/')}"),     r'&#8217;'),  #  closing-single-quote - apostrophe
-        (re.compile(r"{(‘|\\'|'\\)}"),   r'&#8216;'),  #  opening-single-quote
-        (re.compile(r'{(”|"/|/")}'),     r'&#8221;'),  #  closing-double-quote
-        (re.compile(r'{(“|\\"|"\\)}'),   r'&#8220;'),  #  opening-double-quote
+        (re.compile(r'{\*}'),            r'&#8226;'),  # bullet
+        (re.compile(r'{Fr}'),            r'&#8355;'),  # Franc
+        (re.compile(r'{(L=|=L)}'),       r'&#8356;'),  # Lira
+        (re.compile(r'{Rs}'),            r'&#8360;'),  # Rupee
+        (re.compile(r'{(C=|=C)}'),       r'&#8364;'),  # euro
+        (re.compile(r'{tm}'),            r'&#8482;'),  # trademark
+        (re.compile(r'{spades?}'),       r'&#9824;'),  # spade
+        (re.compile(r'{clubs?}'),        r'&#9827;'),  # club
+        (re.compile(r'{hearts?}'),       r'&#9829;'),  # heart
+        (re.compile(r'{diam(onds?|s)}'), r'&#9830;'),  # diamond
+        (re.compile(r'{"}'),             r'&#34;'),  # double-quote
+        (re.compile(r"{'}"),             r'&#39;'),  # single-quote
+        (re.compile(r"{(’|'/|/')}"),     r'&#8217;'),  # closing-single-quote - apostrophe
+        (re.compile(r"{(‘|\\'|'\\)}"),   r'&#8216;'),  # opening-single-quote
+        (re.compile(r'{(”|"/|/")}'),     r'&#8221;'),  # closing-double-quote
+        (re.compile(r'{(“|\\"|"\\)}'),   r'&#8220;'),  # opening-double-quote
     ]
     glyph_defaults = [
-        (re.compile(r'(\d+\'?\"?)( ?)x( ?)(?=\d+)'),                   r'\1\2&#215;\3'),                       #  dimension sign
-        (re.compile(r'(\d+)\'(\s)', re.I),                             r'\1&#8242;\2'),                        #  prime
-        (re.compile(r'(\d+)\"(\s)', re.I),                             r'\1&#8243;\2'),                        #  prime-double
-        (re.compile(r'\b([A-Z][A-Z0-9]{2,})\b(?:[(]([^)]*)[)])'),      r'<acronym title="\2">\1</acronym>'),   #  3+ uppercase acronym
-        (re.compile(r'\b([A-Z][A-Z\'\-]+[A-Z])(?=[\s.,\)>])'),         r'<span class="caps">\1</span>'),       #  3+ uppercase
-        (re.compile(r'\b(\s{0,1})?\.{3}'),                             r'\1&#8230;'),                          #  ellipsis
-        (re.compile(r'^[\*_-]{3,}$', re.M),                            r'<hr />'),                             #  <hr> scene-break
-        (re.compile(r'(^|[^-])--([^-]|$)'),                            r'\1&#8212;\2'),                        #  em dash
-        (re.compile(r'\s-(?:\s|$)'),                                   r' &#8211; '),                          #  en dash
-        (re.compile(r'\b( ?)[([]TM[])]', re.I),                        r'\1&#8482;'),                          #  trademark
-        (re.compile(r'\b( ?)[([]R[])]', re.I),                         r'\1&#174;'),                           #  registered
-        (re.compile(r'\b( ?)[([]C[])]', re.I),                         r'\1&#169;'),                           #  copyright
+        (re.compile(r'(\d+\'?\"?)( ?)x( ?)(?=\d+)'),                   r'\1\2&#215;\3'),  # dimension sign
+        (re.compile(r'(\d+)\'(\s)', re.I),                             r'\1&#8242;\2'),  # prime
+        (re.compile(r'(\d+)\"(\s)', re.I),                             r'\1&#8243;\2'),  # prime-double
+        (re.compile(r'\b([A-Z][A-Z0-9]{2,})\b(?:[(]([^)]*)[)])'),      r'<acronym title="\2">\1</acronym>'),  # 3+ uppercase acronym
+        (re.compile(r'\b([A-Z][A-Z\'\-]+[A-Z])(?=[\s.,\)>])'),         r'<span class="caps">\1</span>'),  # 3+ uppercase
+        (re.compile(r'\b(\s{0,1})?\.{3}'),                             r'\1&#8230;'),  # ellipsis
+        (re.compile(r'^[\*_-]{3,}$', re.M),                            r'<hr />'),  # <hr> scene-break
+        (re.compile(r'(^|[^-])--([^-]|$)'),                            r'\1&#8212;\2'),  # em dash
+        (re.compile(r'\s-(?:\s|$)'),                                   r' &#8211; '),  # en dash
+        (re.compile(r'\b( ?)[([]TM[])]', re.I),                        r'\1&#8482;'),  # trademark
+        (re.compile(r'\b( ?)[([]R[])]', re.I),                         r'\1&#174;'),  # registered
+        (re.compile(r'\b( ?)[([]C[])]', re.I),                         r'\1&#169;'),  # copyright
     ]
 
-
     def __init__(self, restricted=False, lite=False, noimage=False):
         """docstring for __init__"""
         self.restricted = restricted
@@ -457,7 +459,7 @@ class Textile(object):
     def fTable(self, match):
         tatts = self.pba(match.group(1), 'table')
         rows = []
-        for row in [ x for x in match.group(2).split('\n') if x]:
+        for row in [x for x in match.group(2).split('\n') if x]:
             rmtch = re.search(r'^(%s%s\. )(.*)' % (self.a, self.c), row.lstrip())
             if rmtch:
                 ratts = self.pba(rmtch.group(1), 'tr')
@@ -545,7 +547,7 @@ class Textile(object):
             content = re.sub(r'(.+)(?:(?<!<br>)|(?<!<br />))\n(?![#*\s|])', '\\1<br />', match.group(3))
         return '<%s%s>%s%s' % (match.group(1), match.group(2), content, match.group(4))
 
-    def block(self, text, head_offset = 0):
+    def block(self, text, head_offset=0):
         """
         >>> t = Textile()
         >>> t.block('h1. foobar baby')
@@ -888,7 +890,7 @@ class Textile(object):
     def fLink(self, match):
         pre, atts, text, title, url, post = match.groups()
 
-        if pre == None:
+        if pre is None:
             pre = ''
 
         # assume ) at the end of the url is not actually part of the url
@@ -938,7 +940,6 @@ class Textile(object):
             text = pattern.sub(self.fSpan, text)
         return text
 
-
     def fSpan(self, match):
         _, tag, atts, cite, content, end, _ = match.groups()
 
@@ -1025,7 +1026,7 @@ class Textile(object):
 
     def fCode(self, match):
         before, text, after = match.groups()
-        if after == None:
+        if after is None:
             after = ''
         # text needs to be escaped
         if not self.restricted:
@@ -1034,7 +1035,7 @@ class Textile(object):
 
     def fPre(self, match):
         before, text, after = match.groups()
-        if after == None:
+        if after is None:
             after = ''
         # text needs to be escapedd
         if not self.restricted:
@@ -1042,7 +1043,7 @@ class Textile(object):
         return ''.join([before, '<pre>', self.shelve(text), '</pre>', after])
 
     def doSpecial(self, text, start, end, method=None):
-        if method == None:
+        if method is None:
             method = self.fSpecial
         pattern = re.compile(r'(^|\s|[\[({>])%s(.*?)%s(\s|$|[\])}])?' % (re.escape(start), re.escape(end)), re.M|re.S)
         return pattern.sub(method, text)
@@ -1052,7 +1053,7 @@ class Textile(object):
         special blocks like notextile or code
         """
         before, text, after = match.groups()
-        if after == None:
+        if after is None:
             after = ''
         return ''.join([before, self.shelve(self.encode_html(text)), after])
 
@@ -1062,7 +1063,7 @@ class Textile(object):
 
     def fTextile(self, match):
         before, notextile, after = match.groups()
-        if after == None:
+        if after is None:
             after = ''
         return ''.join([before, self.shelve(notextile), after])
 
@@ -1076,6 +1077,7 @@ def textile(text, head_offset=0, html_type='xhtml', encoding=None, output=None):
     return Textile().textile(text, head_offset=head_offset,
                              html_type=html_type)
 
+
 def textile_restricted(text, lite=True, noimage=True, html_type='xhtml'):
     """
     Restricted version of Textile designed for weblog comments and other
