@@ -20,7 +20,7 @@ from calibre.customize.ui import plugin_for_input_format
 class ConvertAction(InterfaceAction):
 
     name = 'Convert Books'
-    action_spec = (_('Convert books'), 'convert.png', _('Convert books between different ebook formats'), _('C'))
+    action_spec = (_('Convert books'), 'convert.png', _('Convert books between different e-book formats'), _('C'))
     dont_add_to = frozenset(['context-menu-device'])
     action_type = 'current'
     action_add_menu = True
