@@ -355,6 +355,7 @@ class DuplicatesQuestion(QDialog):  # {{{
 
 # }}}
 
+
 # Static session-long set of pairs of libraries that have had their custom columns
 # checked for compatibility
 libraries_with_checked_columns = defaultdict(set)
@@ -507,7 +508,7 @@ class CopyToLibraryAction(InterfaceAction):
             if delete_after:
                 msg += ' ' + _('No books were deleted from this library.')
             msg += ' ' + _('The best way to resume this operation is to re-copy all the books with the option to'
-                     ' "Check for duplicates when Copying to Library" in Preferences->Adding books turned on.')
+                     ' "Check for duplicates when copying to library" in Preferences->Import/export->Adding books turned on.')
             warning_dialog(self.gui, _('Canceled'), msg, show=True)
             return
 
@@ -527,10 +528,10 @@ class CopyToLibraryAction(InterfaceAction):
             books = '\n'.join(self.worker.auto_merged_ids.itervalues())
             info_dialog(self.gui, _('Auto merged'),
                     _('Some books were automatically merged into existing '
-                        'records in the target library. Click Show '
-                        'details to see which ones. This behavior is '
-                        'controlled by the Auto merge option in '
-                        'Preferences->Adding books.'), det_msg=books,
+                        'records in the target library. Click "Show '
+                        'details" to see which ones. This behavior is '
+                        'controlled by the Automerge option in '
+                        'Preferences->Import/export->Adding books.'), det_msg=books,
                     show=True)
         if delete_after and self.worker.processed:
             v = self.gui.library_view
