@@ -54,15 +54,15 @@ class Polish(QDialog):  # {{{
 
             'metadata':_('<h3>Updating metadata</h3>'
                          '<p>This will update all metadata <i>except</i> the cover in the'
-                         ' ebook files to match the current metadata in the'
+                         ' e-book files to match the current metadata in the'
                          ' calibre library.</p>'
-                         ' <p>Note that most ebook'
+                         ' <p>Note that most e-book'
                          ' formats are not capable of supporting all the'
                          ' metadata in calibre.</p><p>There is a separate option to'
                          ' update the cover.</p>'),
-            'do_cover': _('<h3>Update cover</h3><p>Update the covers in the ebook files to match the'
+            'do_cover': _('<h3>Update cover</h3><p>Update the covers in the e-book files to match the'
                         ' current cover in the calibre library.</p>'
-                        '<p>If the ebook file does not have'
+                        '<p>If the e-book file does not have'
                         ' an identifiable cover, a new cover is inserted.</p>'
                         ),
             'jacket':_('<h3>Book Jacket</h3>%s')%HELP['jacket'],
@@ -84,7 +84,7 @@ class Polish(QDialog):  # {{{
             ('smarten_punctuation', _('Smarten &punctuation')),
             ('metadata', _('Update &metadata in the book files')),
             ('do_cover', _('Update the &cover in the book files')),
-            ('jacket', _('Add/Replace metadata as a "book &jacket" page')),
+            ('jacket', _('Add/replace metadata as a "book &jacket" page')),
             ('remove_jacket', _('&Remove a previously inserted book jacket')),
             ('remove_unused_css', _('Remove &unused CSS rules from the book')),
             ('compress_images', _('Losslessly compress images')),
@@ -529,6 +529,7 @@ class PolishAction(InterfaceAction):
         if show_reports:
             self.report(db.title(book_id, index_is_id=True), book_id, fmts, job, job.result)
 
+
 if __name__ == '__main__':
     app = QApplication([])
     app
