@@ -91,7 +91,7 @@ class TweakEpubAction(InterfaceAction):
     def tweak_book(self):
         row = self.gui.library_view.currentIndex()
         if not row.isValid():
-            return error_dialog(self.gui, _('Cannot Edit Book'),
+            return error_dialog(self.gui, _('Cannot Edit book'),
                     _('No book selected'), show=True)
 
         book_id = self.gui.library_view.model().id(row)
@@ -99,7 +99,7 @@ class TweakEpubAction(InterfaceAction):
 
     def do_tweak(self, book_id):
         if self.gui.current_view() is not self.gui.library_view:
-            return error_dialog(self.gui, _('Cannot Edit Book'), _(
+            return error_dialog(self.gui, _('Cannot edit book'), _(
                 'Editing of books on the device is not supported'), show=True)
         from calibre.ebooks.oeb.polish.main import SUPPORTED
         db = self.gui.library_view.model().db
@@ -107,7 +107,7 @@ class TweakEpubAction(InterfaceAction):
         fmts = [x.upper().strip() for x in fmts.split(',')]
         tweakable_fmts = set(fmts).intersection(SUPPORTED)
         if not tweakable_fmts:
-            return error_dialog(self.gui, _('Cannot Edit Book'),
+            return error_dialog(self.gui, _('Cannot edit book'),
                     _('The book must be in the %s formats to edit.'
                         '\n\nFirst convert the book to one of these formats.') % (_(' or ').join(SUPPORTED)),
                     show=True)
