@@ -50,7 +50,7 @@ class ViewAction(InterfaceAction):
         cm = partial(self.create_menu_action, self.view_menu)
         self.view_specific_action = cm('specific', _('View specific format'),
                 shortcut='Alt+V', triggered=self.view_specific_format)
-        self.internal_view_action = cm('internal', _('View with calibre viewer'), triggered=self.view_internal)
+        self.internal_view_action = cm('internal', _('View with calibre E-book viewer'), triggered=self.view_internal)
         self.action_pick_random = cm('pick random', _('Read a random book'),
                 icon='random.png', triggered=self.view_random)
         self.clear_sep1 = self.view_menu.addSeparator()
@@ -139,7 +139,7 @@ class ViewAction(InterfaceAction):
                                     'Windows will try to open %s with calibre itself'
                                     ' resulting in a duplicate in your calibre library. You'
                                     ' should install some program capable of viewing this'
-                                    ' file format and tell windows to use that program to open'
+                                    ' file format and tell Windows to use that program to open'
                                     ' files of this type.') % name, show=True)
 
                 open_local_file(name)
@@ -203,7 +203,7 @@ class ViewAction(InterfaceAction):
     def _view_check(self, num, max_=3):
         if num <= max_:
             return True
-        return question_dialog(self.gui, _('Multiple Books Selected'),
+        return question_dialog(self.gui, _('Multiple books selected'),
                 _('You are attempting to open %d books. Opening too many '
                 'books at once can be slow and have a negative effect on the '
                 'responsiveness of your computer. Once started the process '
