@@ -11,7 +11,7 @@ import os, tempfile, shutil, time
 from threading import Thread, Event
 from future_builtins import map
 
-from PyQt5.Qt import (QFileSystemWatcher, QObject, Qt, pyqtSignal, QTimer)
+from PyQt5.Qt import (QFileSystemWatcher, QObject, Qt, pyqtSignal, QTimer, QApplication, QCursor)
 
 from calibre import prints
 from calibre.ptempfile import PersistentTemporaryDirectory
@@ -22,6 +22,7 @@ from calibre.gui2.dialogs.duplicates import DuplicatesQuestion
 
 AUTO_ADDED = frozenset(BOOK_EXTENSIONS) - {'pdr', 'mbp', 'tan'}
 
+
 class AllAllowed(object):
 
     def __init__(self):
@@ -39,6 +40,7 @@ def allowed_formats():
         allowed = AUTO_ADDED - frozenset(gprefs['blocked_auto_formats'])
     return allowed
 
+
 class Worker(Thread):
 
     def __init__(self, path, callback):
@@ -201,7 +203,17 @@ class AutoAdder(QObject):
         if hasattr(self, 'worker'):
             self.worker.join()
 
+    def __enter__(self):
+        QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
+
+    def __exit__(self, *args):
+        QApplication.restoreOverrideCursor()
+
     def add_to_db(self, data):
+        with self:
+            self.do_add(data)
+
+    def do_add(self, data):
         from calibre.ebooks.metadata.opf2 import OPF
 
         gui = self.parent()
@@ -294,9 +306,9 @@ class AutoAdder(QObject):
 
         if count > 0:
             m.books_added(count)
-            gui.status_bar.show_message(_(
-                'Added %(num)d book(s) automatically from %(src)s') %
-                dict(num=count, src=self.worker.path), 2000)
+            gui.status_bar.show_message(
+                ngettext('Added a book automatically from {src}', 'Added {num} books automatically from {src}', count).format(
+                    num=count, src=self.worker.path), 2000)
             gui.refresh_cover_browser()
 
         if needs_rescan:
