@@ -14,7 +14,7 @@ from PyQt5.Qt import QWidget, QListWidgetItem
 
 class PluginWidget(QWidget, Ui_Form):
 
-    TITLE = _('BibTeX Options')
+    TITLE = _('BibTeX options')
     HELP  = _('Options specific to')+' BibTeX '+_('output')
     OPTION_FIELDS = [('bib_cit','{authors}{id}'),
                      ('bib_entry', 0),  # mixed
