@@ -9,15 +9,17 @@ from calibre.gui2.convert import Widget
 
 format_model = None
 
+
 class PluginWidget(Widget, Ui_Form):
 
-    TITLE = _('HTMLZ Output')
+    TITLE = _('HTMLZ output')
     HELP = _('Options specific to')+' HTMLZ '+_('output')
     COMMIT_NAME = 'htmlz_output'
     ICON = I('mimetypes/html.png')
 
     def __init__(self, parent, get_option, get_help, db=None, book_id=None):
-        Widget.__init__(self, parent, ['htmlz_css_type', 'htmlz_class_style'])
+        Widget.__init__(self, parent, ['htmlz_css_type', 'htmlz_class_style',
+            'htmlz_title_filename'])
         self.db, self.book_id = db, book_id
         for x in get_option('htmlz_css_type').option.choices:
             self.opt_htmlz_css_type.addItem(x)
