@@ -4,19 +4,20 @@ __license__ = 'GPL 3'
 __copyright__ = '2009, John Schember <john@nachtimwald.com>'
 __docformat__ = 'restructuredtext en'
 
-import re, os
+import os
 
-from PyQt4.QtCore import SIGNAL, Qt, pyqtSignal
-from PyQt4.QtGui import (QDialog, QWidget, QDialogButtonBox,
-        QBrush, QTextCursor, QTextEdit)
+from PyQt5.Qt import (QDialog, QWidget, QDialogButtonBox,
+        QBrush, QTextCursor, QTextEdit, QByteArray, Qt, pyqtSignal)
 
 from calibre.gui2.convert.regex_builder_ui import Ui_RegexBuilder
 from calibre.gui2.convert.xexp_edit_ui import Ui_Form as Ui_Edit
-from calibre.gui2 import error_dialog, choose_files
-from calibre.ebooks.oeb.iterator import EbookIterator
-from calibre.ebooks.conversion.preprocess import HTMLPreProcessor
+from calibre.gui2 import error_dialog, choose_files, gprefs
 from calibre.gui2.dialogs.choose_format import ChooseFormatDialog
 from calibre.constants import iswindows
+from calibre.utils.ipc.simple_worker import fork_job, WorkerError
+from calibre.ebooks.conversion.search_replace import compile_regular_expression
+from calibre.ptempfile import TemporaryFile
+
 
 class RegexBuilder(QDialog, Ui_RegexBuilder):
 
@@ -28,7 +29,8 @@ class RegexBuilder(QDialog, Ui_RegexBuilder):
         self.regex_valid()
 
         if not db or not book_id:
-            self.button_box.addButton(QDialogButtonBox.Open)
+            button = self.button_box.addButton(QDialogButtonBox.Open)
+            button.clicked.connect(self.open_clicked)
         elif not doc and not self.select_format(db, book_id):
             self.cancelled = True
             return
@@ -37,19 +39,29 @@ class RegexBuilder(QDialog, Ui_RegexBuilder):
             self.preview.setPlainText(doc)
 
         self.cancelled = False
-        self.connect(self.button_box, SIGNAL('clicked(QAbstractButton*)'), self.button_clicked)
-        self.connect(self.regex, SIGNAL('textChanged(QString)'), self.regex_valid)
-        self.connect(self.test, SIGNAL('clicked()'), self.do_test)
-        self.connect(self.previous, SIGNAL('clicked()'), self.goto_previous)
-        self.connect(self.next, SIGNAL('clicked()'), self.goto_next)
+        self.button_box.accepted.connect(self.accept)
+        self.regex.textChanged[str].connect(self.regex_valid)
+        for src, slot in (('test', 'do'), ('previous', 'goto'), ('next',
+            'goto')):
+            getattr(self, src).clicked.connect(getattr(self, '%s_%s'%(slot,
+                src)))
+        self.test.setDefault(True)
 
         self.match_locs = []
+        geom = gprefs.get('regex_builder_geometry', None)
+        if geom is not None:
+            self.restoreGeometry(QByteArray(geom))
+        self.finished.connect(self.save_state)
+
+    def save_state(self, result):
+        geom = bytearray(self.saveGeometry())
+        gprefs['regex_builder_geometry'] = geom
 
     def regex_valid(self):
         regex = unicode(self.regex.text())
         if regex:
             try:
-                re.compile(regex)
+                compile_regular_expression(regex)
                 self.regex.setStyleSheet('QLineEdit { color: black; background-color: rgba(0,255,0,20%); }')
                 return True
             except:
@@ -76,7 +88,7 @@ class RegexBuilder(QDialog, Ui_RegexBuilder):
             extsel.cursor = cursor
             extsel.format.setBackground(QBrush(Qt.yellow))
             try:
-                for match in re.finditer(regex, text):
+                for match in compile_regular_expression(regex).finditer(text):
                     es = QTextEdit.ExtraSelection(extsel)
                     es.cursor.setPosition(match.start(), QTextCursor.MoveAnchor)
                     es.cursor.setPosition(match.end(), QTextCursor.KeepAnchor)
@@ -129,6 +141,8 @@ class RegexBuilder(QDialog, Ui_RegexBuilder):
             d.exec_()
             if d.result() == QDialog.Accepted:
                 format = d.format()
+            else:
+                return False
 
         if not format:
             error_dialog(self, _('No formats available'),
@@ -159,29 +173,32 @@ class RegexBuilder(QDialog, Ui_RegexBuilder):
         return True
 
     def open_book(self, pathtoebook):
-        self.iterator = EbookIterator(pathtoebook)
-        self.iterator.__enter__(only_input_plugin=True)
-        text = [u'']
-        preprocessor = HTMLPreProcessor(None, False)
-        for path in self.iterator.spine:
-            with open(path, 'rb') as f:
-                html = f.read().decode('utf-8', 'replace')
-            html = preprocessor(html, get_preprocess_html=True)
-            text.append(html)
-        self.preview.setPlainText('\n---\n'.join(text))
+        with TemporaryFile('_prepprocess_gui') as tf:
+            err_msg = _('Failed to generate markup for testing. Click '
+                            '"Show Details" to learn more.')
+            try:
+                fork_job('calibre.ebooks.oeb.iterator', 'get_preprocess_html',
+                    (pathtoebook, tf))
+            except WorkerError as e:
+                return error_dialog(self, _('Failed to generate preview'),
+                        err_msg, det_msg=e.orig_tb, show=True)
+            except:
+                import traceback
+                return error_dialog(self, _('Failed to generate preview'),
+                        err_msg, det_msg=traceback.format_exc(), show=True)
+            with open(tf, 'rb') as f:
+                self.preview.setPlainText(f.read().decode('utf-8'))
 
-    def button_clicked(self, button):
-        if button == self.button_box.button(QDialogButtonBox.Open):
-            files = choose_files(self, 'regexp tester dialog', _('Open book'),
-                    select_only_single_file=True)
-            if files:
-                self.open_book(files[0])
-        if button == self.button_box.button(QDialogButtonBox.Ok):
-            self.accept()
+    def open_clicked(self):
+        files = choose_files(self, 'regexp tester dialog', _('Open book'),
+                select_only_single_file=True)
+        if files:
+            self.open_book(files[0])
 
     def doc(self):
         return unicode(self.preview.toPlainText())
 
+
 class RegexEdit(QWidget, Ui_Edit):
 
     doc_update = pyqtSignal(unicode)
@@ -194,9 +211,12 @@ class RegexEdit(QWidget, Ui_Edit):
         self.db = None
         self.doc_cache = None
 
-        self.connect(self.button, SIGNAL('clicked()'), self.builder)
+        self.button.clicked.connect(self.builder)
 
     def builder(self):
+        if self.db is None:
+            self.doc_cache = _('Click the "Open" button below to open a '
+                    'e-book to use for testing.')
         bld = RegexBuilder(self.db, self.book_id, self.edit.text(), self.doc_cache, self)
         if bld.cancelled:
             return
@@ -226,6 +246,9 @@ class RegexEdit(QWidget, Ui_Edit):
     def set_doc(self, doc):
         self.doc_cache = doc
 
+    def set_regex(self, regex):
+        self.edit.setText(regex)
+
     def break_cycles(self):
         self.db = self.doc_cache = None
 
@@ -237,5 +260,8 @@ class RegexEdit(QWidget, Ui_Edit):
     def regex(self):
         return self.text
 
+    def clear(self):
+        self.edit.clear()
+
     def check(self):
         return True
