@@ -165,7 +165,7 @@ class Config(QDialog, Ui_Dialog):
         self.groups.clicked[(QModelIndex)].connect(self.show_pane)
         self.groups.entered[(QModelIndex)].connect(self.show_group_help)
         rb = self.buttonBox.button(self.buttonBox.RestoreDefaults)
-        rb.setText(_('Restore &Defaults'))
+        rb.setText(_('Restore &defaults'))
         rb.clicked.connect(self.restore_defaults)
         self.groups.setMouseTracking(True)
         geom = gprefs.get('convert_single_dialog_geom', None)
@@ -320,6 +320,3 @@ class Config(QDialog, Ui_Dialog):
     def show_group_help(self, index):
         widget = self._groups_model.widgets[index.row()]
         self.help.setPlainText(widget.HELP)
-
-
-
