@@ -12,10 +12,11 @@ from calibre.gui2.convert import Widget
 from calibre.gui2 import error_dialog
 from calibre.utils.localization import localize_user_manual_link
 
+
 class TOCWidget(Widget, Ui_Form):
 
     TITLE = _('Table of\nContents')
-    ICON  = I('series.png')
+    ICON  = I('toc.png')
     HELP  = _('Control the creation/conversion of the Table of Contents.')
     COMMIT_NAME = 'toc'
 
@@ -37,7 +38,6 @@ class TOCWidget(Widget, Ui_Form):
         except TypeError:
             pass  # link already localized
 
-
     def pre_commit_check(self):
         for x in ('level1', 'level2', 'level3'):
             x = getattr(self, 'opt_'+x+'_toc')
