@@ -9,8 +9,8 @@ from functools import partial
 
 from PyQt5.Qt import (QComboBox, QLabel, QSpinBox, QDoubleSpinBox, QDateTimeEdit,
         QDateTime, QGroupBox, QVBoxLayout, QSizePolicy, QGridLayout,
-        QSpacerItem, QIcon, QCheckBox, QWidget, QHBoxLayout,
-        QPushButton, QMessageBox, QToolButton, Qt)
+        QSpacerItem, QIcon, QCheckBox, QWidget, QHBoxLayout, QLineEdit,
+        QPushButton, QMessageBox, QToolButton, Qt, QPlainTextEdit)
 
 from calibre.utils.date import qt_to_dt, now, as_local_time, as_utc
 from calibre.gui2.complete2 import EditWithComplete
@@ -21,6 +21,8 @@ from calibre.utils.config import tweaks
 from calibre.utils.icu import sort_key
 from calibre.library.comments import comments_to_html
 from calibre.gui2.library.delegates import ClearingDoubleSpinBox, ClearingSpinBox
+from calibre.gui2.widgets2 import RatingEditor
+
 
 class Base(object):
 
@@ -64,6 +66,38 @@ class Base(object):
     def break_cycles(self):
         self.db = self.widgets = self.initial_val = None
 
+
+class SimpleText(Base):
+
+    def setup_ui(self, parent):
+        self.widgets = [QLabel('&'+self.col_metadata['name']+':', parent), QLineEdit(parent)]
+
+    def setter(self, val):
+        self.widgets[1].setText(type(u'')(val or ''))
+
+    def getter(self):
+        return self.widgets[1].text().strip()
+
+
+class LongText(Base):
+
+    def setup_ui(self, parent):
+        self._box = QGroupBox(parent)
+        self._box.setTitle('&'+self.col_metadata['name'])
+        self._layout = QVBoxLayout()
+        self._tb = QPlainTextEdit(self._box)
+        self._tb.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Minimum)
+        self._layout.addWidget(self._tb)
+        self._box.setLayout(self._layout)
+        self.widgets = [self._box]
+
+    def setter(self, val):
+        self._tb.setPlainText(type(u'')(val or ''))
+
+    def getter(self):
+        return self._tb.toPlainText()
+
+
 class Bool(Base):
 
     def setup_ui(self, parent):
@@ -88,22 +122,24 @@ class Bool(Base):
         val = self.widgets[1].currentIndex()
         return {2: None, 1: False, 0: True}[val]
 
+
 class Int(Base):
 
     def setup_ui(self, parent):
+        self.was_none = False
         self.widgets = [QLabel('&'+self.col_metadata['name']+':', parent),
                 ClearingSpinBox(parent)]
         w = self.widgets[1]
         w.setRange(-1000000, 100000000)
         w.setSpecialValueText(_('Undefined'))
         w.setSingleStep(1)
+        w.valueChanged.connect(self.valueChanged)
 
     def setter(self, val):
         if val is None:
             val = self.widgets[1].minimum()
-        else:
-            val = int(val)
         self.widgets[1].setValue(val)
+        self.was_none = val == self.widgets[1].minimum()
 
     def getter(self):
         val = self.widgets[1].value()
@@ -111,6 +147,12 @@ class Int(Base):
             val = None
         return val
 
+    def valueChanged(self, to_what):
+        if self.was_none and to_what == -999999:
+            self.setter(0)
+        self.was_none = to_what == self.widgets[1].minimum()
+
+
 class Float(Int):
 
     def setup_ui(self, parent):
@@ -121,33 +163,23 @@ class Float(Int):
         w.setDecimals(2)
         w.setSpecialValueText(_('Undefined'))
         w.setSingleStep(1)
+        self.was_none = False
+        w.valueChanged.connect(self.valueChanged)
 
-    def setter(self, val):
-        if val is None:
-            val = self.widgets[1].minimum()
-        self.widgets[1].setValue(val)
 
-class Rating(Int):
+class Rating(Base):
 
     def setup_ui(self, parent):
-        Int.setup_ui(self, parent)
-        w = self.widgets[1]
-        w.setRange(0, 5)
-        w.setSuffix(' '+_('star(s)'))
-        w.setSpecialValueText(_('Not rated'))
+        allow_half_stars = self.col_metadata['display'].get('allow_half_stars', False)
+        self.widgets = [QLabel('&'+self.col_metadata['name']+':', parent), RatingEditor(parent=parent, is_half_star=allow_half_stars)]
 
     def setter(self, val):
-        if val is None:
-            val = 0
-        self.widgets[1].setValue(int(round(val/2.)))
+        val = max(0, min(int(val or 0), 10))
+        self.widgets[1].rating_value = val
 
     def getter(self):
-        val = self.widgets[1].value()
-        if val == 0:
-            val = None
-        else:
-            val *= 2
-        return val
+        return self.widgets[1].rating_value or None
+
 
 class DateTimeEdit(QDateTimeEdit):
 
@@ -227,6 +259,7 @@ class DateTime(Base):
     def normalize_ui_val(self, val):
         return as_utc(val) if val is not None else None
 
+
 class Comments(Base):
 
     def setup_ui(self, parent):
@@ -258,10 +291,12 @@ class Comments(Base):
     def tab(self):
         def fget(self):
             return self._tb.tab
+
         def fset(self, val):
             self._tb.tab = val
         return property(fget=fget, fset=fset)
 
+
 class MultipleWidget(QWidget):
 
     def __init__(self, parent):
@@ -311,6 +346,7 @@ class MultipleWidget(QWidget):
     def text(self):
         return self.tags_box.text()
 
+
 class Text(Base):
 
     def setup_ui(self, parent):
@@ -396,6 +432,7 @@ class Text(Base):
         if d.exec_() == TagEditor.Accepted:
             self.setter(d.tags)
 
+
 class Series(Base):
 
     def setup_ui(self, parent):
@@ -468,6 +505,7 @@ class Series(Base):
         val, s_index = self.current_val
         mi.set('#' + self.col_metadata['label'], val, extra=s_index)
 
+
 class Enumeration(Base):
 
     def setup_ui(self, parent):
@@ -511,6 +549,16 @@ class Enumeration(Base):
             val = None
         return val
 
+
+def comments_factory(db, key, parent):
+    fm = db.custom_column_num_map[key]
+    ctype = fm.get('display', {}).get('interpret_as', 'html')
+    if ctype == 'short-text':
+        return SimpleText(db, key, parent)
+    if ctype in ('long-text', 'markdown'):
+        return LongText(db, key, parent)
+    return Comments(db, key, parent)
+
 widgets = {
         'bool' : Bool,
         'rating' : Rating,
@@ -518,17 +566,19 @@ widgets = {
         'float': Float,
         'datetime': DateTime,
         'text' : Text,
-        'comments': Comments,
+        'comments': comments_factory,
         'series': Series,
         'enumeration': Enumeration
 }
 
+
 def field_sort_key(y, fm=None):
     m1 = fm[y]
     name = icu_lower(m1['name'])
-    n1 = 'zzzzz' + name if m1['datatype'] == 'comments' else name
+    n1 = 'zzzzz' + name if m1['datatype'] == 'comments' and m1.get('display', {}).get('interpret_as') != 'short-text' else name
     return sort_key(n1)
 
+
 def populate_metadata_page(layout, db, book_id, bulk=False, two_column=False, parent=None):
     def widget_factory(typ, key):
         if bulk:
@@ -555,7 +605,7 @@ def populate_metadata_page(layout, db, book_id, bulk=False, two_column=False, pa
         # Add the key if it really exists in the database
         if key in cols_to_display:
             cols.append(key)
-            if fm[key]['datatype'] == 'comments':
+            if fm[key]['datatype'] == 'comments' and fm[key].get('display', {}).get('interpret_as') != 'short-text':
                 comments_in_tweak += 1
 
     # Add all the remaining fields
@@ -563,7 +613,7 @@ def populate_metadata_page(layout, db, book_id, bulk=False, two_column=False, pa
     for key in cols_to_display:
         if key not in cols:
             cols.append(key)
-            if fm[key]['datatype'] == 'comments':
+            if fm[key]['datatype'] == 'comments' and fm[key].get('display', {}).get('interpret_as') != 'short-text':
                 comments_not_in_tweak += 1
 
     count = len(cols)
@@ -582,9 +632,10 @@ def populate_metadata_page(layout, db, book_id, bulk=False, two_column=False, pa
         dt = fm[key]['datatype']
         if dt == 'composite' or (bulk and dt == 'comments'):
             continue
+        is_comments = dt == 'comments' and fm[key].get('display', {}).get('interpret_as') != 'short-text'
         w = widget_factory(dt, fm[key]['colnum'])
         ans.append(w)
-        if two_column and dt == 'comments':
+        if two_column and is_comments:
             # Here for compatibility with old layout. Comments always started
             # in the left column
             comments_in_tweak -= 1
@@ -599,7 +650,7 @@ def populate_metadata_page(layout, db, book_id, bulk=False, two_column=False, pa
                 comments_not_in_tweak = 0
 
         l = QGridLayout()
-        if dt == 'comments':
+        if is_comments:
             layout.addLayout(l, row, column, layout_rows_for_comments, 1)
             layout.setColumnStretch(column, 100)
             row += layout_rows_for_comments
@@ -608,7 +659,7 @@ def populate_metadata_page(layout, db, book_id, bulk=False, two_column=False, pa
             layout.setColumnStretch(column, 100)
             row += 1
         for c in range(0, len(w.widgets), 2):
-            if dt != 'comments':
+            if not is_comments:
                 w.widgets[c].setWordWrap(True)
                 w.widgets[c].setBuddy(w.widgets[c+1])
                 l.addWidget(w.widgets[c], c, 0)
@@ -631,6 +682,7 @@ def populate_metadata_page(layout, db, book_id, bulk=False, two_column=False, pa
         layout.setRowStretch(layout.rowCount()-1, 100)
     return ans, items
 
+
 class BulkBase(Base):
 
     @property
@@ -702,6 +754,7 @@ class BulkBase(Base):
         if not self.ignore_change_signals:
             self.a_c_checkbox.setChecked(True)
 
+
 class BulkBool(BulkBase, Bool):
 
     def get_initial_value(self, book_ids):
@@ -757,21 +810,23 @@ class BulkBool(BulkBase, Bool):
             else:
                 self.a_c_checkbox.setChecked(True)
 
+
 class BulkInt(BulkBase):
 
     def setup_ui(self, parent):
+        self.was_none = False
         self.make_widgets(parent, QSpinBox)
         self.main_widget.setRange(-1000000, 100000000)
         self.main_widget.setSpecialValueText(_('Undefined'))
         self.main_widget.setSingleStep(1)
+        self.main_widget.valueChanged.connect(self.valueChanged)
 
     def setter(self, val):
         if val is None:
             val = self.main_widget.minimum()
-        else:
-            val = int(val)
         self.main_widget.setValue(val)
         self.ignore_change_signals = False
+        self.was_none = val == self.main_widget.minimum()
 
     def getter(self):
         val = self.main_widget.value()
@@ -779,6 +834,12 @@ class BulkInt(BulkBase):
             val = None
         return val
 
+    def valueChanged(self, to_what):
+        if self.was_none and to_what == -999999:
+            self.setter(0)
+        self.was_none = to_what == self.main_widget.minimum()
+
+
 class BulkFloat(BulkInt):
 
     def setup_ui(self, parent):
@@ -787,29 +848,24 @@ class BulkFloat(BulkInt):
         self.main_widget.setDecimals(2)
         self.main_widget.setSpecialValueText(_('Undefined'))
         self.main_widget.setSingleStep(1)
+        self.was_none = False
+        self.main_widget.valueChanged.connect(self.valueChanged)
+
 
 class BulkRating(BulkBase):
 
     def setup_ui(self, parent):
-        self.make_widgets(parent, QSpinBox)
-        self.main_widget.setRange(0, 5)
-        self.main_widget.setSuffix(' '+_('star(s)'))
-        self.main_widget.setSpecialValueText(_('Not rated'))
-        self.main_widget.setSingleStep(1)
+        allow_half_stars = self.col_metadata['display'].get('allow_half_stars', False)
+        self.make_widgets(parent, partial(RatingEditor, is_half_star=allow_half_stars))
 
     def setter(self, val):
-        if val is None:
-            val = 0
-        self.main_widget.setValue(int(round(val/2.)))
+        val = max(0, min(int(val or 0), 10))
+        self.main_widget.rating_value = val
         self.ignore_change_signals = False
 
     def getter(self):
-        val = self.main_widget.value()
-        if val == 0:
-            val = None
-        else:
-            val *= 2
-        return val
+        return self.main_widget.rating_value or None
+
 
 class BulkDateTime(BulkBase):
 
@@ -862,6 +918,7 @@ class BulkDateTime(BulkBase):
     def normalize_ui_val(self, val):
         return as_utc(val) if val is not None else None
 
+
 class BulkSeries(BulkBase):
 
     def setup_ui(self, parent):
@@ -940,6 +997,7 @@ class BulkSeries(BulkBase):
             self.db.set_custom_bulk(book_ids, val, extras=extras,
                                    num=self.col_id, notify=notify)
 
+
 class BulkEnumeration(BulkBase, Enumeration):
 
     def get_initial_value(self, book_ids):
@@ -984,6 +1042,7 @@ class BulkEnumeration(BulkBase, Enumeration):
             self.main_widget.setCurrentIndex(self.main_widget.findText(val))
         self.ignore_change_signals = False
 
+
 class RemoveTags(QWidget):
 
     def __init__(self, parent, values):
@@ -1008,6 +1067,7 @@ class RemoveTags(QWidget):
         else:
             self.tags_box.setEnabled(True)
 
+
 class BulkText(BulkBase):
 
     def setup_ui(self, parent):
