@@ -14,7 +14,7 @@ from PyQt5.Qt import (
 from calibre.customize.ui import (available_input_formats, available_output_formats,
     device_plugins, disabled_device_plugins)
 from calibre.devices.interface import DevicePlugin, currently_connected_device
-from calibre.devices.errors import (UserFeedback, OpenFeedback, OpenFailed,
+from calibre.devices.errors import (UserFeedback, OpenFeedback, OpenFailed, OpenActionNeeded,
                                     InitialConnectionError)
 from calibre.ebooks.covers import cprefs, override_prefs, scale_cover, generate_cover
 from calibre.gui2.dialogs.choose_format_device import ChooseFormatDeviceDialog
@@ -37,6 +37,7 @@ from calibre.library.save_to_disk import find_plugboard
 from calibre.ptempfile import PersistentTemporaryFile, force_unicode as filename_to_unicode
 # }}}
 
+
 class DeviceJob(BaseJob):  # {{{
 
     def __init__(self, func, done, job_manager, args=[], kwargs={},
@@ -116,11 +117,13 @@ class DeviceJob(BaseJob):  # {{{
 
     # }}}
 
+
 def device_name_for_plugboards(device_class):
     if hasattr(device_class, 'DEVICE_PLUGBOARD_NAME'):
         return device_class.DEVICE_PLUGBOARD_NAME
     return device_class.__class__.__name__
 
+
 class BusyCursor(object):
 
     def __enter__(self):
@@ -162,6 +165,7 @@ class DeviceManager(Thread):  # {{{
         self.ejected_devices  = set([])
         self.mount_connection_requests = Queue.Queue(0)
         self.open_feedback_slot = open_feedback_slot
+        self.open_feedback_only_once_seen = set()
         self.after_callback_feedback_slot = after_callback_feedback_slot
         self.open_feedback_msg = open_feedback_msg
         self._device_information = None
@@ -293,6 +297,10 @@ class DeviceManager(Thread):  # {{{
                         except BlacklistedDevice as e:
                             prints('Ignoring blacklisted device: %s'%
                                     as_unicode(e))
+                        except OpenActionNeeded as e:
+                            if e.only_once_id not in self.open_feedback_only_once_seen:
+                                self.open_feedback_only_once_seen.add(e.only_once_id)
+                                self.open_feedback_msg(e.device_name, e)
                         except:
                             prints('Error while trying to open %s (Driver: %s)'%
                                     (cd, dev))
@@ -593,7 +601,7 @@ class DeviceManager(Thread):  # {{{
 
     def upload_books(self, done, files, names, on_card=None, titles=None,
                      metadata=None, plugboards=None, add_as_step_to_job=None):
-        desc = _('Upload %d books to device')%len(names)
+        desc = ngettext('Upload one book to the device', 'Upload {} books to the device', len(names)).format(len(names))
         if titles:
             desc += u':' + u', '.join(titles)
         return self.create_job_step(self._upload_books, done, to_job=add_as_step_to_job,
@@ -685,6 +693,7 @@ class DeviceManager(Thread):  # {{{
 
     # }}}
 
+
 class DeviceAction(QAction):  # {{{
 
     a_s = pyqtSignal(object)
@@ -704,6 +713,7 @@ class DeviceAction(QAction):  # {{{
                 self.specific)
     # }}}
 
+
 class DeviceMenu(QMenu):  # {{{
 
     fetch_annotations = pyqtSignal()
@@ -853,6 +863,7 @@ class DeviceMenu(QMenu):  # {{{
 
     # }}}
 
+
 class DeviceSignals(QObject):  # {{{
     #: This signal is emitted once, after metadata is downloaded from the
     #: connected device.
@@ -869,9 +880,11 @@ class DeviceSignals(QObject):  # {{{
     #: otherwise a disconnection.
     device_connection_changed = pyqtSignal(object)
 
+
 device_signals = DeviceSignals()
 # }}}
 
+
 class DeviceMixin(object):  # {{{
 
     def __init__(self, *args, **kwargs):
@@ -955,23 +968,34 @@ class DeviceMixin(object):  # {{{
                     _('Cannot configure the device while there are running'
                         ' device jobs.'), show=True)
         dev = self.device_manager.connected_device
+        prefname = 'plugin config dialog:' + dev.type + ':' + dev.name
+        geom = gprefs.get(prefname, None)
+
         cw = dev.config_widget()
-        d = QDialog(self)
-        d.setWindowTitle(_('Configure %s')%dev.get_gui_name())
-        d.setWindowIcon(QIcon(I('config.png')))
-        l = QVBoxLayout(d)
-        d.setLayout(l)
+        config_dialog = QDialog(self)
+
+        config_dialog.setWindowTitle(_('Configure %s')%dev.get_gui_name())
+        config_dialog.setWindowIcon(QIcon(I('config.png')))
+        l = QVBoxLayout(config_dialog)
+        config_dialog.setLayout(l)
         bb = QDialogButtonBox(QDialogButtonBox.Ok|QDialogButtonBox.Cancel)
-        bb.accepted.connect(d.accept)
-        bb.rejected.connect(d.reject)
+        bb.accepted.connect(config_dialog.accept)
+        bb.rejected.connect(config_dialog.reject)
         l.addWidget(cw)
         l.addWidget(bb)
+        config_dialog.resize(config_dialog.sizeHint())
+        if geom is not None:
+            config_dialog.restoreGeometry(geom)
+
         def validate():
             if cw.validate():
-                QDialog.accept(d)
-        d.accept = validate
-        if d.exec_() == d.Accepted:
+                QDialog.accept(config_dialog)
+        config_dialog.accept = validate
+        if config_dialog.exec_() == config_dialog.Accepted:
             dev.save_settings(cw)
+            geom = bytearray(config_dialog.saveGeometry())
+            gprefs[prefname] = geom
+
             do_restart = show_restart_warning(_('Restart calibre for the changes to %s'
                 ' to be applied.')%dev.get_gui_name(), parent=self)
             if do_restart:
@@ -1231,11 +1255,11 @@ class DeviceMixin(object):  # {{{
                             format_count[f] = 1
             for f in self.device_manager.device.settings().format_map:
                 if f in format_count.keys():
-                    formats.append((f, _('%(num)i of %(total)i Books') % dict(
+                    formats.append((f, _('%(num)i of %(total)i books') % dict(
                         num=format_count[f], total=len(rows)),
                         True if f in aval_out_formats else False))
                 elif f in aval_out_formats:
-                    formats.append((f, _('0 of %i Books') % len(rows), True))
+                    formats.append((f, _('0 of %i books') % len(rows), True))
             d = ChooseFormatDeviceDialog(self, _('Choose format to send to device'), formats)
             if d.exec_() != QDialog.Accepted:
                 return
@@ -1353,6 +1377,7 @@ class DeviceMixin(object):  # {{{
     @dynamic_property
     def news_to_be_synced(self):
         doc = 'Set of ids to be sent to device'
+
         def fget(self):
             ans = []
             try:
@@ -1753,6 +1778,7 @@ class DeviceMixin(object):  # {{{
             return False
 
         string_pat = re.compile('(?u)\W|[_]')
+
         def clean_string(x):
             x = x.lower() if x else ''
             return string_pat.sub('', x)
@@ -1992,4 +2018,3 @@ class DeviceMixin(object):  # {{{
         # The status line is reset when the job finishes
         return update_metadata
     # }}}
-
