@@ -77,7 +77,7 @@ class AddEmptyBookDialog(QDialog):
         self.tclear_button.clicked.connect(self.title_edit.clear)
         self._layout.addWidget(self.tclear_button, 7, 1, 1, 1)
 
-        self.format_label = QLabel(_('Also create an empty ebook in format:'))
+        self.format_label = QLabel(_('Also create an empty e-book in format:'))
         self._layout.addWidget(self.format_label, 8, 0, 1, 2)
         c = self.format_value = QComboBox(self)
         from calibre.ebooks.oeb.polish.create import valid_empty_formats
@@ -97,7 +97,7 @@ class AddEmptyBookDialog(QDialog):
 
         self.copy_formats = cf = QCheckBox(_('Also copy book &formats when duplicating a book'), self)
         cf.setToolTip(_(
-            'Also copy all ebook files into the newly created duplicate'
+            'Also copy all e-book files into the newly created duplicate'
             ' books.'))
         cf.setChecked(gprefs.get('create_empty_copy_dup_formats', False))
         self._layout.addWidget(cf, 10, 0, 1, -1)
@@ -171,6 +171,7 @@ class AddEmptyBookDialog(QDialog):
     def selected_title(self):
         return self.title_edit.text().strip()
 
+
 if __name__ == '__main__':
     from calibre.library import db
     db = db()
