@@ -1,4 +1,4 @@
-#!/usr/bin/env  python
+#!/usr/bin/env  python2
 from __future__ import (unicode_literals, division, absolute_import,
                         print_function)
 __license__   = 'GPL v3'
@@ -6,23 +6,30 @@ __copyright__ = '2008, Kovid Goyal kovid@kovidgoyal.net'
 __docformat__ = 'restructuredtext en'
 
 
-from PyQt4.Qt import (
+from PyQt5.Qt import (
     QCoreApplication, QModelIndex, QTimer, Qt, pyqtSignal, QWidget,
     QGridLayout, QDialog, QPixmap, QSize, QPalette, QShortcut, QKeySequence,
     QSplitter, QVBoxLayout, QCheckBox, QPushButton, QIcon, QBrush)
-from PyQt4.QtWebKit import QWebView
+from PyQt5.QtWebKitWidgets import QWebView
 
-from calibre.gui2 import gprefs
+from calibre.gui2 import gprefs, NO_URL_FORMATTING
 from calibre import fit_image
-from calibre.gui2.book_details import render_html
+from calibre.gui2.book_details import render_html, details_context_menu_event, css
 from calibre.gui2.widgets import CoverView
 
-_css = None
-def css():
-    global _css
-    if _css is None:
-        _css = P('templates/book_details.css', data=True).decode('utf-8')
-    return _css
+
+class Details(QWebView):
+
+    def __init__(self, book_info, parent=None):
+        QWebView.__init__(self, parent)
+        self.book_info = book_info
+
+    def sizeHint(self):
+        return QSize(350, 350)
+
+    def contextMenuEvent(self, ev):
+        details_context_menu_event(self, ev, self.book_info)
+
 
 class BookInfo(QDialog):
 
@@ -46,8 +53,7 @@ class BookInfo(QDialog):
         self.cover.sizeHint = self.details_size_hint
         self.splitter.addWidget(self.cover)
 
-        self.details = QWebView(self)
-        self.details.sizeHint = self.details_size_hint
+        self.details = Details(parent.book_details.book_info, self)
         self.details.page().setLinkDelegationPolicy(self.details.page().DelegateAllLinks)
         self.details.linkClicked.connect(self.link_clicked)
         s = self.details.page().settings()
@@ -103,7 +109,7 @@ class BookInfo(QDialog):
                 pass
 
     def link_clicked(self, qurl):
-        link = unicode(qurl.toString())
+        link = unicode(qurl.toString(NO_URL_FORMATTING))
         self.link_delegate(link)
 
     def done(self, r):
@@ -119,8 +125,7 @@ class BookInfo(QDialog):
         if self.current_row is not None:
             id_ = self.view.model().id(self.current_row)
             self.view.model().db.set_cover(id_, data)
-        if self.gui.cover_flow:
-            self.gui.cover_flow.dataChanged()
+        self.gui.refresh_cover_browser()
         ci = self.view.currentIndex()
         if ci.isValid():
             self.view.model().current_changed(ci, ci)
@@ -163,8 +168,13 @@ class BookInfo(QDialog):
                     pixmap.height(), self.cover.size().width()-10,
                     self.cover.size().height()-10)
             if scaled:
-                pixmap = pixmap.scaled(new_width, new_height,
+                try:
+                    dpr = self.devicePixelRatioF()
+                except AttributeError:
+                    dpr = self.devicePixelRatio()
+                pixmap = pixmap.scaled(int(dpr * new_width), int(dpr * new_height),
                         Qt.KeepAspectRatio, Qt.SmoothTransformation)
+                pixmap.setDevicePixelRatio(dpr)
         self.cover.set_pixmap(pixmap)
         self.update_cover_tooltip()
 
@@ -176,7 +186,7 @@ class BookInfo(QDialog):
             tt += '\n\n'
         if self.cover_pixmap is not None:
             sz = self.cover_pixmap.size()
-            tt += _('Cover size: %(width)d x %(height)d')%dict(width=sz.width(), height=sz.height())
+            tt += _('Cover size: %(width)d x %(height)d pixels')%dict(width=sz.width(), height=sz.height())
         self.cover.setToolTip(tt)
 
     def refresh(self, row, mi=None):
@@ -195,6 +205,11 @@ class BookInfo(QDialog):
         self.current_row = row
         self.setWindowTitle(mi.title)
         self.cover_pixmap = QPixmap.fromImage(mi.cover_data[1])
+        try:
+            dpr = self.devicePixelRatioF()
+        except AttributeError:
+            dpr = self.devicePixelRatio()
+        self.cover_pixmap.setDevicePixelRatio(dpr)
         self.resize_cover()
         html = render_html(mi, self.css, True, self, all_fields=True)
         self.details.setHtml(html)
