@@ -45,7 +45,7 @@ class ChoosePluginToolbarsDialog(QDialog):
 
         self._footer_label = QLabel(
             _('You can also customise the plugin locations '
-              'using <b>Preferences -> Customise the toolbar</b>'))
+              'using <b>Preferences -> Interface -> Toolbars</b>'))
         self._layout.addWidget(self._footer_label)
 
         button_box = QDialogButtonBox(QDialogButtonBox.Ok |
@@ -60,4 +60,3 @@ class ChoosePluginToolbarsDialog(QDialog):
         for row in self._locations_list.selectionModel().selectedRows():
             selected.append(self.locations[row.row()])
         return selected
-
