@@ -7,13 +7,39 @@ __docformat__ = 'restructuredtext en'
 
 import sys
 
-from PyQt5.Qt import (QDialog, QIcon, QApplication, QSize, QKeySequence,
+from PyQt5.Qt import (
+    QPainter, QDialog, QIcon, QApplication, QSize, QKeySequence,
     QAction, Qt, QTextBrowser, QDialogButtonBox, QVBoxLayout, QGridLayout,
-    QLabel, QPlainTextEdit, QTextDocument, QCheckBox, pyqtSignal)
+    QLabel, QPlainTextEdit, QTextDocument, QCheckBox, pyqtSignal, QWidget,
+    QSizePolicy)
 
 from calibre.constants import __version__, isfrozen
 from calibre.gui2 import gprefs
 
+
+class Icon(QWidget):
+
+    def __init__(self, parent=None, size=None):
+        QWidget.__init__(self, parent)
+        self.pixmap = None
+        self.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
+        self.size = size or 64
+
+    def set_icon(self, qicon):
+        self.pixmap = qicon.pixmap(self.size, self.size)
+        self.update()
+
+    def sizeHint(self):
+        return QSize(self.size, self.size)
+
+    def paintEvent(self, ev):
+        if self.pixmap is not None:
+            x = (self.width() - self.size) // 2
+            y = (self.height() - self.size) // 2
+            p = QPainter(self)
+            p.drawPixmap(x, y, self.size, self.size, self.pixmap)
+
+
 class MessageBox(QDialog):  # {{{
 
     ERROR = 0
@@ -28,11 +54,8 @@ class MessageBox(QDialog):  # {{{
         self.resize(497, 235)
         self.gridLayout = l = QGridLayout(self)
         l.setObjectName("gridLayout")
-        self.icon_label = la = QLabel('')
-        la.setMaximumSize(QSize(68, 68))
-        la.setScaledContents(True)
-        la.setObjectName("icon_label")
-        l.addWidget(la)
+        self.icon_widget = Icon(self)
+        l.addWidget(self.icon_widget)
         self.msg = la = QLabel(self)
         la.setWordWrap(True), la.setMinimumWidth(400)
         la.setOpenExternalLinks(True)
@@ -74,7 +97,7 @@ class MessageBox(QDialog):  # {{{
 
         self.setWindowTitle(title)
         self.setWindowIcon(self.icon)
-        self.icon_label.setPixmap(self.icon.pixmap(128, 128))
+        self.icon_widget.set_icon(self.icon)
         self.msg.setText(msg)
         self.det_msg.setPlainText(det_msg)
         self.det_msg.setVisible(False)
@@ -166,6 +189,7 @@ class MessageBox(QDialog):  # {{{
         self.resize_needed.emit()
 # }}}
 
+
 class ViewLog(QDialog):  # {{{
 
     def __init__(self, title, html, parent=None, unique_name=None):
@@ -203,12 +227,12 @@ class ViewLog(QDialog):  # {{{
         QApplication.clipboard().setText(txt)
 
     def dialog_closing(self, result):
-        self.geom = bytearray(self.saveGeometry())
-        gprefs[self.unique_name] = self.geom
+        gprefs[self.unique_name] = bytearray(self.saveGeometry())
 # }}}
 
 _proceed_memory = []
 
+
 class ProceedNotification(MessageBox):  # {{{
 
     '''
@@ -280,6 +304,7 @@ class ProceedNotification(MessageBox):  # {{{
 
 # }}}
 
+
 class ErrorNotification(MessageBox):  # {{{
 
     def __init__(self, html_log, log_viewer_title, title, msg,
@@ -320,6 +345,7 @@ class ErrorNotification(MessageBox):  # {{{
         _proceed_memory.remove(self)
 # }}}
 
+
 class JobError(QDialog):  # {{{
 
     WIDTH = 600
@@ -335,9 +361,8 @@ class JobError(QDialog):  # {{{
         self.setLayout(l)
         self.icon = QIcon(I('dialog_error.png'))
         self.setWindowIcon(self.icon)
-        self.icon_label = QLabel()
-        self.icon_label.setPixmap(self.icon.pixmap(68, 68))
-        self.icon_label.setMaximumSize(QSize(68, 68))
+        self.icon_widget = Icon(self)
+        self.icon_widget.set_icon(self.icon)
         self.msg_label = QLabel('<p>&nbsp;')
         self.msg_label.setStyleSheet('QLabel { margin-top: 1ex; }')
         self.msg_label.setWordWrap(True)
@@ -362,7 +387,7 @@ class JobError(QDialog):  # {{{
                 _('Show detailed information about this error'))
         self.suppress = QCheckBox(self)
 
-        l.addWidget(self.icon_label, 0, 0, 1, 1)
+        l.addWidget(self.icon_widget, 0, 0, 1, 1)
         l.addWidget(self.msg_label,  0, 1, 1, 1)
         l.addWidget(self.det_msg,    1, 0, 1, 2)
         l.addWidget(self.suppress,   2, 0, 1, 2, Qt.AlignLeft|Qt.AlignBottom)
@@ -379,8 +404,9 @@ class JobError(QDialog):  # {{{
             self.retry_func()
 
     def update_suppress_state(self):
-        self.suppress.setText(_(
-            'Hide the remaining %d error messages'%len(self.queue)))
+        self.suppress.setText(ngettext(
+            'Hide the remaining error message',
+            'Hide the {} remaining error messages', len(self.queue)).format(len(self.queue)))
         self.suppress.setVisible(len(self.queue) > 3)
         self.do_resize()
 
@@ -448,9 +474,8 @@ class JobError(QDialog):  # {{{
 # }}}
 
 if __name__ == '__main__':
-    app = QApplication([])
-    from calibre.gui2 import question_dialog
-    print question_dialog(None, 'title', 'msg <a href="http://google.com">goog</a> ',
+    from calibre.gui2 import question_dialog, Application
+    app = Application([])
+    print(question_dialog(None, 'title', 'msg <a href="http://google.com">goog</a> ',
             det_msg='det '*1000,
-            show_copy_button=True)
-
+            show_copy_button=True))
