@@ -7,16 +7,16 @@ import re, os
 from collections import namedtuple, defaultdict
 from threading import Thread
 
-from PyQt4.Qt import Qt, QDialog, QGridLayout, QVBoxLayout, QFont, QLabel, \
+from PyQt5.Qt import Qt, QDialog, QGridLayout, QVBoxLayout, QFont, QLabel, \
                      pyqtSignal, QDialogButtonBox, QInputDialog, QLineEdit, \
-                     QDateTime, QCompleter
+                     QDateTime, QCompleter, QCoreApplication, QSize
 
 from calibre.gui2.dialogs.metadata_bulk_ui import Ui_MetadataBulkDialog
 from calibre.gui2.dialogs.tag_editor import TagEditor
 from calibre.ebooks.metadata import string_to_authors, authors_to_string, title_sort
 from calibre.ebooks.metadata.book.formatter import SafeFormat
 from calibre.gui2.custom_column_widgets import populate_metadata_page
-from calibre.gui2 import error_dialog, ResizableDialog, UNDEFINED_QDATETIME, \
+from calibre.gui2 import error_dialog, UNDEFINED_QDATETIME, \
     gprefs, question_dialog, FunctionDispatcher
 from calibre.gui2.progress_indicator import ProgressIndicator
 from calibre.gui2.metadata.basic_widgets import CalendarWidget
@@ -24,10 +24,11 @@ from calibre.utils.config import dynamic, JSONConfig
 from calibre.utils.titlecase import titlecase
 from calibre.utils.icu import sort_key, capitalize
 from calibre.utils.config import prefs, tweaks
-from calibre.utils.magick.draw import identify_data
+from calibre.utils.imghdr import identify
 from calibre.utils.date import qt_to_dt
 from calibre.db import _get_next_series_num_for_list
 
+
 def get_cover_data(stream, ext):  # {{{
     from calibre.ebooks.metadata.meta import get_metadata
     old = prefs['read_file_metadata']
@@ -43,7 +44,7 @@ def get_cover_data(stream, ext):  # {{{
         elif mi.cover_data[1] is not None:
             cdata = mi.cover_data[1]
         if cdata:
-            width, height, fmt = identify_data(cdata)
+            fmt, width, height = identify(cdata)
             area = width*height
     except:
         cdata = area = None
@@ -54,11 +55,16 @@ def get_cover_data(stream, ext):  # {{{
     return cdata, area
 # }}}
 
-Settings = namedtuple('Settings', 'remove_all remove add au aus do_aus rating pub do_series do_autonumber do_remove_format '
-                      'remove_format do_swap_ta do_remove_conv do_auto_author series do_series_restart series_start_value '
-                      'do_title_case cover_action clear_series clear_pub pubdate adddate do_title_sort languages clear_languages restore_original comments')
+
+Settings = namedtuple('Settings',
+    'remove_all remove add au aus do_aus rating pub do_series do_autonumber '
+    'do_swap_ta do_remove_conv do_auto_author series do_series_restart series_start_value series_increment '
+    'do_title_case cover_action clear_series clear_pub pubdate adddate do_title_sort languages clear_languages '
+    'restore_original comments generate_cover_settings')
+
 null = object()
 
+
 class MyBlockingBusy(QDialog):  # {{{
 
     all_done = pyqtSignal()
@@ -135,6 +141,7 @@ class MyBlockingBusy(QDialog):  # {{{
         if args.do_swap_ta:
             title_map = cache.all_field_for('title', self.ids)
             authors_map = cache.all_field_for('authors', self.ids)
+
             def new_title(authors):
                 ans = authors_to_string(authors)
                 return titlecase(ans) if args.do_title_case else ans
@@ -150,6 +157,7 @@ class MyBlockingBusy(QDialog):  # {{{
         if args.do_title_sort:
             lang_map = cache.all_field_for('languages', self.ids)
             title_map = cache.all_field_for('title', self.ids)
+
             def get_sort(book_id):
                 if args.languages:
                     lang = args.languages[0]
@@ -176,20 +184,10 @@ class MyBlockingBusy(QDialog):  # {{{
         if args.cover_action == 'remove':
             cache.set_cover({bid:None for bid in self.ids})
         elif args.cover_action == 'generate':
-            from calibre.ebooks import calibre_cover
-            from calibre.ebooks.metadata import fmt_sidx
-            from calibre.gui2 import config
+            from calibre.ebooks.covers import generate_cover
             for book_id in self.ids:
                 mi = self.db.get_metadata(book_id, index_is_id=True)
-                series_string = None
-                if mi.series:
-                    series_string = _('Book %(sidx)s of %(series)s')%dict(
-                        sidx=fmt_sidx(mi.series_index,
-                        use_roman=config['use_roman_numerals_for_series_number']),
-                        series=mi.series)
-
-                cdata = calibre_cover(mi.title, mi.format_field('authors')[-1],
-                        series_string=series_string)
+                cdata = generate_cover(mi, prefs=args.generate_cover_settings)
                 cache.set_cover({book_id:cdata})
         elif args.cover_action == 'fromfmt':
             for book_id in self.ids:
@@ -207,15 +205,15 @@ class MyBlockingBusy(QDialog):  # {{{
                     if covers:
                         cache.set_cover({book_id:covers[-1][0]})
         elif args.cover_action == 'trim':
-            from calibre.utils.magick import Image
+            from calibre.utils.img import remove_borders_from_image, image_to_data, image_from_data
             for book_id in self.ids:
                 cdata = cache.cover(book_id)
                 if cdata:
-                    im = Image()
-                    im.load(cdata)
-                    im.trim(tweaks['cover_trim_fuzz_value'])
-                    cdata = im.export('jpg')
-                    cache.set_cover({book_id:cdata})
+                    img = image_from_data(cdata)
+                    nimg = remove_borders_from_image(img)
+                    if nimg is not img:
+                        cdata = image_to_data(nimg)
+                        cache.set_cover({book_id:cdata})
         elif args.cover_action == 'clone':
             cdata = None
             for book_id in self.ids:
@@ -225,10 +223,6 @@ class MyBlockingBusy(QDialog):  # {{{
             if cdata:
                 cache.set_cover({bid:cdata for bid in self.ids if bid != book_id})
 
-        # Formats
-        if args.do_remove_format:
-            cache.remove_formats({bid:(args.remove_format,) for bid in self.ids})
-
         if args.restore_original:
             for book_id in self.ids:
                 formats = cache.formats(book_id)
@@ -238,7 +232,7 @@ class MyBlockingBusy(QDialog):  # {{{
 
         # Various fields
         if args.rating != -1:
-            cache.set_field('rating', {bid:args.rating*2 for bid in self.ids})
+            cache.set_field('rating', {bid:args.rating for bid in self.ids})
 
         if args.clear_pub:
             cache.set_field('publisher', {bid:'' for bid in self.ids})
@@ -263,7 +257,7 @@ class MyBlockingBusy(QDialog):  # {{{
             else:
                 def next_series_num(bid, i):
                     if args.do_series_restart:
-                        return sval + i
+                        return sval + (i * args.series_increment)
                     next_num = _get_next_series_num_for_list(sorted(sval.itervalues()), unwrap=False)
                     sval[bid] = next_num
                     return next_num
@@ -299,7 +293,8 @@ class MyBlockingBusy(QDialog):  # {{{
 
 # }}}
 
-class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
+
+class MetadataBulkDialog(QDialog, Ui_MetadataBulkDialog):
 
     s_r_functions = {''              : lambda x: x,
                             _('Lower Case') : lambda x: icu_lower(x),
@@ -309,7 +304,7 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
                     }
 
     s_r_match_modes = [_('Character match'),
-                            _('Regular Expression'),
+                            _('Regular expression'),
                       ]
 
     s_r_replace_modes = [_('Replace field'),
@@ -318,8 +313,8 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
                         ]
 
     def __init__(self, window, rows, model, tab, refresh_books):
-        ResizableDialog.__init__(self, window)
-        Ui_MetadataBulkDialog.__init__(self)
+        QDialog.__init__(self, window)
+        self.setupUi(self)
         self.model = model
         self.db = model.db
         self.refresh_book_list.setChecked(gprefs['refresh_book_list_on_bulk_edit'])
@@ -342,12 +337,8 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
 
         self.initialize_combos()
 
-        for f in sorted(self.db.all_formats()):
-            self.remove_format.addItem(f)
-
-        self.remove_format.setCurrentIndex(-1)
-
         self.series.currentIndexChanged[int].connect(self.series_changed)
+        self.rating.currentIndexChanged.connect(lambda:self.apply_rating.setChecked(True))
         self.series.editTextChanged.connect(self.series_changed)
         self.tag_editor_button.clicked.connect(self.tag_editor)
         self.autonumber_series.stateChanged[int].connect(self.auto_number_changed)
@@ -362,6 +353,8 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
         self.pubdate.dateTimeChanged.connect(self.do_apply_pubdate)
         self.adddate.setDateTime(QDateTime.currentDateTime())
         self.adddate.setMinimumDateTime(UNDEFINED_QDATETIME)
+        self.adddate_cw = CalendarWidget(self.adddate)
+        self.adddate.setCalendarWidget(self.adddate_cw)
         adddate_format = tweaks['gui_timestamp_display_format']
         if adddate_format is not None:
             self.adddate.setDisplayFormat(adddate_format)
@@ -385,13 +378,30 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
         geom = gprefs.get('bulk_metadata_window_geometry', None)
         if geom is not None:
             self.restoreGeometry(bytes(geom))
+        else:
+            self.resize(self.sizeHint())
         ct = gprefs.get('bulk_metadata_window_tab', 0)
         self.central_widget.setCurrentIndex(ct)
         self.languages.init_langs(self.db)
         self.languages.setEditText('')
         self.authors.setFocus(Qt.OtherFocusReason)
+        self.generate_cover_settings = None
+        self.button_config_cover_gen.setVisible(False)
+        self.button_config_cover_gen.clicked.connect(self.customize_cover_generation)
         self.exec_()
 
+    def sizeHint(self):
+        desktop = QCoreApplication.instance().desktop()
+        geom = desktop.availableGeometry(self)
+        nh, nw = max(300, geom.height()-50), max(400, geom.width()-70)
+        return QSize(nw, nh)
+
+    def customize_cover_generation(self):
+        from calibre.gui2.covers import CoverSettingsDialog
+        d = CoverSettingsDialog(parent=self)
+        if d.exec_() == d.Accepted:
+            self.generate_cover_settings = d.prefs_for_rendering
+
     def set_comments(self):
         from calibre.gui2.dialogs.comments_dialog import CommentsDialog
         d = CommentsDialog(self, '' if self.comments is null else (self.comments or ''), _('Comments'))
@@ -438,9 +448,9 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
         fm = self.db.field_metadata
         for f in fm:
             if (f in ['author_sort'] or
-                    (fm[f]['datatype'] in ['text', 'series', 'enumeration', 'comments']
-                     and fm[f].get('search_terms', None)
-                     and f not in ['formats', 'ondevice', 'series_sort']) or
+                    (fm[f]['datatype'] in ['text', 'series', 'enumeration', 'comments', 'rating'] and
+                     fm[f].get('search_terms', None) and
+                     f not in ['formats', 'ondevice', 'series_sort']) or
                     (fm[f]['datatype'] in ['int', 'float', 'bool', 'datetime'] and
                      f not in ['id', 'timestamp'])):
                 self.all_fields.append(f)
@@ -502,7 +512,7 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
 
         self.regexp_heading = _(
                  'In regular expression mode, the search text is an '
-                 'arbitrary python-compatible regular expression. The '
+                 'arbitrary Python-compatible regular expression. The '
                  'replacement text can contain backreferences to parenthesized '
                  'expressions in the pattern. The search is not anchored, '
                  'and can match and replace multiple times on the same string. '
@@ -511,8 +521,8 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
                  'The destination box specifies the field where the result after '
                  'matching and replacement is to be assigned. You can replace '
                  'the text in the field, or prepend or append the matched text. '
-                 'See <a href="http://docs.python.org/library/re.html"> '
-                 'this reference</a> for more information on python\'s regular '
+                 'See <a href="https://docs.python.org/library/re.html">'
+                 'this reference</a> for more information on Python\'s regular '
                  'expressions, and in particular the \'sub\' function.'
                  )
 
@@ -569,12 +579,12 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
     def s_r_sf_itemdata(self, idx):
         if idx is None:
             idx = self.search_field.currentIndex()
-        return unicode(self.search_field.itemData(idx).toString())
+        return unicode(self.search_field.itemData(idx) or '')
 
     def s_r_df_itemdata(self, idx):
         if idx is None:
             idx = self.destination_field.currentIndex()
-        return unicode(self.destination_field.itemData(idx).toString())
+        return unicode(self.destination_field.itemData(idx) or '')
 
     def s_r_get_field(self, mi, field):
         if field:
@@ -738,6 +748,18 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
                 raise Exception(_('You must specify a destination when source is '
                                   'a composite field or a template'))
             dest = src
+
+        if self.destination_field_fm['datatype'] == 'rating' and val[0]:
+            ok = True
+            try:
+                v = int(val[0])
+                if v < 0 or v > 10:
+                    ok = False
+            except:
+                ok = False
+            if not ok:
+                raise Exception(_('The replacement value for a rating column must '
+                                  'be empty or an integer between 0 and 10'))
         dest_mode = self.replace_mode.currentIndex()
 
         if self.destination_field_fm['is_csp']:
@@ -866,6 +888,13 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
             if dest == 'title' and len(val) == 0:
                 val = _('Unknown')
 
+        if not val and dfm['datatype'] == 'datetime':
+            val = None
+        if dfm['datatype'] == 'rating':
+            if (not val or int(val) == 0):
+                val = None
+            if dest == 'rating' and val:
+                val = (int(val) // 2) * 2
         self.set_field_calls[dest][book_id] = val
     # }}}
 
@@ -926,18 +955,19 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
             self.remove_tags.update_items_cache(self.db.all_tags())
 
     def auto_number_changed(self, state):
+        self.series_start_number.setEnabled(bool(state))
+        self.series_increment.setEnabled(bool(state))
         if state:
             self.series_numbering_restarts.setEnabled(True)
-            self.series_start_number.setEnabled(True)
         else:
             self.series_numbering_restarts.setEnabled(False)
             self.series_numbering_restarts.setChecked(False)
-            self.series_start_number.setEnabled(False)
-            self.series_start_number.setValue(1)
+            self.series_start_number.setValue(1.0)
+            self.series_increment.setValue(1.0)
 
     def reject(self):
         self.save_state()
-        ResizableDialog.reject(self)
+        QDialog.reject(self)
 
     def accept(self):
         self.save_state()
@@ -951,7 +981,7 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
 
         if self.s_r_error is not None and do_sr:
             error_dialog(self, _('Search/replace invalid'),
-                    _('Search pattern is invalid: %s')%self.s_r_error.message,
+                    _('Search/replace is invalid: %s')%self.s_r_error.message,
                     show=True)
             return False
         self.changed = bool(self.ids)
@@ -968,7 +998,9 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
         au = unicode(self.authors.text())
         aus = unicode(self.author_sort.text())
         do_aus = self.author_sort.isEnabled()
-        rating = self.rating.value()
+        rating = self.rating.rating_value
+        if not self.apply_rating.isChecked():
+            rating = -1
         pub = unicode(self.publisher.text())
         do_series = self.write_series
         clear_series = self.clear_series.isChecked()
@@ -977,8 +1009,7 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
         do_autonumber = self.autonumber_series.isChecked()
         do_series_restart = self.series_numbering_restarts.isChecked()
         series_start_value = self.series_start_number.value()
-        do_remove_format = self.remove_format.currentIndex() > -1
-        remove_format = unicode(self.remove_format.currentText())
+        series_increment = self.series_increment.value()
         do_swap_ta = self.swap_title_and_author.isChecked()
         do_remove_conv = self.remove_conversion_settings.isChecked()
         do_auto_author = self.auto_author_sort.isChecked()
@@ -1006,11 +1037,11 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
             cover_action = 'clone'
 
         args = Settings(remove_all, remove, add, au, aus, do_aus, rating, pub, do_series,
-                do_autonumber, do_remove_format, remove_format, do_swap_ta,
+                do_autonumber, do_swap_ta,
                 do_remove_conv, do_auto_author, series, do_series_restart,
-                series_start_value, do_title_case, cover_action, clear_series, clear_pub,
+                series_start_value, series_increment, do_title_case, cover_action, clear_series, clear_pub,
                 pubdate, adddate, do_title_sort, languages, clear_languages,
-                restore_original, self.comments)
+                restore_original, self.comments, self.generate_cover_settings)
 
         self.set_field_calls = defaultdict(dict)
         bb = MyBlockingBusy(args, self.ids, self.db, self.refresh_books,
@@ -1187,5 +1218,3 @@ class MetadataBulkDialog(ResizableDialog, Ui_MetadataBulkDialog):
         self.results_count.setValue(999)
         self.starting_from.setValue(1)
         self.multiple_separator.setText(" ::: ")
-
-
