@@ -125,7 +125,7 @@ class ImageTitleLayout(QHBoxLayout):
         pixmap.load(I(icon_name))
         if pixmap is None:
             error_dialog(parent, _('Restart required'),
-                         _('You must restart Calibre before using this plugin!'), show=True)
+                         _('You must restart calibre before using this plugin!'), show=True)
         else:
             title_image_label.setPixmap(pixmap)
         title_image_label.setMaximumSize(32, 32)
@@ -277,7 +277,7 @@ class DisplayPluginModel(QAbstractTableModel):
         QAbstractTableModel.__init__(self)
         self.display_plugins = display_plugins
         self.headers = map(unicode, [_('Plugin Name'), _('Donate'), _('Status'), _('Installed'),
-                                      _('Available'), _('Released'), _('Calibre'), _('Author')])
+                                      _('Available'), _('Released'), _('calibre'), _('Author')])
 
     def rowCount(self, *args):
         return len(self.display_plugins)
@@ -363,7 +363,7 @@ class DisplayPluginModel(QAbstractTableModel):
         if not display_plugin.is_valid_platform():
             return _('Platform unavailable')
         if not display_plugin.is_valid_calibre():
-            return _('Calibre upgrade required')
+            return _('calibre upgrade required')
         if display_plugin.is_installed():
             if display_plugin.is_deprecated:
                 return _('Plugin deprecated')
@@ -408,7 +408,7 @@ class DisplayPluginModel(QAbstractTableModel):
                             ', '.join(display_plugin.platforms)+'\n\n'+
                             _('Right-click to see more options'))
         if numeric_version < display_plugin.calibre_required_version:
-            return (_('You must upgrade to at least Calibre %s before installing this plugin') %
+            return (_('You must upgrade to at least calibre %s before installing this plugin') %
                             self._get_display_version(display_plugin.calibre_required_version)+'\n\n'+
                             _('Right-click to see more options'))
         if display_plugin.installed_version < display_plugin.available_version:
@@ -537,12 +537,12 @@ class PluginUpdaterDialog(SizePersistedDialog):
         self.install_action.triggered.connect(self._install_clicked)
         self.install_action.setEnabled(False)
         self.plugin_view.addAction(self.install_action)
-        self.history_action = QAction(QIcon(I('chapters.png')), _('Version &History'), self)
+        self.history_action = QAction(QIcon(I('chapters.png')), _('Version &history'), self)
         self.history_action.setToolTip(_('Show history of changes to this plugin'))
         self.history_action.triggered.connect(self._history_clicked)
         self.history_action.setEnabled(False)
         self.plugin_view.addAction(self.history_action)
-        self.forum_action = QAction(QIcon(I('plugins/mobileread.png')), _('Plugin &Forum Thread'), self)
+        self.forum_action = QAction(QIcon(I('plugins/mobileread.png')), _('Plugin &forum thread'), self)
         self.forum_action.triggered.connect(self._forum_label_activated)
         self.forum_action.setEnabled(False)
         self.plugin_view.addAction(self.forum_action)
@@ -551,7 +551,7 @@ class PluginUpdaterDialog(SizePersistedDialog):
         sep1.setSeparator(True)
         self.plugin_view.addAction(sep1)
 
-        self.toggle_enabled_action = QAction(_('Enable/&Disable plugin'), self)
+        self.toggle_enabled_action = QAction(_('Enable/&disable plugin'), self)
         self.toggle_enabled_action.setToolTip(_('Enable or disable this plugin'))
         self.toggle_enabled_action.triggered.connect(self._toggle_enabled_clicked)
         self.toggle_enabled_action.setEnabled(False)
@@ -706,8 +706,8 @@ class PluginUpdaterDialog(SizePersistedDialog):
 
         plugin_zip_url = display_plugin.zip_url
         if DEBUG:
-            prints('Downloading plugin zip attachment: ', plugin_zip_url)
-        self.gui.status_bar.showMessage(_('Downloading plugin zip attachment: %s') % plugin_zip_url)
+            prints('Downloading plugin ZIP attachment: ', plugin_zip_url)
+        self.gui.status_bar.showMessage(_('Downloading plugin ZIP attachment: %s') % plugin_zip_url)
         zip_path = self._download_zip(plugin_zip_url)
 
         if DEBUG:
@@ -733,7 +733,7 @@ class PluginUpdaterDialog(SizePersistedDialog):
                         ' {1} plugins</b>. You may have to restart calibre '
                         'for the plugin to take effect.').format(plugin.name, plugin.type),
                     show_copy_button=False)
-            b = d.bb.addButton(_('Restart calibre now'), d.bb.AcceptRole)
+            b = d.bb.addButton(_('&Restart calibre now'), d.bb.AcceptRole)
             b.setIcon(QIcon(I('lt.png')))
             d.do_restart = False
 
@@ -752,11 +752,11 @@ class PluginUpdaterDialog(SizePersistedDialog):
             if DEBUG:
                 prints('ERROR occurred while installing plugin: %s'%display_plugin.name)
                 traceback.print_exc()
-            error_dialog(self.gui, _('Install Plugin Failed'),
+            error_dialog(self.gui, _('Install plugin failed'),
                          _('A problem occurred while installing this plugin.'
                            ' This plugin will now be uninstalled.'
                            ' Please post the error message in details below into'
-                           ' the forum thread for this plugin and restart Calibre.'),
+                           ' the forum thread for this plugin and restart calibre.'),
                          det_msg=traceback.format_exc(), show=True)
             if DEBUG:
                 prints('Due to error now uninstalling plugin: %s'%display_plugin.name)
