@@ -3,23 +3,32 @@ __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
 
 from functools import partial
 
-from PyQt4.QtCore import Qt
-from PyQt4.QtGui import QDialog
+from PyQt5.Qt import Qt, QDialog, QAbstractItemView
 
 from calibre.gui2.dialogs.tag_editor_ui import Ui_TagEditor
 from calibre.gui2 import question_dialog, error_dialog, gprefs
 from calibre.constants import islinux
 from calibre.utils.icu import sort_key, primary_contains
 
+
 class TagEditor(QDialog, Ui_TagEditor):
 
-    def __init__(self, window, db, id_=None, key=None):
+    def __init__(self, window, db, id_=None, key=None, current_tags=None):
         QDialog.__init__(self, window)
         Ui_TagEditor.__init__(self)
         self.setupUi(self)
 
         self.db = db
+        self.sep = ','
+        self.is_names = False
         if key:
+            # Assume that if given a key then it is a custom column
+            try:
+                self.is_names = db.field_metadata[key]['display'].get('is_names', False)
+                if self.is_names:
+                    self.sep = '&'
+            except Exception:
+                pass
             key = db.field_metadata.key_to_label(key)
         self.key = key
         self.index = db.row(id_) if id_ is not None else None
@@ -32,29 +41,34 @@ class TagEditor(QDialog, Ui_TagEditor):
                 tags = self.db.get_custom(self.index, label=key)
         else:
             tags = []
+        if current_tags is not None:
+            tags = sorted(set(current_tags), key=sort_key)
         if tags:
-            tags.sort(key=sort_key)
+            if not self.is_names:
+                tags.sort(key=sort_key)
             for tag in tags:
                 self.applied_tags.addItem(tag)
         else:
             tags = []
 
-        self.tags = tags
+        if self.is_names:
+            self.applied_tags.setDragDropMode(QAbstractItemView.InternalMove)
+            self.applied_tags.setSelectionMode(QAbstractItemView.ExtendedSelection)
 
         if key:
             all_tags = [tag for tag in self.db.all_custom(label=key)]
         else:
             all_tags = [tag for tag in self.db.all_tags()]
-        all_tags = list(set(all_tags))
-        all_tags.sort(key=sort_key)
+        all_tags = sorted(set(all_tags), key=sort_key)
+        q = set(tags)
         for tag in all_tags:
-            if tag not in tags:
+            if tag not in q:
                 self.available_tags.addItem(tag)
 
-        self.apply_button.clicked[()].connect(self.apply_tags)
-        self.unapply_button.clicked[()].connect(self.unapply_tags)
-        self.add_tag_button.clicked[()].connect(self.add_tag)
-        self.delete_button.clicked[()].connect(self.delete_tags)
+        self.apply_button.clicked.connect(lambda: self.apply_tags())
+        self.unapply_button.clicked.connect(lambda: self.unapply_tags())
+        self.add_tag_button.clicked.connect(self.add_tag)
+        self.delete_button.clicked.connect(lambda: self.delete_tags())
         self.add_tag_input.returnPressed[()].connect(self.add_tag)
         # add the handlers for the filter input clear buttons
         for x in ('available', 'applied'):
@@ -63,6 +77,12 @@ class TagEditor(QDialog, Ui_TagEditor):
         self.available_filter_input.textChanged.connect(self.filter_tags)
         self.applied_filter_input.textChanged.connect(partial(self.filter_tags, which='applied_tags'))
 
+        # Restore the focus to the last input box used (typed into)
+        self.add_tag_input.textChanged.connect(partial(self.edit_box_changed, which="add_tag_input"))
+        self.available_filter_input.textChanged.connect(partial(self.edit_box_changed, which="available_filter_input"))
+        self.applied_filter_input.textChanged.connect(partial(self.edit_box_changed, which="applied_filter_input"))
+        getattr(self, gprefs.get('tag_editor_last_filter', 'add_tag_input')).setFocus()
+
         if islinux:
             self.available_tags.itemDoubleClicked.connect(self.apply_tags)
         else:
@@ -73,6 +93,9 @@ class TagEditor(QDialog, Ui_TagEditor):
         if geom is not None:
             self.restoreGeometry(geom)
 
+    def edit_box_changed(self, which):
+        gprefs['tag_editor_last_filter'] = which
+
     def delete_tags(self, item=None):
         confirms, deletes = [], []
         items = self.available_tags.selectedItems() if item is None else [item]
@@ -108,15 +131,19 @@ class TagEditor(QDialog, Ui_TagEditor):
     def apply_tags(self, item=None):
         items = self.available_tags.selectedItems() if item is None else [item]
         rows = [self.available_tags.row(i) for i in items]
+        if not rows:
+            return
         row = max(rows)
+        tags = self._get_applied_tags_box_contents()
         for item in items:
             tag = unicode(item.text())
-            self.tags.append(tag)
+            tags.append(tag)
             self.available_tags.takeItem(self.available_tags.row(item))
 
-        self.tags.sort(key=sort_key)
+        if not self.is_names:
+            tags.sort(key=sort_key)
         self.applied_tags.clear()
-        for tag in self.tags:
+        for tag in tags:
             self.applied_tags.addItem(tag)
 
         if row >= self.available_tags.count():
@@ -129,16 +156,24 @@ class TagEditor(QDialog, Ui_TagEditor):
         # use the filter again when the applied tags were changed
         self.filter_tags(self.applied_filter_input.text(), which='applied_tags')
 
+    def _get_applied_tags_box_contents(self):
+        tags = []
+        for i in range(0, self.applied_tags.count()):
+            tags.append(unicode(self.applied_tags.item(i).text()))
+        return tags
+
     def unapply_tags(self, item=None):
+        tags = self._get_applied_tags_box_contents()
         items = self.applied_tags.selectedItems() if item is None else [item]
         for item in items:
             tag = unicode(item.text())
-            self.tags.remove(tag)
+            tags.remove(tag)
             self.available_tags.addItem(tag)
 
-        self.tags.sort(key=sort_key)
+        if not self.is_names:
+            tags.sort(key=sort_key)
         self.applied_tags.clear()
-        for tag in self.tags:
+        for tag in tags:
             self.applied_tags.addItem(tag)
 
         items = [unicode(self.available_tags.item(x).text()) for x in
@@ -153,19 +188,21 @@ class TagEditor(QDialog, Ui_TagEditor):
         self.filter_tags(self.available_filter_input.text())
 
     def add_tag(self):
-        tags = unicode(self.add_tag_input.text()).split(',')
+        tags = unicode(self.add_tag_input.text()).split(self.sep)
+        tags_in_box = self._get_applied_tags_box_contents()
         for tag in tags:
             tag = tag.strip()
             if not tag:
                 continue
             for item in self.available_tags.findItems(tag, Qt.MatchFixedString):
                 self.available_tags.takeItem(self.available_tags.row(item))
-            if tag not in self.tags:
-                self.tags.append(tag)
+            if tag not in tags_in_box:
+                tags_in_box.append(tag)
 
-        self.tags.sort(key=sort_key)
+        if not self.is_names:
+            tags_in_box.sort(key=sort_key)
         self.applied_tags.clear()
-        for tag in self.tags:
+        for tag in tags_in_box:
             self.applied_tags.addItem(tag)
 
         self.add_tag_input.setText('')
@@ -181,6 +218,7 @@ class TagEditor(QDialog, Ui_TagEditor):
             item.setHidden(bool(q and not primary_contains(q, unicode(item.text()))))
 
     def accept(self):
+        self.tags = self._get_applied_tags_box_contents()
         self.save_state()
         return QDialog.accept(self)
 
@@ -190,3 +228,13 @@ class TagEditor(QDialog, Ui_TagEditor):
 
     def save_state(self):
         gprefs['tag_editor_geometry'] = bytearray(self.saveGeometry())
+
+
+if __name__ == '__main__':
+    from calibre.gui2 import Application
+    from calibre.library import db
+    db = db()
+    app = Application([])
+    d = TagEditor(None, db, current_tags='a b c'.split())
+    if d.exec_() == d.Accepted:
+        print(d.tags)
