@@ -30,7 +30,7 @@ class TemplateLineEditor(QLineEdit):
 
         action_clear_field = menu.addAction(_('Remove any template from the box'))
         action_clear_field.triggered.connect(self.clear_field)
-        action_open_editor = menu.addAction(_('Open Template Editor'))
+        action_open_editor = menu.addAction(_('Open template editor'))
         action_open_editor.triggered.connect(self.open_editor)
         menu.exec_(event.globalPos())
 
