@@ -1,4 +1,4 @@
-#!/usr/bin/env  python
+#!/usr/bin/env  python2
 __license__   = 'GPL v3'
 __copyright__ = '2008, Kovid Goyal kovid@kovidgoyal.net'
 __docformat__ = 'restructuredtext en'
@@ -7,36 +7,50 @@ __docformat__ = 'restructuredtext en'
 Job management.
 '''
 
-import re
+import re, time
 from Queue import Empty, Queue
 
-from PyQt4.Qt import (QAbstractTableModel, QVariant, QModelIndex, Qt,
+from PyQt5.Qt import (QAbstractTableModel, QModelIndex, Qt,
     QTimer, pyqtSignal, QIcon, QDialog, QAbstractItemDelegate, QApplication,
-    QSize, QStyleOptionProgressBarV2, QString, QStyle, QToolTip, QFrame,
+    QSize, QStyleOptionProgressBar, QStyle, QToolTip, QFrame,
     QHBoxLayout, QVBoxLayout, QSizePolicy, QLabel, QCoreApplication, QAction,
-    QByteArray)
+    QByteArray, QSortFilterProxyModel, QTextBrowser, QPlainTextEdit)
 
+from calibre import strftime
+from calibre.constants import islinux, isbsd
 from calibre.utils.ipc.server import Server
 from calibre.utils.ipc.job import ParallelJob
-from calibre.gui2 import Dispatcher, error_dialog, question_dialog, NONE, config, gprefs
+from calibre.gui2 import (Dispatcher, error_dialog, question_dialog,
+        config, gprefs)
 from calibre.gui2.device import DeviceJob
 from calibre.gui2.dialogs.jobs_ui import Ui_JobsDialog
 from calibre import __appname__, as_unicode
-from calibre.gui2.dialogs.job_view_ui import Ui_Dialog
 from calibre.gui2.progress_indicator import ProgressIndicator
 from calibre.gui2.threaded_jobs import ThreadedJobServer, ThreadedJob
+from calibre.gui2.widgets2 import Dialog
+from calibre.utils.search_query_parser import SearchQueryParser, ParseException
+from calibre.utils.icu import lower
 
-class JobManager(QAbstractTableModel): # {{{
+
+class AdaptSQP(SearchQueryParser):
+
+    def __init__(self, *args, **kwargs):
+        pass
+
+
+class JobManager(QAbstractTableModel, AdaptSQP):  # {{{
 
     job_added = pyqtSignal(int)
     job_done  = pyqtSignal(int)
 
     def __init__(self):
         QAbstractTableModel.__init__(self)
-        self.wait_icon     = QVariant(QIcon(I('jobs.png')))
-        self.running_icon  = QVariant(QIcon(I('exec.png')))
-        self.error_icon    = QVariant(QIcon(I('dialog_error.png')))
-        self.done_icon     = QVariant(QIcon(I('ok.png')))
+        SearchQueryParser.__init__(self, ['all'])
+
+        self.wait_icon     = (QIcon(I('jobs.png')))
+        self.running_icon  = (QIcon(I('exec.png')))
+        self.error_icon    = (QIcon(I('dialog_error.png')))
+        self.done_icon     = (QIcon(I('ok.png')))
 
         self.jobs          = []
         self.add_job       = Dispatcher(self._add_job)
@@ -50,22 +64,24 @@ class JobManager(QAbstractTableModel): # {{{
         self.timer.start(1000)
 
     def columnCount(self, parent=QModelIndex()):
-        return 4
+        return 5
 
     def rowCount(self, parent=QModelIndex()):
         return len(self.jobs)
 
     def headerData(self, section, orientation, role):
         if role != Qt.DisplayRole:
-            return NONE
+            return None
         if orientation == Qt.Horizontal:
-            if   section == 0: text = _('Job')
-            elif section == 1: text = _('Status')
-            elif section == 2: text = _('Progress')
-            elif section == 3: text = _('Running time')
-            return QVariant(text)
+            return ({
+              0: _('Job'),
+              1: _('Status'),
+              2: _('Progress'),
+              3: _('Running time'),
+              4: _('Start time'),
+            }.get(section, ''))
         else:
-            return QVariant(section+1)
+            return (section+1)
 
     def show_tooltip(self, arg):
         widget, pos = arg
@@ -74,14 +90,15 @@ class JobManager(QAbstractTableModel): # {{{
     def get_tooltip(self):
         running_jobs = [j for j in self.jobs if j.run_state == j.RUNNING]
         waiting_jobs = [j for j in self.jobs if j.run_state == j.WAITING]
-        lines = [_('There are %d running jobs:')%len(running_jobs)]
+        lines = [ngettext('There is a running job:', 'There are {} running jobs:', len(running_jobs)).format(len(running_jobs))]
         for job in running_jobs:
             desc = job.description
             if not desc:
                 desc = _('Unknown job')
             p = 100. if job.is_finished else job.percent
             lines.append('%s:  %.0f%% done'%(desc, p))
-        lines.extend(['', _('There are %d waiting jobs:')%len(waiting_jobs)])
+        l = ngettext('There is a waiting job', 'There are {} waiting jobs', len(waiting_jobs)).format(len(waiting_jobs))
+        lines.extend(['', l])
         for job in waiting_jobs:
             desc = job.description
             if not desc:
@@ -92,7 +109,7 @@ class JobManager(QAbstractTableModel): # {{{
     def data(self, index, role):
         try:
             if role not in (Qt.DisplayRole, Qt.DecorationRole):
-                return NONE
+                return None
             row, col = index.row(), index.column()
             job = self.jobs[row]
 
@@ -101,17 +118,19 @@ class JobManager(QAbstractTableModel): # {{{
                     desc = job.description
                     if not desc:
                         desc = _('Unknown job')
-                    return QVariant(desc)
+                    return (desc)
                 if col == 1:
-                    return QVariant(job.status_text)
+                    return (job.status_text)
                 if col == 2:
                     p = 100. if job.is_finished else job.percent
-                    return QVariant(p)
+                    return (p)
                 if col == 3:
                     rtime = job.running_time
                     if rtime is None:
-                        return NONE
-                    return QVariant('%dm %ds'%(int(rtime)//60, int(rtime)%60))
+                        return None
+                    return ('%dm %ds'%(int(rtime)//60, int(rtime)%60))
+                if col == 4 and job.start_time is not None:
+                    return (strftime(u'%H:%M -- %d %b', time.localtime(job.start_time)))
             if role == Qt.DecorationRole and col == 0:
                 state = job.run_state
                 if state == job.WAITING:
@@ -124,7 +143,7 @@ class JobManager(QAbstractTableModel): # {{{
         except:
             import traceback
             traceback.print_exc()
-        return NONE
+        return None
 
     def update(self):
         try:
@@ -172,9 +191,9 @@ class JobManager(QAbstractTableModel): # {{{
                     if job.is_finished:
                         self.job_done.emit(len(self.unfinished_jobs()))
             if needs_reset:
-                self.layoutAboutToBeChanged.emit()
+                self.modelAboutToBeReset.emit()
                 self.jobs.sort()
-                self.layoutChanged.emit()
+                self.modelReset.emit()
             else:
                 for job in jobs:
                     idx = self.jobs.index(job)
@@ -197,11 +216,11 @@ class JobManager(QAbstractTableModel): # {{{
                         self.server.kill_job(job)
 
     def _add_job(self, job):
-        self.layoutAboutToBeChanged.emit()
+        self.modelAboutToBeReset.emit()
         self.jobs.append(job)
         self.jobs.sort()
         self.job_added.emit(len(self.unfinished_jobs()))
-        self.layoutChanged.emit()
+        self.modelReset.emit()
 
     def done_jobs(self):
         return [j for j in self.jobs if j.is_finished]
@@ -215,7 +234,7 @@ class JobManager(QAbstractTableModel): # {{{
     def has_device_jobs(self, queued_also=False):
         for job in self.jobs:
             if isinstance(job, DeviceJob):
-                if job.duration is None: # Running or waiting
+                if job.duration is None:  # Running or waiting
                     if (job.is_running or queued_also):
                         return True
         return False
@@ -251,6 +270,18 @@ class JobManager(QAbstractTableModel): # {{{
         else:
             job.kill_on_start = True
 
+    def hide_jobs(self, rows):
+        for r in rows:
+            self.jobs[r].hidden_in_gui = True
+        for r in rows:
+            self.dataChanged.emit(self.index(r, 0), self.index(r, 0))
+
+    def show_hidden_jobs(self):
+        for j in self.jobs:
+            j.hidden_in_gui = False
+        for r in xrange(len(self.jobs)):
+            self.dataChanged.emit(self.index(r, 0), self.index(r, 0))
+
     def kill_job(self, row, view):
         job = self.jobs[row]
         if isinstance(job, DeviceJob):
@@ -299,47 +330,118 @@ class JobManager(QAbstractTableModel): # {{{
                 continue
             if not isinstance(job, ParallelJob):
                 self._kill_job(job)
+
+    def universal_set(self):
+        return set([i for i, j in enumerate(self.jobs) if not getattr(j,
+            'hidden_in_gui', False)])
+
+    def get_matches(self, location, query, candidates=None):
+        if candidates is None:
+            candidates = self.universal_set()
+        ans = set()
+        if not query:
+            return ans
+        query = lower(query)
+        for j in candidates:
+            job = self.jobs[j]
+            if job.description and query in lower(job.description):
+                ans.add(j)
+        return ans
+
+    def find(self, query):
+        query = query.strip()
+        rows = self.parse(query)
+        return rows
+
+# }}}
+
+
+class FilterModel(QSortFilterProxyModel):  # {{{
+
+    search_done = pyqtSignal(object)
+
+    def __init__(self, parent):
+        QSortFilterProxyModel.__init__(self, parent)
+        self.search_filter = None
+
+    def filterAcceptsRow(self, source_row, source_parent):
+        if (self.search_filter is not None and source_row not in
+                self.search_filter):
+            return False
+        m = self.sourceModel()
+        try:
+            job = m.row_to_job(source_row)
+        except:
+            return False
+        return not getattr(job, 'hidden_in_gui', False)
+
+    def find(self, query):
+        ok = True
+        val = None
+        if query:
+            try:
+                val = self.sourceModel().parse(query)
+            except ParseException:
+                ok = False
+        self.search_filter = val
+        self.beginResetModel()
+        self.search_done.emit(ok)
+        self.endResetModel()
+
 # }}}
 
 # Jobs UI {{{
 
-class ProgressBarDelegate(QAbstractItemDelegate): # {{{
+
+class ProgressBarDelegate(QAbstractItemDelegate):  # {{{
 
     def sizeHint(self, option, index):
         return QSize(120, 30)
 
     def paint(self, painter, option, index):
-        opts = QStyleOptionProgressBarV2()
+        opts = QStyleOptionProgressBar()
         opts.rect = option.rect
         opts.minimum = 1
         opts.maximum = 100
         opts.textVisible = True
-        percent, ok = index.model().data(index, Qt.DisplayRole).toInt()
-        if not ok:
+        try:
+            percent = int(index.model().data(index, Qt.DisplayRole))
+        except (TypeError, ValueError):
             percent = 0
         opts.progress = percent
-        opts.text = QString(_('Unavailable') if percent == 0 else '%d%%'%percent)
+        opts.text = (_('Unavailable') if percent == 0 else '%d%%'%percent)
         QApplication.style().drawControl(QStyle.CE_ProgressBar, opts, painter)
 # }}}
 
-class DetailView(QDialog, Ui_Dialog): # {{{
+
+class DetailView(Dialog):  # {{{
 
     def __init__(self, parent, job):
-        QDialog.__init__(self, parent)
-        self.setupUi(self)
-        self.setWindowTitle(job.description)
         self.job = job
-        self.html_view = hasattr(job, 'html_details')
+        self.html_view = hasattr(job, 'html_details') and not getattr(job, 'ignore_html_details', False)
+        Dialog.__init__(self, job.description, 'job-detail-view-dialog', parent)
+
+    def sizeHint(self):
+        return QSize(700, 500)
+
+    def setup_ui(self):
+        self.l = l = QVBoxLayout(self)
         if self.html_view:
-            self.log.setVisible(False)
+            self.tb = w = QTextBrowser(self)
         else:
-            self.tb.setVisible(False)
+            self.log = w = QPlainTextEdit(self)
+            w.setReadOnly(True), w.setLineWrapMode(w.NoWrap)
+        l.addWidget(w)
+        l.addWidget(self.bb)
+        self.bb.clear(), self.bb.setStandardButtons(self.bb.Close)
         self.next_pos = 0
         self.update()
         self.timer = QTimer(self)
         self.timer.timeout.connect(self.update)
         self.timer.start(1000)
-
+        if not self.html_view:
+            v = self.log.verticalScrollBar()
+            v.setValue(v.maximum())
 
     def update(self):
         if self.html_view:
@@ -357,7 +459,10 @@ class DetailView(QDialog, Ui_Dialog): # {{{
                 self.log.appendPlainText(more.decode('utf-8', 'replace'))
 # }}}
 
-class JobsButton(QFrame): # {{{
+
+class JobsButton(QFrame):  # {{{
+
+    tray_tooltip_updated = pyqtSignal(object)
 
     def __init__(self, horizontal=False, size=48, parent=None):
         QFrame.__init__(self, parent)
@@ -366,7 +471,7 @@ class JobsButton(QFrame): # {{{
         self.pi = ProgressIndicator(self, size)
         self._jobs = QLabel('<b>'+_('Jobs:')+' 0')
         self._jobs.mouseReleaseEvent = self.mouseReleaseEvent
-        self.shortcut = _('Shift+Alt+J')
+        self.shortcut = 'Shift+Alt+J'
 
         if horizontal:
             self.setLayout(QHBoxLayout())
@@ -380,15 +485,16 @@ class JobsButton(QFrame): # {{{
         if not horizontal:
             self.layout().setAlignment(self._jobs, Qt.AlignHCenter)
         self._jobs.setMargin(0)
-        self.layout().setMargin(0)
+        self.layout().setContentsMargins(0, 0, 0, 0)
         self._jobs.setSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)
         self.setCursor(Qt.PointingHandCursor)
         b = _('Click to see list of jobs')
         self.setToolTip(b + u' (%s)'%self.shortcut)
         self.action_toggle = QAction(b, parent)
         parent.addAction(self.action_toggle)
-        self.action_toggle.setShortcut(self.shortcut)
         self.action_toggle.triggered.connect(self.toggle)
+        if hasattr(parent, 'keyboard'):
+            parent.keyboard.register_shortcut('toggle jobs list', _('Show/hide the Jobs List'), default_keys=(self.shortcut,), action=self.action_toggle)
 
     def initialize(self, jobs_dialog, job_manager):
         self.jobs_dialog = jobs_dialog
@@ -396,7 +502,6 @@ class JobsButton(QFrame): # {{{
         job_manager.job_done.connect(self.job_done)
         self.jobs_dialog.addAction(self.action_toggle)
 
-
     def mouseReleaseEvent(self, event):
         self.toggle()
 
@@ -420,6 +525,17 @@ class JobsButton(QFrame): # {{{
         src = unicode(self._jobs.text())
         return int(re.search(r'\d+', src).group())
 
+    def tray_tooltip(self, num=0):
+        if num == 0:
+            text = _('No running jobs')
+        elif num == 1:
+            text = _('One running job')
+        else:
+            text = _('%d running jobs') % num
+        if not (islinux or isbsd):
+            text = 'calibre: ' + text
+        return text
+
     def job_added(self, nnum):
         jobs = self._jobs
         src = unicode(jobs.text())
@@ -427,6 +543,7 @@ class JobsButton(QFrame): # {{{
         text = src.replace(str(num), str(nnum))
         jobs.setText(text)
         self.start()
+        self.tray_tooltip_updated.emit(self.tray_tooltip(nnum))
 
     def job_done(self, nnum):
         jobs = self._jobs
@@ -436,6 +553,7 @@ class JobsButton(QFrame): # {{{
         jobs.setText(text)
         if nnum == 0:
             self.no_more_jobs()
+        self.tray_tooltip_updated.emit(self.tray_tooltip(nnum))
 
     def no_more_jobs(self):
         if self.is_running:
@@ -444,14 +562,18 @@ class JobsButton(QFrame): # {{{
 
 # }}}
 
+
 class JobsDialog(QDialog, Ui_JobsDialog):
 
     def __init__(self, window, model):
         QDialog.__init__(self, window)
         Ui_JobsDialog.__init__(self)
         self.setupUi(self)
-        self.jobs_view.setModel(model)
         self.model = model
+        self.proxy_model = FilterModel(self)
+        self.proxy_model.setSourceModel(self.model)
+        self.proxy_model.search_done.connect(self.search.search_done)
+        self.jobs_view.setModel(self.proxy_model)
         self.setWindowModality(Qt.NonModal)
         self.setWindowTitle(__appname__ + _(' - Jobs'))
         self.details_button.clicked.connect(self.show_details)
@@ -460,15 +582,25 @@ class JobsDialog(QDialog, Ui_JobsDialog):
         self.pb_delegate = ProgressBarDelegate(self)
         self.jobs_view.setItemDelegateForColumn(2, self.pb_delegate)
         self.jobs_view.doubleClicked.connect(self.show_job_details)
-        self.jobs_view.horizontalHeader().setMovable(True)
+        self.jobs_view.horizontalHeader().setSectionsMovable(True)
+        self.hide_button.clicked.connect(self.hide_selected)
+        self.hide_all_button.clicked.connect(self.hide_all)
+        self.show_button.clicked.connect(self.show_hidden)
+        self.search.initialize('jobs_search_history',
+                help_text=_('Search for a job by name'))
+        self.search.search.connect(self.find)
+        self.search_button.clicked.connect(lambda :
+                self.find(self.search.current_text))
+        self.clear_button.clicked.connect(lambda : self.search.clear())
         self.restore_state()
 
     def restore_state(self):
         try:
             geom = gprefs.get('jobs_dialog_geometry', bytearray(''))
             self.restoreGeometry(QByteArray(geom))
-            state = gprefs.get('jobs view column layout', bytearray(''))
-            self.jobs_view.horizontalHeader().restoreState(QByteArray(state))
+            state = gprefs.get('jobs view column layout3', None)
+            if state is not None:
+                self.jobs_view.horizontalHeader().restoreState(QByteArray(state))
         except:
             pass
         idx = self.jobs_view.model().index(0, 0)
@@ -479,18 +611,20 @@ class JobsDialog(QDialog, Ui_JobsDialog):
     def save_state(self):
         try:
             state = bytearray(self.jobs_view.horizontalHeader().saveState())
-            gprefs['jobs view column layout'] = state
+            gprefs['jobs view column layout3'] = state
             geom = bytearray(self.saveGeometry())
             gprefs['jobs_dialog_geometry'] = geom
         except:
             pass
 
     def show_job_details(self, index):
-        row = index.row()
-        job = self.jobs_view.model().row_to_job(row)
-        d = DetailView(self, job)
-        d.exec_()
-        d.timer.stop()
+        index = self.proxy_model.mapToSource(index)
+        if index.isValid():
+            row = index.row()
+            job = self.model.row_to_job(row)
+            d = DetailView(self, job)
+            d.exec_()
+            d.timer.stop()
 
     def show_details(self, *args):
         index = self.jobs_view.currentIndex()
@@ -498,8 +632,13 @@ class JobsDialog(QDialog, Ui_JobsDialog):
             self.show_job_details(index)
 
     def kill_job(self, *args):
-        rows = [index.row() for index in
+        indices = [self.proxy_model.mapToSource(index) for index in
                 self.jobs_view.selectionModel().selectedRows()]
+        indices = [i for i in indices if i.isValid()]
+        rows = [index.row() for index in indices]
+        if not rows:
+            return error_dialog(self, _('No job'),
+                _('No job selected'), show=True)
         if question_dialog(self, _('Are you sure?'),
                 ngettext('Do you really want to stop the selected job?',
                     'Do you really want to stop all the selected jobs?',
@@ -514,6 +653,26 @@ class JobsDialog(QDialog, Ui_JobsDialog):
                 _('Do you really want to stop all non-device jobs?')):
             self.model.kill_all_jobs()
 
+    def hide_selected(self, *args):
+        indices = [self.proxy_model.mapToSource(index) for index in
+                self.jobs_view.selectionModel().selectedRows()]
+        indices = [i for i in indices if i.isValid()]
+        rows = [index.row() for index in indices]
+        if not rows:
+            return error_dialog(self, _('No job'),
+                _('No job selected'), show=True)
+        self.model.hide_jobs(rows)
+        self.proxy_model.beginResetModel(), self.proxy_model.endResetModel()
+
+    def hide_all(self, *args):
+        self.model.hide_jobs(list(xrange(0,
+            self.model.rowCount(QModelIndex()))))
+        self.proxy_model.beginResetModel(), self.proxy_model.endResetModel()
+
+    def show_hidden(self, *args):
+        self.model.show_hidden_jobs()
+        self.find(self.search.current_text)
+
     def closeEvent(self, e):
         self.save_state()
         return QDialog.closeEvent(self, e)
@@ -525,5 +684,12 @@ class JobsDialog(QDialog, Ui_JobsDialog):
     def hide(self, *args):
         self.save_state()
         return QDialog.hide(self, *args)
-# }}}
 
+    def reject(self):
+        self.save_state()
+        QDialog.reject(self)
+
+    def find(self, query):
+        self.proxy_model.find(query)
+
+# }}}
