@@ -15,29 +15,32 @@ from textwrap import wrap
 
 from PyQt5.Qt import (
     QListView, QSize, QStyledItemDelegate, QModelIndex, Qt, QImage, pyqtSignal,
-    QTimer, QPalette, QColor, QItemSelection, QPixmap, QMenu, QApplication,
+    QTimer, QPalette, QColor, QItemSelection, QPixmap, QApplication,
     QMimeData, QUrl, QDrag, QPoint, QPainter, QRect, pyqtProperty, QEvent,
     QPropertyAnimation, QEasingCurve, pyqtSlot, QHelpEvent, QAbstractItemView,
     QStyleOptionViewItem, QToolTip, QByteArray, QBuffer, QBrush, qRed, qGreen,
-    qBlue, QItemSelectionModel)
+    qBlue, QItemSelectionModel, QIcon, QFont)
 
 from calibre import fit_image, prints, prepare_string_for_xml, human_readable
-from calibre.constants import DEBUG, config_dir
-from calibre.ebooks.metadata import fmt_sidx
+from calibre.constants import DEBUG, config_dir, islinux
+from calibre.ebooks.metadata import fmt_sidx, rating_to_stars
 from calibre.utils import join_with_timeout
-from calibre.gui2 import gprefs, config
+from calibre.gui2 import gprefs, config, rating_font, empty_index
 from calibre.gui2.library.caches import CoverCache, ThumbnailCache
 from calibre.utils.config import prefs, tweaks
 
 CM_TO_INCH = 0.393701
 CACHE_FORMAT = 'PPM'
 
+
 def auto_height(widget):
     return max(185, QApplication.instance().desktop().availableGeometry(widget).height() / 5.0)
 
+
 class EncodeError(ValueError):
     pass
 
+
 def image_to_data(image):  # {{{
     ba = QByteArray()
     buf = QBuffer(ba)
@@ -50,14 +53,18 @@ def image_to_data(image):  # {{{
 # }}}
 
 # Drag 'n Drop {{{
+
+
 def dragMoveEvent(self, event):
     event.acceptProposedAction()
 
+
 def event_has_mods(self, event=None):
     mods = event.modifiers() if event is not None else \
             QApplication.keyboardModifiers()
     return mods & Qt.ControlModifier or mods & Qt.ShiftModifier
 
+
 def mousePressEvent(base_class, self, event):
     ep = event.pos()
     if self.indexAt(ep) in self.selectionModel().selectedIndexes() and \
@@ -67,6 +74,7 @@ def mousePressEvent(base_class, self, event):
         return self.handle_mouse_press_event(event)
     return base_class.mousePressEvent(self, event)
 
+
 def drag_icon(self, cover, multiple):
     cover = cover.scaledToHeight(120, Qt.SmoothTransformation)
     if multiple:
@@ -95,6 +103,7 @@ def drag_icon(self, cover, multiple):
         cover = base
     return QPixmap.fromImage(cover)
 
+
 def drag_data(self):
     m = self.model()
     db = m.db
@@ -138,6 +147,7 @@ def drag_data(self):
     drag.setPixmap(cover)
     return drag
 
+
 def mouseMoveEvent(base_class, self, event):
     if not self.drag_allowed:
         return
@@ -160,6 +170,7 @@ def mouseMoveEvent(base_class, self, event):
     drag.exec_(Qt.CopyAction)
     self.drag_start_pos = None
 
+
 def dragEnterEvent(self, event):
     if int(event.possibleActions() & Qt.CopyAction) + \
         int(event.possibleActions() & Qt.MoveAction) == 0:
@@ -169,12 +180,14 @@ def dragEnterEvent(self, event):
     if paths:
         event.acceptProposedAction()
 
+
 def dropEvent(self, event):
     paths = self.paths_from_event(event)
     event.setDropAction(Qt.CopyAction)
     event.accept()
     self.files_dropped.emit(paths)
 
+
 def paths_from_event(self, event):
     '''
     Accept a drop event and return a list of paths that can be read from
@@ -187,6 +200,7 @@ def paths_from_event(self, event):
         return [u for u in urls if os.path.splitext(u)[1] and
                 os.path.exists(u)]
 
+
 def setup_dnd_interface(cls_or_self):
     if isinstance(cls_or_self, type):
         cls = cls_or_self
@@ -210,6 +224,8 @@ def setup_dnd_interface(cls_or_self):
 # }}}
 
 # Manage slave views {{{
+
+
 def sync(func):
     @wraps(func)
     def ans(self, *args, **kwargs):
@@ -219,6 +235,7 @@ def sync(func):
             return func(self, *args, **kwargs)
     return ans
 
+
 class AlternateViews(object):
 
     def __init__(self, main_view):
@@ -309,6 +326,8 @@ class AlternateViews(object):
 # }}}
 
 # Rendering of covers {{{
+
+
 class CoverDelegate(QStyledItemDelegate):
 
     MARGIN = 4
@@ -333,6 +352,7 @@ class CoverDelegate(QStyledItemDelegate):
         self.render_queue = LifoQueue()
         self.animating = None
         self.highlight_color = QColor(Qt.white)
+        self.rating_font = QFont(rating_font())
 
     def set_dimensions(self):
         width = self.original_width = gprefs['cover_grid_width']
@@ -384,6 +404,7 @@ class CoverDelegate(QStyledItemDelegate):
         return self.item_size
 
     def render_field(self, db, book_id):
+        is_stars = False
         try:
             field = db.pref('field_under_covers_in_grid', 'title')
             if field == 'size':
@@ -392,13 +413,14 @@ class CoverDelegate(QStyledItemDelegate):
                 mi = db.get_proxy_metadata(book_id)
                 display_name, ans, val, fm = mi.format_field_extended(field)
                 if fm and fm['datatype'] == 'rating':
-                    ans = u'\u2605' * int(val/2.0) if val is not None else ''
-            return '' if ans is None else unicode(ans)
+                    ans = rating_to_stars(val, fm['display'].get('allow_half_stars', False))
+                    is_stars = True
+            return ('' if ans is None else unicode(ans)), is_stars
         except Exception:
             if DEBUG:
                 import traceback
                 traceback.print_exc()
-        return ''
+        return '', is_stars
 
     def render_emblem(self, book_id, rule, rule_index, cache, mi, db, formatter, template_cache):
         ans = cache[book_id].get(rule, False)
@@ -420,16 +442,16 @@ class CoverDelegate(QStyledItemDelegate):
         if raw_icon is not None:
             ans = raw_icon.pixmap(sz, sz)
         elif name == ':ondevice':
-            ans = QPixmap(I('ok.png')).scaled(sz, sz, transformMode=Qt.SmoothTransformation)
+            ans = QIcon(I('ok.png')).pixmap(sz, sz)
         elif name:
-            pmap = QPixmap(os.path.join(config_dir, 'cc_icons', name))
+            pmap = QIcon(os.path.join(config_dir, 'cc_icons', name)).pixmap(sz, sz)
             if not pmap.isNull():
-                ans = pmap.scaled(sz, sz)
+                ans = pmap
         cache[name] = ans
         return ans
 
     def paint(self, painter, option, index):
-        QStyledItemDelegate.paint(self, painter, option, QModelIndex())  # draw the hover and selection highlights
+        QStyledItemDelegate.paint(self, painter, option, empty_index)  # draw the hover and selection highlights
         m = index.model()
         db = m.db
         try:
@@ -486,8 +508,10 @@ class CoverDelegate(QStyledItemDelegate):
                     rect.setBottom(rect.bottom() - self.title_height)
                 if self.animating is not None and self.animating.row() == index.row():
                     cdata = cdata.scaled(cdata.size() * self._animated_size)
-                dx = max(0, int((rect.width() - cdata.width())/2.0))
-                dy = max(0, rect.height() - cdata.height())
+                dpr = cdata.devicePixelRatio()
+                cw, ch = int(cdata.width() / dpr), int(cdata.height() / dpr)
+                dx = max(0, int((rect.width() - cw)/2.0))
+                dy = max(0, rect.height() - ch)
                 right_adjust = dx
                 rect.adjust(dx, dy, -dx, 0)
                 painter.drawPixmap(rect, cdata)
@@ -495,7 +519,9 @@ class CoverDelegate(QStyledItemDelegate):
                     rect = trect
                     rect.setTop(rect.bottom() - self.title_height + 5)
                     painter.setRenderHint(QPainter.TextAntialiasing, True)
-                    title = self.render_field(db, book_id)
+                    title, is_stars = self.render_field(db, book_id)
+                    if is_stars:
+                        painter.setFont(self.rating_font)
                     metrics = painter.fontMetrics()
                     painter.setPen(self.highlight_color)
                     painter.drawText(rect, Qt.AlignCenter|Qt.TextSingleLine,
@@ -513,7 +539,7 @@ class CoverDelegate(QStyledItemDelegate):
                 try:
                     p = self.on_device_emblem
                 except AttributeError:
-                    p = self.on_device_emblem = QPixmap(I('ok.png')).scaled(48, 48, transformMode=Qt.SmoothTransformation)
+                    p = self.on_device_emblem = QIcon(I('ok.png')).pixmap(48, 48)
                 self.paint_embossed_emblem(p, painter, orect, right_adjust, left=False)
         finally:
             painter.restore()
@@ -542,21 +568,23 @@ class CoverDelegate(QStyledItemDelegate):
                 delta = 0 if i == 0 else self.emblem_size + self.MARGIN
                 grect.moveLeft(grect.left() + delta) if horizontal else grect.moveTop(grect.top() + delta)
                 rect = QRect(grect)
-                rect.setWidth(emblem.width()), rect.setHeight(emblem.height())
+                rect.setWidth(int(emblem.width() / emblem.devicePixelRatio())), rect.setHeight(int(emblem.height() / emblem.devicePixelRatio()))
                 painter.drawPixmap(rect, emblem)
         finally:
             painter.restore()
 
     def paint_embossed_emblem(self, pixmap, painter, orect, right_adjust, left=True):
         drect = QRect(orect)
+        pw = int(pixmap.width() / pixmap.devicePixelRatio())
+        ph = int(pixmap.height() / pixmap.devicePixelRatio())
         if left:
             drect.setLeft(drect.left() + right_adjust)
-            drect.setRight(drect.left() + pixmap.width())
+            drect.setRight(drect.left() + pw)
         else:
             drect.setRight(drect.right() - right_adjust)
-            drect.setLeft(drect.right() - pixmap.width() + 1)
+            drect.setLeft(drect.right() - pw + 1)
         drect.setBottom(drect.bottom() - self.title_height)
-        drect.setTop(drect.bottom() - pixmap.height())
+        drect.setTop(drect.bottom() - ph)
         painter.drawPixmap(drect, pixmap)
 
     @pyqtSlot(QHelpEvent, QAbstractItemView, QStyleOptionViewItem, QModelIndex, result=bool)
@@ -597,6 +625,8 @@ class CoverDelegate(QStyledItemDelegate):
 # }}}
 
 # The View {{{
+
+
 @setup_dnd_interface
 class GridView(QListView):
 
@@ -623,8 +653,9 @@ class GridView(QListView):
         self.padding_left = 0
         self.set_color()
         self.ignore_render_requests = Event()
+        dpr = self.device_pixel_ratio
         self.thumbnail_cache = ThumbnailCache(max_size=gprefs['cover_grid_disk_cache_size'],
-            thumbnail_size=(self.delegate.cover_size.width(), self.delegate.cover_size.height()))
+            thumbnail_size=(int(dpr * self.delegate.cover_size.width()), int(dpr * self.delegate.cover_size.height())))
         self.render_thread = None
         self.update_item.connect(self.re_render, type=Qt.QueuedConnection)
         self.doubleClicked.connect(self.double_clicked)
@@ -639,6 +670,13 @@ class GridView(QListView):
         t.setInterval(200), t.setSingleShot(True)
         t.timeout.connect(self.update_memory_cover_cache_size)
 
+    @property
+    def device_pixel_ratio(self):
+        try:
+            return self.devicePixelRatioF()
+        except AttributeError:
+            return self.devicePixelRatio()
+
     @property
     def first_visible_row(self):
         geom = self.viewport().geometry()
@@ -723,7 +761,8 @@ class GridView(QListView):
             self.setSpacing(self.delegate.spacing)
         self.set_color()
         if size_changed:
-            self.thumbnail_cache.set_thumbnail_size(self.delegate.cover_size.width(), self.delegate.cover_size.height())
+            dpr = self.device_pixel_ratio
+            self.thumbnail_cache.set_thumbnail_size(int(dpr * self.delegate.cover_size.width()), int(dpr*self.delegate.cover_size.height()))
         cs = gprefs['cover_grid_disk_cache_size']
         if (cs*(1024**2)) != self.thumbnail_cache.max_size:
             self.thumbnail_cache.set_size(cs)
@@ -787,6 +826,8 @@ class GridView(QListView):
         if has_cover:
             p = QImage()
             p.loadFromData(cdata, CACHE_FORMAT if cdata is tcdata else 'JPEG')
+            dpr = self.device_pixel_ratio
+            p.setDevicePixelRatio(dpr)
             if p.isNull() and cdata is tcdata:
                 # Invalid image in cache
                 self.thumbnail_cache.invalidate((book_id,))
@@ -796,11 +837,13 @@ class GridView(QListView):
             if not use_cache:  # cache is stale
                 if cdata is not None:
                     width, height = p.width(), p.height()
-                    scaled, nwidth, nheight = fit_image(width, height, self.delegate.cover_size.width(), self.delegate.cover_size.height())
+                    scaled, nwidth, nheight = fit_image(
+                        width, height, int(dpr * self.delegate.cover_size.width()), int(dpr * self.delegate.cover_size.height()))
                     if scaled:
                         if self.ignore_render_requests.is_set():
                             return
                         p = p.scaled(nwidth, nheight, Qt.IgnoreAspectRatio, Qt.SmoothTransformation)
+                        p.setDevicePixelRatio(dpr)
                     cdata = p
                 # update cache
                 if cdata is None:
@@ -886,17 +929,12 @@ class GridView(QListView):
         self.context_menu = menu
 
     def contextMenuEvent(self, event):
-        if self.context_menu is not None:
-            menu = self._temp_menu = QMenu(self)
-            sac = self.gui.iactions['Sort By']
-            sort_added = tuple(ac for ac in self.context_menu.actions() if ac is sac.qaction)
-            if not sort_added:
-                menu.addAction(sac.qaction)
-            for ac in self.context_menu.actions():
-                menu.addAction(ac)
-            sac.update_menu()
-            menu.popup(event.globalPos())
-            event.accept()
+        if self.context_menu is None:
+            return
+        from calibre.gui2.main_window import clone_menu
+        m = clone_menu(self.context_menu) if islinux else self.context_menu
+        m.popup(event.globalPos())
+        event.accept()
 
     def get_selected_ids(self):
         m = self.model()
@@ -982,7 +1020,8 @@ class GridView(QListView):
         return super(GridView, self).selectionCommand(index, event)
 
     def wheelEvent(self, ev):
-        if ev.phase() != Qt.ScrollUpdate:
+        if ev.phase() not in (Qt.ScrollUpdate, 0):
+            # 0 is Qt.NoScrollPhase which is not yet available in PyQt
             return
         number_of_pixels = ev.pixelDelta()
         number_of_degrees = ev.angleDelta() / 8
