@@ -12,7 +12,7 @@ from functools import partial
 from threading import Thread
 
 from PyQt5.Qt import (QIcon, QDialog,
-        QDialogButtonBox, QLabel, QGridLayout, QPixmap, Qt)
+        QDialogButtonBox, QLabel, QGridLayout, Qt)
 
 from calibre.gui2.threaded_jobs import ThreadedJob
 from calibre.ebooks.metadata.opf2 import metadata_to_opf
@@ -22,6 +22,7 @@ from calibre.ptempfile import (PersistentTemporaryDirectory,
 
 # Start download {{{
 
+
 class Job(ThreadedJob):
 
     ignore_html_details = True
@@ -43,11 +44,13 @@ class Job(ThreadedJob):
     def log_file(self):
         return open(self.download_debug_log, 'rb')
 
+
 def show_config(gui, parent):
     from calibre.gui2.preferences import show_config_widget
     show_config_widget('Sharing', 'Metadata download', parent=parent,
             gui=gui, never_shutdown=True)
 
+
 class ConfirmDialog(QDialog):
 
     def __init__(self, ids, parent):
@@ -59,12 +62,15 @@ class ConfirmDialog(QDialog):
         self.setLayout(l)
 
         i = QLabel(self)
-        i.setPixmap(QPixmap(I('download-metadata.png')))
+        i.setPixmap(QIcon(I('download-metadata.png')).pixmap(128, 128))
         l.addWidget(i, 0, 0)
+        t = ngettext(
+            'The download of metadata for the <b>selected book</b> will run in the background. Proceed?',
+            'The download of metadata for the <b>{} selected books</b> will run in the background. Proceed?',
+            len(ids)).format(len(ids))
 
         t = QLabel(
-            '<p>'+_('The download of metadata for the <b>%d selected book(s)</b> will'
-                ' run in the background. Proceed?')%len(ids) +
+            '<p>'+ t +
             '<p>'+_('You can monitor the progress of the download '
                 'by clicking the rotating spinner in the bottom right '
                 'corner.') +
@@ -109,6 +115,7 @@ class ConfirmDialog(QDialog):
         self.identify = False
         self.accept()
 
+
 def split_jobs(ids, batch_size=100):
     ans = []
     ids = list(ids)
@@ -118,6 +125,7 @@ def split_jobs(ids, batch_size=100):
         ids = ids[batch_size:]
     return ans
 
+
 def start_download(gui, ids, callback, ensure_fields=None):
     d = ConfirmDialog(ids, gui)
     ret = d.exec_()
@@ -128,7 +136,9 @@ def start_download(gui, ids, callback, ensure_fields=None):
     tf.close()
 
     job = Job('metadata bulk download',
-        _('Download metadata for %d books')%len(ids),
+        ngettext(
+            'Download metadata for one book',
+            'Download metadata for {} books', len(ids)).format(len(ids)),
         download, (ids, tf.name, gui.current_db, d.identify, d.covers,
             ensure_fields), {}, callback)
     job.metadata_and_covers = (d.identify, d.covers)
@@ -138,6 +148,7 @@ def start_download(gui, ids, callback, ensure_fields=None):
 
 # }}}
 
+
 def get_job_details(job):
     (aborted, good_ids, tdir, log_file, failed_ids, failed_covers, title_map,
             lm_map, all_failed) = job.result
@@ -153,6 +164,7 @@ def get_job_details(job):
     return (aborted, good_ids, tdir, log_file, failed_ids, failed_covers,
             all_failed, det_msg, lm_map)
 
+
 class HeartBeat(object):
     CHECK_INTERVAL = 300  # seconds
     ''' Check that the file count in tdir changes every five minutes '''
@@ -171,6 +183,7 @@ class HeartBeat(object):
             self.last_time = time.time()
         return True
 
+
 class Notifier(Thread):
 
     def __init__(self, notifications, title_map, tdir, total):
@@ -201,6 +214,7 @@ class Notifier(Thread):
                                 _('Processed %s')%self.title_map[book_id]))
             time.sleep(1)
 
+
 def download(all_ids, tf, db, do_identify, covers, ensure_fields,
         log=None, abort=None, notifications=None):
     batch_size = 10
@@ -263,5 +277,3 @@ def download(all_ids, tf, db, do_identify, covers, ensure_fields,
                 lm_map, all_failed)
     finally:
         notifier.keep_going = False
-
-
