@@ -32,6 +32,7 @@ Widgets = namedtuple('Widgets', 'new old label button')
 
 # Widgets {{{
 
+
 class LineEdit(EditWithComplete):
 
     changed = pyqtSignal()
@@ -60,6 +61,7 @@ class LineEdit(EditWithComplete):
                     val = val.strip(ism['list_to_ui'].strip())
                     val = [x.strip() for x in val.split(ism['list_to_ui']) if x.strip()]
             return val
+
         def fset(self, val):
             ism = self.metadata['is_multiple']
             if ism:
@@ -87,6 +89,7 @@ class LineEdit(EditWithComplete):
     def current_val(self):
         def fget(self):
             return unicode(self.text())
+
         def fset(self, val):
             self.setText(val)
             self.setCursorPosition(0)
@@ -120,6 +123,7 @@ class LanguagesEdit(LE):
     def current_val(self):
         def fget(self):
             return self.lang_codes
+
         def fset(self, val):
             self.lang_codes = val
         return property(fget=fget, fset=fset)
@@ -137,6 +141,7 @@ class LanguagesEdit(LE):
     def same_as(self, other):
         return self.current_val == other.current_val
 
+
 class RatingsEdit(RatingEdit):
 
     changed = pyqtSignal()
@@ -146,24 +151,22 @@ class RatingsEdit(RatingEdit):
         self.is_new = is_new
         self.field = field
         self.metadata = metadata
-        self.valueChanged.connect(self.changed)
-        if not is_new:
-            self.setReadOnly(True)
+        self.currentIndexChanged.connect(self.changed)
 
     def from_mi(self, mi):
-        val = (mi.get(self.field, default=0) or 0)/2
-        self.setValue(val)
+        self.current_val = mi.get(self.field, default=0)
 
     def to_mi(self, mi):
-        mi.set(self.field, self.value() * 2)
+        mi.set(self.field, self.current_val)
 
     @property
     def is_blank(self):
-        return self.value() == 0
+        return self.current_val == 0
 
     def same_as(self, other):
         return self.current_val == other.current_val
 
+
 class DateEdit(PubdateEdit):
 
     changed = pyqtSignal()
@@ -191,6 +194,7 @@ class DateEdit(PubdateEdit):
     def same_as(self, other):
         return self.text() == other.text()
 
+
 class SeriesEdit(LineEdit):
 
     def __init__(self, *args, **kwargs):
@@ -228,6 +232,7 @@ class SeriesEdit(LineEdit):
         sidx = fmt_sidx(num)
         self.setText(self.text() + ' [%s]' % sidx)
 
+
 class IdentifiersEdit(LineEdit):
 
     def from_mi(self, mi):
@@ -241,12 +246,14 @@ class IdentifiersEdit(LineEdit):
         def fget(self):
             parts = (x.strip() for x in self.current_val.split(',') if x.strip())
             return {k:v for k, v in {x.partition(':')[0].strip():x.partition(':')[-1].strip() for x in parts}.iteritems() if k and v}
+
         def fset(self, val):
             val = ('%s:%s' % (k, v) for k, v in val.iteritems())
             self.setText(', '.join(val))
             self.setCursorPosition(0)
         return property(fget=fget, fset=fset)
 
+
 class CommentsEdit(Editor):
 
     changed = pyqtSignal()
@@ -266,6 +273,7 @@ class CommentsEdit(Editor):
     def current_val(self):
         def fget(self):
             return self.html
+
         def fset(self, val):
             self.html = val or ''
             self.changed.emit()
@@ -288,6 +296,7 @@ class CommentsEdit(Editor):
     def same_as(self, other):
         return self.current_val == other.current_val
 
+
 class CoverView(QWidget):
 
     changed = pyqtSignal()
@@ -310,6 +319,7 @@ class CoverView(QWidget):
     def current_val(self):
         def fget(self):
             return self.pixmap
+
         def fset(self, val):
             self.pixmap = val
             self.changed.emit()
@@ -376,6 +386,7 @@ class CoverView(QWidget):
         p.end()
 # }}}
 
+
 class CompareSingle(QWidget):
 
     def __init__(
@@ -520,6 +531,7 @@ class CompareSingle(QWidget):
                 changed = True
         return changed
 
+
 class CompareMany(QDialog):
 
     def __init__(self, ids, get_metadata, field_metadata, parent=None,
@@ -656,7 +668,10 @@ class CompareMany(QDialog):
 
     def reject_all_remaining(self):
         from calibre.gui2.dialogs.confirm_delete import confirm
-        if not confirm(_('Are you sure you want to reject all %d remaining results?') % len(self.ids), 'confirm_metadata_review_reject', parent=self):
+        if not confirm(ngettext(
+                'Are you sure you want to reject the remaining result?',
+                'Are you sure you want to reject all {} remaining results?', len(self.ids)).format(len(self.ids)),
+                       'confirm_metadata_review_reject', parent=self):
             return
         self.next_item(False)
         for id_ in self.ids:
@@ -672,9 +687,11 @@ class CompareMany(QDialog):
             return
         return QDialog.keyPressEvent(self, ev)
 
+
 if __name__ == '__main__':
-    app = QApplication([])
+    from calibre.gui2 import Application
     from calibre.library import db
+    app = Application([])
     db = db()
     ids = sorted(db.all_ids(), reverse=True)
     ids = tuple(zip(ids[0::2], ids[1::2]))
@@ -685,4 +702,3 @@ if __name__ == '__main__':
         for changed, mi in d.accepted.itervalues():
             if changed and mi is not None:
                 print (mi)
-
