@@ -75,7 +75,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         self.field_metadata = db.field_metadata
 
         self.opt_columns.setColumnCount(4)
-        item = QTableWidgetItem(_('Column Header'))
+        item = QTableWidgetItem(_('Column header'))
         self.opt_columns.setHorizontalHeaderItem(0, item)
         item = QTableWidgetItem(_('Lookup name'))
         self.opt_columns.setHorizontalHeaderItem(1, item)
@@ -134,7 +134,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
             dt = fm['datatype']
             if fm['is_multiple']:
                 if col == 'authors' or fm.get('display', {}).get('is_names', False):
-                    coltype = _('Ampersand separated text, shown in the tag browser')
+                    coltype = _('Ampersand separated text, shown in the Tag browser')
                 else:
                     coltype = self.column_desc['*' + dt]
             else:
