@@ -7,12 +7,13 @@ __docformat__ = 'restructuredtext en'
 
 import importlib
 
-from PyQt5.Qt import QIcon, Qt, QStringListModel
+from PyQt5.Qt import (
+    QIcon, Qt, QStringListModel, QListView, QSizePolicy, QHBoxLayout, QSize,
+    QStackedWidget, pyqtSignal)
 
 from calibre.gui2.preferences import ConfigWidgetBase, test_widget, AbortCommit
 from calibre.ebooks.conversion.plumber import Plumber
 from calibre.utils.logging import Log
-from calibre.gui2.preferences.conversion_ui import Ui_Form
 from calibre.gui2.convert.look_and_feel import LookAndFeelWidget
 from calibre.gui2.convert.heuristics import HeuristicsWidget
 from calibre.gui2.convert.search_and_replace import SearchAndReplaceWidget
@@ -22,6 +23,7 @@ from calibre.gui2.convert.toc import TOCWidget
 from calibre.customize.ui import input_format_plugins, output_format_plugins
 from calibre.gui2.convert import config_widget_for_input_plugin
 
+
 class Model(QStringListModel):
 
     def __init__(self, widgets):
@@ -36,12 +38,40 @@ class Model(QStringListModel):
                 return (QIcon(w.ICON))
         return QStringListModel.data(self, index, role)
 
-class Base(ConfigWidgetBase, Ui_Form):
+
+class ListView(QListView):
+
+    current_changed = pyqtSignal(object, object)
+
+    def __init__(self, parent=None):
+        QListView.__init__(self, parent)
+        self.setSizePolicy(QSizePolicy.MinimumExpanding, QSizePolicy.Expanding)
+        f = self.font()
+        f.setBold(True)
+        self.setFont(f)
+        self.setIconSize(QSize(48, 48))
+        self.setFlow(self.TopToBottom)
+        self.setSpacing(10)
+
+    def currentChanged(self, cur, prev):
+        QListView.currentChanged(self, cur, prev)
+        self.current_changed.emit(cur, prev)
+
+
+class Base(ConfigWidgetBase):
 
     restore_defaults_desc = _('Restore settings to default values. '
             'Only settings for the currently selected section '
             'are restored.')
 
+    def setupUi(self, x):
+        self.resize(720, 603)
+        self.l = l = QHBoxLayout(self)
+        self.list = lv = ListView(self)
+        l.addWidget(lv)
+        self.stack = s = QStackedWidget(self)
+        l.addWidget(s, stretch=10)
+
     def genesis(self, gui):
         log = Log()
         log.outputs = []
@@ -64,7 +94,7 @@ class Base(ConfigWidgetBase, Ui_Form):
             if isinstance(w, TOCWidget):
                 w.manually_fine_tune_toc.hide()
 
-        self.list.currentChanged = self.category_current_changed
+        self.list.current_changed.connect(self.category_current_changed)
         self.list.setCurrentIndex(self.model.index(0))
 
     def initialize(self):
@@ -85,6 +115,7 @@ class Base(ConfigWidgetBase, Ui_Form):
     def category_current_changed(self, n, p):
         self.stack.setCurrentIndex(n.row())
 
+
 class CommonOptions(Base):
 
     def load_conversion_widgets(self):
@@ -92,6 +123,7 @@ class CommonOptions(Base):
                 PageSetupWidget,
                 StructureDetectionWidget, TOCWidget, SearchAndReplaceWidget,]
 
+
 class InputOptions(Base):
 
     def load_conversion_widgets(self):
@@ -101,6 +133,7 @@ class InputOptions(Base):
             if pw is not None:
                 self.conversion_widgets.append(pw)
 
+
 class OutputOptions(Base):
 
     def load_conversion_widgets(self):
@@ -118,7 +151,7 @@ class OutputOptions(Base):
 if __name__ == '__main__':
     from PyQt5.Qt import QApplication
     app = QApplication([])
-    #test_widget('Conversion', 'Input Options')
-    #test_widget('Conversion', 'Common Options')
+    # test_widget('Conversion', 'Input Options')
+    # test_widget('Conversion', 'Common Options')
     test_widget('Conversion', 'Output Options')
 
