@@ -10,18 +10,20 @@ import glob, os, string, shutil
 from functools import partial
 from PyQt5.Qt import (
     QDialog, QVBoxLayout, QListWidget, QListWidgetItem, Qt, QIcon,
-    QApplication, QSize, QPixmap, QDialogButtonBox, QTimer, QLabel)
+    QApplication, QSize, QDialogButtonBox, QTimer, QLabel)
 
 from calibre.constants import config_dir
 from calibre.gui2 import choose_files, error_dialog
 from calibre.utils.icu import sort_key
 
+
 def texture_dir():
     ans = os.path.join(config_dir, 'textures')
     if not os.path.exists(ans):
         os.makedirs(ans)
     return ans
 
+
 def texture_path(fname):
     if not fname:
         return
@@ -29,6 +31,7 @@ def texture_path(fname):
         return I('textures/%s' % fname[1:])
     return os.path.join(texture_dir(), fname)
 
+
 class TextureChooser(QDialog):
 
     def __init__(self, parent=None, initial=None):
@@ -50,7 +53,7 @@ class TextureChooser(QDialog):
         il.itemSelectionChanged.connect(self.update_remove_state)
         l.addWidget(il)
 
-        self.ad = ad = QLabel(_('The builtin textures come from <a href="http://subtlepatterns.com">subtlepatterns.com</a>.'))
+        self.ad = ad = QLabel(_('The builtin textures come from <a href="https://subtlepatterns.com">subtlepatterns.com</a>.'))
         ad.setOpenExternalLinks(True)
         ad.setWordWrap(True)
         l.addWidget(ad)
@@ -91,7 +94,7 @@ class TextureChooser(QDialog):
 
     def create_item(self, data):
         x = data
-        i = QListWidgetItem(QIcon(QPixmap(x['path']).scaled(256, 256, transformMode=Qt.SmoothTransformation)), x['name'], self.images)
+        i = QListWidgetItem(QIcon(x['path']), x['name'], self.images)
         i.setData(Qt.UserRole, x['fname'])
         i.setData(Qt.UserRole+1, x['path'])
         return i
@@ -144,6 +147,7 @@ class TextureChooser(QDialog):
         os.remove(unicode(self.selected_item.data(Qt.UserRole+1) or ''))
         self.images.takeItem(self.images.row(self.selected_item))
 
+
 if __name__ == '__main__':
     app = QApplication([])  # noqa
     d = TextureChooser()
