@@ -437,7 +437,7 @@ class SearchBoxMixin(object):  # {{{
 
     def init_search_box_mixin(self):
         self.search.initialize('main_search_history', colorize=True,
-                help_text=_('Search (For Advanced Search click the button to the left)'))
+                help_text=_('Search (For Advanced search click the button to the left)'))
         self.search.cleared.connect(self.search_box_cleared)
         # Queued so that search.current_text will be correct
         self.search.changed.connect(self.search_box_changed,
@@ -569,4 +569,3 @@ class SavedSearchBoxMixin(object):  # {{{
         self.saved_search.clear()
 
     # }}}
-
