@@ -215,6 +215,7 @@ class RuleEditDialog(Dialog):
         if self.edit_widget.validate():
             Dialog.accept(self)
 
+
 DATA_ROLE = Qt.UserRole
 RENDER_ROLE = DATA_ROLE + 1
 
@@ -269,7 +270,7 @@ class Rules(QWidget):
     RuleEditDialogClass = RuleEditDialog
     changed = pyqtSignal()
 
-    MSG = _('You can specify rules to filter/transform tags here. Click the "Add Rule" button'
+    MSG = _('You can specify rules to filter/transform tags here. Click the "Add rule" button'
             ' below to get started. The rules will be processed in order for every tag until either a'
             ' "remove" or a "keep" rule matches.')
 
@@ -384,7 +385,7 @@ class Tester(Dialog):
     DIALOG_TITLE = _('Test tag mapper rules')
     PREFS_NAME = 'test-tag-mapper-rules'
     LABEL = _('Enter a comma separated list of &tags to test:')
-    PLACEHOLDER = _('Enter tags and click the Test button')
+    PLACEHOLDER = _('Enter tags and click the "Test" button')
     EMPTY_RESULT = '<p>&nbsp;<br>&nbsp;</p>'
 
     def __init__(self, rules, parent=None):
@@ -508,6 +509,7 @@ class RulesDialog(Dialog, SaveLoadMixin):
     def test_rules(self):
         self.TesterClass(self.rules, self).exec_()
 
+
 if __name__ == '__main__':
     app = Application([])
     d = RulesDialog()
