@@ -20,6 +20,7 @@ from calibre.utils.ipc import eintr_retry_call
 COMPLETION_REQUEST = 'completion request'
 CLEAR_REQUEST = 'clear request'
 
+
 class CompletionWorker(Thread):
 
     daemon = True
@@ -159,12 +160,15 @@ class CompletionWorker(Thread):
         return self.worker_process.returncode
 
 _completion_worker = None
+
+
 def completion_worker():
     global _completion_worker
     if _completion_worker is None:
         _completion_worker = CompletionWorker()
     return _completion_worker
 
+
 def run_main(func):
     from multiprocessing.connection import Client
     address, key = cPickle.loads(eintr_retry_call(sys.stdin.read))
@@ -173,12 +177,13 @@ def run_main(func):
 
 Result = namedtuple('Result', 'request_id ans traceback query')
 
+
 def main(control_conn, data_conn):
     from calibre.gui2.tweak_book.completion.basic import handle_control_request
     while True:
         try:
             request = eintr_retry_call(control_conn.recv)
-        except EOFError:
+        except (KeyboardInterrupt, EOFError):
             break
         if request is None:
             break
@@ -196,10 +201,12 @@ def main(control_conn, data_conn):
             except EOFError:
                 break
 
+
 def test_main(control_conn, data_conn):
     obj = control_conn.recv()
     control_conn.send(obj)
 
+
 def test():
     w = CompletionWorker(worker_entry_point='test_main')
     w.wait_for_connection()
