@@ -32,6 +32,7 @@ from calibre.gui2.tweak_book.diff.highlight import get_highlighter
 
 Change = namedtuple('Change', 'ltop lbot rtop rbot kind')
 
+
 class BusyCursor(object):
 
     def __enter__(self):
@@ -40,6 +41,7 @@ class BusyCursor(object):
     def __exit__(self, *args):
         QApplication.restoreOverrideCursor()
 
+
 def beautify_text(raw, syntax):
     from lxml import etree
     from calibre.ebooks.oeb.polish.parsing import parse
@@ -86,6 +88,7 @@ class LineNumberMap(dict):  # {{{
         self.max_width = 1
 # }}}
 
+
 class TextBrowser(PlainTextEdit):  # {{{
 
     resized = pyqtSignal()
@@ -331,6 +334,7 @@ class TextBrowser(PlainTextEdit):  # {{{
         w = self.viewport().rect().width()
         painter = QPainter(self.viewport())
         painter.setClipRect(event.rect())
+        painter.setRenderHint(QPainter.SmoothPixmapTransform, True)
         floor = event.rect().bottom()
         ceiling = event.rect().top()
         fv = self.firstVisibleBlock().blockNumber()
@@ -370,8 +374,7 @@ class TextBrowser(PlainTextEdit):  # {{{
                 if bot > top + 1 and not img.isNull():
                     y_top = self.blockBoundingGeometry(doc.findBlockByNumber(top+1)).translated(origin).y() + 3
                     y_bot -= 3
-                    scaled, imgw, imgh = fit_image(img.width(), img.height(), w - 3, y_bot - y_top)
-                    painter.setRenderHint(QPainter.SmoothPixmapTransform, True)
+                    scaled, imgw, imgh = fit_image(int(img.width()/img.devicePixelRatio()), int(img.height()/img.devicePixelRatio()), w - 3, y_bot - y_top)
                     painter.drawPixmap(QRect(3, y_top, imgw, imgh), img)
 
         painter.end()
@@ -391,6 +394,7 @@ class TextBrowser(PlainTextEdit):  # {{{
 
 # }}}
 
+
 class DiffSplitHandle(QSplitterHandle):  # {{{
 
     WIDTH = 30  # px
@@ -497,6 +501,7 @@ class DiffSplitHandle(QSplitterHandle):  # {{{
             return QSplitterHandle.wheelEvent(self, ev)
 # }}}
 
+
 class DiffSplit(QSplitter):  # {{{
 
     def __init__(self, parent=None, show_open_in_editor=False):
@@ -559,7 +564,12 @@ class DiffSplit(QSplitter):  # {{{
     @property
     def failed_img(self):
         if self._failed_img is None:
+            try:
+                dpr = self.devicePixelRatioF()
+            except AttributeError:
+                dpr = self.devicePixelRatio()
             i = QImage(200, 150, QImage.Format_ARGB32)
+            i.setDevicePixelRatio(dpr)
             i.fill(Qt.white)
             p = QPainter(i)
             r = i.rect().adjusted(10, 10, -10, -10)
@@ -580,6 +590,11 @@ class DiffSplit(QSplitter):  # {{{
         def load(data):
             p = QPixmap()
             p.loadFromData(bytes(data))
+            try:
+                dpr = self.devicePixelRatioF()
+            except AttributeError:
+                dpr = self.devicePixelRatio()
+            p.setDevicePixelRatio(dpr)
             if data and p.isNull():
                 p = self.failed_img
             return p
@@ -632,6 +647,7 @@ class DiffSplit(QSplitter):  # {{{
                     c.removeSelectedText()
                 c.endEditBlock()
                 v.images[top] = (img, w, lines)
+
                 def mapnum(x):
                     return x if x <= top else x + delta
                 lnm = LineNumberMap()
@@ -647,7 +663,7 @@ class DiffSplit(QSplitter):  # {{{
     def get_lines_for_image(self, img, view):
         if img.isNull():
             return 0, 0
-        w, h = img.width(), img.height()
+        w, h = int(img.width()/img.devicePixelRatio()), int(img.height()/img.devicePixelRatio())
         scaled, w, h = fit_image(w, h, view.available_width() - 3, int(0.9 * view.height()))
         line_height = view.blockBoundingRect(view.document().begin()).height()
         return int(ceil(h / line_height)) + 1, w
@@ -885,6 +901,7 @@ class DiffSplit(QSplitter):  # {{{
 
 # }}}
 
+
 class DiffView(QWidget):  # {{{
 
     SYNC_POSITION = 0.4
