@@ -18,7 +18,7 @@ from PyQt5.Qt import (
 from calibre import fit_image
 from calibre.gui2 import error_dialog, pixmap_to_data
 from calibre.gui2.dnd import (
-    IMAGE_EXTENSIONS, dnd_has_extension, dnd_has_image, dnd_get_image, DownloadDialog)
+    image_extensions, dnd_has_extension, dnd_has_image, dnd_get_image, DownloadDialog)
 from calibre.gui2.tweak_book import capitalize
 from calibre.utils.imghdr import identify
 from calibre.utils.img import (
@@ -26,6 +26,7 @@ from calibre.utils.img import (
     normalize_image, oil_paint_image
 )
 
+
 def painter(func):
     @wraps(func)
     def ans(self, painter):
@@ -36,6 +37,7 @@ def painter(func):
             painter.restore()
     return ans
 
+
 class SelectionState(object):
 
     __slots__ = ('last_press_point', 'current_mode', 'rect', 'in_selection', 'drag_corner', 'dragging', 'last_drag_pos')
@@ -53,6 +55,7 @@ class SelectionState(object):
         self.dragging = None
         self.last_drag_pos = None
 
+
 class Command(QUndoCommand):
 
     TEXT = ''
@@ -75,6 +78,7 @@ class Command(QUndoCommand):
         canvas = self.canvas_ref()
         canvas.set_image(self.after_image)
 
+
 def get_selection_rect(img, sr, target):
     ' Given selection rect return the corresponding rectangle in the underlying image as left, top, width, height '
     left_border = (abs(sr.left() - target.left())/target.width()) * img.width()
@@ -83,6 +87,7 @@ def get_selection_rect(img, sr, target):
     bottom_border = (abs(target.bottom() - sr.bottom())/target.height()) * img.height()
     return left_border, top_border, img.width() - left_border - right_border, img.height() - top_border - bottom_border
 
+
 class Trim(Command):
 
     ''' Remove the areas of the image outside the current selection. '''
@@ -95,6 +100,7 @@ class Trim(Command):
         sr = canvas.selection_state.rect
         return img.copy(*get_selection_rect(img, sr, target))
 
+
 class AutoTrim(Trim):
 
     ''' Auto trim borders from the image '''
@@ -103,6 +109,7 @@ class AutoTrim(Trim):
     def __call__(self, canvas):
         return remove_borders_from_image(canvas.current_image)
 
+
 class Rotate(Command):
 
     TEXT = _('Rotate image')
@@ -113,6 +120,7 @@ class Rotate(Command):
         m.rotate(90)
         return img.transformed(m, Qt.SmoothTransformation)
 
+
 class Scale(Command):
 
     TEXT = _('Resize image')
@@ -125,6 +133,7 @@ class Scale(Command):
         img = canvas.current_image
         return img.scaled(self.width, self.height, transformMode=Qt.SmoothTransformation)
 
+
 class Sharpen(Command):
 
     TEXT = _('Sharpen image')
@@ -137,6 +146,7 @@ class Sharpen(Command):
     def __call__(self, canvas):
         return gaussian_sharpen_image(canvas.current_image, sigma=self.sigma)
 
+
 class Blur(Sharpen):
 
     TEXT = _('Blur image')
@@ -145,6 +155,7 @@ class Blur(Sharpen):
     def __call__(self, canvas):
         return gaussian_blur_image(canvas.current_image, sigma=self.sigma)
 
+
 class Oilify(Command):
 
     TEXT = _('Make image look like an oil painting')
@@ -156,6 +167,7 @@ class Oilify(Command):
     def __call__(self, canvas):
         return oil_paint_image(canvas.current_image, radius=self.radius)
 
+
 class Despeckle(Command):
 
     TEXT = _('De-speckle image')
@@ -163,6 +175,7 @@ class Despeckle(Command):
     def __call__(self, canvas):
         return despeckle_image(canvas.current_image)
 
+
 class Normalize(Command):
 
     TEXT = _('Normalize image')
@@ -170,6 +183,7 @@ class Normalize(Command):
     def __call__(self, canvas):
         return normalize_image(canvas.current_image)
 
+
 class Replace(Command):
 
     ''' Replace the current image with another image. If there is a selection,
@@ -191,6 +205,7 @@ class Replace(Command):
             p.end()
         return self.after_image
 
+
 def imageop(func):
     @wraps(func)
     def ans(self, *args, **kwargs):
@@ -205,6 +220,7 @@ def imageop(func):
             QApplication.restoreOverrideCursor()
     return ans
 
+
 class Canvas(QWidget):
 
     BACKGROUND = QColor(60, 60, 60)
@@ -224,11 +240,10 @@ class Canvas(QWidget):
         return self.current_image is not self.original_image
 
     # Drag 'n drop {{{
-    DROPABBLE_EXTENSIONS = IMAGE_EXTENSIONS
 
     def dragEnterEvent(self, event):
         md = event.mimeData()
-        if dnd_has_extension(md, self.DROPABBLE_EXTENSIONS) or dnd_has_image(md):
+        if dnd_has_extension(md, image_extensions()) or dnd_has_image(md):
             event.acceptProposedAction()
 
     def dropEvent(self, event):
@@ -595,14 +610,23 @@ class Canvas(QWidget):
             i = self.current_image
             width, height = i.width(), i.height()
             scaled, width, height = fit_image(width, height, pwidth, pheight)
+            try:
+                dpr = self.devicePixelRatioF()
+            except AttributeError:
+                dpr = self.devicePixelRatio()
             if scaled:
-                i = self.current_image.scaled(width, height, transformMode=Qt.SmoothTransformation)
+                i = self.current_image.scaled(int(dpr * width), int(dpr * height), transformMode=Qt.SmoothTransformation)
             self.current_scaled_pixmap = QPixmap.fromImage(i)
+            self.current_scaled_pixmap.setDevicePixelRatio(dpr)
 
     @painter
     def draw_pixmap(self, painter):
         p = self.current_scaled_pixmap
-        width, height = p.width(), p.height()
+        try:
+            dpr = self.devicePixelRatioF()
+        except AttributeError:
+            dpr = self.devicePixelRatio()
+        width, height = int(p.width()/dpr), int(p.height()/dpr)
         pwidth, pheight = self.last_canvas_size
         x = int(abs(pwidth - width)/2.)
         y = int(abs(pheight - height)/2.)
