@@ -12,7 +12,7 @@ from functools import partial
 from PyQt5.Qt import (
     QGridLayout, QSize, QListView, QStyledItemDelegate, QLabel, QPixmap,
     QApplication, QSizePolicy, QAbstractListModel, Qt, QRect, QCheckBox,
-    QPainter, QModelIndex, QSortFilterProxyModel, QLineEdit, QToolButton,
+    QPainter, QSortFilterProxyModel, QLineEdit, QToolButton,
     QIcon, QFormLayout, pyqtSignal, QTreeWidget, QTreeWidgetItem, QVBoxLayout,
     QMenu, QInputDialog, QHBoxLayout)
 
@@ -20,7 +20,7 @@ from calibre import fit_image
 from calibre.constants import plugins
 from calibre.ebooks.metadata import string_to_authors
 from calibre.ebooks.metadata.book.base import Metadata
-from calibre.gui2 import choose_files, error_dialog, pixmap_to_data
+from calibre.gui2 import choose_files, error_dialog, pixmap_to_data, empty_index
 from calibre.gui2.languages import LanguagesEdit
 from calibre.gui2.tweak_book import current_container, tprefs
 from calibre.gui2.tweak_book.widgets import Dialog
@@ -29,6 +29,7 @@ from calibre.ptempfile import PersistentTemporaryFile
 from calibre.utils.localization import get_lang, canonicalize_lang
 from calibre.utils.icu import sort_key
 
+
 class ChooseName(Dialog):  # {{{
 
     ''' Chooses the filename for a newly imported file, with error checking '''
@@ -71,6 +72,8 @@ class ChooseName(Dialog):  # {{{
 # }}}
 
 # Images {{{
+
+
 class ImageDelegate(QStyledItemDelegate):
 
     MARGIN = 4
@@ -98,7 +101,7 @@ class ImageDelegate(QStyledItemDelegate):
         return self.item_size
 
     def paint(self, painter, option, index):
-        QStyledItemDelegate.paint(self, painter, option, QModelIndex())  # draw the hover and selection highlights
+        QStyledItemDelegate.paint(self, painter, option, empty_index)  # draw the hover and selection highlights
         name = unicode(index.data(Qt.DisplayRole) or '')
         cover = self.cover_cache.get(name, None)
         if cover is None:
@@ -108,11 +111,16 @@ class ImageDelegate(QStyledItemDelegate):
             except:
                 pass
             else:
+                try:
+                    dpr = painter.device().devicePixelRatioF()
+                except AttributeError:
+                    dpr = painter.device().devicePixelRatio()
                 cover.loadFromData(raw)
+                cover.setDevicePixelRatio(dpr)
                 if not cover.isNull():
                     scaled, width, height = fit_image(cover.width(), cover.height(), self.cover_size.width(), self.cover_size.height())
                     if scaled:
-                        cover = self.cover_cache[name] = cover.scaled(width, height, transformMode=Qt.SmoothTransformation)
+                        cover = self.cover_cache[name] = cover.scaled(int(dpr*width), int(dpr*height), transformMode=Qt.SmoothTransformation)
 
         painter.save()
         try:
@@ -121,8 +129,8 @@ class ImageDelegate(QStyledItemDelegate):
             trect = QRect(rect)
             rect.setBottom(rect.bottom() - self.title_height)
             if not cover.isNull():
-                dx = max(0, int((rect.width() - cover.width())/2.0))
-                dy = max(0, rect.height() - cover.height())
+                dx = max(0, int((rect.width() - int(cover.width()/cover.devicePixelRatio()))/2.0))
+                dy = max(0, rect.height() - int(cover.height()/cover.devicePixelRatio()))
                 rect.adjust(dx, dy, -dx, 0)
                 painter.drawPixmap(rect, cover)
             rect = trect
@@ -134,6 +142,7 @@ class ImageDelegate(QStyledItemDelegate):
         finally:
             painter.restore()
 
+
 class Images(QAbstractListModel):
 
     def __init__(self, parent):
@@ -170,6 +179,7 @@ class Images(QAbstractListModel):
             return name
         return None
 
+
 class InsertImage(Dialog):
 
     image_activated = pyqtSignal(object)
@@ -313,12 +323,14 @@ class InsertImage(Dialog):
         self.fm.setFilterFixedString(f)
 # }}}
 
+
 def get_resource_data(rtype, parent):
     if rtype == 'image':
         d = InsertImage(parent)
         if d.exec_() == d.Accepted:
             return d.chosen_image, d.chosen_image_is_external, d.fullpage.isChecked(), d.preserve_aspect_ratio.isChecked()
 
+
 def create_folder_tree(container):
     root = {}
 
@@ -331,6 +343,7 @@ def create_folder_tree(container):
             current[x] = current = current.get(x, {})
     return root
 
+
 class ChooseFolder(Dialog):  # {{{
 
     def __init__(self, msg=None, parent=None):
@@ -449,13 +462,12 @@ class NewBook(Dialog):  # {{{
 
 # }}}
 
+
 if __name__ == '__main__':
     app = QApplication([])  # noqa
     from calibre.gui2.tweak_book import set_current_container
     from calibre.gui2.tweak_book.boss import get_container
     set_current_container(get_container(sys.argv[-1]))
 
-    d = ChooseFolder()
-    if d.exec_() == d.Accepted:
-        print (repr(d.chosen_folder))
-
+    d = InsertImage(for_browsing=True)
+    d.exec_()
