@@ -684,7 +684,7 @@ class WordsModel(FileCollection):
             try:
                 return lsk_cache[loc]
             except KeyError:
-                lsk_cache[loc] = (psk(calibre_langcode_to_name(canonicalize_lang(loc[0]))), psk(loc[1] or ''))
+                lsk_cache[loc] = psk(calibre_langcode_to_name(canonicalize_lang(loc[0])) + (loc[1] or ''))
             return lsk_cache[loc]
 
         self.sort_keys = tuple((psk(entry.word), locale_sort_key(entry.locale), len(entry.usage)) for entry in self.files)
