@@ -278,10 +278,6 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
         self.toggle_to_tray_action = self.system_tray_menu.addAction(QIcon(I('page.png')), '')
         self.toggle_to_tray_action.triggered.connect(self.system_tray_icon_activated)
         self.system_tray_menu.addAction(self.donate_action)
-        self.donate_button.clicked.connect(self.donate_action.trigger)
-        self.donate_button.setToolTip(self.donate_action.text().replace('&', ''))
-        self.donate_button.setIcon(self.donate_action.icon())
-        self.donate_button.setStatusTip(self.donate_button.toolTip())
         self.eject_action = self.system_tray_menu.addAction(
                 QIcon(I('eject.png')), _('&Eject connected device'))
         self.eject_action.setEnabled(False)
@@ -401,8 +397,7 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
         self.read_settings()
 
         self.finalize_layout()
-        if self.bars_manager.showing_donate:
-            self.donate_button.start_animation()
+        self.bars_manager.start_animation()
         self.set_window_title()
 
         for ac in self.iactions.values():
@@ -484,8 +479,8 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
                 Dispatcher(self.content_server_start_failed)
 
     def content_server_start_failed(self, msg):
-        error_dialog(self, _('Failed to start Content Server'),
-                _('Could not start the content server. Error:\n\n%s')%msg,
+        error_dialog(self, _('Failed to start Content server'),
+                _('Could not start the Content server. Error:\n\n%s')%msg,
                 show=True)
 
     def resizeEvent(self, ev):
@@ -558,7 +553,7 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
     def test_server(self, *args):
         if self.content_server is not None and \
                 self.content_server.exception is not None:
-            error_dialog(self, _('Failed to start content server'),
+            error_dialog(self, _('Failed to start Content server'),
                          unicode(self.content_server.exception)).exec_()
 
     @property
@@ -750,7 +745,7 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
         self.set_number_of_books_shown()
         self.update_status_bar()
 
-    def job_exception(self, job, dialog_title=_('Conversion Error'), retry_func=None):
+    def job_exception(self, job, dialog_title=_('Conversion error'), retry_func=None):
         if not hasattr(self, '_modeless_dialogs'):
             self._modeless_dialogs = []
         minz = self.is_minimized_to_tray
@@ -773,7 +768,7 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
                 title = job.description.split(':')[-1].partition('(')[-1][:-1]
                 msg = _('<p><b>Failed to convert: %s')%title
                 msg += '<p>'+_('''
-                Many older ebook reader devices are incapable of displaying
+                Many older e-book reader devices are incapable of displaying
                 EPUB files that have internal components over a certain size.
                 Therefore, when converting to EPUB, calibre automatically tries
                 to split up the EPUB into smaller sized pieces.  For some
@@ -783,7 +778,7 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
                 maximum split size under EPUB Output in the conversion dialog,
                 or by turning on Heuristic Processing, also in the conversion
                 dialog. Note that if you make the maximum split size too large,
-                your ebook reader may have trouble with the EPUB.
+                your e-book reader may have trouble with the EPUB.
                         ''')
                 if not minz:
                     d = error_dialog(self, _('Conversion Failed'), msg,
@@ -800,7 +795,7 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
                     idx = job.details.index('calibre.ebooks.mobi.reader.mobi6.KFXError:')
                     msg += '<p>' + re.sub(r'(https:\S+)', r'<a href="\1">{}</a>'.format(_('here')),
                                           job.details[idx:].partition(':')[2].strip())
-                    d = error_dialog(self, _('Conversion Failed'), msg, det_msg=job.details)
+                    d = error_dialog(self, _('Conversion failed'), msg, det_msg=job.details)
                     d.setModal(False)
                     d.show()
                     self._modeless_dialogs.append(d)
@@ -890,7 +885,7 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
 
         if self.proceed_question.questions:
             msg = _('There are library updates waiting. Are you sure you want to quit?')
-            if not question_dialog(self, _('Library Updates Waiting'), msg):
+            if not question_dialog(self, _('Library updates waiting'), msg):
                 return False
 
         from calibre.db.delete_service import has_jobs
@@ -960,11 +955,11 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
         try:
             try:
                 if self.content_server is not None:
-                    # If the content server has any sockets being closed then
+                    # If the Content server has any sockets being closed then
                     # this can take quite a long time (minutes). Tell the user that it is
                     # happening.
                     self.show_shutdown_message(
-                        _('Shutting down the content server. This could take a while ...'))
+                        _('Shutting down the Content server. This could take a while...'))
                     s = self.content_server
                     self.content_server = None
                     s.exit()
