@@ -1,59 +1,55 @@
 __license__   = 'GPL v3'
 __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
 
-import re, binascii, cPickle
+import re, binascii, cPickle, ssl, json
 from future_builtins import map
+from threading import Thread, Event
 
-from PyQt4.Qt import (QThread, pyqtSignal, Qt, QUrl, QDialog, QGridLayout,
-        QLabel, QCheckBox, QDialogButtonBox, QIcon, QPixmap)
-import mechanize
+from PyQt5.Qt import (QObject, pyqtSignal, Qt, QUrl, QDialog, QGridLayout,
+        QLabel, QCheckBox, QDialogButtonBox, QIcon)
 
 from calibre.constants import (__appname__, __version__, iswindows, isosx,
         isportable, is64bit, numeric_version)
-from calibre import browser, prints, as_unicode
+from calibre import prints, as_unicode
 from calibre.utils.config import prefs
+from calibre.utils.https import get_https_resource_securely
 from calibre.gui2 import config, dynamic, open_url
 from calibre.gui2.dialogs.plugin_updater import get_plugin_updates_available
 
-URL = 'http://status.calibre-ebook.com/latest'
+URL = 'https://code.calibre-ebook.com/latest'
 # URL = 'http://localhost:8000/latest'
 NO_CALIBRE_UPDATE = (0, 0, 0)
 
+
 def get_download_url():
     which = ('portable' if isportable else 'windows' if iswindows
             else 'osx' if isosx else 'linux')
     if which == 'windows' and is64bit:
         which += '64'
-    return 'http://calibre-ebook.com/download_' + which
+    return 'https://calibre-ebook.com/download_' + which
+
 
 def get_newest_version():
-    br = browser()
-    req = mechanize.Request(URL)
-    req.add_header('CALIBRE_VERSION', __version__)
-    req.add_header('CALIBRE_OS',
-            'win' if iswindows else 'osx' if isosx else 'oth')
-    req.add_header('CALIBRE_INSTALL_UUID', prefs['installation_uuid'])
-    version = br.open(req).read().strip()
-    try:
-        version = version.decode('utf-8').strip()
-    except UnicodeDecodeError:
-        version = u''
-    ans = NO_CALIBRE_UPDATE
-    m = re.match(ur'(\d+)\.(\d+).(\d+)$', version)
-    if m is not None:
-        ans = tuple(map(int, (m.group(1), m.group(2), m.group(3))))
-    return ans
+    return NO_CALIBRE_UPDATE
 
-class CheckForUpdates(QThread):
+
+class Signal(QObject):
 
     update_found = pyqtSignal(object, object)
-    INTERVAL = 24*60*60
+
+
+class CheckForUpdates(Thread):
+
+    INTERVAL = 24*60*60  # seconds
+    daemon = True
 
     def __init__(self, parent):
-        QThread.__init__(self, parent)
+        Thread.__init__(self)
+        self.shutdown_event = Event()
+        self.signal = Signal(parent)
 
     def run(self):
-        while True:
+        while not self.shutdown_event.is_set():
             calibre_update_version = NO_CALIBRE_UPDATE
             plugins_update_found = 0
             try:
@@ -69,8 +65,12 @@ class CheckForUpdates(QThread):
             except Exception as e:
                 prints('Failed to check for plugin update:', as_unicode(e))
             if calibre_update_version != NO_CALIBRE_UPDATE or plugins_update_found > 0:
-                self.update_found.emit(calibre_update_version, plugins_update_found)
-            self.sleep(self.INTERVAL)
+                self.signal.update_found.emit(calibre_update_version, plugins_update_found)
+            self.shutdown_event.wait(self.INTERVAL)
+
+    def shutdown(self):
+        self.shutdown_event.set()
+
 
 class UpdateNotification(QDialog):
 
@@ -82,14 +82,13 @@ class UpdateNotification(QDialog):
         self.setLayout(self.l)
         self.logo = QLabel()
         self.logo.setMaximumWidth(110)
-        self.logo.setPixmap(QPixmap(I('lt.png')).scaled(100, 100,
-            Qt.IgnoreAspectRatio, Qt.SmoothTransformation))
+        self.logo.setPixmap(QIcon(I('lt.png')).pixmap(100, 100))
         ver = calibre_version
         if ver.endswith('.0'):
             ver = ver[:-2]
         self.label = QLabel(('<p>'+
             _('New version <b>%(ver)s</b> of %(app)s is available for download. '
-            'See the <a href="http://calibre-ebook.com/whats-new'
+            'See the <a href="https://calibre-ebook.com/whats-new'
             '">new features</a>.'))%dict(
                 app=__appname__, ver=ver))
         self.label.setOpenExternalLinks(True)
@@ -132,13 +131,17 @@ class UpdateNotification(QDialog):
 
         QDialog.accept(self)
 
+
 class UpdateMixin(object):
 
-    def __init__(self, opts):
+    def __init__(self, *args, **kw):
+        pass
+
+    def init_update_mixin(self, opts):
         self.last_newest_calibre_version = NO_CALIBRE_UPDATE
         if not opts.no_update_check:
             self.update_checker = CheckForUpdates(self)
-            self.update_checker.update_found.connect(self.update_found,
+            self.update_checker.signal.update_found.connect(self.update_found,
                     type=Qt.QueuedConnection)
             self.update_checker.start()
 
@@ -159,7 +162,7 @@ class UpdateMixin(object):
         if has_calibre_update:
             plt = u''
             if has_plugin_updates:
-                plt = _(' (%d plugin updates)')%number_of_plugin_updates
+                plt = ngettext(' (one plugin update)', ' ({} plugin updates)', number_of_plugin_updates).format(number_of_plugin_updates)
             msg = (u'<span style="color:green; font-weight: bold">%s: '
                     u'<a href="update:%s">%s%s</a></span>') % (
                         _('Update found'), version_url, calibre_version, plt)
@@ -192,12 +195,13 @@ class UpdateMixin(object):
         if not plugin:
             return
         if number_of_updates:
-            plugin.qaction.setText(_('Plugin Updates')+'*')
+            plugin.qaction.setText(_('Plugin updates')+'*')
             plugin.qaction.setIcon(QIcon(I('plugins/plugin_updater_updates.png')))
             plugin.qaction.setToolTip(
-                _('There are %d plugin updates available')%number_of_updates)
+                ngettext('A plugin update is available',
+                         'There are {} plugin updates available', number_of_updates).format(number_of_updates))
         else:
-            plugin.qaction.setText(_('Plugin Updates'))
+            plugin.qaction.setText(_('Plugin updates'))
             plugin.qaction.setIcon(QIcon(I('plugins/plugin_updater.png')))
             plugin.qaction.setToolTip(_('Install and configure user plugins'))
 
@@ -207,3 +211,9 @@ class UpdateMixin(object):
             calibre_version, number_of_plugin_updates = cPickle.loads(binascii.unhexlify(url[len('update:'):]))
             self.update_found(calibre_version, number_of_plugin_updates, force=True)
 
+
+if __name__ == '__main__':
+    from calibre.gui2 import Application
+    app = Application([])
+    UpdateNotification('x.y.z', False).exec_()
+    del app
