@@ -196,15 +196,15 @@ class BookmarkManager(QWidget):
 
     def export_bookmarks(self):
         filename = choose_save_file(
-            self, 'export-viewer-bookmarks', _('Export Bookmarks'),
-            filters=[(_('Saved Bookmarks'), ['pickle'])], all_files=False, initial_filename='bookmarks.pickle')
+            self, 'export-viewer-bookmarks', _('Export bookmarks'),
+            filters=[(_('Saved bookmarks'), ['pickle'])], all_files=False, initial_filename='bookmarks.pickle')
         if filename:
             with open(filename, 'wb') as fileobj:
                 cPickle.dump(self.get_bookmarks(), fileobj, -1)
 
     def import_bookmarks(self):
-        files = choose_files(self, 'export-viewer-bookmarks', _('Import Bookmarks'),
-            filters=[(_('Saved Bookmarks'), ['pickle'])], all_files=False, select_only_single_file=True)
+        files = choose_files(self, 'export-viewer-bookmarks', _('Import bookmarks'),
+            filters=[(_('Saved bookmarks'), ['pickle'])], all_files=False, select_only_single_file=True)
         if not files:
             return
         filename = files[0]
@@ -230,4 +230,3 @@ class BookmarkManager(QWidget):
                         bookmarks.append(bm)
                 self.set_bookmarks([bm for bm in bookmarks if bm['title'] != 'calibre_current_page_bookmark'])
                 self.edited.emit(self.get_bookmarks())
-
