@@ -87,7 +87,7 @@ class Worker(Thread):
             self.exception = self.traceback = None
         except BadZipfile:
             self.exception = _(
-                'This ebook is corrupted and cannot be opened. If you '
+                'This e-book is corrupted and cannot be opened. If you '
                 'downloaded it from somewhere, try downloading it again.')
             self.traceback = ''
         except WorkerError as err:
@@ -612,15 +612,16 @@ class EbookViewer(MainWindow):
 
     def open_ebook(self, checked):
         files = choose_files(self, 'ebook viewer open dialog',
-                     _('Choose ebook'),
-                     [(_('Ebooks'), available_input_formats())],
+                     _('Choose e-book'),
+                     [(_('E-books'), available_input_formats())],
                      all_files=False,
                      select_only_single_file=True)
         if files:
             self.load_ebook(files[0])
 
     def open_recent(self, action):
-        self.load_ebook(action.path)
+        if hasattr(action, 'path'):
+            self.load_ebook(action.path)
 
     def font_size_larger(self):
         self.view.magnify_fonts()
@@ -912,7 +913,7 @@ class EbookViewer(MainWindow):
         self.bookmarks_menu.clear()
         sc = _(' or ').join(self.view.shortcuts.get_shortcuts('Bookmark'))
         self.bookmarks_menu.addAction(_("Bookmark this location [%s]") % sc, self.bookmark)
-        self.bookmarks_menu.addAction(_("Show/hide Bookmarks"), self.bookmarks_dock.toggleViewAction().trigger)
+        self.bookmarks_menu.addAction(_("Show/hide bookmarks"), self.bookmarks_dock.toggleViewAction().trigger)
         self.bookmarks_menu.addSeparator()
         current_page = None
         self.existing_bookmarks = []
@@ -960,7 +961,7 @@ class EbookViewer(MainWindow):
             self.iterator.__exit__()
         self.iterator = EbookIterator(pathtoebook, copy_bookmarks_to_file=self.view.document.copy_bookmarks_to_file)
         self.history.clear()
-        self.open_progress_indicator(_('Loading ebook...'))
+        self.open_progress_indicator(_('Loading e-book...'))
         worker = Worker(target=partial(self.iterator.__enter__, view_kepub=True))
         worker.path_to_ebook = pathtoebook
         worker.start()
@@ -975,7 +976,7 @@ class EbookViewer(MainWindow):
                 DRMErrorMessage(self).exec_()
             else:
                 r = getattr(worker.exception, 'reason', worker.exception)
-                error_dialog(self, _('Could not open ebook'),
+                error_dialog(self, _('Could not open e-book'),
                         as_unicode(r) or _('Unknown error'),
                         det_msg=tb, show=True)
             self.close_progress_indicator()
@@ -1159,7 +1160,7 @@ class EbookViewer(MainWindow):
 
 
 def config(defaults=None):
-    desc = _('Options to control the ebook viewer')
+    desc = _('Options to control the e-book viewer')
     if defaults is None:
         c = Config('viewer', desc)
     else:
@@ -1191,7 +1192,7 @@ def option_parser():
     parser = c.option_parser(usage=_('''\
 %prog [options] file
 
-View an ebook.
+View an e-book.
 '''))
     setup_gui_option_parser(parser)
     return parser
