@@ -5,25 +5,27 @@ Miscellaneous widgets used in the GUI
 '''
 import re, os
 
-from PyQt4.Qt import (QIcon, QFont, QLabel, QListWidget, QAction,
+from PyQt5.Qt import (QIcon, QFont, QLabel, QListWidget, QAction,
         QListWidgetItem, QTextCharFormat, QApplication, QSyntaxHighlighter,
         QCursor, QColor, QWidget, QPixmap, QSplitterHandle, QToolButton,
-        QVariant, Qt, pyqtSignal, QRegExp, QSize, QSplitter, QPainter,
+        Qt, pyqtSignal, QRegExp, QSize, QSplitter, QPainter,
         QLineEdit, QComboBox, QPen, QGraphicsScene, QMenu, QStringListModel,
-        QCompleter, QStringList, QTimer, QRect, QGraphicsView, QByteArray)
+        QCompleter, QTimer, QRect, QGraphicsView)
 
 from calibre.gui2 import (error_dialog, pixmap_to_data, gprefs,
         warning_dialog)
 from calibre.gui2.filename_pattern_ui import Ui_Form
-from calibre import fit_image
+from calibre import fit_image, strftime
 from calibre.ebooks import BOOK_EXTENSIONS
 from calibre.utils.config import prefs, XMLConfig
 from calibre.gui2.progress_indicator import ProgressIndicator as _ProgressIndicator
 from calibre.gui2.dnd import (dnd_has_image, dnd_get_image, dnd_get_files,
-    IMAGE_EXTENSIONS, dnd_has_extension, DownloadDialog)
+    image_extensions, dnd_has_extension, DownloadDialog)
+from calibre.utils.localization import localize_user_manual_link
 
 history = XMLConfig('history')
 
+
 class ProgressIndicator(QWidget):  # {{{
 
     def __init__(self, *args):
@@ -57,6 +59,7 @@ class ProgressIndicator(QWidget):  # {{{
         self.setVisible(False)
 # }}}
 
+
 class FilenamePattern(QWidget, Ui_Form):  # {{{
 
     changed_signal = pyqtSignal()
@@ -64,8 +67,13 @@ class FilenamePattern(QWidget, Ui_Form):  # {{{
     def __init__(self, parent):
         QWidget.__init__(self, parent)
         self.setupUi(self)
+        try:
+            self.help_label.setText(self.help_label.text() % localize_user_manual_link(
+                'https://manual.calibre-ebook.com/regexp.html'))
+        except TypeError:
+            pass  # link already localized
 
-        self.test_button.clicked[()].connect(self.do_test)
+        self.test_button.clicked.connect(self.do_test)
         self.re.lineEdit().returnPressed[()].connect(self.do_test)
         self.filename.returnPressed[()].connect(self.do_test)
         self.re.lineEdit().textChanged.connect(lambda x: self.changed_signal.emit())
@@ -101,7 +109,7 @@ class FilenamePattern(QWidget, Ui_Form):  # {{{
         ext = os.path.splitext(fname)[1][1:].lower()
         if ext not in BOOK_EXTENSIONS:
             return warning_dialog(self, _('Test name invalid'),
-                    _('The name <b>%r</b> does not appear to end with a'
+                    _('The name <b>%s</b> does not appear to end with a'
                         ' file extension. The name must end with a file '
                         ' extension like .epub or .mobi')%fname, show=True)
 
@@ -137,7 +145,7 @@ class FilenamePattern(QWidget, Ui_Form):  # {{{
             self.publisher.setText(_('No match'))
 
         if mi.pubdate:
-            self.pubdate.setText(mi.pubdate.strftime('%Y-%m-%d'))
+            self.pubdate.setText(strftime('%Y-%m-%d', mi.pubdate))
         else:
             self.pubdate.setText(_('No match'))
 
@@ -164,6 +172,7 @@ class FilenamePattern(QWidget, Ui_Form):  # {{{
 
 # }}}
 
+
 class FormatList(QListWidget):  # {{{
     DROPABBLE_EXTENSIONS = BOOK_EXTENSIONS
     formats_dropped = pyqtSignal(object, object)
@@ -171,14 +180,14 @@ class FormatList(QListWidget):  # {{{
 
     def dragEnterEvent(self, event):
         md = event.mimeData()
-        if dnd_has_extension(md, self.DROPABBLE_EXTENSIONS):
+        if dnd_has_extension(md, self.DROPABBLE_EXTENSIONS, allow_all_extensions=True):
             event.acceptProposedAction()
 
     def dropEvent(self, event):
         event.setDropAction(Qt.CopyAction)
         md = event.mimeData()
         # Now look for ebook files
-        urls, filenames = dnd_get_files(md, self.DROPABBLE_EXTENSIONS)
+        urls, filenames = dnd_get_files(md, self.DROPABBLE_EXTENSIONS, allow_all_extensions=True)
         if not urls:
             # Nothing found
             return
@@ -204,19 +213,21 @@ class FormatList(QListWidget):  # {{{
 
 # }}}
 
+
 class ImageDropMixin(object):  # {{{
     '''
     Adds support for dropping images onto widgets and a context menu for
     copy/pasting images.
     '''
-    DROPABBLE_EXTENSIONS = IMAGE_EXTENSIONS
+    DROPABBLE_EXTENSIONS = None
 
     def __init__(self):
         self.setAcceptDrops(True)
 
     def dragEnterEvent(self, event):
         md = event.mimeData()
-        if dnd_has_extension(md, self.DROPABBLE_EXTENSIONS) or \
+        exts = self.DROPABBLE_EXTENSIONS or image_extensions()
+        if dnd_has_extension(md, exts) or \
                 dnd_has_image(md):
             event.acceptProposedAction()
 
@@ -237,13 +248,15 @@ class ImageDropMixin(object):  # {{{
                 d.start_download()
                 if d.err is None:
                     pmap = QPixmap()
-                    pmap.loadFromData(open(d.fpath, 'rb').read())
+                    with lopen(d.fpath, 'rb') as f:
+                        data = f.read()
+                    pmap.loadFromData(data)
                     if not pmap.isNull():
-                        self.handle_image_drop(pmap)
+                        self.handle_image_drop(pmap, data=data)
 
-    def handle_image_drop(self, pmap):
+    def handle_image_drop(self, pmap, data=None):
         self.set_pixmap(pmap)
-        self.cover_changed.emit(pixmap_to_data(pmap, quality=100))
+        self.cover_changed.emit(data or pixmap_to_data(pmap, format='PNG'))
 
     def dragMoveEvent(self, event):
         event.acceptProposedAction()
@@ -256,8 +269,8 @@ class ImageDropMixin(object):  # {{{
 
     def build_context_menu(self):
         cm = QMenu(self)
-        paste = cm.addAction(_('Paste Cover'))
-        copy = cm.addAction(_('Copy Cover'))
+        paste = cm.addAction(_('Paste cover'))
+        copy = cm.addAction(_('Copy cover'))
         if not QApplication.instance().clipboard().mimeData().hasImage():
             paste.setEnabled(False)
         copy.triggered.connect(self.copy_to_clipboard)
@@ -278,9 +291,10 @@ class ImageDropMixin(object):  # {{{
         if not pmap.isNull():
             self.set_pixmap(pmap)
             self.cover_changed.emit(
-                    pixmap_to_data(pmap, quality=100))
+                    pixmap_to_data(pmap, format='PNG'))
 # }}}
 
+
 class ImageView(QWidget, ImageDropMixin):  # {{{
 
     BORDER_WIDTH = 1
@@ -289,7 +303,7 @@ class ImageView(QWidget, ImageDropMixin):  # {{{
     def __init__(self, parent=None, show_size_pref_name=None, default_show_size=False):
         QWidget.__init__(self, parent)
         self.show_size_pref_name = ('show_size_on_cover_' + show_size_pref_name) if show_size_pref_name else None
-        self._pixmap = QPixmap(self)
+        self._pixmap = QPixmap()
         self.setMinimumSize(QSize(150, 200))
         ImageDropMixin.__init__(self)
         self.draw_border = True
@@ -335,9 +349,9 @@ class ImageView(QWidget, ImageDropMixin):  # {{{
         cw, ch = self.rect().width(), self.rect().height()
         scaled, nw, nh = fit_image(w, h, cw, ch)
         if scaled:
-            pmap = pmap.scaled(nw, nh, Qt.IgnoreAspectRatio,
+            pmap = pmap.scaled(int(nw*pmap.devicePixelRatio()), int(nh*pmap.devicePixelRatio()), Qt.IgnoreAspectRatio,
                     Qt.SmoothTransformation)
-        w, h = pmap.width(), pmap.height()
+        w, h = int(pmap.width()/pmap.devicePixelRatio()), int(pmap.height()/pmap.devicePixelRatio())
         x = int(abs(cw - w)/2.)
         y = int(abs(ch - h)/2.)
         target = QRect(x, y, w, h)
@@ -363,6 +377,7 @@ class ImageView(QWidget, ImageDropMixin):  # {{{
         p.end()
 # }}}
 
+
 class CoverView(QGraphicsView, ImageDropMixin):  # {{{
 
     cover_changed = pyqtSignal(object)
@@ -384,6 +399,8 @@ class CoverView(QGraphicsView, ImageDropMixin):  # {{{
 # }}}
 
 # BasicList {{{
+
+
 class BasicListItem(QListWidgetItem):
 
     def __init__(self, text, user_data=None):
@@ -395,6 +412,7 @@ class BasicListItem(QListWidgetItem):
             return self.text() == other.text()
         return False
 
+
 class BasicList(QListWidget):
 
     def add_item(self, text, user_data=None, replace=False):
@@ -418,6 +436,7 @@ class BasicList(QListWidget):
             yield self.item(i)
 # }}}
 
+
 class LineEditECM(object):  # {{{
 
     '''
@@ -428,18 +447,18 @@ class LineEditECM(object):  # {{{
         menu = self.createStandardContextMenu()
         menu.addSeparator()
 
-        case_menu = QMenu(_('Change Case'))
-        action_upper_case = case_menu.addAction(_('Upper Case'))
-        action_lower_case = case_menu.addAction(_('Lower Case'))
-        action_swap_case = case_menu.addAction(_('Swap Case'))
-        action_title_case = case_menu.addAction(_('Title Case'))
+        case_menu = QMenu(_('Change case'))
+        action_upper_case = case_menu.addAction(_('Upper case'))
+        action_lower_case = case_menu.addAction(_('Lower case'))
+        action_swap_case = case_menu.addAction(_('Swap case'))
+        action_title_case = case_menu.addAction(_('Title case'))
         action_capitalize = case_menu.addAction(_('Capitalize'))
 
-        action_upper_case.triggered[()].connect(self.upper_case)
-        action_lower_case.triggered[()].connect(self.lower_case)
-        action_swap_case.triggered[()].connect(self.swap_case)
-        action_title_case.triggered[()].connect(self.title_case)
-        action_capitalize.triggered[()].connect(self.capitalize)
+        action_upper_case.triggered.connect(self.upper_case)
+        action_lower_case.triggered.connect(self.lower_case)
+        action_swap_case.triggered.connect(self.swap_case)
+        action_title_case.triggered.connect(self.title_case)
+        action_capitalize.triggered.connect(self.capitalize)
 
         menu.addMenu(case_menu)
         menu.exec_(event.globalPos())
@@ -466,6 +485,7 @@ class LineEditECM(object):  # {{{
 
 # }}}
 
+
 class EnLineEdit(LineEditECM, QLineEdit):  # {{{
 
     '''
@@ -474,9 +494,16 @@ class EnLineEdit(LineEditECM, QLineEdit):  # {{{
     Includes an extended content menu.
     '''
 
-    pass
+    def event(self, ev):
+        # See https://bugreports.qt.io/browse/QTBUG-46911
+        if ev.type() == ev.ShortcutOverride and (
+                ev.key() in (Qt.Key_Left, Qt.Key_Right) and (ev.modifiers() & ~Qt.KeypadModifier) == Qt.ControlModifier):
+            ev.accept()
+        return QLineEdit.event(self, ev)
+
 # }}}
 
+
 class ItemsCompleter(QCompleter):  # {{{
 
     '''
@@ -504,6 +531,7 @@ class ItemsCompleter(QCompleter):  # {{{
 
 # }}}
 
+
 class CompleteLineEdit(EnLineEdit):  # {{{
 
     '''
@@ -563,6 +591,7 @@ class CompleteLineEdit(EnLineEdit):  # {{{
 
 # }}}
 
+
 class EnComboBox(QComboBox):  # {{{
 
     '''
@@ -574,7 +603,7 @@ class EnComboBox(QComboBox):  # {{{
     def __init__(self, *args):
         QComboBox.__init__(self, *args)
         self.setLineEdit(EnLineEdit(self))
-        self.setAutoCompletionCaseSensitivity(Qt.CaseInsensitive)
+        self.completer().setCaseSensitivity(Qt.CaseInsensitive)
         self.setMinimumContentsLength(20)
 
     def text(self):
@@ -589,6 +618,7 @@ class EnComboBox(QComboBox):  # {{{
 
 # }}}
 
+
 class CompleteComboBox(EnComboBox):  # {{{
 
     def __init__(self, *args):
@@ -606,6 +636,7 @@ class CompleteComboBox(EnComboBox):  # {{{
 
 # }}}
 
+
 class HistoryLineEdit(QComboBox):  # {{{
 
     lost_focus = pyqtSignal()
@@ -625,7 +656,7 @@ class HistoryLineEdit(QComboBox):  # {{{
 
     def initialize(self, name):
         self._name = name
-        self.addItems(QStringList(history.get(self.store_name, [])))
+        self.addItems(history.get(self.store_name, []))
         self.setEditText('')
         self.lineEdit().editingFinished.connect(self.save_history)
 
@@ -659,12 +690,14 @@ class HistoryLineEdit(QComboBox):  # {{{
 
 # }}}
 
+
 class ComboBoxWithHelp(QComboBox):  # {{{
     '''
     A combobox where item 0 is help text. CurrentText will return '' for item 0.
     Be sure to always fetch the text with currentText. Don't use the signals
     that pass a string, because they will not correct the text.
     '''
+
     def __init__(self, parent=None):
         QComboBox.__init__(self, parent)
         self.currentIndexChanged[int].connect(self.index_changed)
@@ -708,6 +741,7 @@ class ComboBoxWithHelp(QComboBox):  # {{{
 
 # }}}
 
+
 class EncodingComboBox(QComboBox):  # {{{
     '''
     A combobox that holds text encodings support
@@ -733,11 +767,11 @@ class EncodingComboBox(QComboBox):  # {{{
 
 # }}}
 
+
 class PythonHighlighter(QSyntaxHighlighter):  # {{{
 
     Rules = []
     Formats = {}
-    Config = {}
 
     KEYWORDS = ["and", "as", "assert", "break", "class", "continue", "def",
         "del", "elif", "else", "except", "exec", "finally", "for", "from",
@@ -760,8 +794,6 @@ class PythonHighlighter(QSyntaxHighlighter):  # {{{
 
     def __init__(self, parent=None):
         super(PythonHighlighter, self).__init__(parent)
-        if not self.Config:
-            self.loadConfig()
 
         self.initializeFormats()
 
@@ -780,7 +812,7 @@ class PythonHighlighter(QSyntaxHighlighter):  # {{{
                 r"|\b[+-]?[0-9]+(?:\.[0-9]+)?(?:[eE][+-]?[0-9]+)?\b"),
                 "number"))
         PythonHighlighter.Rules.append((QRegExp(
-                r"\bPyQt4\b|\bQt?[A-Z][a-z]\w+\b"), "pyqt"))
+                r"\bPyQt5\b|\bQt?[A-Z][a-z]\w+\b"), "pyqt"))
         PythonHighlighter.Rules.append((QRegExp(r"\b@\w+\b"), "decorator"))
         stringRe = QRegExp(r"""(?:'[^']*'|"[^"]*")""")
         stringRe.setMinimal(True)
@@ -792,31 +824,12 @@ class PythonHighlighter(QSyntaxHighlighter):  # {{{
         self.tripleDoubleRe = QRegExp(r'''"""(?!')''')
 
     @classmethod
-    def loadConfig(cls):
-        Config = cls.Config
-
-        for name in ("window", "shell"):
-            Config["%swidth" % name] = QVariant(QApplication.desktop().availableGeometry().width() / 2).toInt()[0]
-            Config["%sheight" % name] = QVariant(QApplication.desktop().availableGeometry().height() / 2).toInt()[0]
-            Config["%sy" % name] = QVariant(0).toInt()[0]
-        Config["toolbars"] = QByteArray(b'')
-        Config["splitter"] = QByteArray(b'')
-        Config["shellx"] = QVariant(0).toInt()[0]
-        Config["windowx"] = QVariant(QApplication.desktop().availableGeometry().width() / 2).toInt()[0]
-        Config["remembergeometry"] = QVariant(True).toBool()
-        Config["startwithshell"] = QVariant(True).toBool()
-        Config["showwindowinfo"] = QVariant(True).toBool()
-        Config["backupsuffix"] = QVariant(".bak").toString()
-        Config["cwd"]  = QVariant(".").toString()
-        Config["tooltipsize"] = QVariant(150).toInt()[0]
-        Config["maxlinestoscan"] = QVariant(5000).toInt()[0]
-        Config["pythondocpath"] = QVariant("http://docs.python.org").toString()
-        Config["autohidefinddialog"] = QVariant(True).toBool()
-        Config["findcasesensitive"] = QVariant(False).toBool()
-        Config["findwholewords"] = QVariant(False).toBool()
-        Config["tabwidth"] = QVariant(4).toInt()[0]
-        Config["fontfamily"] = QVariant("monospace").toString()
-        Config["fontsize"] = QVariant(10).toInt()[0]
+    def initializeFormats(cls):
+        if cls.Formats:
+            return
+        baseFormat = QTextCharFormat()
+        baseFormat.setFontFamily('monospace')
+        baseFormat.setFontPointSize(11)
         for name, color, bold, italic in (
                 ("normal", "#000000", False, False),
                 ("keyword", "#000080", True, False),
@@ -828,42 +841,30 @@ class PythonHighlighter(QSyntaxHighlighter):  # {{{
                 ("number", "#924900", False, False),
                 ("error", "#FF0000", False, False),
                 ("pyqt", "#50621A", False, False)):
-            Config["%sfontcolor" % name] = QVariant(color).toString()
-            Config["%sfontbold" % name] = QVariant(bold).toBool()
-            Config["%sfontitalic" % name] = QVariant(italic).toBool()
 
-    @classmethod
-    def initializeFormats(cls):
-        Config = cls.Config
-        baseFormat = QTextCharFormat()
-        baseFormat.setFontFamily(Config["fontfamily"])
-        baseFormat.setFontPointSize(Config["fontsize"])
-        for name in ("normal", "keyword", "builtin", "constant",
-                "decorator", "comment", "string", "number", "error",
-                "pyqt"):
             format = QTextCharFormat(baseFormat)
-            format.setForeground(QColor(Config["%sfontcolor" % name]))
-            if Config["%sfontbold" % name]:
+            format.setForeground(QColor(color))
+            if bold:
                 format.setFontWeight(QFont.Bold)
-            format.setFontItalic(Config["%sfontitalic" % name])
-            PythonHighlighter.Formats[name] = format
+            format.setFontItalic(italic)
+            cls.Formats[name] = format
 
     def highlightBlock(self, text):
         NORMAL, TRIPLESINGLE, TRIPLEDOUBLE, ERROR = range(4)
 
-        textLength = text.length()
+        textLength = len(text)
         prevState = self.previousBlockState()
 
         self.setFormat(0, textLength,
                        PythonHighlighter.Formats["normal"])
 
-        if text.startsWith("Traceback") or text.startsWith("Error: "):
+        if text.startswith(u"Traceback") or text.startswith(u"Error: "):
             self.setCurrentBlockState(ERROR)
             self.setFormat(0, textLength,
                            PythonHighlighter.Formats["error"])
             return
         if prevState == ERROR and \
-           not (text.startsWith('>>>') or text.startsWith("#")):
+           not (text.startswith(u'>>>') or text.startswith(u"#")):
             self.setCurrentBlockState(ERROR)
             self.setFormat(0, textLength,
                            PythonHighlighter.Formats["error"])
@@ -880,21 +881,21 @@ class PythonHighlighter(QSyntaxHighlighter):  # {{{
         # Slow but good quality highlighting for comments. For more
         # speed, comment this out and add the following to __init__:
         # PythonHighlighter.Rules.append((QRegExp(r"#.*"), "comment"))
-        if text.isEmpty():
+        if not text:
             pass
-        elif text[0] == "#":
-            self.setFormat(0, text.length(),
+        elif text[0] == u"#":
+            self.setFormat(0, len(text),
                            PythonHighlighter.Formats["comment"])
         else:
             stack = []
             for i, c in enumerate(text):
-                if c in ('"', "'"):
+                if c in (u'"', u"'"):
                     if stack and stack[-1] == c:
                         stack.pop()
                     else:
                         stack.append(c)
-                elif c == "#" and len(stack) == 0:
-                    self.setFormat(i, text.length(),
+                elif c == u"#" and len(stack) == 0:
+                    self.setFormat(i, len(text),
                                    PythonHighlighter.Formats["comment"])
                     break
 
@@ -909,13 +910,13 @@ class PythonHighlighter(QSyntaxHighlighter):  # {{{
                           TRIPLEDOUBLE)):
             if self.previousBlockState() == state:
                 if i == -1:
-                    i = text.length()
+                    i = len(text)
                     self.setCurrentBlockState(state)
                 self.setFormat(0, i + 3,
                                PythonHighlighter.Formats["string"])
             elif i > -1:
                 self.setCurrentBlockState(state)
-                self.setFormat(i, text.length(),
+                self.setFormat(i, len(text),
                                PythonHighlighter.Formats["string"])
 
     def rehighlight(self):
@@ -926,6 +927,8 @@ class PythonHighlighter(QSyntaxHighlighter):  # {{{
 # }}}
 
 # Splitter {{{
+
+
 class SplitterHandle(QSplitterHandle):
 
     double_clicked = pyqtSignal(object)
@@ -948,6 +951,7 @@ class SplitterHandle(QSplitterHandle):
     def mouseDoubleClickEvent(self, ev):
         self.double_clicked.emit(self)
 
+
 class LayoutButton(QToolButton):
 
     def __init__(self, icon, text, splitter=None, parent=None, shortcut=None):
@@ -983,6 +987,7 @@ class LayoutButton(QToolButton):
         else:
             self.set_state_to_hide()
 
+
 class Splitter(QSplitter):
 
     state_changed = pyqtSignal(object)
@@ -1163,3 +1168,12 @@ class Splitter(QSplitter):
 # }}}
 
 
+if __name__ == '__main__':
+    from PyQt5.Qt import QTextEdit
+    app = QApplication([])
+    w = QTextEdit()
+    s = PythonHighlighter(w)
+    # w.setSyntaxHighlighter(s)
+    w.setText(open(__file__, 'rb').read().decode('utf-8'))
+    w.show()
+    app.exec_()
