@@ -13,11 +13,19 @@ FIELDS = ['all', 'title', 'title_sort', 'author_sort', 'authors', 'comments',
           'rating', 'series_index', 'series', 'size', 'tags', 'timestamp',
           'uuid', 'languages', 'identifiers']
 
-#Allowed fields for template
-TEMPLATE_ALLOWED_FIELDS = [ 'author_sort', 'authors', 'id', 'isbn', 'pubdate', 'title_sort',
-    'publisher', 'series_index', 'series', 'tags', 'timestamp', 'title', 'uuid' ]
+# Allowed fields for template
+TEMPLATE_ALLOWED_FIELDS = ['author_sort', 'authors', 'id', 'isbn', 'pubdate', 'title_sort',
+    'publisher', 'series_index', 'series', 'tags', 'timestamp', 'title', 'uuid']
 
-class AuthorSortMismatchException(Exception): pass
-class EmptyCatalogException(Exception): pass
-class InvalidGenresSourceFieldException(Exception): pass
+
+class AuthorSortMismatchException(Exception):
+    pass
+
+
+class EmptyCatalogException(Exception):
+    pass
+
+
+class InvalidGenresSourceFieldException(Exception):
+    pass
 
