@@ -55,6 +55,7 @@ class CSV_XML(CatalogPlugin):
         from calibre.utils.html2text import html2text
         from calibre.utils.logging import default_log as log
         from lxml import etree
+        from calibre.ebooks.metadata import authors_to_string
 
         self.fmt = path_to_output.rpartition('.')[2]
         self.notification = notification
@@ -116,6 +117,11 @@ class CSV_XML(CatalogPlugin):
                 for field in fields:
                     if field.startswith('#'):
                         item = db.get_field(entry['id'], field, index_is_id=True)
+                        if isinstance(item, (list, tuple)):
+                            if fm.get(field, {}).get('display', {}).get('is_names', False):
+                                item = ' & '.join(item)
+                            else:
+                                item = ', '.join(item)
                     elif field == 'library_name':
                         item = current_library
                     elif field == 'title_sort':
@@ -131,7 +137,9 @@ class CSV_XML(CatalogPlugin):
                         for format in item:
                             fmt_list.append(format.rpartition('.')[2].lower())
                         item = ', '.join(fmt_list)
-                    elif field in ['authors', 'tags']:
+                    elif field == 'authors':
+                        item = authors_to_string(item)
+                    elif field == 'tags':
                         item = ', '.join(item)
                     elif field == 'isbn':
                         # Could be 9, 10 or 13 digits, with hyphens, possibly ending in 'X'
