@@ -20,6 +20,7 @@ lost_cr_exception_pat = re.compile(r'(Ph\.D)|(D\.Phil)|((Dr|Mr|Mrs|Ms)\.[A-Z])')
 sanitize_pat = re.compile(r'<script|<table|<tr|<td|<th|<style|<iframe',
         re.IGNORECASE)
 
+
 def comments_to_html(comments):
     '''
     Convert random comment text to normalized, xml-legal block of <p>s
@@ -130,9 +131,20 @@ def comments_to_html(comments):
 
     return result.renderContents(encoding=None)
 
+
+def markdown(val):
+    try:
+        md = markdown.Markdown
+    except AttributeError:
+        from calibre.ebooks.markdown import Markdown
+        md = markdown.Markdown = Markdown()
+    return md.convert(val)
+
+
 def merge_comments(one, two):
     return comments_to_html(one) + '\n\n' + comments_to_html(two)
 
+
 def sanitize_html(html):
     if not html:
         return u''
@@ -149,6 +161,7 @@ def sanitize_html(html):
     stream = TreeWalker(tree)
     return serializer.render(stream)
 
+
 def sanitize_comments_html(html):
     from calibre.ebooks.markdown import Markdown
     text = html2text(html)
@@ -156,6 +169,7 @@ def sanitize_comments_html(html):
     html = md.convert(text)
     return sanitize_html(html)
 
+
 def test():
     for pat, val in [
             ('lineone\n\nlinetwo',
