@@ -3,26 +3,10 @@ Created on 25 May 2010
 
 @author: charles
 '''
-import copy, traceback
+import traceback
 from collections import OrderedDict
 
-from calibre.utils.config import tweaks
-
-class TagsIcons(dict):
-    '''
-    If the client wants icons to be in the tag structure, this class must be
-    instantiated and filled in with real icons. If this class is instantiated
-    and passed to get_categories, All items must be given a value not None
-    '''
-
-    category_icons = ['authors', 'series', 'formats', 'publisher', 'rating',
-                      'news',    'tags',   'custom:', 'user:',     'search',
-                      'identifiers', 'languages', 'gst']
-    def __init__(self, icon_dict):
-        for a in self.category_icons:
-            if a not in icon_dict:
-                raise ValueError('Missing category icon [%s]'%a)
-            self[a] = icon_dict[a]
+from calibre.utils.config_base import tweaks
 
 category_icon_map = {
                     'authors'    : 'user_profile.png',
@@ -40,6 +24,303 @@ category_icon_map = {
                     'languages'  : 'languages.png',
             }
 
+# Builtin metadata {{{
+
+
+def _builtin_field_metadata():
+    # This is a function so that changing the UI language allows newly created
+    # field metadata objects to have correctly translated labels for builtin
+    # fields.
+    return [
+            ('authors',   {'table':'authors',
+                           'column':'name',
+                           'link_column':'author',
+                           'category_sort':'sort',
+                           'datatype':'text',
+                           'is_multiple':{'cache_to_list': ',',
+                                          'ui_to_list': '&',
+                                          'list_to_ui': ' & '},
+                           'kind':'field',
+                           'name':_('Authors'),
+                           'search_terms':['authors', 'author'],
+                           'is_custom':False,
+                           'is_category':True,
+                           'is_csp': False}),
+            ('languages', {'table':'languages',
+                           'column':'lang_code',
+                           'link_column':'lang_code',
+                           'category_sort':'lang_code',
+                           'datatype':'text',
+                           'is_multiple':{'cache_to_list': ',',
+                                          'ui_to_list': ',',
+                                          'list_to_ui': ', '},
+                           'kind':'field',
+                           'name':_('Languages'),
+                           'search_terms':['languages', 'language'],
+                           'is_custom':False,
+                           'is_category':True,
+                           'is_csp': False}),
+
+            ('series',    {'table':'series',
+                           'column':'name',
+                           'link_column':'series',
+                           'category_sort':'(title_sort(name))',
+                           'datatype':'series',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':ngettext('Series', 'Series', 1),
+                           'search_terms':['series'],
+                           'is_custom':False,
+                           'is_category':True,
+                           'is_csp': False}),
+            ('formats',   {'table':None,
+                           'column':None,
+                           'datatype':'text',
+                           'is_multiple':{'cache_to_list': ',',
+                                          'ui_to_list': ',',
+                                          'list_to_ui': ', '},
+                           'kind':'field',
+                           'name':_('Formats'),
+                           'search_terms':['formats', 'format'],
+                           'is_custom':False,
+                           'is_category':True,
+                           'is_csp': False}),
+            ('publisher', {'table':'publishers',
+                           'column':'name',
+                           'link_column':'publisher',
+                           'category_sort':'name',
+                           'datatype':'text',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':_('Publisher'),
+                           'search_terms':['publisher'],
+                           'is_custom':False,
+                           'is_category':True,
+                           'is_csp': False}),
+            ('rating',    {'table':'ratings',
+                           'column':'rating',
+                           'link_column':'rating',
+                           'category_sort':'rating',
+                           'datatype':'rating',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':_('Rating'),
+                           'search_terms':['rating'],
+                           'is_custom':False,
+                           'is_category':True,
+                           'is_csp': False}),
+            ('news',      {'table':'news',
+                           'column':'name',
+                           'category_sort':'name',
+                           'datatype':None,
+                           'is_multiple':{},
+                           'kind':'category',
+                           'name':_('News'),
+                           'search_terms':[],
+                           'is_custom':False,
+                           'is_category':True,
+                           'is_csp': False}),
+            ('tags',      {'table':'tags',
+                           'column':'name',
+                           'link_column': 'tag',
+                           'category_sort':'name',
+                           'datatype':'text',
+                           'is_multiple':{'cache_to_list': ',',
+                                          'ui_to_list': ',',
+                                          'list_to_ui': ', '},
+                           'kind':'field',
+                           'name':_('Tags'),
+                           'search_terms':['tags', 'tag'],
+                           'is_custom':False,
+                           'is_category':True,
+                           'is_csp': False}),
+            ('identifiers',   {'table':None,
+                           'column':None,
+                           'datatype':'text',
+                           'is_multiple':{'cache_to_list': ',',
+                                          'ui_to_list': ',',
+                                          'list_to_ui': ', '},
+                           'kind':'field',
+                           'name':_('Identifiers'),
+                           'search_terms':['identifiers', 'identifier', 'isbn'],
+                           'is_custom':False,
+                           'is_category':True,
+                           'is_csp': True}),
+            ('author_sort',{'table':None,
+                            'column':None,
+                            'datatype':'text',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':_('Author sort'),
+                           'search_terms':['author_sort'],
+                           'is_custom':False,
+                           'is_category':False,
+                           'is_csp': False}),
+            ('au_map',    {'table':None,
+                           'column':None,
+                           'datatype':'text',
+                           'is_multiple':{'cache_to_list': ',',
+                                          'ui_to_list': None,
+                                          'list_to_ui': None},
+                           'kind':'field',
+                           'name':None,
+                           'search_terms':[],
+                           'is_custom':False,
+                           'is_category':False,
+                           'is_csp': False}),
+            ('comments',  {'table':None,
+                           'column':None,
+                           'datatype':'text',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':_('Comments'),
+                           'search_terms':['comments', 'comment'],
+                           'is_custom':False,
+                           'is_category':False,
+                           'is_csp': False}),
+            ('cover',     {'table':None,
+                           'column':None,
+                           'datatype':'int',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':_('Cover'),
+                           'search_terms':['cover'],
+                           'is_custom':False,
+                           'is_category':False,
+                           'is_csp': False}),
+            ('id',        {'table':None,
+                           'column':None,
+                           'datatype':'int',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':None,
+                           'search_terms':['id'],
+                           'is_custom':False,
+                           'is_category':False,
+                           'is_csp': False}),
+            ('last_modified', {'table':None,
+                           'column':None,
+                           'datatype':'datetime',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':_('Modified'),
+                           'search_terms':['last_modified'],
+                           'is_custom':False,
+                           'is_category':False,
+                           'is_csp': False}),
+            ('ondevice',  {'table':None,
+                           'column':None,
+                           'datatype':'text',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':_('On device'),
+                           'search_terms':['ondevice'],
+                           'is_custom':False,
+                           'is_category':False,
+                           'is_csp': False}),
+            ('path',      {'table':None,
+                           'column':None,
+                           'datatype':'text',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':_('Path'),
+                           'search_terms':[],
+                           'is_custom':False,
+                           'is_category':False,
+                           'is_csp': False}),
+            ('pubdate',   {'table':None,
+                           'column':None,
+                           'datatype':'datetime',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':_('Published'),
+                           'search_terms':['pubdate'],
+                           'is_custom':False,
+                           'is_category':False,
+                           'is_csp': False}),
+            ('marked',    {'table':None,
+                           'column':None,
+                           'datatype':'text',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name': None,
+                           'search_terms':['marked'],
+                           'is_custom':False,
+                           'is_category':False,
+                           'is_csp': False}),
+            ('series_index',{'table':None,
+                             'column':None,
+                             'datatype':'float',
+                             'is_multiple':{},
+                             'kind':'field',
+                             'name':None,
+                             'search_terms':['series_index'],
+                             'is_custom':False,
+                             'is_category':False,
+                           'is_csp': False}),
+            ('series_sort',  {'table':None,
+                           'column':None,
+                           'datatype':'text',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':_('Series sort'),
+                           'search_terms':['series_sort'],
+                           'is_custom':False,
+                           'is_category':False,
+                           'is_csp': False}),
+            ('sort',      {'table':None,
+                           'column':None,
+                           'datatype':'text',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':_('Title sort'),
+                           'search_terms':['title_sort'],
+                           'is_custom':False,
+                           'is_category':False,
+                           'is_csp': False}),
+            ('size',      {'table':None,
+                           'column':None,
+                           'datatype':'float',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':_('Size'),
+                           'search_terms':['size'],
+                           'is_custom':False,
+                           'is_category':False,
+                           'is_csp': False}),
+            ('timestamp', {'table':None,
+                           'column':None,
+                           'datatype':'datetime',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':_('Date'),
+                           'search_terms':['date'],
+                           'is_custom':False,
+                           'is_category':False,
+                           'is_csp': False}),
+            ('title',     {'table':None,
+                           'column':None,
+                           'datatype':'text',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':_('Title'),
+                           'search_terms':['title'],
+                           'is_custom':False,
+                           'is_category':False,
+                           'is_csp': False}),
+            ('uuid',      {'table':None,
+                           'column':None,
+                           'datatype':'text',
+                           'is_multiple':{},
+                           'kind':'field',
+                           'name':None,
+                           'search_terms':['uuid'],
+                           'is_custom':False,
+                           'is_category':False,
+                           'is_csp': False}),
+        ]
+# }}}
+
 
 class FieldMetadata(dict):
     '''
@@ -98,296 +379,13 @@ class FieldMetadata(dict):
     VALID_DATA_TYPES = frozenset([None, 'rating', 'text', 'comments', 'datetime',
                 'int', 'float', 'bool', 'series', 'composite', 'enumeration'])
 
-    # Builtin metadata {{{
-
-    _field_metadata_prototype = [
-            ('authors',   {'table':'authors',
-                           'column':'name',
-                           'link_column':'author',
-                           'category_sort':'sort',
-                           'datatype':'text',
-                           'is_multiple':{'cache_to_list': ',',
-                                          'ui_to_list': '&',
-                                          'list_to_ui': ' & '},
-                           'kind':'field',
-                           'name':_('Authors'),
-                           'search_terms':['authors', 'author'],
-                           'is_custom':False,
-                           'is_category':True,
-                           'is_csp': False}),
-            ('languages', {'table':'languages',
-                           'column':'lang_code',
-                           'link_column':'lang_code',
-                           'category_sort':'lang_code',
-                           'datatype':'text',
-                           'is_multiple':{'cache_to_list': ',',
-                                          'ui_to_list': ',',
-                                          'list_to_ui': ', '},
-                           'kind':'field',
-                           'name':_('Languages'),
-                           'search_terms':['languages', 'language'],
-                           'is_custom':False,
-                           'is_category':True,
-                           'is_csp': False}),
-
-            ('series',    {'table':'series',
-                           'column':'name',
-                           'link_column':'series',
-                           'category_sort':'(title_sort(name))',
-                           'datatype':'series',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name':ngettext('Series', 'Series', 2),
-                           'search_terms':['series'],
-                           'is_custom':False,
-                           'is_category':True,
-                           'is_csp': False}),
-            ('formats',   {'table':None,
-                           'column':None,
-                           'datatype':'text',
-                           'is_multiple':{'cache_to_list': ',',
-                                          'ui_to_list': ',',
-                                          'list_to_ui': ', '},
-                           'kind':'field',
-                           'name':_('Formats'),
-                           'search_terms':['formats', 'format'],
-                           'is_custom':False,
-                           'is_category':True,
-                           'is_csp': False}),
-            ('publisher', {'table':'publishers',
-                           'column':'name',
-                           'link_column':'publisher',
-                           'category_sort':'name',
-                           'datatype':'text',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name':_('Publishers'),
-                           'search_terms':['publisher'],
-                           'is_custom':False,
-                           'is_category':True,
-                           'is_csp': False}),
-            ('rating',    {'table':'ratings',
-                           'column':'rating',
-                           'link_column':'rating',
-                           'category_sort':'rating',
-                           'datatype':'rating',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name':_('Ratings'),
-                           'search_terms':['rating'],
-                           'is_custom':False,
-                           'is_category':True,
-                           'is_csp': False}),
-            ('news',      {'table':'news',
-                           'column':'name',
-                           'category_sort':'name',
-                           'datatype':None,
-                           'is_multiple':{},
-                           'kind':'category',
-                           'name':_('News'),
-                           'search_terms':[],
-                           'is_custom':False,
-                           'is_category':True,
-                           'is_csp': False}),
-            ('tags',      {'table':'tags',
-                           'column':'name',
-                           'link_column': 'tag',
-                           'category_sort':'name',
-                           'datatype':'text',
-                           'is_multiple':{'cache_to_list': ',',
-                                          'ui_to_list': ',',
-                                          'list_to_ui': ', '},
-                           'kind':'field',
-                           'name':_('Tags'),
-                           'search_terms':['tags', 'tag'],
-                           'is_custom':False,
-                           'is_category':True,
-                           'is_csp': False}),
-            ('identifiers',   {'table':None,
-                           'column':None,
-                           'datatype':'text',
-                           'is_multiple':{'cache_to_list': ',',
-                                          'ui_to_list': ',',
-                                          'list_to_ui': ', '},
-                           'kind':'field',
-                           'name':_('Identifiers'),
-                           'search_terms':['identifiers', 'identifier', 'isbn'],
-                           'is_custom':False,
-                           'is_category':True,
-                           'is_csp': True}),
-            ('author_sort',{'table':None,
-                            'column':None,
-                            'datatype':'text',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name':_('Author Sort'),
-                           'search_terms':['author_sort'],
-                           'is_custom':False,
-                           'is_category':False,
-                           'is_csp': False}),
-            ('au_map',    {'table':None,
-                           'column':None,
-                           'datatype':'text',
-                           'is_multiple':{'cache_to_list': ',',
-                                          'ui_to_list': None,
-                                          'list_to_ui': None},
-                           'kind':'field',
-                           'name':None,
-                           'search_terms':[],
-                           'is_custom':False,
-                           'is_category':False,
-                           'is_csp': False}),
-            ('comments',  {'table':None,
-                           'column':None,
-                           'datatype':'text',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name':_('Comments'),
-                           'search_terms':['comments', 'comment'],
-                           'is_custom':False,
-                           'is_category':False,
-                           'is_csp': False}),
-            ('cover',     {'table':None,
-                           'column':None,
-                           'datatype':'int',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name':None,
-                           'search_terms':['cover'],
-                           'is_custom':False,
-                           'is_category':False,
-                           'is_csp': False}),
-            ('id',        {'table':None,
-                           'column':None,
-                           'datatype':'int',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name':None,
-                           'search_terms':[],
-                           'is_custom':False,
-                           'is_category':False,
-                           'is_csp': False}),
-            ('last_modified', {'table':None,
-                           'column':None,
-                           'datatype':'datetime',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name':_('Modified'),
-                           'search_terms':['last_modified'],
-                           'is_custom':False,
-                           'is_category':False,
-                           'is_csp': False}),
-            ('ondevice',  {'table':None,
-                           'column':None,
-                           'datatype':'text',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name':_('On Device'),
-                           'search_terms':['ondevice'],
-                           'is_custom':False,
-                           'is_category':False,
-                           'is_csp': False}),
-            ('path',      {'table':None,
-                           'column':None,
-                           'datatype':'text',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name':_('Path'),
-                           'search_terms':[],
-                           'is_custom':False,
-                           'is_category':False,
-                           'is_csp': False}),
-            ('pubdate',   {'table':None,
-                           'column':None,
-                           'datatype':'datetime',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name':_('Published'),
-                           'search_terms':['pubdate'],
-                           'is_custom':False,
-                           'is_category':False,
-                           'is_csp': False}),
-            ('marked',    {'table':None,
-                           'column':None,
-                           'datatype':'text',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name': None,
-                           'search_terms':['marked'],
-                           'is_custom':False,
-                           'is_category':False,
-                           'is_csp': False}),
-            ('series_index',{'table':None,
-                             'column':None,
-                             'datatype':'float',
-                             'is_multiple':{},
-                             'kind':'field',
-                             'name':None,
-                             'search_terms':['series_index'],
-                             'is_custom':False,
-                             'is_category':False,
-                           'is_csp': False}),
-            ('sort',      {'table':None,
-                           'column':None,
-                           'datatype':'text',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name':_('Title Sort'),
-                           'search_terms':['title_sort'],
-                           'is_custom':False,
-                           'is_category':False,
-                           'is_csp': False}),
-            ('size',      {'table':None,
-                           'column':None,
-                           'datatype':'float',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name':_('Size'),
-                           'search_terms':['size'],
-                           'is_custom':False,
-                           'is_category':False,
-                           'is_csp': False}),
-            ('timestamp', {'table':None,
-                           'column':None,
-                           'datatype':'datetime',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name':_('Date'),
-                           'search_terms':['date'],
-                           'is_custom':False,
-                           'is_category':False,
-                           'is_csp': False}),
-            ('title',     {'table':None,
-                           'column':None,
-                           'datatype':'text',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name':_('Title'),
-                           'search_terms':['title'],
-                           'is_custom':False,
-                           'is_category':False,
-                           'is_csp': False}),
-            ('uuid',      {'table':None,
-                           'column':None,
-                           'datatype':'text',
-                           'is_multiple':{},
-                           'kind':'field',
-                           'name':None,
-                           'search_terms':[],
-                           'is_custom':False,
-                           'is_category':False,
-                           'is_csp': False}),
-        ]
-    # }}}
-
     # search labels that are not db columns
-    search_items = [    'all',
-                        'search',
-                    ]
+    search_items = ['all', 'search']
 
     def __init__(self):
-        self._field_metadata = copy.deepcopy(self._field_metadata_prototype)
+        self._field_metadata = _builtin_field_metadata()
         self._tb_cats = OrderedDict()
+        self._tb_custom_fields = {}
         self._search_term_map = {}
         self.custom_label_to_key_map = {}
         for k,v in self._field_metadata:
@@ -423,12 +421,10 @@ class FieldMetadata(dict):
             yield key
 
     def __contains__(self, key):
-        return self.has_key(key)
+        return key in self._tb_cats or key == 'title_sort'
 
     def has_key(self, key):
-        if key == 'title_sort':
-            return True
-        return key in self._tb_cats
+        return key in self
 
     def keys(self):
         return self._tb_cats.keys()
@@ -438,11 +434,20 @@ class FieldMetadata(dict):
                 if self._tb_cats[k]['kind']=='field' and
                    self._tb_cats[k]['datatype'] is not None]
 
+    def ui_sortable_field_keys(self):
+        ans = {k:self._tb_cats[k]['name'] for k in set(self.sortable_field_keys()) - {
+            'sort', 'author_sort', 'au_map', 'series_sort', 'marked',
+            'series_index', 'path', 'formats', 'identifiers', 'uuid',
+            'comments',
+        } if self._tb_cats[k]['name']}
+        ans['cover'] = _('Has cover')
+        return ans
+
     def displayable_field_keys(self):
         return [k for k in self._tb_cats.keys()
                 if self._tb_cats[k]['kind']=='field' and
                    self._tb_cats[k]['datatype'] is not None and
-                   k not in ('au_map', 'marked', 'ondevice', 'cover') and
+                   k not in ('au_map', 'marked', 'ondevice', 'cover', 'series_sort') and
                    not self.is_series_index(k)]
 
     def standard_field_keys(self):
@@ -477,10 +482,8 @@ class FieldMetadata(dict):
             yield (key, self._tb_cats[key])
 
     def custom_iteritems(self):
-        for key in self._tb_cats:
-            fm = self._tb_cats[key]
-            if fm['is_custom']:
-                yield (key, self._tb_cats[key])
+        for key, meta in self._tb_custom_fields.iteritems():
+            yield (key, meta)
 
     def items(self):
         return list(self.iteritems())
@@ -488,10 +491,20 @@ class FieldMetadata(dict):
     def is_custom_field(self, key):
         return key.startswith(self.custom_field_prefix)
 
+    def is_ignorable_field(self, key):
+        'Custom fields and user categories are ignorable'
+        return self.is_custom_field(key) or key.startswith('@')
+
+    def ignorable_field_keys(self):
+        return [k for k in self._tb_cats.iterkeys() if self.is_ignorable_field(k)]
+
     def is_series_index(self, key):
-        m = self[key]
-        return (m['datatype'] == 'float' and key.endswith('_index') and
-                key[:-6] in self)
+        try:
+            m = self._tb_cats[key]
+            return (m['datatype'] == 'float' and key.endswith('_index') and
+                    key[:-6] in self._tb_cats)
+        except (KeyError, ValueError, TypeError, AttributeError):
+            return False
 
     def key_to_label(self, key):
         if 'label' not in self._tb_cats[key]:
@@ -516,6 +529,8 @@ class FieldMetadata(dict):
         return l
 
     def custom_field_metadata(self, include_composites=True):
+        if include_composites:
+            return self._tb_custom_fields
         l = {}
         for k in self.custom_field_keys(include_composites):
             l[k] = self._tb_cats[k]
@@ -537,6 +552,7 @@ class FieldMetadata(dict):
                              'is_custom':True,     'is_category':is_category,
                              'link_column':'value','category_sort':'value',
                              'is_csp' : is_csp,     'is_editable': is_editable,}
+        self._tb_custom_fields[key] = self._tb_cats[key]
         self._add_search_terms_to_map(key, [key])
         self.custom_label_to_key_map[label] = key
         if datatype == 'series':
@@ -635,9 +651,7 @@ class FieldMetadata(dict):
                 self._search_term_map[t] = key
 
     def search_term_to_field_key(self, term):
-        if term in self._search_term_map:
-            return  self._search_term_map[term]
-        return term
+        return self._search_term_map.get(term, term)
 
     def searchable_fields(self):
         return [k for k in self._tb_cats.keys()
