@@ -10,6 +10,7 @@ import os
 
 from calibre.utils.date import isoformat, DEFAULT_DATE
 
+
 class SchemaUpgrade(object):
 
     def __init__(self):
@@ -24,7 +25,6 @@ class SchemaUpgrade(object):
                 meth()
                 self.user_version = uv+1
 
-
     def upgrade_version_1(self):
         '''
         Normalize indices.
@@ -162,7 +162,6 @@ class SchemaUpgrade(object):
         '''
         )
 
-
     def upgrade_version_6(self):
         'Show authors in order'
         self.conn.executescript('''
@@ -332,7 +331,7 @@ class SchemaUpgrade(object):
                 FROM {tn};
 
                 '''.format(tn=table_name, cn=column_name,
-                           vcn=view_column_name, scn= sort_column_name))
+                           vcn=view_column_name, scn=sort_column_name))
             self.conn.executescript(script)
 
         def create_cust_tag_browser_view(table_name, link_table_name):
@@ -380,7 +379,7 @@ class SchemaUpgrade(object):
 
         db_tables = self.conn.get('''SELECT name FROM sqlite_master
                                      WHERE type='table'
-                                     ORDER BY name''');
+                                     ORDER BY name''')
         tables = []
         for (table,) in db_tables:
             tables.append(table)
@@ -417,6 +416,7 @@ class SchemaUpgrade(object):
         'Cache has_cover'
         self.conn.execute('ALTER TABLE books ADD COLUMN has_cover BOOL DEFAULT 0')
         data = self.conn.get('SELECT id,path FROM books', all=True)
+
         def has_cover(path):
             if path:
                 path = os.path.join(self.library_path, path.replace('/', os.sep),
