@@ -20,10 +20,11 @@ from calibre.ebooks.metadata import fmt_sidx
 from calibre.constants import __appname__
 from calibre import human_readable, isbytestring
 from calibre.utils.cleantext import clean_xml_chars
-from calibre.utils.date import utcfromtimestamp, as_local_time
+from calibre.utils.date import utcfromtimestamp, as_local_time, is_date_undefined
 from calibre.utils.filenames import ascii_filename
 from calibre.utils.icu import sort_key
 
+
 def CLASS(*args, **kwargs):  # class is a reserved word in Python
     kwargs['class'] = ' '.join(args)
     return kwargs
@@ -70,6 +71,7 @@ def build_search_box(num, search, sort, order, prefix):  # {{{
     return div
     # }}}
 
+
 def build_navigation(start, num, total, url_base):  # {{{
     end = min((start+num-1), total)
     tagline = SPAN('Books %d to %d of %d'%(start, end, total),
@@ -92,6 +94,7 @@ def build_navigation(start, num, total, url_base):  # {{{
 
     # }}}
 
+
 def build_index(books, num, search, sort, order, start, total, url_base, CKEYS,
         prefix, have_kobo_browser=False):
     logo = DIV(IMG(src=prefix+'/static/calibre.png', alt=__appname__), id='logo')
@@ -260,7 +263,11 @@ class MobileServer(object):
                                              no_tag_count=True)
             book['title'] = record[FM['title']]
             for x in ('timestamp', 'pubdate'):
-                book[x] = strftime('%d %b, %Y', as_local_time(record[FM[x]]))
+                dval = record[FM[x]]
+                if is_date_undefined(dval):
+                    book[x] = ''
+                else:
+                    book[x] = strftime('%d %b, %Y', as_local_time(dval))
             book['id'] = record[FM['id']]
             books.append(book)
             for key in CKEYS:
