@@ -30,6 +30,7 @@ dprefs.defaults['preferred_locales'] = {}
 dprefs.defaults['user_dictionaries'] = [{'name':_('Default'), 'is_active':True, 'words':[]}]
 not_present = object()
 
+
 class UserDictionary(object):
 
     __slots__ = ('name', 'is_active', 'words')
@@ -43,8 +44,10 @@ class UserDictionary(object):
         return {'name':self.name, 'is_active': self.is_active, 'words':[
             (w, l) for w, l in self.words]}
 
+
 _builtins = _custom = None
 
+
 def builtin_dictionaries():
     global _builtins
     if _builtins is None:
@@ -59,6 +62,7 @@ def builtin_dictionaries():
         _builtins = frozenset(dics)
     return _builtins
 
+
 def custom_dictionaries(reread=False):
     global _custom
     if _custom is None or reread:
@@ -79,6 +83,7 @@ def custom_dictionaries(reread=False):
         _custom = frozenset(dics)
     return _custom
 
+
 default_en_locale = 'en-US'
 try:
     ul = parse_lang_code(get_system_locale() or 'en-US')
@@ -88,14 +93,17 @@ if ul is not None and ul.langcode == 'eng' and ul.countrycode in 'GB BS BZ GH IE
     default_en_locale = 'en-' + ul.countrycode
 default_preferred_locales = {'eng':default_en_locale, 'deu':'de-DE', 'spa':'es-ES', 'fra':'fr-FR'}
 
+
 def best_locale_for_language(langcode):
     best_locale = dprefs['preferred_locales'].get(langcode, default_preferred_locales.get(langcode, None))
     if best_locale is not None:
         return parse_lang_code(best_locale)
 
+
 def preferred_dictionary(locale):
     return {parse_lang_code(k):v for k, v in dprefs['preferred_dictionaries'].iteritems()}.get(locale, None)
 
+
 def remove_dictionary(dictionary):
     if dictionary.builtin:
         raise ValueError('Cannot remove builtin dictionaries')
@@ -103,6 +111,7 @@ def remove_dictionary(dictionary):
     shutil.rmtree(base)
     dprefs['preferred_dictionaries'] = {k:v for k, v in dprefs['preferred_dictionaries'].iteritems() if v != dictionary.id}
 
+
 def rename_dictionary(dictionary, name):
     lf = os.path.join(os.path.dirname(dictionary.dicpath), 'locales')
     with open(lf, 'r+b') as f:
@@ -111,6 +120,7 @@ def rename_dictionary(dictionary, name):
         f.seek(0), f.truncate(), f.write(b'\n'.join(lines))
     custom_dictionaries(reread=True)
 
+
 def get_dictionary(locale, exact_match=False):
     preferred = preferred_dictionary(locale)
     # First find all dictionaries that match locale exactly
@@ -152,6 +162,7 @@ def get_dictionary(locale, exact_match=False):
             if d.primary_locale.langcode == locale.langcode:
                 return d
 
+
 def load_dictionary(dictionary):
     from calibre.spell.import_from import convert_to_utf8
     with open(dictionary.dicpath, 'rb') as dic, open(dictionary.affpath, 'rb') as aff:
@@ -160,6 +171,7 @@ def load_dictionary(dictionary):
         obj = hunspell.Dictionary(dic_data, aff_data)
     return LoadedDictionary(dictionary.primary_locale, dictionary.locales, obj, dictionary.builtin, dictionary.name, dictionary.id)
 
+
 class Dictionaries(object):
 
     def __init__(self):
@@ -358,7 +370,7 @@ class Dictionaries(object):
                     d = self.dictionary_for_locale(locale)
                     if d is not None:
                         try:
-                            ans = d.obj.recognized(word)
+                            ans = d.obj.recognized(word.replace('\u2010', '-'))
                         except ValueError:
                             pass
                     else:
@@ -371,6 +383,7 @@ class Dictionaries(object):
     def suggestions(self, word, locale=None):
         locale = locale or self.default_locale
         d = self.dictionary_for_locale(locale)
+        has_unicode_hyphen = '\u2010' in word
         ans = ()
 
         def add_suggestion(w, ans):
@@ -378,7 +391,7 @@ class Dictionaries(object):
 
         if d is not None:
             try:
-                ans = d.obj.suggest(unicode(word))
+                ans = d.obj.suggest(unicode(word).replace('\u2010', '-'))
             except ValueError:
                 pass
             else:
@@ -397,22 +410,34 @@ class Dictionaries(object):
                                 fw = w1 + m.group() + ' ' + capitalize(w2)
                                 ans = add_suggestion(fw, ans)
 
+        if has_unicode_hyphen:
+            ans = tuple(w.replace('-', '\u2010') for w in ans)
         return ans
 
-def test_dictionaries():
-    dictionaries = Dictionaries()
-    dictionaries.initialize()
-    eng = parse_lang_code('en')
-    rec = partial(dictionaries.recognized, locale=eng)
-    sg = partial(dictionaries.suggestions, locale=eng)
-    if not rec('recognized'):
-        raise ValueError('recognized not recognized')
-    if 'adequately' not in sg('ade-quately'):
-        raise ValueError('adequately not in %s' % sg('ade-quately'))
-    if 'magic. Wand' not in sg('magic.wand'):
-        raise ValueError('magic. Wand not in: %s' % sg('magic.wand'))
-    d = load_dictionary(get_dictionary(parse_lang_code('es'))).obj
-    assert d.recognized('Achí')
 
-if __name__ == '__main__':
-    test_dictionaries()
+def find_tests():
+    import unittest
+
+    class TestDictionaries(unittest.TestCase):
+
+        def setUp(self):
+            dictionaries = Dictionaries()
+            dictionaries.initialize()
+            eng = parse_lang_code('en')
+            self.recognized = partial(dictionaries.recognized, locale=eng)
+            self.suggestions = partial(dictionaries.suggestions, locale=eng)
+
+        def ar(self, w):
+            if not self.recognized(w):
+                raise AssertionError('The word %r was not recognized' % w)
+
+        def test_dictionaries(self):
+            for w in 'recognized one-half one\u2010half'.split():
+                self.ar(w)
+            d = load_dictionary(get_dictionary(parse_lang_code('es'))).obj
+            self.assertTrue(d.recognized('Achí'))
+            self.assertIn('one\u2010half', self.suggestions('oone\u2010half'))
+            self.assertIn('adequately', self.suggestions('ade-quately'))
+            self.assertIn('magic. Wand', self.suggestions('magic.wand'))
+
+    return unittest.TestLoader().loadTestsFromTestCase(TestDictionaries)
