@@ -7,7 +7,6 @@ __docformat__ = 'restructuredtext en'
 
 import hashlib, binascii
 from functools import partial
-from itertools import repeat
 from collections import OrderedDict, namedtuple
 from urllib import urlencode
 
@@ -16,24 +15,27 @@ from lxml.builder import ElementMaker
 
 from calibre.constants import __appname__
 from calibre.db.view import sanitize_sort_field_name
-from calibre.ebooks.metadata import fmt_sidx, authors_to_string
+from calibre.ebooks.metadata import fmt_sidx, authors_to_string, rating_to_stars
 from calibre.library.comments import comments_to_html
 from calibre import guess_type, prepare_string_for_xml as xml
 from calibre.utils.icu import sort_key
-from calibre.utils.date import as_utc, timestampfromdt
+from calibre.utils.date import as_utc, timestampfromdt, is_date_undefined
 
 from calibre.srv.errors import HTTPNotFound
 from calibre.srv.routes import endpoint
 from calibre.srv.utils import get_library_data, http_date, Offsets
 
+
 def hexlify(x):
     if isinstance(x, unicode):
         x = x.encode('utf-8')
     return binascii.hexlify(x)
 
+
 def unhexlify(x):
     return binascii.unhexlify(x).decode('utf-8')
 
+
 def atom(ctx, rd, endpoint, output):
     rd.outheaders.set('Content-Type', 'application/atom+xml; charset=UTF-8', replace_all=True)
     if isinstance(output, bytes):
@@ -45,6 +47,7 @@ def atom(ctx, rd, endpoint, output):
         ans = etree.tostring(output, encoding='utf-8', xml_declaration=True, pretty_print=True)
     return ans
 
+
 def format_tag_string(tags, sep, joinval=', '):
     if tags:
         tlist = tags if sep is None else [t.strip() for t in tags.split(sep)]
@@ -54,10 +57,11 @@ def format_tag_string(tags, sep, joinval=', '):
     return joinval.join(tlist) if tlist else ''
 
 # Vocabulary for building OPDS feeds {{{
+DC_NS = 'http://purl.org/dc/terms/'
 E = ElementMaker(namespace='http://www.w3.org/2005/Atom',
                  nsmap={
                      None   : 'http://www.w3.org/2005/Atom',
-                     'dc'   : 'http://purl.org/dc/terms/',
+                     'dc'   : DC_NS,
                      'opds' : 'http://opds-spec.org/2010/catalog',
                      })
 
@@ -67,6 +71,7 @@ TITLE   = E.title
 ID      = E.id
 ICON    = E.icon
 
+
 def UPDATED(dt, *args, **kwargs):
     return E.updated(as_utc(dt).strftime('%Y-%m-%dT%H:%M:%S+00:00'), *args, **kwargs)
 
@@ -74,12 +79,14 @@ LINK = partial(E.link, type='application/atom+xml')
 NAVLINK = partial(E.link,
         type='application/atom+xml;type=feed;profile=opds-catalog')
 
+
 def SEARCH_LINK(url_for, *args, **kwargs):
     kwargs['rel'] = 'search'
     kwargs['title'] = 'Search'
     kwargs['href'] = url_for('/opds/search', query='XXX').replace('XXX', '{searchTerms}')
     return LINK(*args, **kwargs)
 
+
 def AUTHOR(name, uri=None):
     args = [E.name(name)]
     if uri is not None:
@@ -88,6 +95,7 @@ def AUTHOR(name, uri=None):
 
 SUBTITLE = E.subtitle
 
+
 def NAVCATALOG_ENTRY(url_for, updated, title, description, query):
     href = url_for('/opds/navcatalog', which=hexlify(query))
     id_ = 'calibre-navcatalog:'+str(hashlib.sha1(href).hexdigest())
@@ -106,6 +114,7 @@ LAST_LINK  = partial(NAVLINK, rel='last')
 NEXT_LINK  = partial(NAVLINK, rel='next', title='Next')
 PREVIOUS_LINK  = partial(NAVLINK, rel='previous')
 
+
 def html_to_lxml(raw):
     raw = u'<div>%s</div>'%raw
     root = html.fragment_fromstring(raw)
@@ -128,6 +137,7 @@ def html_to_lxml(raw):
             from calibre.ebooks.oeb.parse_utils import _html4_parse
             return _html4_parse(raw)
 
+
 def CATALOG_ENTRY(item, item_kind, request_context, updated, catalog_name,
                   ignore_count=False, add_kind=False):
     id_ = 'calibre:category:'+item.name
@@ -137,9 +147,10 @@ def CATALOG_ENTRY(item, item_kind, request_context, updated, catalog_name,
         iid += ':'+item_kind
     href = request_context.url_for('/opds/category', category=hexlify(catalog_name), which=hexlify(iid))
     link = NAVLINK(href=href)
-    count = (_('%d books') if item.count > 1 else _('%d book'))%item.count
     if ignore_count:
         count = ''
+    else:
+        count = ngettext('one book', '{} books', item.count).format(item.count)
     if item.use_sort_as_name:
         name = item.sort
     else:
@@ -152,6 +163,7 @@ def CATALOG_ENTRY(item, item_kind, request_context, updated, catalog_name,
             link
             )
 
+
 def CATALOG_GROUP_ENTRY(item, category, request_context, updated):
     id_ = 'calibre:category-group:'+category+':'+item.text
     iid = item.text
@@ -160,16 +172,17 @@ def CATALOG_GROUP_ENTRY(item, category, request_context, updated):
         TITLE(item.text),
         ID(id_),
         UPDATED(updated),
-        E.content(_('%d items')%item.count, type='text'),
+        E.content(ngettext('one item', '{} items', item.count).format(item.count), type='text'),
         link
     )
 
+
 def ACQUISITION_ENTRY(book_id, updated, request_context):
     field_metadata = request_context.db.field_metadata
     mi = request_context.db.get_metadata(book_id)
     extra = []
     if mi.rating > 0:
-        rating = u''.join(repeat(u'\u2605', int(mi.rating/2.)))
+        rating = rating_to_stars(mi.rating)
         extra.append(_('RATING: %s<br />')%rating)
     if mi.tags:
         extra.append(_('TAGS: %s<br />')%xml(format_tag_string(mi.tags, None)))
@@ -198,16 +211,26 @@ def ACQUISITION_ENTRY(book_id, updated, request_context):
         extra.append(comments)
     if extra:
         extra = html_to_lxml('\n'.join(extra))
-    ans = E.entry(TITLE(mi.title), E.author(E.name(authors_to_string(mi.authors))), ID('urn:uuid:' + mi.uuid), UPDATED(updated))
+    ans = E.entry(TITLE(mi.title), E.author(E.name(authors_to_string(mi.authors))), ID('urn:uuid:' + mi.uuid), UPDATED(mi.last_modified),
+                  E.published(mi.timestamp.isoformat()))
+    if mi.pubdate and not is_date_undefined(mi.pubdate):
+        ans.append(ans.makeelement('{%s}date' % DC_NS))
+        ans[-1].text = mi.pubdate.isoformat()
     if len(extra):
         ans.append(E.content(extra, type='xhtml'))
     get = partial(request_context.ctx.url_for, '/get', book_id=book_id, library_id=request_context.library_id)
     if mi.formats:
+        fm = mi.format_metadata
         for fmt in mi.formats:
             fmt = fmt.lower()
             mt = guess_type('a.'+fmt)[0]
             if mt:
-                ans.append(E.link(type=mt, href=get(what=fmt), rel="http://opds-spec.org/acquisition"))
+                link = E.link(type=mt, href=get(what=fmt), rel="http://opds-spec.org/acquisition")
+                ffm = fm.get(fmt.upper())
+                if ffm:
+                    link.set('length', str(ffm['size']))
+                    link.set('mtime', ffm['mtime'].isoformat())
+                ans.append(link)
     ans.append(E.link(type='image/jpeg', href=get(what='cover'), rel="http://opds-spec.org/cover"))
     ans.append(E.link(type='image/jpeg', href=get(what='thumb'), rel="http://opds-spec.org/thumbnail"))
 
@@ -218,6 +241,7 @@ def ACQUISITION_ENTRY(book_id, updated, request_context):
 
 default_feed_title = __appname__ + ' ' + _('Library')
 
+
 class Feed(object):  # {{{
 
     def __init__(self, id_, updated, request_context, subtitle=None,
@@ -251,6 +275,7 @@ class Feed(object):  # {{{
 
     # }}}
 
+
 class TopLevel(Feed):  # {{{
 
     def __init__(self,
@@ -279,6 +304,7 @@ class TopLevel(Feed):  # {{{
             ))
 # }}}
 
+
 class NavFeed(Feed):
 
     def __init__(self, id_, updated, request_context, offsets, page_url, up_url, title=None):
@@ -295,6 +321,7 @@ class NavFeed(Feed):
             kwargs['title'] = title
         Feed.__init__(self, id_, updated, request_context, **kwargs)
 
+
 class AcquisitionFeed(NavFeed):
 
     def __init__(self, id_, updated, request_context, items, offsets, page_url, up_url, title=None):
@@ -302,6 +329,7 @@ class AcquisitionFeed(NavFeed):
         for book_id in items:
             self.root.append(ACQUISITION_ENTRY(book_id, updated, request_context))
 
+
 class CategoryFeed(NavFeed):
 
     def __init__(self, items, which, id_, updated, request_context, offsets, page_url, up_url, title=None):
@@ -313,6 +341,7 @@ class CategoryFeed(NavFeed):
             self.root.append(CATALOG_ENTRY(
                 item, item.category, request_context, updated, which, ignore_count=ignore_count, add_kind=which != item.category))
 
+
 class CategoryGroupFeed(NavFeed):
 
     def __init__(self, items, which, id_, updated, request_context, offsets, page_url, up_url, title=None):
@@ -320,6 +349,7 @@ class CategoryGroupFeed(NavFeed):
         for item in items:
             self.root.append(CATALOG_GROUP_ENTRY(item, which, request_context, updated))
 
+
 class RequestContext(object):
 
     def __init__(self, ctx, rd):
@@ -353,6 +383,7 @@ class RequestContext(object):
     def search(self, query):
         return self.ctx.search(self.rd, self.db, query)
 
+
 def get_acquisition_feed(rc, ids, offset, page_url, up_url, id_,
         sort_by='title', ascending=True, feed_title=None):
     if not ids:
@@ -367,6 +398,7 @@ def get_acquisition_feed(rc, ids, offset, page_url, up_url, id_,
         rc.outheaders['Last-Modified'] = http_date(timestampfromdt(lm))
         return AcquisitionFeed(id_, lm, rc, items, offsets, page_url, up_url, title=feed_title).root
 
+
 def get_all_books(rc, which, page_url, up_url, offset=0):
     try:
         offset = int(offset)
@@ -429,6 +461,7 @@ def get_navcatalog(request_context, which, page_url, up_url, offset=0):
 
     return ans.root
 
+
 @endpoint('/opds', postprocess=atom)
 def opds(ctx, rd):
     rc = RequestContext(ctx, rd)
@@ -459,6 +492,7 @@ def opds(ctx, rd):
     rd.outheaders['Last-Modified'] = http_date(timestampfromdt(last_modified))
     return TopLevel(last_modified, cats, rc).root
 
+
 @endpoint('/opds/navcatalog/{which}', postprocess=atom)
 def opds_navcatalog(ctx, rd, which):
     try:
@@ -478,6 +512,7 @@ def opds_navcatalog(ctx, rd, which):
         return get_navcatalog(rc, which, page_url, up_url, offset=offset)
     raise HTTPNotFound('Not found')
 
+
 @endpoint('/opds/category/{category}/{which}', postprocess=atom)
 def opds_category(ctx, rd, category, which):
     try:
@@ -555,6 +590,7 @@ def opds_categorygroup(ctx, rd, category, which):
     owhich = hexlify('N'+which)
     up_url = rc.url_for('/opds/navcatalog', which=owhich)
     items = categories[category]
+
     def belongs(x, which):
         return getattr(x, 'sort', x.name).lower().startswith(which.lower())
     items = [x for x in items if belongs(x, which)]
@@ -572,6 +608,7 @@ def opds_categorygroup(ctx, rd, category, which):
 
     return CategoryFeed(items, category, id_, updated, rc, offsets, page_url, up_url, title=feed_title).root
 
+
 @endpoint('/opds/search/{query=""}', postprocess=atom)
 def opds_search(ctx, rd, query):
     try:
