@@ -9,15 +9,18 @@ __docformat__ = 'restructuredtext en'
 
 from datetime import datetime, timedelta
 
+
 def align_block(raw, multiple=4, pad=b'\0'):
     '''
     Return raw with enough pad bytes append to ensure its length is a multiple
     of 4.
     '''
     extra = len(raw) % multiple
-    if extra == 0: return raw
+    if extra == 0:
+        return raw
     return raw + pad*(multiple - extra)
 
+
 class UnknownTable(object):
 
     def __init__(self, raw):
@@ -29,6 +32,7 @@ class UnknownTable(object):
     def __len__(self):
         return len(self.raw)
 
+
 class DateTimeProperty(object):
 
     def __init__(self, name):
@@ -42,6 +46,7 @@ class DateTimeProperty(object):
         td = val - datetime(1904, 1, 1)
         setattr(obj, self.name, int(td.total_seconds()))
 
+
 class FixedProperty(object):
 
     def __init__(self, name):
@@ -54,16 +59,18 @@ class FixedProperty(object):
     def __set__(self, obj, val):
         return int(round(val*(0x10000)))
 
+
 def max_power_of_two(x):
-	"""
-    Return the highest exponent of two, so that
-	(2 ** exponent) <= x
-	"""
-	exponent = 0
-	while x:
-		x = x >> 1
-		exponent += 1
-	return max(exponent - 1, 0)
+    """
+Return the highest exponent of two, so that
+    (2 ** exponent) <= x
+    """
+    exponent = 0
+    while x:
+        x = x >> 1
+        exponent += 1
+    return max(exponent - 1, 0)
+
 
 def load_font(stream_or_path):
     raw = stream_or_path
