@@ -1,7 +1,6 @@
 #!/usr/local/bin/python2.7
 # vim:fileencoding=utf-8
-from __future__ import (unicode_literals, division, absolute_import,
-                        print_function)
+from __future__ import (unicode_literals, division, absolute_import, print_function)
 
 __license__ = 'GPL v3'
 __copyright__ = '2014, Kovid Goyal <kovid at kovidgoyal.net>'
@@ -26,9 +25,11 @@ DEFAULT_LEVEL1 = '/'
 DEFAULT_LEVEL2 = '-_ 0123456789'
 DEFAULT_LEVEL3 = '.'
 
+
 class PluginFailed(RuntimeError):
     pass
 
+
 class Worker(Thread):
 
     daemon = True
@@ -36,7 +37,7 @@ class Worker(Thread):
     def __init__(self, requests, results):
         Thread.__init__(self)
         self.requests, self.results = requests, results
-        atexit.register(lambda : requests.put(None))
+        atexit.register(lambda: requests.put(None))
 
     def run(self):
         while True:
@@ -50,9 +51,12 @@ class Worker(Thread):
                 self.results.put((False, as_unicode(e)))
                 # import traceback
                 # traceback.print_exc()
+
+
 wlock = Lock()
 workers = []
 
+
 def split(tasks, pool_size):
     '''
     Split a list into a list of sub lists, with the number of sub lists being
@@ -61,23 +65,32 @@ def split(tasks, pool_size):
     and i is the index of the element x in the original list.
     '''
     ans, count = [], 0
-    delta = int(ceil(len(tasks)/pool_size))
+    delta = int(ceil(len(tasks) / pool_size))
     while tasks:
-        section = [(count+i, task) for i, task in enumerate(tasks[:delta])]
+        section = [(count + i, task) for i, task in enumerate(tasks[:delta])]
         tasks = tasks[delta:]
         count += len(section)
         ans.append(section)
     return ans
 
+
 def default_scorer(*args, **kwargs):
     try:
         return CScorer(*args, **kwargs)
     except PluginFailed:
         return PyScorer(*args, **kwargs)
 
+
 class Matcher(object):
 
-    def __init__(self, items, level1=DEFAULT_LEVEL1, level2=DEFAULT_LEVEL2, level3=DEFAULT_LEVEL3, scorer=None):
+    def __init__(
+        self,
+        items,
+        level1=DEFAULT_LEVEL1,
+        level2=DEFAULT_LEVEL2,
+        level3=DEFAULT_LEVEL3,
+        scorer=None
+    ):
         with wlock:
             if not workers:
                 requests, results = Queue(), Queue()
@@ -87,9 +100,11 @@ class Matcher(object):
         items = map(lambda x: normalize('NFC', unicode(x)), filter(None, items))
         self.items = items = tuple(items)
         tasks = split(items, len(workers))
-        self.task_maps = [{j:i for j, (i, _) in enumerate(task)} for task in tasks]
+        self.task_maps = [{j: i for j, (i, _) in enumerate(task)} for task in tasks]
         scorer = scorer or default_scorer
-        self.scorers = [scorer(tuple(map(itemgetter(1), task_items))) for task_items in tasks]
+        self.scorers = [
+            scorer(tuple(map(itemgetter(1), task_items))) for task_items in tasks
+        ]
         self.sort_keys = None
 
     def __call__(self, query, limit=None):
@@ -98,7 +113,10 @@ class Matcher(object):
             for i, scorer in enumerate(self.scorers):
                 workers[0].requests.put((i, scorer, query))
             if self.sort_keys is None:
-                self.sort_keys = {i:primary_sort_key(x) for i, x in enumerate(self.items)}
+                self.sort_keys = {
+                    i: primary_sort_key(x)
+                    for i, x in enumerate(self.items)
+                }
             num = len(self.task_maps)
             scores, positions = {}, {}
             error = None
@@ -117,12 +135,14 @@ class Matcher(object):
 
         if error is not None:
             raise Exception('Failed to score items: %s' % error)
-        items = sorted(((-scores[i], item, positions[i]) for i, item in enumerate(self.items)),
+        items = sorted(((-scores[i], item, positions[i])
+                        for i, item in enumerate(self.items)),
                        key=itemgetter(0))
         if limit is not None:
             del items[limit:]
         return OrderedDict(x[1:] for x in filter(itemgetter(0), items))
 
+
 def get_items_from_dir(basedir, acceptq=lambda x: True):
     if isinstance(basedir, bytes):
         basedir = basedir.decode(filesystem_encoding)
@@ -136,19 +156,25 @@ def get_items_from_dir(basedir, acceptq=lambda x: True):
                     x = x.replace(os.sep, '/')
                 yield x
 
+
 class FilesystemMatcher(Matcher):
 
     def __init__(self, basedir, *args, **kwargs):
         Matcher.__init__(self, get_items_from_dir(basedir), *args, **kwargs)
 
+
 # Python implementation of the scoring algorithm {{{
+
+
 def calc_score_for_char(ctx, prev, current, distance):
     factor = 1.0
     ans = ctx.max_score_per_char
 
     if prev in ctx.level1:
         factor = 0.9
-    elif prev in ctx.level2 or (icu_lower(prev) == prev and icu_upper(current) == current):
+    elif prev in ctx.level2 or (
+        icu_lower(prev) == prev and icu_upper(current) == current
+    ):
         factor = 0.8
     elif prev in ctx.level3:
         factor = 0.7
@@ -157,9 +183,10 @@ def calc_score_for_char(ctx, prev, current, distance):
 
     return ans * factor
 
+
 def process_item(ctx, haystack, needle):
     # non-recursive implementation using a stack
-    stack = [(0, 0, 0, 0, [-1]*len(needle))]
+    stack = [(0, 0, 0, 0, [-1] * len(needle))]
     final_score, final_positions = stack[0][-2:]
     push, pop = stack.append, stack.pop
     while stack:
@@ -179,7 +206,9 @@ def process_item(ctx, haystack, needle):
                 pos += hidx
 
                 distance = pos - last_idx
-                score_for_char = ctx.max_score_per_char if distance <= 1 else calc_score_for_char(ctx, haystack[pos-1], haystack[pos], distance)
+                score_for_char = ctx.max_score_per_char if distance <= 1 else calc_score_for_char(
+                    ctx, haystack[pos - 1], haystack[pos], distance
+                )
                 hidx = pos + 1
                 push((hidx, i, last_idx, score, list(positions)))
                 last_idx = positions[i] = pos
@@ -192,10 +221,19 @@ def process_item(ctx, haystack, needle):
             final_positions = positions
     return final_score, final_positions
 
-class PyScorer(object):
-    __slots__ = ('level1', 'level2', 'level3', 'max_score_per_char', 'items', 'memory')
 
-    def __init__(self, items, level1=DEFAULT_LEVEL1, level2=DEFAULT_LEVEL2, level3=DEFAULT_LEVEL3):
+class PyScorer(object):
+    __slots__ = (
+        'level1', 'level2', 'level3', 'max_score_per_char', 'items', 'memory'
+    )
+
+    def __init__(
+        self,
+        items,
+        level1=DEFAULT_LEVEL1,
+        level2=DEFAULT_LEVEL2,
+        level3=DEFAULT_LEVEL3
+    ):
         self.level1, self.level2, self.level3 = level1, level2, level3
         self.max_score_per_char = 0
         self.items = items
@@ -205,21 +243,37 @@ class PyScorer(object):
             self.max_score_per_char = (1.0 / len(item) + 1.0 / len(needle)) / 2.0
             self.memory = {}
             yield process_item(self, item, needle)
+
+
 # }}}
 
+
 class CScorer(object):
 
-    def __init__(self, items, level1=DEFAULT_LEVEL1, level2=DEFAULT_LEVEL2, level3=DEFAULT_LEVEL3):
+    def __init__(
+        self,
+        items,
+        level1=DEFAULT_LEVEL1,
+        level2=DEFAULT_LEVEL2,
+        level3=DEFAULT_LEVEL3
+    ):
         speedup, err = plugins['matcher']
         if speedup is None:
-            raise PluginFailed('Failed to load the matcher plugin with error: %s' % err)
-        self.m = speedup.Matcher(items, primary_collator().capsule, unicode(level1), unicode(level2), unicode(level3))
+            raise PluginFailed(
+                'Failed to load the matcher plugin with error: %s' % err
+            )
+        self.m = speedup.Matcher(
+            items,
+            primary_collator().capsule,
+            unicode(level1), unicode(level2), unicode(level3)
+        )
 
     def __call__(self, query):
         scores, positions = self.m.calculate_scores(query)
         for score, pos in izip(scores, positions):
             yield score, pos
 
+
 def test(return_tests=False):
     import unittest
 
@@ -230,9 +284,16 @@ def test(return_tests=False):
             from calibre.utils.mem import get_memory as memory
             m = Matcher(['a'], scorer=CScorer)
             m('a')
+
             def doit(c):
-                m = Matcher([c+'im/one.gif', c+'im/two.gif', c+'text/one.html',], scorer=CScorer)
+                m = Matcher([
+                    c + 'im/one.gif',
+                    c + 'im/two.gif',
+                    c + 'text/one.html',
+                ],
+                            scorer=CScorer)
                 m('one')
+
             start = memory()
             for i in xrange(10):
                 doit(str(i))
@@ -243,13 +304,16 @@ def test(return_tests=False):
                 doit(str(i))
             gc.collect()
             used100 = memory() - start
-            self.assertLessEqual(used100, 2 * used10)
+            if used100 > 0 and used10 > 0:
+                self.assertLessEqual(used100, 2 * used10)
 
         def test_non_bmp(self):
             raw = '_\U0001f431-'
             m = Matcher([raw], scorer=CScorer)
             positions = next(m(raw).itervalues())
-            self.assertEqual(positions, (0, 1, (2 if sys.maxunicode >= 0x10ffff else 3)))
+            self.assertEqual(
+                positions, (0, 1, (2 if sys.maxunicode >= 0x10ffff else 3))
+            )
 
     if return_tests:
         return unittest.TestLoader().loadTestsFromTestCase(Test)
@@ -262,19 +326,24 @@ def test(return_tests=False):
 
     TestRunner(verbosity=4)
 
+
 if sys.maxunicode >= 0x10ffff:
     get_char = lambda string, pos: string[pos]
 else:
+
     def get_char(string, pos):
-        chs = 2 if ('\ud800' <= string[pos] <= '\udbff') else 1  # UTF-16 surrogate pair in python narrow builds
-        return string[pos:pos+chs]
+        chs = 2 if ('\ud800' <= string[pos] <= '\udbff'
+                    ) else 1  # UTF-16 surrogate pair in python narrow builds
+        return string[pos:pos + chs]
+
 
 def main(basedir=None, query=None):
     from calibre import prints
     from calibre.utils.terminal import ColoredStream
     if basedir is None:
         try:
-            basedir = raw_input('Enter directory to scan [%s]: ' % os.getcwdu()).decode(sys.stdin.encoding).strip() or os.getcwdu()
+            basedir = raw_input('Enter directory to scan [%s]: ' % os.getcwdu()
+                                ).decode(sys.stdin.encoding).strip() or os.getcwdu()
         except (EOFError, KeyboardInterrupt):
             return
     m = FilesystemMatcher(basedir)
@@ -302,6 +371,7 @@ def main(basedir=None, query=None):
             prints(path[p:])
         query = None
 
+
 if __name__ == '__main__':
     # main(basedir='/t', query='ns')
     # test()
