@@ -14,7 +14,7 @@ from contextlib import nested, closing
 
 
 from calibre import (browser, __appname__, iswindows, force_unicode,
-                    strftime, preferred_encoding, as_unicode)
+                    strftime, preferred_encoding, as_unicode, random_user_agent)
 from calibre.ebooks.BeautifulSoup import BeautifulSoup, NavigableString, CData, Tag
 from calibre.ebooks.metadata.opf2 import OPFCreator
 from calibre import entity_to_unicode
@@ -22,20 +22,25 @@ from calibre.web import Recipe
 from calibre.ebooks.metadata.toc import TOC
 from calibre.ebooks.metadata import MetaInformation
 from calibre.web.feeds import feed_from_xml, templates, feeds_from_index, Feed
-from calibre.web.fetch.simple import option_parser as web2disk_option_parser
-from calibre.web.fetch.simple import RecursiveFetcher
+from calibre.web.fetch.simple import option_parser as web2disk_option_parser, RecursiveFetcher, AbortArticle
+from calibre.web.fetch.utils import prepare_masthead_image
 from calibre.utils.threadpool import WorkRequest, ThreadPool, NoResultsPending
 from calibre.ptempfile import PersistentTemporaryFile
 from calibre.utils.date import now as nowf
-from calibre.utils.magick.draw import save_cover_data_to, add_borders_to_image
+from calibre.utils.icu import numeric_sort_key
+from calibre.utils.img import save_cover_data_to, add_borders_to_image, image_to_data
 from calibre.utils.localization import canonicalize_lang
+from calibre.utils.logging import ThreadSafeWrapper
+
 
 class LoginFailed(ValueError):
     pass
 
+
 class DownloadDenied(ValueError):
     pass
 
+
 class BasicNewsRecipe(Recipe):
     '''
     Base class that contains logic needed in all recipes. By overriding
@@ -44,7 +49,7 @@ class BasicNewsRecipe(Recipe):
     to creating recipes, see :doc:`news`.
     '''
 
-    #: The title to use for the ebook
+    #: The title to use for the e-book
     title                  = _('Unknown News Source')
 
     #: A couple of lines that describe the content this recipe downloads.
@@ -92,7 +97,7 @@ class BasicNewsRecipe(Recipe):
     #: By default: Day_Name, Day_Number Month_Name Year
     timefmt                = ' [%a, %d %b %Y]'
 
-    #: List of feeds to download
+    #: List of feeds to download.
     #: Can be either ``[url1, url2, ...]`` or ``[('title1', url1), ('title2', url2),...]``
     feeds = None
 
@@ -101,7 +106,7 @@ class BasicNewsRecipe(Recipe):
 
     #: Convenient flag to disable loading of stylesheets for websites
     #: that have overly complex stylesheets unsuitable for conversion
-    #: to ebooks formats
+    #: to e-book formats.
     #: If True stylesheets are not downloaded and processed
     no_stylesheets         = False
 
@@ -109,7 +114,7 @@ class BasicNewsRecipe(Recipe):
     remove_javascript      = True
 
     #: If True the GUI will ask the user for a username and password
-    #: to use while downloading
+    #: to use while downloading.
     #: If set to "optional" the use of a username and password becomes optional
     needs_subscription     = False
 
@@ -143,7 +148,7 @@ class BasicNewsRecipe(Recipe):
     #: manually (though manual cleanup will always be superior).
     auto_cleanup = False
 
-    #: Specify elements that the auto cleanup algorithm should never remove
+    #: Specify elements that the auto cleanup algorithm should never remove.
     #: The syntax is a XPath expression. For example::
     #:
     #:   auto_cleanup_keep = '//div[@id="article-image"]' will keep all divs with
@@ -156,10 +161,12 @@ class BasicNewsRecipe(Recipe):
     #:
     auto_cleanup_keep = None
 
-    #: Specify any extra :term:`CSS` that should be added to downloaded :term:`HTML` files
+    #: Specify any extra :term:`CSS` that should be added to downloaded :term:`HTML` files.
     #: It will be inserted into `<style>` tags, just before the closing
     #: `</head>` tag thereby overriding all :term:`CSS` except that which is
     #: declared using the style attribute on individual :term:`HTML` tags.
+    #: Note that if you want to programmatically generate the extra_css override
+    #: the :meth:`get_extra_css()` method instead.
     #: For example::
     #:
     #:     extra_css = '.heading { font: serif x-large }'
@@ -173,7 +180,7 @@ class BasicNewsRecipe(Recipe):
     #: the ignore_duplicate_articles option.
     remove_empty_feeds = False
 
-    #: List of regular expressions that determines which links to follow
+    #: List of regular expressions that determines which links to follow.
     #: If empty, it is ignored. Used only if is_link_wanted is
     #: not implemented. For example::
     #:
@@ -185,7 +192,7 @@ class BasicNewsRecipe(Recipe):
     #: :attr:`BasicNewsRecipe.filter_regexps` should be defined.
     match_regexps         = []
 
-    #: List of regular expressions that determines which links to ignore
+    #: List of regular expressions that determines which links to ignore.
     #: If empty it is ignored. Used only if is_link_wanted is not
     #: implemented. For example::
     #:
@@ -219,7 +226,7 @@ class BasicNewsRecipe(Recipe):
     #:    }
     #:
     #: All keys are optional. For a full explanation of the search criteria, see
-    #: `Beautiful Soup <http://www.crummy.com/software/BeautifulSoup/bs3/documentation.html#Searching%20the%20Parse%20Tree>`_
+    #: `Beautiful Soup <https://www.crummy.com/software/BeautifulSoup/bs3/documentation.html#Searching%20the%20Parse%20Tree>`_
     #: A common example::
     #:
     #:   remove_tags = [dict(name='div', attrs={'class':'advert'})]
@@ -248,7 +255,7 @@ class BasicNewsRecipe(Recipe):
     #: tags before the first element with `id="content"`.
     remove_tags_before    = None
 
-    #: List of attributes to remove from all tags
+    #: List of attributes to remove from all tags.
     #: For example::
     #:
     #:   remove_attributes = ['style', 'font']
@@ -275,7 +282,7 @@ class BasicNewsRecipe(Recipe):
     #:         lambda match: '</body>'),
     #:     ]
     #:
-    #: will remove everythong from `<!--Article ends here-->` to `</body>`.
+    #: will remove everything from `<!--Article ends here-->` to `</body>`.
     preprocess_regexps    = []
 
     #: The CSS that is used to style the templates, i.e., the navigation bars and
@@ -313,31 +320,30 @@ class BasicNewsRecipe(Recipe):
     #: are expressed as a percentage of the downloaded cover.
     #: cover_margins = (10, 15, '#ffffff') pads the cover with a white margin
     #: 10px on the left and right, 15px on the top and bottom.
-    #: Color names defined at http://www.imagemagick.org/script/color.php
-    #: Note that for some reason, white does not always work on windows. Use
+    #: Color names defined at https://www.imagemagick.org/script/color.php
+    #: Note that for some reason, white does not always work in Windows. Use
     #: #ffffff instead
     cover_margins = (0, 0, '#ffffff')
 
-    #: Set to a non empty string to disable this recipe
+    #: Set to a non empty string to disable this recipe.
     #: The string will be used as the disabled message
     recipe_disabled = None
 
     #: Ignore duplicates of articles that are present in more than one section.
     #: A duplicate article is an article that has the same title and/or URL.
-    #: To ignore articles with the same title, set this to:
-    #: ignore_duplicate_articles = {'title'}
-    #: To use URLs instead, set it to:
-    #: ignore_duplicate_articles = {'url'}
-    #: To match on title or URL, set it to:
-    #: ignore_duplicate_articles = {'title', 'url'}
+    #: To ignore articles with the same title, set this to::
+    #:
+    #:   ignore_duplicate_articles = {'title'}
+    #:
+    #: To use URLs instead, set it to::
+    #:
+    #:   ignore_duplicate_articles = {'url'}
+    #:
+    #: To match on title or URL, set it to::
+    #:
+    #:   ignore_duplicate_articles = {'title', 'url'}
     ignore_duplicate_articles = None
 
-    #: If you set this True, then calibre will use javascript to login to the
-    #: website. This is needed for some websites that require the use of
-    #: javascript to login. If you set this to True you must implement the
-    #: :meth:`javascript_login` method, to do the actual logging in.
-    use_javascript_to_login = False
-
     # The following parameters control how the recipe attempts to minimize
     # jpeg image sizes
 
@@ -377,7 +383,17 @@ class BasicNewsRecipe(Recipe):
     #: assigned (default None).
     scale_news_images = None
 
-    # See the built-in profiles for examples of these settings.
+    #: If set to True then links in downloaded articles that point to other downloaded articles are
+    #: changed to point to the downloaded copy of the article rather than its original web URL. If you
+    #: set this to True, you might also need to implement :meth:`canonicalize_internal_url` to work
+    #: with the URL scheme of your particular website.
+    resolve_internal_links = False
+
+    #: Set to True if you want to use gziped transfers. Note that some old servers flake out with this
+    #: so it is off by default.
+    handle_gzip = False
+
+    # See the built-in recipes for examples of these settings.
 
     def short_title(self):
         return self.title
@@ -389,10 +405,17 @@ class BasicNewsRecipe(Recipe):
         ignore it.
 
         :param url: The URL to be followed
-        :param tag: The Tag from which the URL was derived
+        :param tag: The tag from which the URL was derived
         '''
         raise NotImplementedError
 
+    def get_extra_css(self):
+        '''
+        By default returns `self.extra_css`. Override if you want to programmatically generate the
+        extra_css.
+        '''
+        return self.extra_css
+
     def get_cover_url(self):
         '''
         Return a :term:`URL` to the cover image for this issue or `None`.
@@ -449,10 +472,18 @@ class BasicNewsRecipe(Recipe):
         '''
         return url
 
+    def preprocess_image(self, img_data, image_url):
+        '''
+        Perform some processing on downloaded image data. This is called on the raw
+        data before any resizing is done. Must return the processed raw data. Return
+        None to skip the image.
+        '''
+        return img_data
+
     def get_browser(self, *args, **kwargs):
         '''
         Return a browser instance used to fetch documents from the web. By default
-        it returns a `mechanize <http://wwwsearch.sourceforge.net/mechanize/>`_
+        it returns a `mechanize <https://github.com/jjlee/mechanize>`_
         browser instance that supports cookies, ignores robots.txt, handles
         refreshes and has a mozilla firefox user agent.
 
@@ -463,7 +494,7 @@ class BasicNewsRecipe(Recipe):
             def get_browser(self):
                 br = BasicNewsRecipe.get_browser(self)
                 if self.username is not None and self.password is not None:
-                    br.open('http://www.nytimes.com/auth/login')
+                    br.open('https://www.nytimes.com/auth/login')
                     br.select_form(name='login')
                     br['USERID']   = self.username
                     br['PASSWORD'] = self.password
@@ -471,47 +502,14 @@ class BasicNewsRecipe(Recipe):
                 return br
 
         '''
-        if self.use_javascript_to_login:
-            if getattr(self, 'browser', None) is not None:
-                return self.clone_browser(self.browser)
-            from calibre.web.jsbrowser.browser import Browser
-            br = Browser()
-            with br:
-                self.javascript_login(br, self.username, self.password)
-                kwargs['user_agent'] = br.user_agent
-                ans = browser(*args, **kwargs)
-                ans.copy_cookies_from_jsbrowser(br)
-            return ans
-        else:
-            br = browser(*args, **kwargs)
-            br.addheaders += [('Accept', '*/*')]
-            return br
-
-    def javascript_login(self, browser, username, password):
-        '''
-        This method is used to login to a website that uses javascript for its
-        login form. After the login is complete, the cookies returned from the
-        website are copied to a normal (non-javascript) browser and the
-        download proceeds using those cookies.
-
-        An example implementation::
-
-            def javascript_login(self, browser, username, password):
-                browser.visit('http://some-page-that-has-a-login')
-                form = browser.select_form(nr=0) # Select the first form on the page
-                form['username'] = username
-                form['password'] = password
-                browser.submit(timeout=120) # Submit the form and wait at most two minutes for loading to complete
-
-        Note that you can also select forms with CSS2 selectors, like this::
-
-            browser.select_form('form#login_form')
-            browser.select_from('form[name="someform"]')
-
-        '''
-        raise NotImplementedError('You must implement the javascript_login()'
-                                  ' method if you set use_javascript_to_login'
-                                  ' to True')
+        if 'user_agent' not in kwargs:
+            # More and more news sites are serving JPEG XR images to IE
+            kwargs['user_agent'] = random_user_agent(allow_ie=False)
+        br = browser(*args, **kwargs)
+        br.addheaders += [('Accept', '*/*')]
+        if self.handle_gzip:
+            br.set_handle_gzip(True)
+        return br
 
     def clone_browser(self, br):
         '''
@@ -545,16 +543,16 @@ class BasicNewsRecipe(Recipe):
         Override in a subclass to customize extraction of the :term:`URL` that points
         to the content for each article. Return the
         article URL. It is called with `article`, an object representing a parsed article
-        from a feed. See `feedparser <http://packages.python.org/feedparser/>`_.
+        from a feed. See `feedparser <https://pythonhosted.org/feedparser/>`_.
         By default it looks for the original link (for feeds syndicated via a
         service like feedburner or pheedo) and if found,
         returns that or else returns
-        `article.link <http://packages.python.org/feedparser/reference-entry-link.html>`_.
+        `article.link <https://pythonhosted.org/feedparser/reference-entry-link.html>`_.
         '''
         for key in article.keys():
             if key.endswith('_origlink'):
                 url = article[key]
-                if url and url.startswith('http://'):
+                if url and (url.startswith('http://') or url.startswith('https://')):
                     return url
         ans = article.get('link', None)
         if not ans and getattr(article, 'links', None):
@@ -573,11 +571,17 @@ class BasicNewsRecipe(Recipe):
         an ad page, return the HTML of the real page. Otherwise return
         None.
 
-        `soup`: A `BeautifulSoup <http://www.crummy.com/software/BeautifulSoup/documentation.html>`_
+        `soup`: A `BeautifulSoup <https://www.crummy.com/software/BeautifulSoup/bs3/documentation.html>`_
         instance containing the downloaded :term:`HTML`.
         '''
         return None
 
+    def abort_article(self, msg=None):
+        ''' Call this method inside any of the preprocess methods to abort the
+        download for the current article. Useful to skip articles that contain
+        inappropriate content, such as pure video articles. '''
+        raise AbortArticle(msg or _('Article download aborted'))
+
     def preprocess_raw_html(self, raw_html, url):
         '''
         This method is called with the source of each downloaded :term:`HTML` file, before
@@ -609,7 +613,7 @@ class BasicNewsRecipe(Recipe):
         It can be used to do arbitrarily powerful pre-processing on the :term:`HTML`.
         It should return `soup` after processing it.
 
-        `soup`: A `BeautifulSoup <http://www.crummy.com/software/BeautifulSoup/documentation.html>`_
+        `soup`: A `BeautifulSoup <https://www.crummy.com/software/BeautifulSoup/bs3/documentation.html>`_
         instance containing the downloaded :term:`HTML`.
         '''
         return soup
@@ -621,7 +625,7 @@ class BasicNewsRecipe(Recipe):
         It can be used to do arbitrarily powerful post-processing on the :term:`HTML`.
         It should return `soup` after processing it.
 
-        :param soup: A `BeautifulSoup <http://www.crummy.com/software/BeautifulSoup/documentation.html>`_  instance containing the downloaded :term:`HTML`.
+        :param soup: A `BeautifulSoup <https://www.crummy.com/software/BeautifulSoup/bs3/documentation.html>`_  instance containing the downloaded :term:`HTML`.
         :param first_fetch: True if this is the first page of an article.
 
         '''
@@ -634,10 +638,29 @@ class BasicNewsRecipe(Recipe):
         '''
         pass
 
+    def canonicalize_internal_url(self, url, is_link=True):
+        '''
+        Return a set of canonical representations of ``url``.  The default
+        implementation uses just the server hostname and path of the URL,
+        ignoring any query parameters, fragments, etc. The canonical
+        representations must be unique across all URLs for this news source. If
+        they are not, then internal links may be resolved incorrectly.
+
+        :param is_link: Is True if the URL is coming from an internal link in
+                        an HTML file. False if the URL is the URL used to
+                        download an article.
+        '''
+        try:
+            parts = urlparse.urlparse(url)
+        except Exception:
+            self.log.error('Failed to parse url: %r, ignoring' % url)
+            return frozenset()
+        return frozenset([(parts.netloc, (parts.path or '').rstrip('/'))])
+
     def index_to_soup(self, url_or_raw, raw=False, as_tree=False):
         '''
         Convenience method that takes an URL to the index page and returns
-        a `BeautifulSoup <http://www.crummy.com/software/BeautifulSoup/documentation.html>`_
+        a `BeautifulSoup <https://www.crummy.com/software/BeautifulSoup/bs3/documentation.html>`_
         of it.
 
         `url_or_raw`: Either a URL or the downloaded index page as a string
@@ -817,9 +840,9 @@ class BasicNewsRecipe(Recipe):
         Called when each HTML page belonging to article is downloaded.
         Intended to be used to get article metadata like author/summary/etc.
         from the parsed HTML (soup).
+
         :param article: A object of class :class:`calibre.web.feeds.Article`.
-        If you change the summary, remember to also change the
-        text_summary
+            If you change the summary, remember to also change the text_summary
         :param soup: Parsed HTML belonging to this article
         :param first: True iff the parsed HTML is the first page of the article.
         '''
@@ -838,10 +861,10 @@ class BasicNewsRecipe(Recipe):
         '''
         Initialize the recipe.
         :param options: Parsed commandline options
-        :param parser:  Command line option parser. Used to intelligently merge options.
+        :param log:  Logging object
         :param progress_reporter: A Callable that takes two arguments: progress (a number between 0 and 1) and a string message. The message should be optional.
         '''
-        self.log = log
+        self.log = ThreadSafeWrapper(log)
         if not isinstance(self.title, unicode):
             self.title = unicode(self.title, 'utf-8', 'replace')
 
@@ -914,6 +937,7 @@ class BasicNewsRecipe(Recipe):
             setattr(self.web2disk_options, extra, getattr(self, extra))
 
         self.web2disk_options.postprocess_html = self._postprocess_html
+        self.web2disk_options.preprocess_image = self.preprocess_image
         self.web2disk_options.encoding = self.encoding
         self.web2disk_options.preprocess_raw_html = self.preprocess_raw_html_
 
@@ -927,15 +951,18 @@ class BasicNewsRecipe(Recipe):
 
     def _postprocess_html(self, soup, first_fetch, job_info):
         if self.no_stylesheets:
-            for link in list(soup.findAll('link', type=re.compile('css')))+list(soup.findAll('style')):
-                link.extract()
+            for link in soup.findAll('link'):
+                if (link.get('type') or 'text/css').lower() == 'text/css' and (link.get('rel') or 'stylesheet').lower() == 'stylesheet':
+                    link.extract()
+            for style in soup.findAll('style'):
+                style.extract()
         head = soup.find('head')
         if not head:
             head = soup.find('body')
         if not head:
             head = soup.find(True)
         style = BeautifulSoup(u'<style type="text/css" title="override_css">%s</style>'%(
-            self.template_css +'\n\n'+(self.extra_css if self.extra_css else ''))).find('style')
+            self.template_css +'\n\n'+(self.get_extra_css() or ''))).find('style')
         head.insert(len(head.contents), style)
         if first_fetch and job_info:
             url, f, a, feed_len = job_info
@@ -945,7 +972,7 @@ class BasicNewsRecipe(Recipe):
                                              not self.has_single_feed,
                                              url, __appname__,
                                              center=self.center_navbar,
-                                             extra_css=self.extra_css)
+                                             extra_css=self.get_extra_css() or '')
                 elem = BeautifulSoup(templ.render(doctype='xhtml').decode('utf-8')).find('div')
                 body.insert(0, elem)
         if self.remove_javascript:
@@ -1024,7 +1051,7 @@ class BasicNewsRecipe(Recipe):
         templ = (templates.TouchscreenIndexTemplate if self.touchscreen else
                 templates.IndexTemplate)
         templ = templ(lang=self.lang_for_html)
-        css = self.template_css + '\n\n' +(self.extra_css if self.extra_css else '')
+        css = self.template_css + '\n\n' +(self.get_extra_css() or '')
         timefmt = self.timefmt
         return templ.generate(self.title, "mastheadImage.jpg", timefmt, feeds,
                               extra_css=css).render(doctype='xhtml')
@@ -1033,12 +1060,13 @@ class BasicNewsRecipe(Recipe):
     def description_limiter(cls, src):
         if not src:
             return ''
+        src = force_unicode(src, 'utf-8')
         pos = cls.summary_length
         fuzz = 50
-        si = src.find(';', pos)
+        si = src.find(u';', pos)
         if si > 0 and si-pos > fuzz:
             si = -1
-        gi = src.find('>', pos)
+        gi = src.find(u'>', pos)
         if gi > 0 and gi-pos > fuzz:
             gi = -1
         npos = max(si, gi)
@@ -1046,8 +1074,9 @@ class BasicNewsRecipe(Recipe):
             npos = pos
         ans = src[:npos+1]
         if len(ans) < len(src):
-            return (ans+u'\u2026') if isinstance(ans, unicode) else (ans +
-                    '...')
+            from calibre.utils.cleantext import clean_xml_chars
+            # Truncating the string could cause a dangling UTF-16 half-surrogate, which will cause lxml to barf, clean it
+            ans = clean_xml_chars(ans) + u'\u2026'
         return ans
 
     def feed2index(self, f, feeds):
@@ -1079,7 +1108,7 @@ class BasicNewsRecipe(Recipe):
         templ = (templates.TouchscreenFeedTemplate if self.touchscreen else
                     templates.FeedTemplate)
         templ = templ(lang=self.lang_for_html)
-        css = self.template_css + '\n\n' +(self.extra_css if self.extra_css else '')
+        css = self.template_css + '\n\n' +(self.get_extra_css() or '')
 
         return templ.generate(f, feeds, self.description_limiter,
                               extra_css=css).render(doctype='xhtml')
@@ -1228,7 +1257,9 @@ class BasicNewsRecipe(Recipe):
         for req in self.jobs:
             tp.putRequest(req, block=True, timeout=0)
 
-        self.report_progress(0, _('Starting download [%d thread(s)]...')%self.simultaneous_downloads)
+        self.report_progress(0, ngettext(
+            'Starting download in a single thread...',
+            'Starting download [{} threads]...', self.simultaneous_downloads).format(self.simultaneous_downloads))
         while True:
             try:
                 tp.poll()
@@ -1279,10 +1310,10 @@ class BasicNewsRecipe(Recipe):
             if not cdata:
                 return
             if self.cover_margins[0] or self.cover_margins[1]:
-                cdata = add_borders_to_image(cdata,
+                cdata = image_to_data(add_borders_to_image(cdata,
                             left=self.cover_margins[0],right=self.cover_margins[0],
                             top=self.cover_margins[1],bottom=self.cover_margins[1],
-                            border_color=self.cover_margins[2])
+                            border_color=self.cover_margins[2]))
 
             cpath = os.path.join(self.output_dir, 'cover.jpg')
             save_cover_data_to(cdata, cpath)
@@ -1350,14 +1381,14 @@ class BasicNewsRecipe(Recipe):
 
     def default_cover(self, cover_file):
         '''
-        Create a generic cover for recipes that dont have a cover
+        Create a generic cover for recipes that don't have a cover
         '''
         try:
-            from calibre.ebooks import calibre_cover
+            from calibre.ebooks.covers import create_cover
             title = self.title if isinstance(self.title, unicode) else \
                     self.title.decode(preferred_encoding, 'replace')
-            date = strftime(self.timefmt)
-            img_data = calibre_cover(title, date)
+            date = strftime(self.timefmt).replace('[', '').replace(']', '')
+            img_data = create_cover(title, [date])
             cover_file.write(img_data)
             cover_file.flush()
         except:
@@ -1378,22 +1409,7 @@ class BasicNewsRecipe(Recipe):
                 width=self.MI_WIDTH, height=self.MI_HEIGHT)
 
     def prepare_masthead_image(self, path_to_image, out_path):
-        from calibre import fit_image
-        from calibre.utils.magick import Image, create_canvas
-
-        img = Image()
-        img.open(path_to_image)
-        width, height = img.size
-        scaled, nwidth, nheight = fit_image(width, height, self.MI_WIDTH, self.MI_HEIGHT)
-        img2 = create_canvas(width, height)
-        frame = create_canvas(self.MI_WIDTH, self.MI_HEIGHT)
-        img2.compose(img)
-        if scaled:
-            img2.size = (nwidth, nheight, 'LanczosFilter', 0.5)
-        left = int((self.MI_WIDTH - nwidth)/2.0)
-        top = int((self.MI_HEIGHT - nheight)/2.0)
-        frame.compose(img2, left, top)
-        frame.save(out_path)
+        prepare_masthead_image(path_to_image, out_path, self.MI_WIDTH, self.MI_HEIGHT)
 
     def create_opf(self, feeds, dir=None):
         if dir is None:
@@ -1468,6 +1484,8 @@ class BasicNewsRecipe(Recipe):
         self.play_order_counter = 0
         self.play_order_map = {}
 
+        self.article_url_map = aumap = defaultdict(set)
+
         def feed_index(num, parent):
             f = feeds[num]
             for j, a in enumerate(f):
@@ -1487,8 +1505,11 @@ class BasicNewsRecipe(Recipe):
                     if po is None:
                         self.play_order_counter += 1
                         po = self.play_order_counter
-                    parent.add_item('%sindex.html'%adir, None,
-                            a.title if a.title else _('Untitled Article'),
+                    arelpath = '%sindex.html'%adir
+                    for curl in self.canonicalize_internal_url(a.orig_url, is_link=False):
+                        aumap[curl].add(arelpath)
+                    parent.add_item(arelpath, None,
+                            a.title if a.title else _('Untitled article'),
                             play_order=po, author=auth,
                             description=desc, toc_thumbnail=tt)
                     last = os.path.join(self.output_dir, ('%sindex.html'%adir).replace('/', os.sep))
@@ -1566,13 +1587,19 @@ class BasicNewsRecipe(Recipe):
 
     def error_in_article_download(self, request, traceback):
         self.jobs_done += 1
-        self.log.error('Failed to download article:', request.article.title,
-        'from', request.article.url)
-        self.log.debug(traceback)
-        self.log.debug('\n')
-        self.report_progress(float(self.jobs_done)/len(self.jobs),
-                _('Article download failed: %s')%force_unicode(request.article.title))
-        self.failed_downloads.append((request.feed, request.article, traceback))
+        if traceback and re.search('^AbortArticle:', traceback, flags=re.M) is not None:
+            self.log.warn('Aborted download of article:', request.article.title,
+                          'from', request.article.url)
+            self.report_progress(float(self.jobs_done)/len(self.jobs),
+                _('Article download aborted: %s')%force_unicode(request.article.title))
+        else:
+            self.log.error('Failed to download article:', request.article.title,
+            'from', request.article.url)
+            self.log.debug(traceback)
+            self.log.debug('\n')
+            self.report_progress(float(self.jobs_done)/len(self.jobs),
+                    _('Article download failed: %s')%force_unicode(request.article.title))
+            self.failed_downloads.append((request.feed, request.article, traceback))
 
     def parse_feeds(self):
         '''
@@ -1618,14 +1645,14 @@ class BasicNewsRecipe(Recipe):
     def tag_to_string(self, tag, use_alt=True, normalize_whitespace=True):
         '''
         Convenience method to take a
-        `BeautifulSoup <http://www.crummy.com/software/BeautifulSoup/documentation.html>`_
+        `BeautifulSoup <https://www.crummy.com/software/BeautifulSoup/bs3/documentation.html>`_
         `Tag` and extract the text from it recursively, including any CDATA sections
         and alt tag attributes. Return a possibly empty unicode string.
 
         `use_alt`: If `True` try to use the alt attribute for tags that don't
         have any textual content
 
-        `tag`: `BeautifulSoup <http://www.crummy.com/software/BeautifulSoup/documentation.html>`_
+        `tag`: `BeautifulSoup <https://www.crummy.com/software/BeautifulSoup/bs3/documentation.html>`_
         `Tag`
         '''
         if tag is None:
@@ -1685,6 +1712,23 @@ class BasicNewsRecipe(Recipe):
             divtag.append(brtag)
         return soup
 
+    def internal_postprocess_book(self, oeb, opts, log):
+        if self.resolve_internal_links and self.article_url_map:
+            seen = set()
+            for item in oeb.spine:
+                for a in item.data.xpath('//*[local-name()="a" and @href]'):
+                    if a.get('rel') == 'calibre-downloaded-from':
+                        continue
+                    url = a.get('href')
+                    for curl in self.canonicalize_internal_url(url):
+                        articles = self.article_url_map.get(curl)
+                        if articles:
+                            arelpath = sorted(articles, key=numeric_sort_key)[0]
+                            a.set('href', item.relhref(arelpath))
+                            if url not in seen:
+                                log.debug('Resolved internal URL: %s -> %s' % (url, arelpath))
+                                seen.add(url)
+
 
 class CustomIndexRecipe(BasicNewsRecipe):
 
@@ -1718,16 +1762,18 @@ class CustomIndexRecipe(BasicNewsRecipe):
         self.create_opf()
         return res
 
+
 class AutomaticNewsRecipe(BasicNewsRecipe):
 
     auto_cleanup = True
 
+
 class CalibrePeriodical(BasicNewsRecipe):
 
     #: Set this to the slug for the calibre periodical
     calibre_periodicals_slug = None
 
-    LOG_IN = 'http://news.calibre-ebook.com/accounts/login'
+    LOG_IN = 'https://news.calibre-ebook.com/accounts/login'
     needs_subscription = True
     __author__ = 'calibre Periodicals'
 
@@ -1749,7 +1795,7 @@ class CalibrePeriodical(BasicNewsRecipe):
         self.log('Fetching downloaded recipe')
         try:
             raw = self.browser.open_novisit(
-                'http://news.calibre-ebook.com/subscribed_files/%s/0/temp.downloaded_recipe'
+                'https://news.calibre-ebook.com/subscribed_files/%s/0/temp.downloaded_recipe'
                 % self.calibre_periodicals_slug
                     ).read()
         except Exception as e:
@@ -1773,4 +1819,3 @@ class CalibrePeriodical(BasicNewsRecipe):
         except:
             self.log.exception('Failed to compile downloaded recipe')
         return os.path.abspath('index.html')
-
