@@ -1,4 +1,4 @@
-#!/usr/bin/env  python
+#!/usr/bin/env  python2
 
 __license__   = 'GPL v3'
 __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
@@ -13,17 +13,23 @@ from lxml.html.builder import HTML, HEAD, TITLE, STYLE, DIV, BODY, \
 
 from calibre import preferred_encoding, strftime, isbytestring
 
-def CLASS(*args, **kwargs): # class is a reserved word in Python
+
+def CLASS(*args, **kwargs):  # class is a reserved word in Python
     kwargs['class'] = ' '.join(args)
     return kwargs
 
 # Regular templates
+
+
 class Template(object):
 
     IS_HTML = True
 
+    def __init__(self, lang=None):
+        self.html_lang = lang
+
     def generate(self, *args, **kwargs):
-        if not kwargs.has_key('style'):
+        if 'style' not in kwargs:
             kwargs['style'] = ''
         for key in kwargs.keys():
             if isbytestring(kwargs[key]):
@@ -48,6 +54,7 @@ class Template(object):
         return etree.tostring(self.root, encoding='utf-8', xml_declaration=True,
                 pretty_print=True)
 
+
 class EmbeddedContent(Template):
 
     def _generate(self, article, style=None, extra_css=None):
@@ -76,6 +83,7 @@ class EmbeddedContent(Template):
                 elem = SPAN(elem)
             div.append(elem)
 
+
 class IndexTemplate(Template):
 
     def _generate(self, title, masthead, datefmt, feeds, extra_css=None, style=None):
@@ -100,6 +108,9 @@ class IndexTemplate(Template):
                 ul,
                 CLASS('calibre_rescale_100'))
         self.root = HTML(head, BODY(div))
+        if self.html_lang:
+            self.root.set('lang', self.html_lang)
+
 
 class FeedTemplate(Template):
 
@@ -130,6 +141,7 @@ class FeedTemplate(Template):
         return navbar
 
     def _generate(self, f, feeds, cutoff, extra_css=None, style=None):
+        from calibre.utils.cleantext import clean_xml_chars
         feed = feeds[f]
         head = HEAD(TITLE(feed.title))
         if style:
@@ -147,8 +159,8 @@ class FeedTemplate(Template):
         body.append(div)
         if getattr(feed, 'image', None):
             div.append(DIV(IMG(
-                alt = feed.image_alt if feed.image_alt else '',
-                src = feed.image_url
+                alt=feed.image_alt if feed.image_alt else '',
+                src=feed.image_url
                 ),
                 CLASS('calibre_feed_image')))
         if getattr(feed, 'description', None):
@@ -168,12 +180,15 @@ class FeedTemplate(Template):
                             style='padding-bottom:0.5em')
                     )
             if article.summary:
-                li.append(DIV(cutoff(article.text_summary),
+                li.append(DIV(clean_xml_chars(cutoff(article.text_summary)),
                     CLASS('article_description', 'calibre_rescale_70')))
             ul.append(li)
         div.append(ul)
         div.append(self.get_navbar(f, feeds, top=False))
         self.root = HTML(head, body)
+        if self.html_lang:
+            self.root.set('lang', self.html_lang)
+
 
 class NavBarTemplate(Template):
 
@@ -196,7 +211,7 @@ class NavBarTemplate(Template):
             if not url.startswith('file://'):
                 navbar.append(HR())
                 text = 'This article was downloaded by '
-                p = PT(text, STRONG(__appname__), A(url, href=url),
+                p = PT(text, STRONG(__appname__), A(url, href=url, rel='calibre-downloaded-from'),
                         style='text-align:left; max-width: 100%; overflow: hidden;')
                 p[0].tail = ' from '
                 navbar.append(p)
@@ -211,10 +226,10 @@ class NavBarTemplate(Template):
             navbar.append(A(_('Next'), href=href))
         href = '%s../index.html#article_%d'%(prefix, art)
         navbar.iterchildren(reversed=True).next().tail = ' | '
-        navbar.append(A(_('Section Menu'), href=href))
+        navbar.append(A(_('Section menu'), href=href))
         href = '%s../../index.html#feed_%d'%(prefix, feed)
         navbar.iterchildren(reversed=True).next().tail = ' | '
-        navbar.append(A(_('Main Menu'), href=href))
+        navbar.append(A(_('Main menu'), href=href))
         if art > 0 and not bottom:
             href = '%s../article_%d/index.html'%(prefix, art-1)
             navbar.iterchildren(reversed=True).next().tail = ' | '
@@ -253,8 +268,8 @@ class TouchscreenIndexTemplate(Template):
         for i, feed in enumerate(feeds):
             if feed:
                 tr = TR()
-                tr.append(TD( CLASS('calibre_rescale_120'), A(feed.title, href='feed_%d/index.html'%i)))
-                tr.append(TD( '%s' % len(feed.articles), style="text-align:right"))
+                tr.append(TD(CLASS('calibre_rescale_120'), A(feed.title, href='feed_%d/index.html'%i)))
+                tr.append(TD('%s' % len(feed.articles), style="text-align:right"))
                 toc.append(tr)
         div = DIV(
                 masthead_p,
@@ -262,6 +277,9 @@ class TouchscreenIndexTemplate(Template):
                 DIV(CLASS('divider')),
                 toc)
         self.root = HTML(head, BODY(div))
+        if self.html_lang:
+            self.root.set('lang', self.html_lang)
+
 
 class TouchscreenFeedTemplate(Template):
 
@@ -296,7 +314,7 @@ class TouchscreenFeedTemplate(Template):
         if f > 0:
             link = A(CLASS('feed_link'),
                      trim_title(feeds[f-1].title),
-                     href = '../feed_%d/index.html' % int(f-1))
+                     href='../feed_%d/index.html' % int(f-1))
         navbar_tr.append(TD(CLASS('feed_prev'),link))
 
         # Up to Sections
@@ -308,13 +326,12 @@ class TouchscreenFeedTemplate(Template):
         if f < len(feeds)-1:
             link = A(CLASS('feed_link'),
                      trim_title(feeds[f+1].title),
-                     href = '../feed_%d/index.html' % int(f+1))
+                     href='../feed_%d/index.html' % int(f+1))
         navbar_tr.append(TD(CLASS('feed_next'),link))
         navbar_t.append(navbar_tr)
         top_navbar = navbar_t
         bottom_navbar = copy.copy(navbar_t)
-        #print "\n%s\n" % etree.tostring(navbar_t, pretty_print=True)
-
+        # print "\n%s\n" % etree.tostring(navbar_t, pretty_print=True)
 
         # Build the page
         head = HEAD(TITLE(feed.title))
@@ -331,8 +348,8 @@ class TouchscreenFeedTemplate(Template):
 
         if getattr(feed, 'image', None):
             div.append(DIV(IMG(
-                alt = feed.image_alt if feed.image_alt else '',
-                src = feed.image_url
+                alt=feed.image_alt if feed.image_alt else '',
+                src=feed.image_url
                 ),
                 CLASS('calibre_feed_image')))
         if getattr(feed, 'description', None):
@@ -341,11 +358,9 @@ class TouchscreenFeedTemplate(Template):
             d.append(BR())
             div.append(d)
 
-        toc = TABLE(CLASS('toc'),width="100%",border="0",cellpadding="3px")
         for i, article in enumerate(feed.articles):
             if not getattr(article, 'downloaded', False):
                 continue
-            tr = TR()
 
             div_td = DIV(CLASS('article_summary'),
                     A(article.title, CLASS('summary_headline','calibre_rescale_120',
@@ -356,13 +371,13 @@ class TouchscreenFeedTemplate(Template):
             if article.summary:
                 div_td.append(DIV(cutoff(article.text_summary),
                     CLASS('summary_text', 'calibre_rescale_100')))
-            tr.append(TD(div_td))
-            toc.append(tr)
+            div.append(div_td)
 
-        div.append(toc)
-        div.append(BR())
         div.append(bottom_navbar)
         self.root = HTML(head, body)
+        if self.html_lang:
+            self.root.set('lang', self.html_lang)
+
 
 class TouchscreenNavBarTemplate(Template):
 
@@ -379,6 +394,14 @@ class TouchscreenNavBarTemplate(Template):
         navbar_t = TABLE(CLASS('touchscreen_navbar'))
         navbar_tr = TR()
 
+        if bottom and not url.startswith('file://'):
+            navbar.append(HR())
+            text = 'This article was downloaded by '
+            p = PT(text, STRONG(__appname__), A(url, href=url, rel='calibre-downloaded-from'),
+                    style='text-align:left; max-width: 100%; overflow: hidden;')
+            p[0].tail = ' from '
+            navbar.append(p)
+            navbar.append(BR())
         # | Previous
         if art > 0:
             link = A(CLASS('article_link'),_('Previous'),href='%s../article_%d/index.html'%(prefix, art-1))
@@ -402,6 +425,6 @@ class TouchscreenNavBarTemplate(Template):
         navbar_tr.append(TD(CLASS('article_next'),link))
         navbar_t.append(navbar_tr)
         navbar.append(navbar_t)
-        #print "\n%s\n" % etree.tostring(navbar, pretty_print=True)
+        # print "\n%s\n" % etree.tostring(navbar, pretty_print=True)
 
         self.root = HTML(head, BODY(navbar))
