@@ -9,13 +9,11 @@ __docformat__ = 'restructuredtext en'
     These templates control the content of titles displayed in the various sections
 
     Available fields:
-    {title}          Title of the book
-    {series}         Series name
-    {series_index}   Number of the book in the series
-    {rating}         Rating
-    {rating_parens}  Rating, in parentheses
-    {pubyear}        Year the book was published
-    {pubyear_parens} Year the book was published, in parentheses
+        Any column, custom or otherwise, defined for the book, plus
+        {rating_parens}  Rating, in parentheses
+        {pubyear}        Year the book was published
+        {pubyear_parens} Year the book was published, in parentheses
+
 
 '''
 # Books by Author
@@ -39,4 +37,4 @@ by_recently_added_series_title_template = '{title} ({series} [{series_index}])'
 
 # By Month added
 by_month_added_normal_title_template = '{title} {pubyear_parens}'
-by_month_added_series_title_template = '[{series_index}] {title} {pubyear_parens}'
\ No newline at end of file
+by_month_added_series_title_template = '[{series_index}] {title} {pubyear_parens}'
