@@ -19,7 +19,7 @@
  * @option Number|Date expires Either an integer specifying the expiration date from now on in days or a Date object.
  *                             If a negative value is specified (e.g. a date in the past), the cookie will be deleted.
  *                             If set to null or omitted, the cookie will be a session cookie and will not be retained
- *                             when the the browser exits.
+ *                             when the browser exits.
  * @option String path The value of the path atribute of the cookie (default: path of page that created the cookie).
  * @option String domain The value of the domain attribute of the cookie (default: domain of page that created the cookie).
  * @option Boolean secure If true, the secure attribute of the cookie will be set and the cookie transmission will
@@ -285,6 +285,15 @@ function booklist(hide_sort) {
     first_page(); 
 }
 
+function search_result() {
+    var test = $("#booklist #page0").html();
+    if (!test) {
+        $("#booklist").html("No books found matching this query");
+        return;
+    }
+    booklist();
+}
+
 function show_details(a_dom) {
     var book = $(a_dom).closest('div.summary');
     var bd = $('#book_details_dialog');
@@ -315,9 +324,15 @@ function show_details(a_dom) {
 function book() {
     hidesort();
     $('.details .left img').load(function() {
+        var rb = $('#random_button');
+        rb.button();
         var img = $('.details .left img');
         var height = $('#main').height();
-        height = Math.max(height, img.height() + 100);
+        var bh = 0;
+        if (rb.length > 0) {
+            bh = rb.height();
+        }
+        height = Math.max(height, img.height() + bh + 100);
         $('#main').height(height);
     });
 }
